(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     90600,       2846]*)
(*NotebookOutlinePosition[     91244,       2868]*)
(*  CellTagsIndexPosition[     91200,       2864]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mortality in the Barro-Becker Model", "Title"],

Cell[BoxData[
    \(<< Graphics`Legend`\)], "Input"],

Cell["The utility function:", "Text"],

Cell[BoxData[
    \(u[N_] := \[Sum]\+\(n = 0\)\%N\((\((In - N\ f - n\ p)\)\^\(1 - \
\[Sigma]\)\/\(1 - \[Sigma]\) + \ \(n\^\[Epsilon]\) \[Beta]\ V)\) 
          Binomial[N, n] \(s\^n\) \((1 - s)\)\^\(N - n\)\)], "Input"],

Cell[BoxData[
    \(Survivors[
        N_] := \[Sum]\+\(n = 0\)\%N 
            n\ Binomial[N, n] \(s\^n\) \((1 - s)\)\^\(N - n\) /. 
        par\)], "Input"],

Cell["\<\
The following computes optimal fertility for fixed children's utility\
\>", "Text"],

Cell[BoxData[
    \(computemax[sin_] := 
      Module[{local}, \[IndentingNewLine]par = 
          Join[prepar, {s \[Rule] sin}]; \[IndentingNewLine]Nmax = 
          Floor[In/\((f + p)\) /. par]; \[IndentingNewLine]Nutil = 
          Table[u[N] /. par, {N, Nmax}]; \[IndentingNewLine]For[i = 1, 
          i <= Nmax, \(i++\), 
          If[Nutil[\([i]\)] == Max[Nutil], 
            Nopt = i]]; \[IndentingNewLine]Nopt\[IndentingNewLine]]\)], \
"Input"],

Cell["\<\
And this one iterates to find fertility adjusting for changes in children's \
utility brought about by mortality.\
\>", "Text"],

Cell[BoxData[
    \(\(computemaxiter[sin_, Vstart_] := 
        Module[{local}, \[IndentingNewLine]Vin = 
            Vstart; \[IndentingNewLine]crit = 1; \[IndentingNewLine]While[
            crit > 0.0001, \[IndentingNewLine]par = 
              Join[prepariter, {s \[Rule] sin}, {V \[Rule] \ 
                    Vin}]; \[IndentingNewLine]Nmax = 
              Floor[In/\((f + p)\) /. par]; \[IndentingNewLine]Nutil = 
              Table[u[N] /. par, {N, Nmax}]; \[IndentingNewLine]For[i = 1, 
              i <= Nmax, \(i++\), 
              If[Nutil[\([i]\)] == Max[Nutil], 
                Nopt = i]]; \[IndentingNewLine]Vnew = 
              u[Nopt] /. par; \[IndentingNewLine]\[IndentingNewLine]crit = 
              Abs[Vnew - Vin]; \[IndentingNewLine]Vin = 
              Vnew;\[IndentingNewLine]]; \[IndentingNewLine]par = 
            Join[prepariter, {s \[Rule] sin}, {V \[Rule] \ 
                  Vin}]; \[IndentingNewLine]Nmax = 
            Floor[In/\((f + p)\) /. par]; \[IndentingNewLine]Nutil = 
            Table[u[N] /. par, {N, Nmax}]; \[IndentingNewLine]For[i = 1, 
            i <= Nmax, \(i++\), 
            If[Nutil[\([i]\)] == Max[Nutil], 
              Nopt = i]]; \[IndentingNewLine]Nopt\[IndentingNewLine]];\)\)], \
"Input"],

Cell["Trying to hit actual values with calibrated parameters", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] 1, f \[Rule] 1/12, p \[Rule] 5/12, V \[Rule]  .54, 
          In \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \({computemax[ .73], Survivors[computemax[ .73]], 
      u[computemax[ .73]] /. par, \((V/u[computemax[ .73]])\) /. 
        par}\), "\[IndentingNewLine]", 
    \({computemax[ .965], Survivors[computemax[ .965]], 
      u[computemax[ .965]] /. par, \((V/u[computemax[ .965]])\) /. 
        par}\), "\[IndentingNewLine]", 
    \(\(trubeta = V/u[computemax[ .73]] /. par;\)\), "\[IndentingNewLine]", 
    \(\(Vtru = u[computemax[ .73]] /. par;\)\)}], "Input"],

Cell[BoxData[
    \({5, 3.6499999999999995`, 7.965397176880935`, 
      0.06779322964174544`}\)], "Output"],

Cell[BoxData[
    \({4, 3.86`, 8.004424722059776`, 0.0674626870450525`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] 1, f \[Rule] 1/12, p \[Rule] 5/12, V \[Rule]  .54, 
          In \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \(biplot = 
      Plot[{computemax[s], Survivors[computemax[s]]}, {s, 0.01,  .99}, 
        PlotRange \[Rule] {{0, 1}, {0, 10}}, 
        PlotRange \[Rule] {{0, 1}, {0, 8}}, 
        AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
        PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
              Thickness[ .008]}}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.02935 .0618 L
.03921 .0618 L
.04463 .0618 L
.04976 .0618 L
.05245 .0618 L
.05318 .0618 L
.05396 .0618 L
.05463 .0618 L
.05536 .12361 L
.05663 .12361 L
.05735 .12361 L
.058 .18541 L
.05927 .18541 L
.06047 .18541 L
.06167 .24721 L
.06294 .24721 L
.06415 .24721 L
.06524 .30902 L
.06653 .30902 L
.06792 .30902 L
.06924 .30902 L
.07045 .37082 L
.07176 .37082 L
.07317 .37082 L
.07438 .37082 L
.0757 .37082 L
.07651 .43262 L
.07725 .43262 L
.07872 .43262 L
.08147 .43262 L
.08276 .43262 L
.08344 .43262 L
.08415 .43262 L
.08495 .49443 L
.08568 .49443 L
.08711 .49443 L
.09311 .49443 L
.09576 .49443 L
.09706 .49443 L
.09826 .49443 L
.09935 .49443 L
.1005 .55623 L
.10166 .55623 L
.10293 .55623 L
.11343 .55623 L
.13233 .55623 L
.17384 .55623 L
.21379 .55623 L
.22421 .55623 L
Mistroke
.22971 .55623 L
.23273 .55623 L
.23557 .55623 L
.23689 .55623 L
.23761 .55623 L
.23828 .55623 L
.23901 .49443 L
.23981 .49443 L
.24121 .49443 L
.24631 .49443 L
.25626 .49443 L
.29635 .49443 L
.30685 .49443 L
.31238 .49443 L
.31825 .49443 L
.32071 .49443 L
.32201 .49443 L
.32337 .49443 L
.3241 .43262 L
.32489 .43262 L
.32628 .43262 L
.32902 .43262 L
.33896 .43262 L
.38076 .43262 L
.40007 .43262 L
.41024 .43262 L
.41579 .43262 L
.42099 .43262 L
.42234 .43262 L
.42362 .43262 L
.42433 .37082 L
.4251 .37082 L
.42645 .37082 L
.43244 .37082 L
.44299 .37082 L
.46374 .37082 L
.50567 .37082 L
.52649 .37082 L
.53669 .37082 L
.54115 .37082 L
.54604 .37082 L
.54832 .37082 L
.55075 .37082 L
.55193 .37082 L
.55305 .37082 L
.55405 .37082 L
.55514 .30902 L
.55629 .30902 L
.55755 .30902 L
.56012 .30902 L
Mistroke
.56471 .30902 L
.58486 .30902 L
.62633 .30902 L
.66625 .30902 L
.68655 .30902 L
.70869 .30902 L
.71896 .30902 L
.72459 .30902 L
.7299 .30902 L
.73485 .30902 L
.73621 .30902 L
.73696 .30902 L
.73765 .30902 L
.73887 .24721 L
.74022 .24721 L
.74957 .24721 L
.78963 .24721 L
.83221 .24721 L
.87323 .24721 L
.91269 .24721 L
.95468 .24721 L
.99 .24721 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.02935 .00181 L
.03921 .00242 L
.04463 .00276 L
.04976 .00308 L
.05245 .00324 L
.05318 .00329 L
.05396 .00334 L
.05463 .00338 L
.05536 .00684 L
.05663 .007 L
.05735 .00709 L
.058 .01075 L
.05927 .01099 L
.06047 .01121 L
.06167 .01524 L
.06294 .01556 L
.06415 .01586 L
.06524 .02016 L
.06653 .02056 L
.06792 .02099 L
.06924 .0214 L
.07045 .02612 L
.07176 .02661 L
.07317 .02713 L
.07438 .02758 L
.0757 .02807 L
.07651 .0331 L
.07725 .03342 L
.07872 .03406 L
.08147 .03525 L
.08276 .0358 L
.08344 .0361 L
.08415 .03641 L
.08495 .042 L
.08568 .04236 L
.08711 .04307 L
.09311 .04604 L
.13233 .0736 L
.17406 .09682 L
.21424 .11917 L
.22478 .12503 L
.23033 .12812 L
.23337 .12981 L
.23621 .13138 L
.23748 .13209 L
.23868 .13276 L
.23935 .11834 L
.24007 .1187 L
.24134 .11933 L
Mistroke
.24699 .12212 L
.25694 .12704 L
.27892 .13791 L
.29882 .14774 L
.30881 .15268 L
.31406 .15528 L
.31692 .15669 L
.31959 .15802 L
.32194 .15918 L
.32326 .15983 L
.32445 .14037 L
.32576 .14093 L
.32719 .14155 L
.32978 .14267 L
.33914 .14672 L
.38116 .1649 L
.40204 .17393 L
.41226 .17835 L
.41673 .18029 L
.41909 .18131 L
.42039 .18187 L
.42162 .1824 L
.42281 .18292 L
.4241 .15726 L
.42527 .1577 L
.42635 .1581 L
.43075 .15973 L
.44035 .16329 L
.46051 .17077 L
.50111 .18582 L
.52153 .19339 L
.54015 .2003 L
.54508 .20213 L
.54768 .20309 L
.55045 .20412 L
.55285 .20501 L
.55351 .20525 L
.55422 .20552 L
.55551 .17166 L
.5567 .17203 L
.55796 .17242 L
.5602 .17311 L
.58172 .17976 L
.6209 .19187 L
.6626 .20476 L
.70275 .21716 L
.71327 .22041 L
.72468 .22394 L
.72992 .22556 L
.73278 .22644 L
Mistroke
.73547 .22727 L
.73664 .22763 L
.73775 .22798 L
.73903 .1827 L
.7402 .18299 L
.74541 .18428 L
.78473 .194 L
.82658 .20434 L
.86686 .2143 L
.90967 .22488 L
.95092 .23508 L
.99 .24474 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{354.25, 218.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005R0000fR000`400?l00000o`00003oo`3ooomS
0?ooo`00E03oool2000000@0oooo0P0000030?ooo`@00000;03oool2000000@0oooo0P0000050?oo
o`<00000;03oool2000000@0oooo0P0000030?ooo`<00000;P3oool2000000@0oooo0P0000040?oo
o`800000<`3oool5000001D0oooo001C0?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool0;03oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo02X0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000=03oool00`000000oooo0?ooo`0E0?ooo`00D`3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo02/0oooo00@000000?ooo`3oool00000203oool5
000002/0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000/0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000=03oool00`000000oooo0?ooo`0E0?oo
o`00D`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo02X0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000/0?ooo`040000003oool0oooo000000P0oooo
0`00000]0?ooo`040000003oool0oooo000000T0oooo0P00000e0?ooo`030000003oool0oooo01D0
oooo001C0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0000002`0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000=03oool00`000000oooo0?ooo`0E0?ooo`00E03oool2000000X0oooo0P00000]0?ooo`800000
2`3oool2000002d0oooo0P00000:0?ooo`<00000;@3oool2000000X0oooo0P00000d0?ooo`800000
5`3oool00?l0ooooH`3oool00?l0ooooH`3oool00?l0ooooH`3oool00?l0ooooH`3oool00?l0oooo
EP3oool3000000X0oooo000O0?ooool00000;@00000=0?ooo`030000003oool0oooo00L0oooo000O
0?ooo`040000003oool00000000000@0oooo2000000>0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo0`00
000:0?ooo`007`3oool010000000oooo0000000000040?ooo`P00000;03oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo00P0oooo100000090?ooo`007`3oool00`000000oooo0?ooo`3o
0?oood40oooo000O0?ooo`030000003oool0oooo0?l0oooo@@3oool001l0oooo00<000000?ooo`3o
ool03`3oool200000?l0oooo<03oool001l0oooo00<000000?ooo`3oool03`3oool300000?l0oooo
;`3oool001l0oooo00<000000?ooo`3oool03`3oool400000?l0oooo;P3oool001l0oooo00<00000
0?ooo`3oool0403oool400000?l0oooo;@3oool001l0oooo00<000000?ooo`3oool04@3oool30000
0?l0oooo;@3oool001l0oooo0P00000C0?ooo`800000o`3oool]0?ooo`007`3oool00`000000oooo
0?ooo`3o0?oood40oooo000O0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3o
oolW0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`@00000o`3ooolX0?ooo`007`3oool00`00
0000oooo0?ooo`0E0?ooo`D00000o`3ooolW0?ooo`007`3oool00`000000oooo0?ooo`0H0?ooo`@0
0000o`3ooolU0?ooo`007`3oool00`000000oooo0?ooo`0I0?ooo`@00000o`3ooolT0?ooo`007`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo8`3oool001l0oooo00<00000
0?ooo`3oool0o`3ooom10?ooo`007`3ooolA00000180oooo00<000000?ooo`3oool0o`3ooolN0?oo
o`007`3oool00`000000oooo0000000>00000140oooo1000003o0?oooah0oooo000O0?ooo`030000
003oool0oooo00`0oooo0P00000B0?ooo`D00000o`3ooolL0?ooo`007`3oool00`000000oooo0?oo
o`0<0?ooo`800000503oool400000?l0oooo6`3oool001l0oooo00<000000?ooo`3oool0303oool2
000001H0oooo0`00003o0?oooaX0oooo000O0?ooo`030000003oool0oooo00`0oooo0P00000G0?oo
o`030000003oool0oooo0?l0oooo6@3oool001l0oooo00<000000?ooo`3oool0303oool2000001d0
oooo00<000000?ooo`3oool0o`3ooolC0?ooo`007`3oool00`000000oooo0?ooo`0<0?ooo`800000
703oool400000?l0oooo4`3oool001l0oooo00<000000?ooo`3oool0303oool2000001d0oooo1000
003o0?oooa80oooo000O0?ooo`8000003@3oool2000001l0oooo1000003o0?oooa00oooo000O0?oo
o`030000003oool0oooo00`0oooo0P00000P0?ooo`@00000o`3oool?0?ooo`007`3oool00`000000
oooo0?ooo`0<0?ooo`8000008P3oool00`000000oooo0?ooo`3o0?ooo`h0oooo000O0?ooo`030000
003oool0oooo00`0oooo0P00000W0?ooo`030000003oool0oooo0?l0oooo2@3oool001l0oooo00<0
00000?ooo`3oool0303oool2000002H0oooo1000003o0?ooo`T0oooo000O0?ooo`030000003oool0
oooo00`0oooo0P00000W0?ooo`@00000o`3oool80?ooo`007`3oool00`000000oooo0?ooo`0<0?oo
o`800000:@3oool400000?l0oooo1P3oool001H0oooo100000050?ooo`030000003oool0oooo00`0
oooo0P00000Z0?ooo`@00000o`3oool50?ooo`005P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00`0oooo0P00000/0?ooo`030000003oool0oooo0?l0oooo103oool001L0oooo00<0
00000?ooo`3oool01@3oool2000000d0oooo0`00000a0?ooo`030000003oool0oooo0?d0oooo000H
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool300000300oooo10000008
0?ooo`030000003oool0oooo0?80oooo000F0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool03@3oool200000340oooo1@0000050?ooo`@00000lP3oool001L0oooo0P0000060?oo
o`030000003oool0oooo00d0oooo0P00000b0?ooo`@000001P3oool400000?40oooo000O0?ooo`03
0000003oool0oooo00d0oooo0P00000c0?ooo`<00000203oool400000>l0oooo000O0?ooo`030000
003oool0oooo00d0oooo0P00000o0?ooo`@000002`3oool300000>00oooo000O0?ooo`030000003o
ool0oooo00d0oooo0P0000110?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool500000=h0oooo000O0?ooo`030000003oool0oooo00d0oooo0P0000150?ooo`<000001P3oool6
00000=d0oooo000O0?ooo`030000003oool0oooo00d0oooo0P0000160?ooo`D000000`3oool20000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3G0?ooo`007`3oool00`000000
oooo0?ooo`0=0?ooo`800000A`3oool6000000030?ooo`000000000000H0oooo1@00003F0?ooo`00
7`3oool2000000h0oooo0P00001:0?ooo`@000002@3oool700000=<0oooo000O0?ooo`030000003o
ool0oooo00d0oooo0P00001<0?ooo`030000003oool0oooo00/0oooo1@00000>0?ooo`8000000`3o
ool00`000000oooo0?ooo`2l0?ooo`007`3oool00`000000oooo0?ooo`0=0?ooo`800000G@3oool0
0`000000oooo0?ooo`0<0?ooo`8000000P3oool500000;`0oooo000O0?ooo`030000003oool0oooo
00d0oooo0P00001Q0?ooo`030000003oool0oooo00P0oooo0P0000020?ooo`P00000^@3oool001l0
oooo00<000000?ooo`3oool03@3oool200000640oooo1P0000050?ooo`8000001P3oool5000001`0
oooo00<000000?ooo`3oool0V@3oool001l0oooo00<000000?ooo`3oool03@3oool200000680oooo
1`0000030?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo
1@00002H0?ooo`007`3oool00`000000oooo0?ooo`0=0?ooo`800000IP3oool400000080oooo0P00
000>0?ooo`@000005@3oool7000009D0oooo000O0?ooo`030000003oool0oooo00d0oooo0P00001X
0?ooo`030000003oool0oooo00800000403oool6000001D0oooo1@00002D0?ooo`007`3oool00`00
0000oooo0?ooo`0=0?ooo`800000J`3oool200000180oooo1@00000G0?ooo`030000003oool0oooo
0080oooo0P00000[0?ooo`800000HP3oool001l0oooo0P00000>0?ooo`<00000P@3oool00`000000
oooo0?ooo`0>0?ooo`8000002`3oool7000002H0oooo1`00001M0?ooo`007`3oool00`000000oooo
0?ooo`0=0?ooo`<00000R@3oool00`000000oooo0?ooo`060?ooo`8000003@3oool6000002L0oooo
1P00001L0?ooo`007`3oool00`000000oooo0?ooo`0>0?ooo`800000QP3oool6000000H0oooo0P00
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool2000000P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1E0?ooo`007`3oool00`000000oooo0?ooo`0>
0?ooo`800000QP3oool8000000@0oooo0P00000F0?ooo`D000006P3oool2000000d0oooo1`00001A
0?ooo`007`3oool00`000000oooo0?ooo`0>0?ooo`800000R`3oool4000000<0oooo0P00000G0?oo
o`L000005`3oool2000000h0oooo1P00001A0?ooo`007`3oool00`000000oooo0?ooo`0>0?ooo`80
0000S@3oool00`000000oooo0?ooo`020?ooo`8000006P3oool5000001H0oooo0P00000H0?ooo`80
0000B`3oool001l0oooo00<000000?ooo`3oool03P3oool200000940oooo0`00000M0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool2000001P0oooo1`0000160?ooo`007`3o
ool00`000000oooo0?ooo`0>0?ooo`800000T@3oool300000280oooo1000000?0?ooo`8000006P3o
ool6000004D0oooo000O0?ooo`030000003oool0oooo00h0oooo0P00002g0?ooo`H00000303oool2
000001l0oooo00<000000?ooo`3oool00P3oool2000003l0oooo000O0?ooo`8000003`3oool20000
0;T0oooo1@0000030?ooo`030000003oool0oooo00D0oooo0P00000T0?ooo`L00000>P3oool001l0
oooo00<000000?ooo`3oool03P3oool200000;`0oooo00<000000?ooo`3oool00P3oool6000002P0
oooo200000050?ooo`030000003oool0oooo0340oooo000O0?ooo`030000003oool0oooo00h0oooo
0P0000320?ooo`H00000;P3oool00`000000oooo0?ooo`020?ooo`<00000<P3oool001l0oooo00<0
00000?ooo`3oool03P3oool200000<H0oooo0`00000c0?ooo`D00000;`3oool001l0oooo00<00000
0?ooo`3oool03P3oool200000<H0oooo0`00000d0?ooo`D000001@3oool00`000000oooo0?ooo`0V
0?ooo`007`3oool00`000000oooo0?ooo`0>0?ooo`800000o`3oool20?ooo`030000003oool0oooo
0080oooo1000000V0?ooo`007`3oool00`000000oooo0?ooo`0>0?ooo`800000o`3oool80?ooo`H0
00008`3oool001P0oooo0`0000040?ooo`030000003oool0oooo00h0oooo0P00003o0?ooo`X0oooo
1@0000050?ooo`030000003oool0oooo01X0oooo000I0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03P3oool200000?l0oooo3P3oool00`000000oooo0?ooo`020?ooo`@000006P3o
ool001H0oooo1@0000040?ooo`8000003`3oool300000<P0ooooCP00000I0?ooo`005P3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo00h0oooo0`0000380?ooodd000006P3oool0
01L0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0?0?ooo`800000b03oool20000
06D0oooo000H0?ooo`8000001@3oool00`000000oooo0?ooo`0?0?ooo`800000b03oool2000006D0
oooo000O0?ooo`030000003oool0oooo00l0oooo0P0000380?ooo`800000I@3oool001l0oooo00<0
00000?ooo`3oool03`3oool200000<P0oooo0P00001U0?ooo`007`3oool00`000000oooo0?ooo`0?
0?ooo`800000b03oool2000006D0oooo000O0?ooo`030000003oool0oooo00l0oooo0P0000380?oo
o`800000I@3oool001l0oooo00<000000?ooo`3oool03`3oool200000<P0oooo0P00001U0?ooo`00
7`3oool00`000000oooo0?ooo`0?0?ooo`800000b03oool2000006D0oooo000O0?ooo`800000403o
ool200000<P0oooo0P00001U0?ooo`007`3oool00`000000oooo0?ooo`0?0?ooo`800000b03oool2
000006D0oooo000O0?ooo`030000003oool0oooo00l0oooo0P0000380?ooo`800000I@3oool001l0
oooo00<000000?ooo`3oool03`3oool200000<P0oooo0P00001U0?ooo`007`3oool00`000000oooo
0?ooo`0?0?ooo`800000b03oool2000006D0oooo000O0?ooo`030000003oool0oooo00l0oooo0P00
00380?ooo`800000I@3oool001l0oooo00<000000?ooo`3oool03`3oool200000<P0oooo0P00001U
0?ooo`007`3oool00`000000oooo0?ooo`0?0?ooo`800000b03oool2000006D0oooo000O0?ooo`03
0000003oool0oooo00l0oooo0P0000380?ooo`800000I@3oool001l0oooo0P00000@0?ooo`<00000
T03oooli000006D0oooo000O0?ooo`030000003oool0oooo00l0oooo1000002?0?ooocT00000I@3o
ool001l0oooo00<000000?ooo`3oool04@3oool2000008l0oooo0P00002L0?ooo`007`3oool00`00
0000oooo0?ooo`0A0?ooo`800000S`3oool2000009`0oooo000O0?ooo`030000003oool0oooo0140
oooo0P00002?0?ooo`800000W03oool001l0oooo00<000000?ooo`3oool04@3oool2000008l0oooo
0P00002L0?ooo`007`3oool00`000000oooo0?ooo`0A0?ooo`800000S`3oool2000009`0oooo000O
0?ooo`030000003oool0oooo0140oooo0P00002?0?ooo`800000W03oool001l0oooo00<000000?oo
o`3oool04@3oool2000008l0oooo0P00002L0?ooo`007`3oool200000180oooo0P00002?0?ooo`80
0000W03oool001l0oooo00<000000?ooo`3oool04@3oool2000008l0oooo0P00002L0?ooo`007`3o
ool00`000000oooo0?ooo`0A0?ooo`800000S`3oool2000009`0oooo000O0?ooo`030000003oool0
oooo0140oooo0P00002?0?ooo`800000W03oool001l0oooo00<000000?ooo`3oool04@3oool20000
08l0oooo0P00002L0?ooo`007`3oool00`000000oooo0?ooo`0A0?ooo`800000S`3oool2000009`0
oooo000O0?ooo`030000003oool0oooo0140oooo0P00002?0?ooo`800000W03oool001H0oooo0`00
00060?ooo`030000003oool0oooo0140oooo0P00002?0?ooo`800000W03oool001H0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`0A0?ooo`800000S`3oool2000009`0oooo000F
0?ooo`040000003oool0oooo000000D0oooo0P00000B0?ooo`<00000I`3ooolY000009`0oooo000F
0?ooo`<000001P3oool00`000000oooo0?ooo`0B0?ooo`<00000IP3ooolY000009`0oooo000G0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool2000006H0oooo0P0000330?oo
o`005`3oool3000000D0oooo00<000000?ooo`3oool04`3oool2000006H0oooo0P0000330?ooo`00
7`3oool00`000000oooo0?ooo`0C0?ooo`800000IP3oool200000<<0oooo000O0?ooo`030000003o
ool0oooo01<0oooo0P00001V0?ooo`800000``3oool001l0oooo00<000000?ooo`3oool04`3oool2
000006H0oooo0P0000330?ooo`007`3oool00`000000oooo0?ooo`0C0?ooo`800000IP3oool20000
0<<0oooo000O0?ooo`030000003oool0oooo01<0oooo0P00001V0?ooo`800000``3oool001l0oooo
00<000000?ooo`3oool04`3oool2000006H0oooo0P0000330?ooo`007`3oool2000001@0oooo0P00
001V0?ooo`800000``3oool001l0oooo00<000000?ooo`3oool04`3oool2000006H0oooo0P000033
0?ooo`007`3oool00`000000oooo0?ooo`0C0?ooo`800000IP3oool200000<<0oooo000O0?ooo`03
0000003oool0oooo01<0oooo0P00001V0?ooo`800000``3oool001l0oooo00<000000?ooo`3oool0
4`3oool2000006H0oooo0P0000330?ooo`007`3oool00`000000oooo0?ooo`0C0?ooo`800000IP3o
ool200000<<0oooo000O0?ooo`030000003oool0oooo01<0oooo0P00001V0?ooo`800000``3oool0
01l0oooo00<000000?ooo`3oool04`3oool2000006H0oooo0P0000330?ooo`007`3oool00`000000
oooo0?ooo`0C0?ooo`800000IP3oool200000<<0oooo000O0?ooo`800000503oool4000004H0oooo
800000330?ooo`007`3oool00`000000oooo0?ooo`0D0?ooo`<00000AP3ooolP00000<<0oooo000O
0?ooo`030000003oool0oooo01D0oooo0P0000160?ooo`800000h@3oool001l0oooo00<000000?oo
o`3oool05@3oool2000004H0oooo0P00003Q0?ooo`007`3oool00`000000oooo0?ooo`0E0?ooo`80
0000AP3oool200000>40oooo000O0?ooo`030000003oool0oooo01D0oooo0P0000160?ooo`800000
h@3oool001l0oooo00<000000?ooo`3oool05@3oool2000004H0oooo0P00003Q0?ooo`007`3oool0
0`000000oooo0?ooo`0E0?ooo`800000AP3oool200000>40oooo000O0?ooo`030000003oool0oooo
01D0oooo0P0000160?ooo`800000h@3oool001l0oooo0P00000F0?ooo`800000AP3oool200000>40
oooo000O0?ooo`030000003oool0oooo01D0oooo0P0000160?ooo`800000h@3oool001l0oooo00<0
00000?ooo`3oool05@3oool2000004H0oooo0P00003Q0?ooo`007`3oool00`000000oooo0?ooo`0E
0?ooo`800000AP3oool200000>40oooo000O0?ooo`030000003oool0oooo01D0oooo0P0000160?oo
o`800000h@3oool001l0oooo00<000000?ooo`3oool05@3oool2000004H0oooo0P00003Q0?ooo`00
7`3oool00`000000oooo0?ooo`0E0?ooo`800000AP3oool200000>40oooo000G0?ooo`8000001P3o
ool00`000000oooo0?ooo`0E0?ooo`800000AP3oool200000>40oooo000F0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool05@3oool2000004H0oooo0P00003Q0?ooo`005P3oool0
10000000oooo0?ooo`0000050?ooo`8000005P3oool6000002P0oooo6`00003R0?ooo`005`3oool2
000000H0oooo00<000000?ooo`3oool05@3oool7000002L0oooo6`00003R0?ooo`005P3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo01X0oooo0P00000W0?ooo`800000n`3oool0
01L0oooo0P0000060?ooo`030000003oool0oooo01X0oooo0P00000W0?ooo`800000n`3oool001l0
oooo00<000000?ooo`3oool06P3oool2000002L0oooo0P00003k0?ooo`007`3oool00`000000oooo
0?ooo`0J0?ooo`8000009`3oool200000?/0oooo000O0?ooo`030000003oool0oooo01X0oooo0P00
000W0?ooo`800000n`3oool001l0oooo00<000000?ooo`3oool06P3oool2000002L0oooo0P00003k
0?ooo`007`3oool00`000000oooo0?ooo`0J0?ooo`8000009`3oool200000?/0oooo000O0?ooo`03
0000003oool0oooo01X0oooo0P00000W0?ooo`800000n`3oool001l0oooo0P00000K0?ooo`800000
9`3oool200000?/0oooo000O0?ooo`030000003oool0oooo01X0oooo0P00000W0?ooo`800000n`3o
ool001l0oooo00<000000?ooo`3oool06P3oool2000002L0oooo0P00003k0?ooo`007`3oool00`00
0000oooo0?ooo`0J0?ooo`8000009`3oool200000?/0oooo000O0?ooo`030000003oool0oooo01X0
oooo0P00000W0?ooo`800000n`3oool001l0oooo00<000000?ooo`3oool06P3oool2000002L0oooo
0P00003k0?ooo`007`3oool00`000000oooo0?ooo`0J0?ooo`8000009`3oool200000?/0oooo000O
0?ooo`030000003oool0oooo01X0oooo0P00000W0?ooo`800000n`3oool001l0oooo00<000000?oo
o`3oool06P3oool2000002L0oooo0P00003k0?ooo`007`3oool2000001/0oooo:`00003k0?ooo`00
7`3oool00`000000oooo0?ooo`0K0?ooobX00000n`3oool001l0oooo00<000000?ooo`3oool0o`3o
oom10?ooo`007`3oool00`000000oooo0?ooo`3o0?oood40oooo000O0?ooo`030000003oool0oooo
0?l0oooo@@3oool001l0oooo00<000000?ooo`3oool0o`3ooom10?ooo`007`3oool00`000000oooo
0?ooo`3o0?oood40oooo000O0?ooo`030000003oool0oooo0?l0oooo@@3oool001l0oooo00<00000
0?ooo`3oool0o`3ooom10?ooo`007`3oool200000?l0oooo@P3oool001l0oooo00<000000?ooo`3o
ool0o`3ooom10?ooo`007`3oool00`000000oooo0?ooo`3o0?oood40oooo000O0?ooo`030000003o
ool0oooo0?l0oooo@@3oool001l0oooo00<000000?ooo`3oool0o`3ooom10?ooo`007`3oool00`00
0000oooo0?ooo`3o0?oood40oooo000O0?ooo`030000003oool0oooo0?l0oooo@@3oool00100oooo
1@0000020?ooo`8000001P3oool00`000000oooo0?ooo`3o0?oood40oooo000B0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo
@@3oool00180oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
0P00003o0?oood80oooo000B0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3o0?ooodL0oooo000B0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3o0?ooodL0oooo000A0?ooo`800000103oool200000?l0ooooBP3oool00?l0ooooH`3oool0
0?l0ooooH`3oool00?l0ooooH`3oool00?l0ooooH`3oool00?l0ooooH`3oool00?l0ooooH`3oool0
0?l0ooooH`3oool00?l0ooooH`3oool00?l0ooooH`3oool000T0oooo0`0000001@3oool000000000
00000000oooo008000000P3oool300000080oooo0`0000040?ooo`@0000000<0oooo000000000000
0P0000030?ooo`<0000000<0oooo0000000000000P3oool200000?l0oooo;03oool000P0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00003o0?ooobd0oooo00080?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`02
0?ooo`@000000P3oool010000000oooo0?ooo`00003o0?ooobd0oooo00080?ooo`030000003oool0
oooo00<0oooo0`0000040?ooo`800000103oool00`000000oooo0?ooo`030?ooo`<000000P3oool4
000000<0oooo0P0000020?ooo`@00000o`3oool^0?ooo`00203oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o
0?ooocd0oooo00090?ooo`<0000000<0oooo0000000000001`3oool010000000oooo0?ooo`3oool2
000000H0oooo0P00003o0?ooocl0oooo003o0?ooof<0oooo003o0?ooof<0oooo0000\
\>"],
  ImageRangeCache->{{{0, 353.25}, {217.938, 0}} -> {-0.103813, -0.688424, \
0.00333819, 0.054013}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(SetDirectory["\<c:/temp\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<biplot.eps\>", biplot, "\<EPS\>"];\)\)}], "Input"],

Cell["\<\
Now adding the lines with utility adjusted for mortality change\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] 1, f \[Rule] 1/12, p \[Rule] 5/12, V \[Rule]  .54, 
          In \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \({computemax[ .73], 
      Survivors[computemax[ .73]]}\), "\[IndentingNewLine]", 
    \({computemax[ .965], Survivors[computemax[ .965]]}\)}], "Input"],

Cell[BoxData[
    \({5, 3.6499999999999995`}\)], "Output"],

Cell[BoxData[
    \({4, 3.86`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prepariter = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] trubeta, f \[Rule] 1/12, p \[Rule] 5/12, 
          In \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \({computemaxiter[ .73, Vtru], 
      Survivors[computemaxiter[ .73, Vtru]]}\), "\[IndentingNewLine]", 
    \({computemaxiter[ .965, Vtru], 
      Survivors[computemaxiter[ .965, Vtru]]}\)}], "Input"],

Cell[BoxData[
    \({5, 3.6499999999999995`}\)], "Output"],

Cell[BoxData[
    \({4, 3.86`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prepariter = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] trubeta, f \[Rule] 1/12, p \[Rule] 5/12, 
          In \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \(\(prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] 1, f \[Rule] 1/12, p \[Rule] 5/12, V \[Rule]  .54, 
          In \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \(biplot = 
      Plot[{computemax[s], Survivors[computemax[s]], computemaxiter[s, Vtru], 
          Survivors[computemaxiter[s, Vtru]]}, {s, 0.01,  .99}, 
        PlotRange \[Rule] {{0, 1}, {0, 10}}, 
        PlotRange \[Rule] {{0, 1}, {0, 8}}, 
        AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
        PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
              Thickness[ .008]}}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.01 .0618 m
.02935 .0618 L
.03921 .0618 L
.04463 .0618 L
.04976 .0618 L
.05245 .0618 L
.05318 .0618 L
.05396 .0618 L
.05463 .0618 L
.05536 .12361 L
.05663 .12361 L
.05735 .12361 L
.058 .18541 L
.05927 .18541 L
.06047 .18541 L
.06167 .24721 L
.06294 .24721 L
.06415 .24721 L
.06524 .30902 L
.06653 .30902 L
.06792 .30902 L
.06924 .30902 L
.07045 .37082 L
.07176 .37082 L
.07317 .37082 L
.07438 .37082 L
.0757 .37082 L
.07651 .43262 L
.07725 .43262 L
.07872 .43262 L
.08147 .43262 L
.08276 .43262 L
.08344 .43262 L
.08415 .43262 L
.08495 .49443 L
.08568 .49443 L
.08711 .49443 L
.09311 .49443 L
.09576 .49443 L
.09706 .49443 L
.09826 .49443 L
.09935 .49443 L
.1005 .55623 L
.10166 .55623 L
.10293 .55623 L
.11343 .55623 L
.13233 .55623 L
.17384 .55623 L
.21379 .55623 L
.22421 .55623 L
Mistroke
.22971 .55623 L
.23273 .55623 L
.23557 .55623 L
.23689 .55623 L
.23761 .55623 L
.23828 .55623 L
.23901 .49443 L
.23981 .49443 L
.24121 .49443 L
.24631 .49443 L
.25626 .49443 L
.29635 .49443 L
.30685 .49443 L
.31238 .49443 L
.31825 .49443 L
.32071 .49443 L
.32201 .49443 L
.32337 .49443 L
.3241 .43262 L
.32489 .43262 L
.32628 .43262 L
.32902 .43262 L
.33896 .43262 L
.38076 .43262 L
.40007 .43262 L
.41024 .43262 L
.41579 .43262 L
.42099 .43262 L
.42234 .43262 L
.42362 .43262 L
.42433 .37082 L
.4251 .37082 L
.42645 .37082 L
.43244 .37082 L
.44299 .37082 L
.46374 .37082 L
.50567 .37082 L
.52649 .37082 L
.53669 .37082 L
.54115 .37082 L
.54604 .37082 L
.54832 .37082 L
.55075 .37082 L
.55193 .37082 L
.55305 .37082 L
.55405 .37082 L
.55514 .30902 L
.55629 .30902 L
.55755 .30902 L
.56012 .30902 L
Mistroke
.56471 .30902 L
.58486 .30902 L
.62633 .30902 L
.66625 .30902 L
.68655 .30902 L
.70869 .30902 L
.71896 .30902 L
.72459 .30902 L
.7299 .30902 L
.73485 .30902 L
.73621 .30902 L
.73696 .30902 L
.73765 .30902 L
.73887 .24721 L
.74022 .24721 L
.74957 .24721 L
.78963 .24721 L
.83221 .24721 L
.87323 .24721 L
.91269 .24721 L
.95468 .24721 L
.99 .24721 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.02935 .00181 L
.03921 .00242 L
.04463 .00276 L
.04976 .00308 L
.05245 .00324 L
.05318 .00329 L
.05396 .00334 L
.05463 .00338 L
.05536 .00684 L
.05663 .007 L
.05735 .00709 L
.058 .01075 L
.05927 .01099 L
.06047 .01121 L
.06167 .01524 L
.06294 .01556 L
.06415 .01586 L
.06524 .02016 L
.06653 .02056 L
.06792 .02099 L
.06924 .0214 L
.07045 .02612 L
.07176 .02661 L
.07317 .02713 L
.07438 .02758 L
.0757 .02807 L
.07651 .0331 L
.07725 .03342 L
.07872 .03406 L
.08147 .03525 L
.08276 .0358 L
.08344 .0361 L
.08415 .03641 L
.08495 .042 L
.08568 .04236 L
.08711 .04307 L
.09311 .04604 L
.13233 .0736 L
.17406 .09682 L
.21424 .11917 L
.22478 .12503 L
.23033 .12812 L
.23337 .12981 L
.23621 .13138 L
.23748 .13209 L
.23868 .13276 L
.23935 .11834 L
.24007 .1187 L
.24134 .11933 L
Mistroke
.24699 .12212 L
.25694 .12704 L
.27892 .13791 L
.29882 .14774 L
.30881 .15268 L
.31406 .15528 L
.31692 .15669 L
.31959 .15802 L
.32194 .15918 L
.32326 .15983 L
.32445 .14037 L
.32576 .14093 L
.32719 .14155 L
.32978 .14267 L
.33914 .14672 L
.38116 .1649 L
.40204 .17393 L
.41226 .17835 L
.41673 .18029 L
.41909 .18131 L
.42039 .18187 L
.42162 .1824 L
.42281 .18292 L
.4241 .15726 L
.42527 .1577 L
.42635 .1581 L
.43075 .15973 L
.44035 .16329 L
.46051 .17077 L
.50111 .18582 L
.52153 .19339 L
.54015 .2003 L
.54508 .20213 L
.54768 .20309 L
.55045 .20412 L
.55285 .20501 L
.55351 .20525 L
.55422 .20552 L
.55551 .17166 L
.5567 .17203 L
.55796 .17242 L
.5602 .17311 L
.58172 .17976 L
.6209 .19187 L
.6626 .20476 L
.70275 .21716 L
.71327 .22041 L
.72468 .22394 L
.72992 .22556 L
.73278 .22644 L
Mistroke
.73547 .22727 L
.73664 .22763 L
.73775 .22798 L
.73903 .1827 L
.7402 .18299 L
.74541 .18428 L
.78473 .194 L
.82658 .20434 L
.86686 .2143 L
.90967 .22488 L
.95092 .23508 L
.99 .24474 L
Mfstroke
[ ] 0 setdash
.01 .0618 m
.02935 .0618 L
.03921 .0618 L
.04976 .0618 L
.05264 .0618 L
.05536 .0618 L
.05781 .0618 L
.05848 .0618 L
.05919 .0618 L
.06047 .12361 L
.06165 .12361 L
.06292 .18541 L
.06412 .18541 L
.06522 .18541 L
.0665 .18541 L
.06723 .24721 L
.0679 .24721 L
.06923 .24721 L
.07045 .24721 L
.07114 .24721 L
.07187 .30902 L
.0726 .30902 L
.07341 .30902 L
.07476 .30902 L
.0762 .30902 L
.07693 .30902 L
.07761 .30902 L
.0789 .37082 L
.08011 .37082 L
.08142 .37082 L
.08436 .37082 L
.08508 .37082 L
.08585 .37082 L
.0867 .43262 L
.08749 .43262 L
.09311 .43262 L
.09558 .43262 L
.09693 .43262 L
.09821 .43262 L
.09941 .43262 L
.1007 .49443 L
.10188 .49443 L
.10296 .49443 L
.11373 .49443 L
.11918 .49443 L
.12428 .49443 L
.12684 .49443 L
.12758 .49443 L
.12828 .49443 L
.1296 .55623 L
Mistroke
.1303 .55623 L
.13105 .55623 L
.1324 .55623 L
.13545 .55623 L
.15604 .55623 L
.17829 .55623 L
.18876 .55623 L
.19447 .55623 L
.19726 .55623 L
.1998 .55623 L
.20092 .55623 L
.20214 .55623 L
.20329 .49443 L
.20436 .49443 L
.20923 .49443 L
.21957 .49443 L
.26003 .49443 L
.28033 .49443 L
.28922 .49443 L
.29392 .49443 L
.29893 .49443 L
.30029 .49443 L
.30157 .49443 L
.30272 .49443 L
.30397 .43262 L
.30515 .43262 L
.30641 .43262 L
.30865 .43262 L
.31887 .43262 L
.34035 .43262 L
.37939 .43262 L
.38968 .43262 L
.39944 .43262 L
.40483 .43262 L
.4063 .43262 L
.40787 .43262 L
.40921 .43262 L
.40997 .43262 L
.41069 .37082 L
.41194 .37082 L
.41326 .37082 L
.41563 .37082 L
.42095 .37082 L
.46013 .37082 L
.50184 .37082 L
.52109 .37082 L
.53123 .37082 L
.53679 .37082 L
.54198 .37082 L
.5446 .37082 L
Mistroke
.54535 .37082 L
.54607 .37082 L
.54741 .30902 L
.54813 .30902 L
.5489 .30902 L
.55027 .30902 L
.55339 .30902 L
.56392 .30902 L
.58465 .30902 L
.62746 .30902 L
.66871 .30902 L
.7084 .30902 L
.71902 .30902 L
.72893 .30902 L
.73392 .30902 L
.73536 .30902 L
.73672 .30902 L
.73794 .30902 L
.73927 .24721 L
.74063 .24721 L
.74213 .24721 L
.74516 .24721 L
.75061 .24721 L
.792 .24721 L
.83183 .24721 L
.87418 .24721 L
.91498 .24721 L
.95421 .24721 L
.99 .24721 L
Mfstroke
[ .02 .02 ] 0 setdash
.01 .00062 m
.02935 .00181 L
.03921 .00242 L
.04976 .00308 L
.05264 .00325 L
.05536 .00342 L
.05781 .00357 L
.05848 .00361 L
.05919 .00366 L
.06047 .00747 L
.06165 .00762 L
.06292 .01167 L
.06412 .01189 L
.06522 .01209 L
.0665 .01233 L
.06723 .01662 L
.0679 .01679 L
.06923 .01711 L
.07045 .01742 L
.07114 .01759 L
.07187 .02221 L
.0726 .02244 L
.07341 .02269 L
.07476 .0231 L
.0762 .02355 L
.07693 .02377 L
.07761 .02398 L
.0789 .02926 L
.08011 .0297 L
.08142 .03019 L
.08436 .03128 L
.08508 .03155 L
.08585 .03184 L
.0867 .03751 L
.08749 .03785 L
.09311 .04028 L
.09558 .04135 L
.09693 .04194 L
.09821 .04249 L
.09941 .04301 L
.1007 .04979 L
.10188 .05037 L
.10296 .05091 L
.11373 .05623 L
.11918 .05893 L
.12428 .06145 L
.12684 .06271 L
.12758 .06308 L
.12828 .06343 L
.1296 .07209 L
Mistroke
.1303 .07248 L
.13105 .07289 L
.1324 .07364 L
.13545 .07534 L
.15604 .08679 L
.17829 .09917 L
.18876 .10499 L
.19447 .10817 L
.19726 .10972 L
.1998 .11114 L
.20092 .11176 L
.20214 .11244 L
.20329 .10051 L
.20436 .10104 L
.20923 .10345 L
.21957 .10856 L
.26003 .12857 L
.28033 .1386 L
.28922 .143 L
.29392 .14532 L
.29893 .1478 L
.30029 .14847 L
.30157 .1491 L
.30272 .14967 L
.30397 .1315 L
.30515 .13202 L
.30641 .13256 L
.30865 .13353 L
.31887 .13795 L
.34035 .14724 L
.37939 .16413 L
.38968 .16859 L
.39944 .17281 L
.40483 .17514 L
.4063 .17578 L
.40787 .17645 L
.40921 .17703 L
.40997 .17736 L
.41069 .15229 L
.41194 .15276 L
.41326 .15325 L
.41563 .15412 L
.42095 .1561 L
.46013 .17063 L
.50184 .18609 L
.52109 .19323 L
.53123 .19699 L
.53679 .19905 L
.54198 .20098 L
.5446 .20195 L
Mistroke
.54535 .20223 L
.54607 .20249 L
.54741 .16916 L
.54813 .16938 L
.5489 .16962 L
.55027 .17004 L
.55339 .17101 L
.56392 .17426 L
.58465 .18067 L
.62746 .1939 L
.66871 .20664 L
.7084 .21891 L
.71902 .22219 L
.72893 .22525 L
.73392 .22679 L
.73536 .22724 L
.73672 .22766 L
.73794 .22804 L
.73927 .18276 L
.74063 .18309 L
.74213 .18346 L
.74516 .18421 L
.75061 .18556 L
.792 .19579 L
.83183 .20564 L
.87418 .21611 L
.91498 .22619 L
.95421 .23589 L
.99 .24474 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00AP3oool2000000@0oooo0P0000030?ooo`@00000803oool2000000@0oooo0P0000050?oo
o`<00000803oool2000000@0oooo0P0000030?ooo`<000008@3oool2000000@0oooo0P0000040?oo
o`8000009`3oool500000180oooo00150?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool0803oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000O0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`0B0?ooo`00A@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool00000203oool5
000001l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000O0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`0B0?oo
o`00A@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01h0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo
0`00000P0?ooo`040000003oool0oooo000000T0oooo0P00000Y0?ooo`030000003oool0oooo0180
oooo00150?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000007`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool000000200oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool00`000000oooo0?ooo`0B0?ooo`00AP3oool2000000X0oooo0P00000Q0?ooo`800000
2`3oool200000240oooo0P00000:0?ooo`<00000803oool2000000X0oooo0P00000X0?ooo`800000
503oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo503oool3000000X0
oooo003o0?oooaL0oooo00<000000?ooo`3oool01`3oool001h0ooookP0000070?ooo`<000002P3o
ool001h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool01@3oool4000000T0oooo000N0?ooo`030000003oool0oooo
00/0oooo0P00003b0?ooo`007P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?00
oooo000N0?ooo`030000003oool0oooo00`0oooo0P00003a0?ooo`007P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool000000>l0oooo000N0?ooo`030000003oool0oooo00d0oooo0`00003_
0?ooo`007P3oool00`000000oooo0?ooo`0@0?ooo`800000k@3oool001h0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`3[0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3o
ool00`000000oooo0?ooo`0A0?ooo`<00000j`3oool001h0oooo00<000000?ooo`3oool0503oool2
00000>T0oooo000N0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0i`3oool001h0
oooo00<000000?ooo`3oool05P3oool400000>D0oooo000N0?ooo`030000003oool0000000`00000
l`3oool001h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000=0?ooo`030000003o
ool0oooo0><0oooo000N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000003P3oool2
00000><0oooo000N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000403oool00`00
0000oooo0?ooo`3P0?ooo`007P3oool00`000000oooo0?ooo`090?ooo`030000003oool000000140
oooo0P00003P0?ooo`007P3oool00`000000oooo0?ooo`090?ooo`030000003oool0000001<0oooo
0P00003N0?ooo`007P3oool00`000000oooo0?ooo`090?ooo`030000003oool0000001D0oooo0P00
003L0?ooo`007P3oool00`000000oooo0?ooo`090?ooo`030000003oool0000001H0oooo0P00003K
0?ooo`007P3oool00`000000oooo0?ooo`0:0?ooo`800000603oool200000=T0oooo000N0?ooo`03
0000003oool0oooo00X0oooo0P00000J0?ooo`8000001@3oool00`000000oooo0?ooo`3?0?ooo`00
7P3oool00`000000oooo0?ooo`0:0?ooo`800000703oool2000000<0oooo0P00003@0?ooo`007P3o
ool00`000000oooo0?ooo`0:0?ooo`8000007P3oool00`000000oooo0?ooo`020?ooo`800000cP3o
ool001h0oooo00<000000?ooo`3oool02P3oool2000001l0oooo0P00003B0?ooo`005P3oool40000
00@0oooo00<000000?ooo`3oool02P3oool200000240oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`370?ooo`005P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0
oooo0P00000Z0?ooo`800000a`3oool001L0oooo00<000000?ooo`3oool0103oool2000000/0oooo
0P00000V0?ooo`030000003oool0oooo00<0oooo0P0000350?ooo`00603oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo0P00000W0?ooo`<00000103oool00`000000oooo0?oo
o`320?ooo`005P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00X0oooo0P00
000Y0?ooo`030000003oool0oooo00<0oooo0P0000080?ooo`800000^03oool001L0oooo0P000005
0?ooo`030000003oool0oooo00X0oooo0P00000a0?ooo`<00000103oool00`000000oooo0000002h
0?ooo`007P3oool00`000000oooo0?ooo`0:0?ooo`800000=03oool200000080oooo00<000000?oo
o`3oool00P3oool300000;<0oooo000N0?ooo`030000003oool0oooo00X0oooo0P00000e0?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool00P00002a0?ooo`007P3oool00`000000oooo
0?ooo`0:0?ooo`800000=`3oool2000000@0oooo00<000000?ooo`3oool00P3oool200000:l0oooo
000N0?ooo`030000003oool0oooo00X0oooo0P00000i0?ooo`<00000203oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo09`0oooo000N0?ooo`030000003oool0oooo00X0oooo0P000015
0?ooo`80000000<0oooo0000003oool02P3oool2000009d0oooo000N0?ooo`030000003oool0oooo
00X0oooo0P0000170?ooo`@000001`3oool00`000000oooo0?ooo`05000009T0oooo000N0?ooo`03
0000003oool0oooo00X0oooo0P00001;0?ooo`<00000103oool010000000oooo0?ooo`0000040?oo
o`800000U`3oool001h0oooo00<000000?ooo`3oool02P3oool2000004h0oooo0P0000020?ooo`04
0000003oool0oooo000000H0oooo1000000B0?ooo`030000003oool0oooo07h0oooo000N0?ooo`03
0000003oool0oooo00X0oooo0P00001@0?ooo`<000000P3oool00`000000oooo0?ooo`080?ooo`80
0000403oool00`000000oooo0?ooo`04000007X0oooo000N0?ooo`030000003oool0oooo00X0oooo
0P00001B0?ooo`040000003oool0oooo000000`0oooo0P00000>0?ooo`030000003oool0oooo00<0
oooo1000001g0?ooo`007P3oool00`000000oooo0?ooo`0:0?ooo`<00000H`3oool3000000/0oooo
00<000000?ooo`3oool02@3oool200000280oooo0P00001?0?ooo`007P3oool00`000000oooo0?oo
o`0;0?ooo`800000I@3oool3000000T0oooo00<000000?ooo`0000002P3oool300000240oooo0`00
001=0?ooo`007P3oool00`000000oooo0?ooo`0;0?ooo`800000J03oool5000000@0oooo00<00000
0?ooo`0000003@3oool3000001/0oooo00<000000?ooo`3oool00P3oool3000004/0oooo000N0?oo
o`030000003oool0oooo00/0oooo0P00001]0?ooo`800000103oool00`000000oooo0?ooo`0@0?oo
o`<000005P3oool00`000000oooo0?ooo`080?ooo`@00000A03oool001h0oooo00<000000?ooo`3o
ool02`3oool2000006h0oooo100000000`3oool000000?ooo`0C0?ooo`<00000503oool00`000000
oooo0?ooo`0;0?ooo`@00000@@3oool001h0oooo00<000000?ooo`3oool02`3oool200000780oooo
0P00000F0?ooo`<000004@3oool2000001@0oooo0`00000k0?ooo`007P3oool00`000000oooo0?oo
o`0;0?ooo`800000S`3oool3000000`0oooo0P00000F0?ooo`@00000>03oool001h0oooo00<00000
0?ooo`3oool02`3oool200000980oooo0`0000090?ooo`030000003oool0oooo01`0oooo0P00000c
0?ooo`007P3oool00`000000oooo0?ooo`0;0?ooo`800000U03oool2000002P0oooo1000000`0?oo
o`007P3oool00`000000oooo0?ooo`0;0?ooo`800000V03oool3000002H0oooo0P00000_0?ooo`00
7P3oool00`000000oooo0?ooo`0;0?ooo`800000VP3oool5000002L0oooo1000000X0?ooo`007P3o
ool00`000000oooo0?ooo`0;0?ooo`800000b@3oool3000002H0oooo000N0?ooo`030000003oool0
oooo00/0oooo0P00003?0?ooo`@000007`3oool001P0oooo0`0000030?ooo`030000003oool0oooo
00/0oooo0P00003C0?ooo`8000007@3oool001T0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`800000f03oool2000001P0oooo000F0?ooo`D000000`3oool2000000`0oooo
0`00002N0?oooc`000005`3oool001H0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0<0?ooo`800000WP3oool00`000000oooo0?ooo`1@0?ooo`005`3oool00`000000oooo0000
00040?ooo`030000003oool0oooo00`0oooo0P00002N0?ooo`030000003oool0oooo0500oooo000H
0?ooo`800000103oool00`000000oooo0?ooo`0<0?ooo`800000WP3oool00`000000oooo0?ooo`1@
0?ooo`007P3oool00`000000oooo0?ooo`0<0?ooo`800000WP3oool00`000000oooo0?ooo`1@0?oo
o`007P3oool00`000000oooo0?ooo`0<0?ooo`800000WP3oool00`000000oooo0?ooo`1@0?ooo`00
7P3oool00`000000oooo0?ooo`0<0?ooo`800000WP3oool00`000000oooo0?ooo`1@0?ooo`007P3o
ool00`000000oooo0?ooo`0<0?ooo`800000WP3oool00`000000oooo0?ooo`1@0?ooo`007P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0000009`0oooo00<000000?ooo`3oool0D@3oool0
01h0oooo00<000000?ooo`3oool0303oool00`000000oooo0000002L0?ooo`030000003oool0oooo
0540oooo000N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000W03oool00`000000
oooo0?ooo`1A0?ooo`007P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000009`0oooo
00<000000?ooo`3oool0D@3oool001h0oooo00<000000?ooo`3oool0303oool00`000000oooo0000
002L0?ooo`030000003oool0oooo0540oooo000N0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`000000W03oool00`000000oooo0?ooo`1A0?ooo`007P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0000009`0oooo00<000000?ooo`3oool0D@3oool001h0oooo00<000000?ooo`3o
ool0303oool4000006h0oooo;P00001C0?ooo`007P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0000006h0oooo00<000000?ooo`000000OP3oool001h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0000001^0?ooo`030000003oool0000007h0oooo000N0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`000000KP3oool00`000000oooo0000001n0?ooo`007P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0000006h0oooo00<000000?ooo`000000OP3oool001h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0000001^0?ooo`030000003oool0000007h0
oooo000N0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000KP3oool00`000000oooo
0000001n0?ooo`007P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000006h0oooo00<0
00000?ooo`000000OP3oool001h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000001^
0?ooo`030000003oool0000007h0oooo000N0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`000000KP3oool00`000000oooo0000001n0?ooo`007P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0000006h0oooo00<000000?ooo`000000OP3oool001h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0000001^0?ooo`030000003oool0000007h0oooo000F0?ooo`<000001@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0000006h0oooo00<000000?ooo`000000OP3o
ool001H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0000006h0oooo00<000000?ooo`000000OP3oool001H0oooo00@000000?ooo`3oool00000103o
ool2000000h0oooo1@00001<0?ooob<00000OP3oool001H0oooo0`0000050?ooo`030000003oool0
oooo00h0oooo00@000000?ooo`3oool00000C03oool010000000oooo0?ooo`00002M0?ooo`005`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000
C03oool010000000oooo0?ooo`00002M0?ooo`005`3oool3000000@0oooo00<000000?ooo`3oool0
3P3oool010000000oooo0?ooo`00001<0?ooo`040000003oool0oooo000009d0oooo000N0?ooo`03
0000003oool0oooo00h0oooo00@000000?ooo`3oool00000C03oool010000000oooo0?ooo`00002M
0?ooo`007P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000004`0oooo00@00000
0?ooo`3oool00000W@3oool001h0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00
001<0?ooo`040000003oool0oooo000009d0oooo000N0?ooo`030000003oool0oooo00h0oooo00@0
00000?ooo`3oool00000C03oool010000000oooo0?ooo`00002M0?ooo`007P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0000004`0oooo00@000000?ooo`3oool00000W@3oool001h0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0000001<0?ooo`040000003oool0oooo000009d0
oooo000N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`000000C03oool010000000oooo
0?ooo`00002M0?ooo`007P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000004`0oooo
00@000000?ooo`3oool00000W@3oool001h0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0000001<0?ooo`040000003oool0oooo000009d0oooo000N0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`000000C03oool010000000oooo0?ooo`00002M0?ooo`007P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0000004`0oooo00@000000?ooo`3oool00000W@3oool001h0oooo
00<000000?ooo`3oool03`3oool600000300oooo7@00002M0?ooo`007P3oool00`000000oooo0?oo
o`0@0?ooo`050000003oool0oooo0?ooo`000000<03oool01@000000oooo0?ooo`3oool000000;D0
oooo000N0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000`0?ooo`05
0000003oool0oooo0?ooo`000000]@3oool001h0oooo00<000000?ooo`3oool0403oool01@000000
oooo0?ooo`3oool000000300oooo00D000000?ooo`3oool0oooo0000002e0?ooo`007P3oool00`00
0000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000<03oool01@000000oooo0?ooo`3o
ool000000;D0oooo000N0?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000
000`0?ooo`050000003oool0oooo0?ooo`000000]@3oool001h0oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool000000300oooo00D000000?ooo`3oool0oooo0000002e0?ooo`00
7P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000<03oool01@000000
oooo0?ooo`3oool000000;D0oooo000N0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3o
ool00000;`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;<0oooo000N0?ooo`03
0000003oool0oooo0140oooo00@000000?ooo`3oool00000;`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0;<0oooo000N0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3o
ool00000;`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;<0oooo000N0?ooo`03
0000003oool0oooo0140oooo00@000000?ooo`3oool00000;`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0;<0oooo000N0?ooo`030000003oool0oooo0140oooo00@000000?ooo`3o
ool00000;`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;<0oooo000G0?ooo`80
00001@3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000002l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`2c0?ooo`005P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0140oooo00@000000?ooo`3oool00000;`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0;<0oooo000F0?ooo`040000003oool0oooo000000@0oooo0P00000B
0?ooo`/000004@3ooolM00000;D0oooo000G0?ooo`8000001@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0<L0oooo000F0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`370?ooo`005`3oool2000000D0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`370?ooo`007P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0<L0oooo000N0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0a`3o
ool001h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`370?ooo`007P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0<L0oooo000N0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0a`3oool001h0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`370?ooo`007P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0<L0oooo000N
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0a`3oool001h0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`370?ooo`007P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0<L0oooo000N0?ooo`030000003oool0oooo01@0oooo8P0000390?ooo`007P3o
ool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`00
0000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo
0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o
0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`00
7P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool0
0`000000oooo0?ooo`3o0?ooo`00403oool500000080oooo0P0000050?ooo`030000003oool0oooo
0?l0oooo000B0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0?l0oooo000B0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`800000o`3oool10?ooo`004P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0o`3oool50?ooo`004P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0o`3oool50?ooo`004@3oool2000000@0oooo0P00003o0?ooo`P0
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo00080?ooo`<0000000D0oooo00000000000000000?oo
o`0200000080oooo0`0000020?ooo`<00000103oool4000000030?ooo`0000000000008000000`3o
ool3000000030?ooo`00000000000080oooo0P00003Z0?ooo`001`3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo00000>/0oooo00070?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`@000000P3oool01000
0000oooo0?ooo`00003[0?ooo`001`3oool00`000000oooo0?ooo`030?ooo`<00000103oool20000
00@0oooo00<000000?ooo`3oool00`3oool300000080oooo100000030?ooo`8000000P3oool40000
0>`0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0?/0oooo00080?ooo`<0000000<0oooo00000000
00001`3oool010000000oooo0?ooo`3oool2000000H0oooo0P00003m0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.8167, \
0.00421906, 0.0682658}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(SetDirectory["\<c:/temp\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<biplot.eps\>", biplot, "\<EPS\>"];\)\)}], "Input"],

Cell["Giving mortality decline a better shot", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prepar = {\[Sigma] \[Rule]  .01, \[Epsilon] \[Rule]  .01, \[Beta] \
\[Rule] 1, f \[Rule] 1/12, p \[Rule] 5/12, V \[Rule] 100, 
          In \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \({computemax[ .73], Survivors[computemax[ .73]], 
      u[computemax[ .73]] /. par, \((V/u[computemax[ .73]])\) /. 
        par}\), "\[IndentingNewLine]", 
    \({computemax[ .965], Survivors[computemax[ .965]], 
      u[computemax[ .965]] /. par, \((V/u[computemax[ .965]])\) /. 
        par}\)}], "Input"],

Cell[BoxData[
    \({5, 3.6499999999999995`, 112.99888420144957`, 
      0.8849644906380162`}\)], "Output"],

Cell[BoxData[
    \({3, 2.895`, 113.41041659609525`, 0.8817532198664282`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prepar = {\[Sigma] \[Rule]  .01, \[Epsilon] \[Rule]  .01, \[Beta] \
\[Rule] 1, f \[Rule] 1/12, p \[Rule] 5/12, V \[Rule] 100, 
          In \[Rule] 14};\)\), "\[IndentingNewLine]", 
    \(plot3 = 
      Plot[{computemax[s], Survivors[computemax[s]]}, {s, 0.15,  .99}, 
        PlotRange \[Rule] {{0, 1}, {0, 10}}, 
        AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
        PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
              Thickness[ .008]}}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.43133 .61803 m
.43133 .61803 L
.43195 .61803 L
.43253 .61803 L
.43361 .61803 L
.43603 .61803 L
.44468 .61803 L
.45379 .61803 L
.46157 .61803 L
.4637 .61803 L
.46599 .61803 L
.46709 .61803 L
.46814 .61803 L
.46908 .55623 L
.4701 .55623 L
.48724 .55623 L
.49634 .55623 L
.50136 .55623 L
.50613 .55623 L
.5083 .55623 L
.5106 .55623 L
.51129 .55623 L
.51193 .55623 L
.51251 .55623 L
.51313 .49443 L
.51373 .49443 L
.51436 .49443 L
.51548 .49443 L
.52404 .49443 L
.54083 .49443 L
.54918 .49443 L
.55378 .49443 L
.55814 .49443 L
.56219 .49443 L
.5633 .49443 L
.56391 .49443 L
.56448 .49443 L
.56548 .43262 L
.5666 .43262 L
.57431 .43262 L
.60842 .43262 L
.61757 .43262 L
.62203 .43262 L
.62398 .43262 L
.625 .43262 L
.62609 .43262 L
.62724 .37082 L
.6283 .37082 L
.63038 .37082 L
.63497 .37082 L
Mistroke
.64469 .37082 L
.6781 .37082 L
.68689 .37082 L
.69123 .37082 L
.69524 .37082 L
.69747 .37082 L
.69812 .37082 L
.69872 .37082 L
.69985 .30902 L
.70046 .30902 L
.70111 .30902 L
.70226 .30902 L
.70487 .30902 L
.71367 .30902 L
.7472 .30902 L
.76587 .30902 L
.77471 .30902 L
.7786 .30902 L
.78081 .30902 L
.78288 .30902 L
.78385 .30902 L
.78486 .30902 L
.78597 .24721 L
.78699 .24721 L
.79134 .24721 L
.80053 .24721 L
.81724 .24721 L
.85088 .24721 L
.86821 .24721 L
.87319 .24721 L
.8779 .24721 L
.87995 .24721 L
.88107 .24721 L
.88212 .24721 L
.88325 .18541 L
.88386 .18541 L
.8845 .18541 L
.88669 .18541 L
.92313 .18541 L
.94136 .18541 L
.95824 .18541 L
.96617 .18541 L
.97006 .18541 L
.97176 .18541 L
.97273 .18541 L
.97363 .18541 L
.97451 .12361 L
.97545 .12361 L
.97737 .12361 L
.98141 .12361 L
Mistroke
.99 .12361 L
Mfstroke
[ .02 .02 ] 0 setdash
.15 .25957 m
.15792 .27327 L
.16246 .28113 L
.16659 .28828 L
.16767 .29015 L
.16884 .29217 L
.16994 .29408 L
.17096 .28528 L
.17204 .28709 L
.17323 .28907 L
.17449 .29117 L
.17564 .29309 L
.17672 .29489 L
.17774 .28561 L
.17882 .28734 L
.18 .28923 L
.18196 .29238 L
.18299 .29404 L
.18408 .29579 L
.1847 .28538 L
.18539 .28644 L
.1866 .28831 L
.18897 .29197 L
.19008 .29368 L
.19068 .29462 L
.19126 .29552 L
.19238 .28536 L
.1934 .28687 L
.19571 .2903 L
.19817 .29394 L
.19945 .29583 L
.20017 .29691 L
.20086 .28552 L
.20148 .2864 L
.20206 .28722 L
.20335 .28905 L
.20536 .29192 L
.20751 .29497 L
.20815 .29587 L
.20875 .29673 L
.20987 .28535 L
.21092 .28679 L
.21206 .28834 L
.21438 .29149 L
.21684 .29483 L
.21785 .2962 L
.21893 .29768 L
.21956 .29852 L
.22012 .28569 L
.22124 .28714 L
Mistroke
.22546 .29261 L
.22777 .29562 L
.2289 .29709 L
.22995 .29844 L
.23094 .28545 L
.23198 .28675 L
.23418 .28946 L
.23802 .29421 L
.2402 .2969 L
.2414 .29838 L
.24253 .29979 L
.24359 .28604 L
.24474 .28739 L
.24674 .28974 L
.24916 .29257 L
.25171 .29558 L
.2539 .29815 L
.2545 .29885 L
.25514 .29961 L
.25631 .28513 L
.25742 .28637 L
.25843 .28749 L
.2607 .29001 L
.26477 .29455 L
.26706 .29709 L
.26826 .29843 L
.26892 .29916 L
.26953 .29984 L
.27064 .28435 L
.27123 .28497 L
.27187 .28564 L
.27402 .2879 L
.27902 .29315 L
.28148 .29574 L
.28256 .29687 L
.28376 .29813 L
.28482 .29925 L
.28582 .28263 L
.28687 .28367 L
.28801 .2848 L
.29264 .28938 L
.29671 .29341 L
.29895 .29562 L
.30107 .29771 L
.30227 .2989 L
.30295 .29957 L
.30357 .28142 L
.30467 .28245 L
.30585 .28353 L
.31029 .28766 L
Mistroke
.31456 .29161 L
.31915 .29587 L
.3205 .29712 L
.32178 .29831 L
.32293 .29937 L
.32358 .27998 L
.32418 .2805 L
.3289 .28458 L
.33338 .28846 L
.33823 .29265 L
.34045 .29458 L
.3428 .29661 L
.34377 .29745 L
.34481 .29835 L
.34595 .27795 L
.34701 .2788 L
.35554 .28566 L
.36343 .29199 L
.36778 .29549 L
.36884 .29634 L
.36998 .29726 L
.37064 .27488 L
.37123 .27532 L
.37241 .27619 L
.38217 .28344 L
.39082 .28985 L
.39517 .29308 L
.39636 .29396 L
.39702 .29444 L
.39763 .2949 L
.39821 .29533 L
.39883 .27114 L
.39992 .27188 L
.41747 .28381 L
.42173 .28671 L
.42631 .28982 L
.42766 .29074 L
.42894 .29161 L
.43008 .29239 L
.43073 .29283 L
.43133 .26658 L
.43195 .26696 L
.43253 .26732 L
.43361 .26799 L
.43603 .26948 L
.44468 .27482 L
.45379 .28046 L
.46157 .28527 L
.4637 .28658 L
.46599 .28799 L
Mistroke
.46709 .28868 L
.46814 .28933 L
.46908 .26092 L
.4701 .26148 L
.48724 .27102 L
.49634 .27608 L
.50136 .27887 L
.50613 .28153 L
.5083 .28273 L
.5106 .28401 L
.51129 .28439 L
.51193 .28475 L
.51251 .28507 L
.51313 .25371 L
.51373 .254 L
.51436 .25431 L
.51548 .25487 L
.52404 .2591 L
.54083 .2674 L
.54918 .27153 L
.55378 .2738 L
.55814 .27596 L
.56219 .27796 L
.5633 .27851 L
.56391 .27881 L
.56448 .27909 L
.56548 .24464 L
.5666 .24512 L
.57431 .24846 L
.60842 .26322 L
.61757 .26718 L
.62203 .26911 L
.62398 .26995 L
.625 .27039 L
.62609 .27086 L
.62724 .23259 L
.6283 .23299 L
.63038 .23376 L
.63497 .23546 L
.64469 .23907 L
.6781 .25145 L
.68689 .25471 L
.69123 .25632 L
.69524 .25781 L
.69747 .25864 L
.69812 .25888 L
.69872 .2591 L
.69985 .21627 L
.70046 .21645 L
.70111 .21665 L
Mistroke
.70226 .21701 L
.70487 .21782 L
.71367 .22054 L
.7472 .2309 L
.76587 .23667 L
.77471 .2394 L
.7786 .2406 L
.78081 .24128 L
.78288 .24192 L
.78385 .24222 L
.78486 .24254 L
.78597 .1943 L
.78699 .19455 L
.79134 .19563 L
.80053 .1979 L
.81724 .20203 L
.85088 .21035 L
.86821 .21463 L
.87319 .21587 L
.8779 .21703 L
.87995 .21754 L
.88107 .21781 L
.88212 .21807 L
.88325 .16376 L
.88386 .16388 L
.8845 .164 L
.88669 .1644 L
.92313 .17116 L
.94136 .17454 L
.95824 .17767 L
.96617 .17914 L
.97006 .17986 L
.97176 .18018 L
.97273 .18035 L
.97363 .18052 L
.97451 .12046 L
.97545 .12057 L
.97737 .12081 L
.98141 .12131 L
.99 .12237 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{319.813, 197.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004o0000aB000`400?l00000o`00003oo`3ooom0
0?ooo`00C03oool2000000@0oooo0P0000030?ooo`@000009`3oool2000000@0oooo0P0000050?oo
o`<000009@3oool2000000@0oooo0P0000030?ooo`<00000:03oool2000000@0oooo0P0000040?oo
o`800000;03oool5000001<0oooo001;0?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool09`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo02<0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000V0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000;@3oool00`000000oooo0?ooo`0C0?ooo`00B`3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203oool5
000002@0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000V0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000;@3oool00`000000oooo0?ooo`0C0?oo
o`00B`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000U0?ooo`040000003oool0oooo000000P0oooo
0`00000W0?ooo`040000003oool0oooo000000T0oooo0P00000^0?ooo`030000003oool0oooo01<0
oooo001;0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009P3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0000002D0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000;@3oool00`000000oooo0?ooo`0C0?ooo`00C03oool2000000X0oooo0P00000X0?ooo`800000
2`3oool2000002H0oooo0P00000:0?ooo`<000009`3oool2000000X0oooo0P00000]0?ooo`800000
5@3oool00?l0oooo@03oool00?l0oooo@03oool00?l0oooo@03oool00?l0oooo@03oool00?l0oooo
=03oool3000000T0oooo000N0?ooool000003@00000<0?ooo`030000003oool0oooo00H0oooo000N
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`07
0?ooo`<000002@3oool001h0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo00L0oooo100000080?ooo`007P3oool00`000000oooo0?ooo`3o0?oooal0
oooo000N0?ooo`030000003oool0oooo0?l0oooo7`3oool001h0oooo00<000000?ooo`3oool0o`3o
oolO0?ooo`007P3oool00`000000oooo0?ooo`3o0?oooal0oooo000N0?ooo`030000003oool0oooo
0?l0oooo7`3oool001h0oooo0P00003o0?ooob00oooo000N0?ooo`030000003oool0oooo0?l0oooo
7`3oool001h0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`007P3oool00`000000oooo0?ooo`3o
0?oooal0oooo000N0?ooo`030000003oool0oooo0?l0oooo7`3oool001h0oooo00<000000?ooo`3o
ool0o`3ooolO0?ooo`007P3oool00`000000oooo0?ooo`3o0?oooal0oooo000N0?ooo`030000003o
ool0oooo0?l0oooo7`3oool001h0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`007P3oool20000
0?l0oooo803oool001h0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`007P3oool00`000000oooo
0?ooo`3o0?oooal0oooo000N0?ooo`030000003oool0oooo0?l0oooo7`3oool001h0oooo00<00000
0?ooo`3oool0o`3ooolO0?ooo`007P3oool00`000000oooo0?ooo`3o0?oooal0oooo000N0?ooo`03
0000003oool0oooo0?l0oooo7`3oool001h0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`007P3o
ool200000?l0oooo803oool001h0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`007P3oool00`00
0000oooo0?ooo`3o0?oooal0oooo000N0?ooo`030000003oool0oooo0?l0oooo7`3oool001h0oooo
00<000000?ooo`3oool0o`3ooolO0?ooo`007P3oool00`000000oooo0?ooo`3o0?oooal0oooo000F
0?ooo`@00000103oool00`000000oooo0?ooo`3o0?oooal0oooo000F0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`005`3oool00`000000oooo0?ooo`040?ooo`<0
0000o`3oool10?ooo`H00000603oool001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`3o0?ooo`40oooo1P00000H0?ooo`005P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0?l0oooo0@3oool2000001`0oooo000G0?ooo`8000001@3oool00`000000oooo0?oo
o`3o0?ooo`40oooo0P00000L0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`40oooo0P00000L
0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`40oooo0P00000L0?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooo`40oooo0P00000L0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`40oooo
0P00000L0?ooo`007P3oool200000?l0oooo0P3oool2000001`0oooo000N0?ooo`030000003oool0
oooo0?l0oooo0@3oool2000001`0oooo000N0?ooo`030000003oool0oooo0>X0oooo00<000000?oo
o`3oool04`3oool2000001`0oooo000N0?ooo`030000003oool0oooo0>X0oooo1`00000?0?ooo`80
0000703oool001h0oooo00<000000?ooo`3oool0j`3oool6000000@0oooo00<000000?ooo`3oool0
203oool2000001`0oooo000N0?ooo`030000003oool0oooo0?@0oooo1@0000070?ooo`800000703o
ool001h0oooo00<000000?ooo`3oool0j03oool2000000/0oooo1`0000040?ooo`800000703oool0
01h0oooo00<000000?ooo`3oool0j03oool2000000d0oooo1@0000030?ooo`<00000703oool001h0
oooo00<000000?ooo`3oool0j03oool2000001D0oooo0`00000L0?ooo`007P3oool200000>T0oooo
6P00000L0?ooo`007P3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo01D0oooo6P00
000L0?ooo`007P3oool00`000000oooo0?ooo`3>0?ooo`H00000503oool2000003@0oooo000N0?oo
o`030000003oool0oooo0<h0oooo1`00000C0?ooo`800000=03oool001h0oooo00<000000?ooo`3o
ool0dP3oool3000000@0oooo00<000000?ooo`3oool0303oool2000003@0oooo000N0?ooo`030000
003oool0oooo0=T0oooo1`0000080?ooo`800000=03oool001h0oooo00<000000?ooo`3oool0fP3o
ool6000000D0oooo00<000000?ooo`3oool00P00000d0?ooo`007P3oool00`000000oooo0?ooo`3>
0?ooo`8000004`3oool4000000030?ooo`000000000003@0oooo000N0?ooo`800000^03oool20000
00@0oooo00<000000?ooo`3oool03P3oool2000001<0oooo1`00000d0?ooo`007P3oool00`000000
oooo0?ooo`2g0?ooo`8000000`3oool4000000h0oooo0P00000E0?ooo`D00000=03oool001h0oooo
00<000000?ooo`3oool0]`3oool2000000@0oooo1P00000;0?ooo`800000603oool2000003@0oooo
000N0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool03`3oool2000000H0oooo1@00
000:0?ooo`800000603oool2000003@0oooo000N0?ooo`030000003oool0oooo0:@0oooo0`00000@
0?ooo`8000002@3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`800000603o
ool2000003@0oooo000N0?ooo`030000003oool0oooo0:@0oooo1000000N0?ooo`L0000000<0oooo
000000000000603oool2000003@0oooo000H0?ooo`<000000`3oool00`000000oooo0?ooo`2T0?oo
o`@00000103oool00`000000oooo0?ooo`0G0?ooo`P000006P3oool2000003@0oooo000I0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0X`3oool3000000D0oooo1000000M0?ooo`03
0000003oool0oooo01T0oooo0P00000d0?ooo`005P3oool5000000<0oooo0`00002G0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool6000000D0oooo0P00000E0?oooa`00000
=03oool001H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2C0?ooo`800000
00<0oooo0000000000000P00000D0?ooo`D00000103oool2000001D0oooo7000000d0?ooo`005`3o
ool00`000000oooo000000040?ooo`030000003oool0oooo08D0oooo0`00000;0?ooo`8000000P3o
ool6000001@0oooo00<000000?ooo`3oool00`3oool2000001D0oooo0P00001>0?ooo`00603oool2
000000@0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`070?ooo`<000002`3oool2
000000@0oooo1@00000G0?ooo`@000005@3oool2000004h0oooo000N0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`060?ooo`@00000203oool30000
00@0oooo00<000000?ooo`3oool0103oool2000000L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0A0?ooo`@000005@3oool2000004h0oooo000N0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0AP3oool3000000L0oooo1@0000070?ooo`800000103oool3000000D0
oooo0P00000;0?ooo`D00000:@3oool2000004h0oooo000N0?ooo`030000003oool0oooo02H0oooo
0P0000170?ooo`@000001P3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0
0P3oool2000000D0oooo1@0000020?ooo`800000303oool4000002T0oooo0P00001>0?ooo`007P3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`<000001`3oool2000000@0oooo100000020?ooo`8000001P3o
ool5000000030?ooo`000000000000`0oooo1000000Y0?ooo`800000CP3oool001h0oooo0P00000X
0?ooo`800000<@3oool00`000000oooo0?ooo`020?ooo`@000001P3oool3000000<0oooo0P000005
0?ooo`030000003oool0oooo008000001@3oool5000000X0oooo0`0000000`3oool000000000000>
0?ooo`800000:@3oool2000004h0oooo000N0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo0P00000:0?oo
o`@000000P3oool500000080oooo0P0000020?ooo`@0000000<0oooo000000000000103oool60000
00L0oooo100000180?ooo`800000CP3oool001h0oooo00<000000?ooo`3oool0:03oool01@000000
oooo000000000000oooo00<000000P3oool3000000<0oooo00D000000?ooo`3oool0oooo00000007
0?ooo`<0000000@0oooo00000000000000000P3oool3000000H0oooo00@000000?ooo`3oool0oooo
100000001@3oool000000000003oool0000000<0oooo0P0000030?ooo`H000001@3oool4000000P0
oooo1@0000170?ooo`800000CP3oool001h0oooo00<000000?ooo`3oool0:P3oool7000000030?oo
o`000000000000T000000`3oool200000080oooo0`000000103oool000000000000000020?ooo`<0
000000@0oooo0000003oool0oooo100000040?ooo`D000001@3oool2000000D0oooo100000070?oo
o`<000002P3oool00`000000oooo0?ooo`160?ooo`800000CP3oool001h0oooo00<000000?ooo`3o
ool0:P3oool7000000030?ooo`000000000000X000000P3oool200000080oooo0`000000103oool0
00000000000000020?ooo`80000000<0oooo0000000000001`0000040?ooo`@00000103oool30000
00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1B0?ooo`800000CP3oool001h0
oooo00<000000?ooo`3oool0:`3ooolG00000080oooo0P0000020?ooo`8000000`3oool200000080
oooo0`0000030?ooo`<00000103oool00`000000oooo0?ooo`040?ooo`<00000IP3oool2000004h0
oooo000N0?ooo`030000003oool0oooo02/0oooo0P0000030?ooo`030000003oool0000000<0oooo
0`0000000`3oool000000?ooo`03000000050?ooo`00000000000000003oool00P0000020?ooo`80
00000`3oool2000000<0oooo0`0000020?ooo`<00000303oool2000006H0oooo0P00001>0?ooo`00
7P3oool00`000000oooo0?ooo`0f0?ooo`<000000`3oool3000000030?ooo`00000000000080oooo
0P0000020?ooo`8000000`3oool2000000<0oooo0P0000040?ooo`800000M03oool2000004h0oooo
000N0?ooo`030000003oool0oooo0<h0oooo0P00001>0?ooo`007P3oool200000;P0oooo6@00001>
0?ooo`007P3oool00`000000oooo0?ooo`2g0?oooaT00000CP3oool001h0oooo00<000000?ooo`3o
ool0]`3oool2000006D0oooo000N0?ooo`030000003oool0oooo0;L0oooo0P00001U0?ooo`007P3o
ool00`000000oooo0?ooo`2g0?ooo`800000I@3oool001h0oooo00<000000?ooo`3oool0]`3oool2
000006D0oooo000N0?ooo`030000003oool0oooo0;L0oooo0P00001U0?ooo`007P3oool00`000000
oooo0?ooo`2g0?ooo`800000I@3oool001h0oooo0P00002h0?ooo`800000I@3oool001h0oooo00<0
00000?ooo`3oool0]`3oool2000006D0oooo000N0?ooo`030000003oool0oooo0;L0oooo0P00001U
0?ooo`007P3oool00`000000oooo0?ooo`2g0?ooo`800000I@3oool001h0oooo00<000000?ooo`3o
ool0]`3oool2000006D0oooo000N0?ooo`030000003oool0oooo0;L0oooo0P00001U0?ooo`005P3o
ool3000000D0oooo00<000000?ooo`3oool0]`3oool2000006D0oooo000F0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0]`3oool2000006D0oooo000F0?ooo`040000003oool0
oooo000000@0oooo0`00002T0?oooaD00000I@3oool001H0oooo0`0000050?ooo`030000003oool0
oooo0:@0oooo5@00001U0?ooo`005`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0:@0oooo0P00001h0?ooo`005`3oool3000000@0oooo00<000000?ooo`3oool0Y03oool2000007P0
oooo000N0?ooo`030000003oool0oooo0:@0oooo0P00001h0?ooo`007P3oool00`000000oooo0?oo
o`2T0?ooo`800000N03oool001h0oooo00<000000?ooo`3oool0Y03oool2000007P0oooo000N0?oo
o`030000003oool0oooo0:@0oooo0P00001h0?ooo`007P3oool200000:D0oooo0P00001h0?ooo`00
7P3oool00`000000oooo0?ooo`2T0?ooo`800000N03oool001h0oooo00<000000?ooo`3oool0Y03o
ool2000007P0oooo000N0?ooo`030000003oool0oooo0:@0oooo0P00001h0?ooo`007P3oool00`00
0000oooo0?ooo`2T0?ooo`800000N03oool001h0oooo00<000000?ooo`3oool0Y03oool2000007P0
oooo000N0?ooo`030000003oool0oooo0:@0oooo0P00001h0?ooo`007P3oool00`000000oooo0?oo
o`2T0?ooo`800000N03oool001h0oooo00<000000?ooo`3oool0Y03oool2000007P0oooo000N0?oo
o`800000U03ooolB000007T0oooo000N0?ooo`030000003oool0oooo09<0oooo4P00001i0?ooo`00
7P3oool00`000000oooo0?ooo`2C0?ooo`800000R@3oool001h0oooo00<000000?ooo`3oool0T`3o
ool2000008T0oooo000N0?ooo`030000003oool0oooo09<0oooo0P0000290?ooo`007P3oool00`00
0000oooo0?ooo`2C0?ooo`800000R@3oool001h0oooo00<000000?ooo`3oool0T`3oool2000008T0
oooo000N0?ooo`030000003oool0oooo09<0oooo0P0000290?ooo`007P3oool2000009@0oooo0P00
00290?ooo`007P3oool00`000000oooo0?ooo`2C0?ooo`800000R@3oool001h0oooo00<000000?oo
o`3oool0T`3oool2000008T0oooo000N0?ooo`030000003oool0oooo09<0oooo0P0000290?ooo`00
7P3oool00`000000oooo0?ooo`2C0?ooo`800000R@3oool001h0oooo00<000000?ooo`3oool0T`3o
ool2000008T0oooo000G0?ooo`8000001@3oool00`000000oooo0?ooo`2C0?ooo`800000R@3oool0
01H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2C0?ooo`800000R@3oool0
01H0oooo00@000000?ooo`3oool00000103oool3000008D0oooo400000290?ooo`005`3oool20000
00D0oooo00<000000?ooo`3oool0Q@3oool@000008T0oooo000F0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0Q@3oool2000009L0oooo000G0?ooo`8000001@3oool00`000000
oooo0?ooo`250?ooo`800000U`3oool001h0oooo00<000000?ooo`3oool0Q@3oool2000009L0oooo
000N0?ooo`030000003oool0oooo08D0oooo0P00002G0?ooo`007P3oool00`000000oooo0?ooo`25
0?ooo`800000U`3oool001h0oooo00<000000?ooo`3oool0Q@3oool2000009L0oooo000N0?ooo`80
0000QP3oool2000009L0oooo000N0?ooo`030000003oool0oooo08D0oooo0P00002G0?ooo`007P3o
ool00`000000oooo0?ooo`250?ooo`800000U`3oool001h0oooo00<000000?ooo`3oool0Q@3oool2
000009L0oooo000N0?ooo`030000003oool0oooo08D0oooo0P00002G0?ooo`007P3oool00`000000
oooo0?ooo`250?ooo`800000U`3oool001h0oooo00<000000?ooo`3oool0Q@3oool2000009L0oooo
000N0?ooo`030000003oool0oooo08D0oooo0P00002G0?ooo`007P3oool00`000000oooo0?ooo`25
0?ooo`800000U`3oool001h0oooo0P00001j0?ooo`h00000U`3oool001h0oooo00<000000?ooo`3o
ool0N@3oool>000009L0oooo000N0?ooo`030000003oool0oooo07T0oooo0P00002S0?ooo`007P3o
ool00`000000oooo0?ooo`1i0?ooo`800000X`3oool001h0oooo00<000000?ooo`3oool0N@3oool2
00000:<0oooo000N0?ooo`030000003oool0oooo07T0oooo0P00002S0?ooo`007P3oool00`000000
oooo0?ooo`1i0?ooo`800000X`3oool001h0oooo00<000000?ooo`3oool0N@3oool200000:<0oooo
000N0?ooo`800000NP3oool200000:<0oooo000N0?ooo`030000003oool0oooo07T0oooo0P00002S
0?ooo`007P3oool00`000000oooo0?ooo`1i0?ooo`800000X`3oool001h0oooo00<000000?ooo`3o
ool0N@3oool200000:<0oooo000N0?ooo`030000003oool0oooo07T0oooo0P00002S0?ooo`007P3o
ool00`000000oooo0?ooo`1i0?ooo`800000X`3oool00100oooo1@0000020?ooo`8000001@3oool0
0`000000oooo0?ooo`1i0?ooo`800000X`3oool00180oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0N@3oool200000:<0oooo000B0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000K`3oool<
00000:<0oooo000B0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`1d
0?ooo``00000X`3oool00180oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0?l0oooo903oool00140oooo0P0000040?ooo`800000o`3ooolW0?ooo`00o`3ooom00?ooo`00
o`3ooom00?ooo`00o`3ooom00?ooo`00o`3ooom00?ooo`00o`3ooom00?ooo`00o`3ooom00?ooo`00
o`3ooom00?ooo`00o`3ooom00?ooo`00203oool3000000050?ooo`00000000000000003oool00P00
00020?ooo`<000000P3oool3000000@0oooo100000000`3oool0000000000002000000<0oooo0`00
00000`3oool00000000000020?ooo`800000o`3oool:0?ooo`001`3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo00000?l0oooo2`3oool000L0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo100000020?oo
o`040000003oool0oooo00000?l0oooo2`3oool000L0oooo00<000000?ooo`3oool00`3oool30000
00@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`@000000`3oool20000
0080oooo1000003o0?ooo``0oooo00070?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo6`3oool000P0
oooo0`0000000`3oool00000000000070?ooo`040000003oool0oooo0?ooo`8000001P3oool20000
0?l0oooo7@3oool00?l0oooo@03oool00?l0oooo@03oool00001\
\>"],
  ImageRangeCache->{{{0, 318.813}, {196.688, 0}} -> {-0.114143, -0.747411, \
0.00374325, 0.060567}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(SetDirectory["\<c:/temp\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<biplot2new.eps\>", plot3, "\<EPS\>"];\)\)}], "Input"],

Cell["\<\
Maybe there is a theorem here that the reduction in expected net fertility \
could be at most equal to one. Or something like that.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[u[N] /. {f \[Rule] 0}]\)], "Input"],

Cell[BoxData[
    \(\[Sum]\+\(n = 0\)\%N\((\((In - N\ 0 - n\ p)\)\^\(1 - \[Sigma]\)\/\(1 - \
\[Sigma]\) + n\^\(\((1 - \[Sigma])\)\ \[Epsilon]\)\ V)\)\ Binomial[N, 
          n]\ s\^n\ \((1 - s)\)\^\(N - n\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(u2[N_, 
        s_] := \[Sum]\+\(n = 0\)\%N\((\((In - n\ p)\)\^\(1 - \[Sigma]\)\/\(1 \
- \[Sigma]\) + \(n\^\(\(\ \)\(\[Epsilon]\)\)\) V)\) 
          Binomial[N, n] \(s\^n\) \((1 - s)\)\^\(N - n\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(u2[N, s]\)], "Input"],

Cell[BoxData[
    \(\[Sum]\+\(n = 0\)\%N\((\((In - n\ p)\)\^\(1 - \[Sigma]\)\/\(1 - \
\[Sigma]\) + n\^\[Epsilon]\ V)\)\ Binomial[N, 
          n]\ s\^n\ \((1 - s)\)\^\(N - n\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[D[u2[N, s], s]]\)], "Input"],

Cell[BoxData[
    \(\[Sum]\+\(n = 0\)\%N\[PartialD]\_s\((\((\((In - n\ p)\)\^\(1 - \[Sigma]\
\)\/\(1 - \[Sigma]\) + n\^\[Epsilon]\ V)\)\ Binomial[N, 
              n]\ s\^n\ \((1 - s)\)\^\(N - n\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[D[s\^n\ \((1 - s)\)\^\(N - n\), s]]\)], "Input"],

Cell[BoxData[
    \(\((1 - s)\)\^\(\(-1\) - n + N\)\ s\^\(\(-1\) + n\)\ \((n - 
          N\ s)\)\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{1017, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 52, 0, 115, "Title"],
Cell[1782, 54, 52, 1, 30, "Input"],
Cell[1837, 57, 37, 0, 33, "Text"],
Cell[1877, 59, 219, 3, 61, "Input"],
Cell[2099, 64, 158, 4, 51, "Input"],
Cell[2260, 70, 93, 2, 33, "Text"],
Cell[2356, 74, 454, 9, 150, "Input"],
Cell[2813, 85, 137, 3, 33, "Text"],
Cell[2953, 90, 1258, 22, 390, "Input"],
Cell[4214, 114, 70, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[4309, 118, 665, 11, 110, "Input"],
Cell[4977, 131, 107, 2, 29, "Output"],
Cell[5087, 135, 85, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5209, 141, 556, 10, 70, "Input"],
Cell[5768, 153, 25128, 720, 227, 7719, 501, "GraphicsData", "PostScript", \
"Graphics"],
Cell[30899, 875, 130, 3, 29, "Output"]
}, Open  ]],
Cell[31044, 881, 149, 2, 50, "Input"],
Cell[31196, 885, 87, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[31308, 891, 361, 6, 70, "Input"],
Cell[31672, 899, 58, 1, 29, "Output"],
Cell[31733, 902, 44, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31814, 908, 402, 7, 70, "Input"],
Cell[32219, 917, 58, 1, 29, "Output"],
Cell[32280, 920, 44, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32361, 926, 811, 14, 110, "Input"],
Cell[33175, 942, 28817, 981, 186, 11872, 767, "GraphicsData", "PostScript", \
"Graphics"],
Cell[61995, 1925, 130, 3, 29, "Output"]
}, Open  ]],
Cell[62140, 1931, 149, 2, 50, "Input"],
Cell[62292, 1935, 54, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[62371, 1939, 517, 9, 70, "Input"],
Cell[62891, 1950, 107, 2, 29, "Output"],
Cell[63001, 1954, 87, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63125, 1960, 511, 9, 70, "Input"],
Cell[63639, 1971, 25123, 808, 206, 9429, 610, "GraphicsData", "PostScript", \
"Graphics"],
Cell[88765, 2781, 130, 3, 29, "Output"]
}, Open  ]],
Cell[88910, 2787, 152, 2, 50, "Input"],
Cell[89065, 2791, 155, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[89245, 2798, 64, 1, 30, "Input"],
Cell[89312, 2801, 220, 3, 61, "Output"]
}, Open  ]],
Cell[89547, 2807, 229, 4, 61, "Input"],

Cell[CellGroupData[{
Cell[89801, 2815, 41, 1, 30, "Input"],
Cell[89845, 2818, 189, 3, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90071, 2826, 57, 1, 30, "Input"],
Cell[90131, 2829, 213, 3, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90381, 2837, 77, 1, 31, "Input"],
Cell[90461, 2840, 111, 2, 29, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

