(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     33736,        944]*)
(*NotebookOutlinePosition[     34379,        966]*)
(*  CellTagsIndexPosition[     34335,        962]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mortality in the Barro-Becker Model", "Title"],

Cell["\<\
This is the sequential choice model that is used in the paper.\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Setup", "Section"],

Cell["\<\
Setting up some fixed parameters. Notice that T-K has to be at least equal to \
two; otherwise people have births until the last period and their are \
children left who did not have a chance to die yet.prob\
\>", "Text"],

Cell[BoxData[{
    \(\(T = 14;\)\), "\[IndentingNewLine]", 
    \(\(K = 12;\)\)}], "Input"],

Cell["The utility function:", "Text"],

Cell[BoxData[
    \(\(u[c_] := c\^\(1 - \[Sigma]\)\/\(1 - \[Sigma]\);\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the Optimum", "Section"],

Cell["The prodedure for computing the optimal solution:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(computemax[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]par = 
          Join[prepar, {si \[Rule] sin, 
              sc \[Rule] scin}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Here\ nmax\ is\ K\ because\ old\ children\ cause\ no\ cost\ \
*) \[IndentingNewLine]\[IndentingNewLine]nmax = 
          K; \[IndentingNewLine]\[IndentingNewLine]For[n = 0, 
          n \[LessEqual] nmax, \(n++\), 
          Util[T, n, 0] = \[Beta]\ n\^\[Epsilon]\ V /. 
              par]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          The\ following\ loop\ performs\ the\ backward\ induction\ \
*) \[IndentingNewLine] (*\ First\ the\ non - fecund, \ 
          than\ the\ fecund\ period\ *) \[IndentingNewLine] (*\ 
          Order\ of\ \(indeces : \ Period\), \ old\ children, \ 
          young\ children\ *) \[IndentingNewLine]\[IndentingNewLine]For[
          j = 1, j < T - K, \(j++\), \[IndentingNewLine]For[n = 0, 
            n < nmax, \(n++\), \[IndentingNewLine]Util[T - j, n, 0] = 
              u[w] + \[Gamma]\ \ Util[T - j + 1, n, 0] /. 
                par; \[IndentingNewLine]Util[T - j, n, 1] = 
              u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) Util[T - j + 1, n, 0])\) /. 
                par;\[IndentingNewLine]]; \[IndentingNewLine]Util[T - j, 
              nmax, 0] = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax, 0] /. 
              par;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine] (*\ In\ the\ fecund\ period, \ 
          fertility\ choice\ only\ if\ n\ is\ less\ than\ max\ \
*) \[IndentingNewLine]\[IndentingNewLine]For[j = T - K, 
          j \[LessEqual] T, \(j++\), \[IndentingNewLine]For[n = 0, 
            n < nmax - 
                1, \(n++\), \[IndentingNewLine]\[IndentingNewLine]Ubirthchild \
= u[w - q - p] + \[Gamma]\ \((sc\ si\ Util[T - j + 1, n + 1, 
                            1] + \((1 - sc)\) si\ Util[T - j + 1, n, 1] + 
                        sc \((1 - si)\)\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) \((1 - si)\) 
                          Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Unobirthchild = 
              u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Ubirthnochild = 
              u[w - q] + \[Gamma]\ \((si\ Util[T - j + 1, n, 
                            1] + \((1 - si)\) Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Unobirthnochild = 
              u[w] + \[Gamma]\ \ Util[T - j + 1, n, 0] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]If[
              Ubirthchild > Unobirthchild, Birth[T - j, n, 1] = 1, 
              Birth[T - j, n, 1] = 0]; \[IndentingNewLine]If[
              Ubirthnochild > Unobirthnochild, Birth[T - j, n, 0] = 1, 
              Birth[T - j, n, 0] = 
                0]; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, n, 0] = 
              Max[Ubirthnochild, Unobirthnochild]; \[IndentingNewLine]Util[
                T - j, n, 1] = 
              Max[Ubirthchild, 
                Unobirthchild];\[IndentingNewLine]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine] (*\ 
            nmax - 1\ and\ nmax\ are\ done\ separately, \ 
            because\ a\ birth\ may\ not\ be\ possible\ *) \[IndentingNewLine]\
\[IndentingNewLine]Unobirthchild = 
            u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, nmax, 
                          0] + \((1 - sc)\) Util[T - j + 1, nmax - 1, 0])\) /. 
              par; \[IndentingNewLine]\[IndentingNewLine]Ubirthnochild = 
            u[w - q] + \[Gamma]\ \((si\ Util[T - j + 1, nmax - 1, 
                          1] + \((1 - si)\) Util[T - j + 1, nmax - 1, 0])\) /. 
              par; \[IndentingNewLine]\[IndentingNewLine]Unobirthnochild = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax - 1, 0] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]If[
            Ubirthnochild > Unobirthnochild, Birth[T - j, nmax - 1, 0] = 1, 
            Birth[T - j, nmax - 1, 0] = 
              0]; \[IndentingNewLine]\[IndentingNewLine]Birth[T - j, 
              nmax - 1, 1] = 
            0; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, nmax - 1, 
              0] = Max[Ubirthnochild, 
              Unobirthnochild]; \[IndentingNewLine]Util[T - j, nmax - 1, 1] = 
            Unobirthchild; \[IndentingNewLine]\[IndentingNewLine]Birth[T - j, 
              nmax, 0] = 0; \[IndentingNewLine]Birth[T - j, nmax, 1] = 
            0; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, nmax, 0] = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax, 0] /. 
              par;\[IndentingNewLine]];\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(nmax\)\" is similar to \
existing symbol \"\!\(Nmax\)\"."\)], "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing Fertility and Reproduction Rates", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComputeFertility[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]par = 
          Join[prepar, {si \[Rule] sin, 
              sc \[Rule] scin}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          In\ the\ initial\ period, \ 
          zero\ children\ for\ sure\ \
*) \[IndentingNewLine]\[IndentingNewLine]ageatfirstchild = 
          0; \[IndentingNewLine]\[IndentingNewLine]prob[0, 0, 0] = 
          1; \[IndentingNewLine]For[n = 1, n \[LessEqual] nmax, \(n++\), 
          prob[0, n, 0] = 0]; \[IndentingNewLine]For[n = 0, 
          n \[LessEqual] nmax, \(n++\), 
          prob[0, n, 1] = 0]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          The\ following\ loops\ moves\ forward\ in\ time\ \
*) \[IndentingNewLine] (*\ First\ the\ fecund, \ 
          than\ the\ non - fecund\ period\ *) \[IndentingNewLine] (*\ 
          Order\ of\ \(indeces : \ Period\), \ old\ children, \ 
          young\ children\ *) \[IndentingNewLine] (*\ 
          n = 0\ \((at\ least)\)\ will\ have\ to\ be\ done\ separately\ \
*) \[IndentingNewLine]\[IndentingNewLine]For[j = 0, 
          j \[LessEqual] 
            K, \(j++\), \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Age\ at\ first\ birth\ \
*) \[IndentingNewLine]If[\((ageatfirstchild \[Equal] 
                    0)\) && \((Birth[j, 0, 0] == 1)\), 
              ageatfirstchild = j]\[IndentingNewLine]\[IndentingNewLine] (*\ 
              Expected\ number\ of\ children\ \((born\ previously)\)\ and\ \
expected\ number\ of\ births\ *) \[IndentingNewLine]\[IndentingNewLine]\(FR[
                j] = \[Sum]\+\(n = 0\)\%nmax\((prob[j, n, 0] Birth[j, n, 0] + 
                    prob[j, n, 1] 
                      Birth[j, n, 1])\)\); \[IndentingNewLine]Eofn[
              j] = \[Sum]\+\(n = 0\)\%nmax\((n\ prob[j, n, 0] + \((n + 1)\) 
                    prob[j, n, 1])\); \[IndentingNewLine] (*\ 
            First\ the\ n = 0\ case, \ 
            the\ loop\ below\ does\ the\ rest\ *) \[IndentingNewLine]\
\[IndentingNewLine]prob[j + 1, 0, 
              0] = \((1 - si\ Birth[j, 0, 0])\) 
                  prob[j, 0, 0] + \((1 - si\ Birth[j, 0, 1])\) \((1 - sc)\) 
                  prob[j, 0, 1] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, 0, 1] = 
            si\ Birth[j, 0, 0] prob[j, 0, 0] + 
                si\ Birth[j, 0, 1] \((1 - sc)\) prob[j, 0, 1] /. 
              
              par; \[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]\
For[n = 1, 
            n \[LessEqual] 
              nmax, \(n++\), \[IndentingNewLine]\[IndentingNewLine]prob[
                j + 1, n, 
                0] = \((1 - si\ Birth[j, n, 0])\) 
                    prob[j, n, 0] + \((1 - si\ Birth[j, n, 1])\) \((1 - sc)\) 
                    prob[j, n, 1] + \((1 - si\ Birth[j, n - 1, 1])\) 
                    sc\ prob[j, n - 1, 1] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, n, 
                1] = si\ Birth[j, n, 0] prob[j, n, 0] + 
                  si\ Birth[j, n, 1] \((1 - sc)\) prob[j, n, 1] + 
                  si\ Birth[j, n - 1, 1] sc\ prob[j, n - 1, 1] /. 
                par;\[IndentingNewLine]];\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]For[j = K + 1, 
          j \[LessEqual] 
            T, \(j++\), \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Fertility\ Rates\ and\ Expected\ number\ of\ children\ \((born\ \
previously)\)\ *) \[IndentingNewLine]\[IndentingNewLine]FR[j] = 
            0; \[IndentingNewLine]Eofn[
              j] = \[Sum]\+\(n = 0\)\%nmax\((n\ prob[j, n, 0] + \((n + 1)\) 
                    prob[j, n, 
                      1])\); \[IndentingNewLine]\[IndentingNewLine] (*\ 
            First\ the\ n = 0\ case, \ 
            the\ loop\ below\ does\ the\ rest\ *) \[IndentingNewLine]\
\[IndentingNewLine]prob[j + 1, 0, 0] = 
            prob[j, 0, 0] + \((1 - sc)\) prob[j, 0, 1] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, 0, 1] = 
            0 /. par; \[IndentingNewLine]\[IndentingNewLine]For[n = 1, 
            n \[LessEqual] 
              nmax, \(n++\), \[IndentingNewLine]\[IndentingNewLine]prob[
                j + 1, n, 0] = 
              prob[j, n, 0] + \((1 - sc)\) prob[j, n, 1] + 
                  sc\ prob[j, n - 1, 1] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, n, 
                1] = 0 /. 
                par;\[IndentingNewLine]];\[IndentingNewLine]\
\[IndentingNewLine]];\[IndentingNewLine]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"prob\" is similar to \
existing symbol \"prob\"."\)], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing TFR and NFR", "Section"],

Cell[BoxData[
    \(TFRNFRAge[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]computemax[sin, 
          scin]; \[IndentingNewLine]ComputeFertility[sin, 
          scin]; \[IndentingNewLine]{\[Sum]\+\(j = 0\)\%T FR[j], Eofn[T], 
          ageatfirstchild}\[IndentingNewLine]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Actual Computation", "Section"],

Cell["15 is the lowest V (up to 0.1) that gives five births", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Vset = 8;\)\), "\[IndentingNewLine]", 
    \(\(Vlo = 1;\)\), "\[IndentingNewLine]", 
    \(\(Vhi = 20;\)\), "\[IndentingNewLine]", 
    \(\(NTarget = 5;\)\), "\[IndentingNewLine]", 
    \(\(it = 1;\)\), "\[IndentingNewLine]", 
    \(While[
      it < 30, \[IndentingNewLine]Clear[Util, Birth, prob, 
        FR]; \[IndentingNewLine]prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \
\[Rule]  .5, \[Beta] \[Rule] 0.2, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, 
          q \[Rule] 1/12, V \[Rule] Vset, 
          w \[Rule] 
            1}; \[IndentingNewLine]\[IndentingNewLine]If[\(TFRNFRAge[ .84, 
              0.87]\)[\([1]\)] > NTarget, Vhi = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vlo, Vlo = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vhi]; \[IndentingNewLine]\
\[IndentingNewLine]it = it + 1\[IndentingNewLine]]\), "\[IndentingNewLine]", 
    \(Vset\)}], "Input"],

Cell[BoxData[
    \(16.55460660904646`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[Util, Birth, prob, FR];\)\), "\[IndentingNewLine]", 
    \(\(prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] 0.2, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, q \[Rule] 1/12, 
          V \[Rule] 16.6, w \[Rule] 1};\)\), "\[IndentingNewLine]", 
    \({\(TFRNFRAge[ .84, 0.87]\)[\([1]\)], \(TFRNFRAge[ .84, 
          0.87]\)[\([2]\)], \(TFRNFRAge[ .84, 
          0.87]\)[\([3]\)]}\), "\[IndentingNewLine]", 
    \({\(TFRNFRAge[ .97, 0.995]\)[\([1]\)], \(TFRNFRAge[ .97, 
          0.995]\)[\([2]\)], \(TFRNFRAge[ .97, 0.995]\)[\([3]\)]}\)}], "Input"],

Cell[BoxData[
    \({5.16`, 3.7709279999999996`, 7}\)], "Output"],

Cell[BoxData[
    \({5.`, 4.825749999999999`, 8}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Vset = 8;\)\), "\[IndentingNewLine]", 
    \(\(Vlo = 1;\)\), "\[IndentingNewLine]", 
    \(\(Vhi = 20;\)\), "\[IndentingNewLine]", 
    \(\(NTarget = 5;\)\), "\[IndentingNewLine]", 
    \(\(it = 1;\)\), "\[IndentingNewLine]", 
    \(While[
      it < 30, \[IndentingNewLine]Clear[Util, Birth, prob, 
        FR]; \[IndentingNewLine]prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \
\[Rule]  .5, \[Beta] \[Rule] 0.2, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, 
          q \[Rule] 1/12, V \[Rule] Vset, 
          w \[Rule] 
            1}; \[IndentingNewLine]\[IndentingNewLine]If[\(TFRNFRAge[ .73, 
              1]\)[\([1]\)] > NTarget, Vhi = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vlo, Vlo = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vhi]; \[IndentingNewLine]\
\[IndentingNewLine]it = it + 1\[IndentingNewLine]]\), "\[IndentingNewLine]", 
    \(Vset\)}], "Input"],

Cell[BoxData[
    \(15.21022006124258`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] 0.2, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, q \[Rule] 1/12, 
          V \[Rule] 15.22, w \[Rule] 1};\)\), "\[IndentingNewLine]", 
    \({\(TFRNFRAge[ .73, 1]\)[\([1]\)], \(TFRNFRAge[ .73, 
          1]\)[\([2]\)], \(TFRNFRAge[ .73, 
          1]\)[\([3]\)]}\), "\[IndentingNewLine]", 
    \({\(TFRNFRAge[ .965, 1]\)[\([1]\)], \(TFRNFRAge[ .965, 
          1]\)[\([2]\)], \(TFRNFRAge[ .965, 1]\)[\([3]\)]}\)}], "Input"],

Cell[BoxData[
    \({5.0729`, 3.7032169999999995`, 7}\)], "Output"],

Cell[BoxData[
    \({4.035`, 3.893775`, 8}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] 0.2, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, q \[Rule] 1/12, 
          V \[Rule] 15.05, w \[Rule] 1};\)\), "\[IndentingNewLine]", 
    \(seqplot1 = 
      Plot[{\(TFRNFRAge[s, 1]\)[\([1]\)], \(TFRNFRAge[s, 1]\)[\([2]\)]}, {s, 
          0.01,  .99}, PlotRange \[Rule] {{0, 1}, {0, 10}}, 
        AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
        PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
              Thickness[ .008]}}]\)}], "Input"],

Cell[BoxData[
    \($Aborted\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] 0.2, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, q \[Rule] 1/12, 
          V \[Rule] 15.05, w \[Rule] 1};\)\), "\[IndentingNewLine]", 
    \(seqplot2 = 
      Plot[\(TFRNFRAge[s, 1]\)[\([3]\)], {s, 0.04,  .99}, 
        PlotRange \[Rule] {{0, 1}, {0, 10}}, 
        AxesLabel \[Rule] {"\<s\>", "\<Age\>"}, 
        PlotStyle \[Rule] {{Thickness[ .008]}}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.375 ]
[1.025 0 10 6.375 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -11 0 ]
[0 .64303 11 12.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Age) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.04464 .61803 m
.04464 .61803 L
.0458 .61803 L
.0469 .55623 L
.04788 .55623 L
.04895 .55623 L
.05013 .49443 L
.05143 .49443 L
.05269 .49443 L
.05339 .49443 L
.05405 .49443 L
.05532 .43262 L
.05648 .43262 L
.05766 .43262 L
.05876 .43262 L
.06001 .37082 L
.06113 .37082 L
.06366 .37082 L
.06585 .37082 L
.06708 .37082 L
.06822 .30902 L
.06945 .30902 L
.07061 .30902 L
.07324 .30902 L
.0758 .30902 L
.07653 .30902 L
.07723 .30902 L
.07854 .24721 L
.07978 .24721 L
.08095 .24721 L
.08361 .24721 L
.089 .24721 L
.09365 .24721 L
.09493 .24721 L
.09562 .24721 L
.09627 .24721 L
.09742 .18541 L
.09867 .18541 L
.12057 .18541 L
.15952 .18541 L
.17938 .18541 L
.18984 .18541 L
.19556 .18541 L
.20091 .18541 L
.20335 .18541 L
.20456 .18541 L
.20567 .18541 L
.20695 .24721 L
.20763 .24721 L
.20835 .24721 L
Mistroke
.21079 .24721 L
.22166 .24721 L
.24079 .24721 L
.26076 .24721 L
.27125 .24721 L
.28232 .24721 L
.28713 .24721 L
.29227 .24721 L
.29379 .24721 L
.29523 .24721 L
.29651 .24721 L
.29724 .24721 L
.29792 .30902 L
.29913 .30902 L
.30047 .30902 L
.30318 .30902 L
.32234 .30902 L
.3625 .30902 L
.38096 .30902 L
.39142 .30902 L
.39652 .30902 L
.40114 .30902 L
.4023 .30902 L
.40353 .30902 L
.40418 .30902 L
.40488 .37082 L
.40613 .37082 L
.41083 .37082 L
.42117 .37082 L
.44223 .37082 L
.48252 .37082 L
.5213 .37082 L
.53143 .37082 L
.54246 .37082 L
.54751 .37082 L
.55288 .37082 L
.55508 .37082 L
.55746 .37082 L
.55812 .37082 L
.55882 .37082 L
.56007 .43262 L
.56124 .43262 L
.56252 .43262 L
.60295 .43262 L
.64187 .43262 L
.68323 .43262 L
.70395 .43262 L
.72308 .43262 L
.74169 .43262 L
.74622 .43262 L
Mistroke
.74871 .43262 L
.74994 .43262 L
.75108 .43262 L
.75173 .49443 L
.75241 .49443 L
.75387 .49443 L
.75642 .49443 L
.76142 .49443 L
.80291 .49443 L
.8429 .49443 L
.88137 .49443 L
.92229 .49443 L
.94268 .49443 L
.9617 .49443 L
.96872 .49443 L
.97536 .49443 L
.97714 .49443 L
.97812 .49443 L
.97903 .49443 L
.98002 .55623 L
.9811 .55623 L
.98302 .55623 L
.99 .55623 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{330.875, 204.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005:0000c1000`40O003h00OogooBgoo001:Ool2
0004Ool20003Ool4000XOol20004Ool20005Ool3000WOol20004Ool20003Ool3000ZOol20004Ool2
0004Ool2000^Ool5000IOol004Uoo`04001oogoo0008Ool00`00Oomoo`0XOol01000Oomoo`002goo
00<007ooOol09Goo00@007ooOol000Qoo`04001oogoo000XOol01000Oomoo`0027oo00@007ooOol0
02moo`03001oogoo01Uoo`00BGoo00@007ooOol000Uoo`03001oogoo02Moo`04001oogoo0008Ool5
000VOol01000Oomoo`0027oo00@007ooOol002Qoo`04001oogoo0008Ool01000Oomoo`00;goo00<0
07ooOol06Goo0019Ool01000Oomoo`002Woo00<007ooOol09Woo00@007ooOol000Qoo`04001oogoo
000WOol01000Oomoo`0027oo0`00:Goo00@007ooOol000Uoo`80031oo`03001oogoo01Uoo`00BGoo
00@007ooOol000Qoo`04001oogoo000WOol01000Oomoo`002Goo00<007oo00009goo00@007ooOol0
00Uoo`03001oogoo02Qoo`04001oogoo0008Ool01000Oomoo`00;goo00<007ooOol06Goo001:Ool2
000:Ool2000YOol2000;Ool2000XOol2000:Ool3000YOol2000:Ool2000_Ool2000KOol00?mood]o
o`00ogooBgoo003oOom;Ool00?mood]oo`00ogoo>Goo0`003goo000IOooo000G000<Ool00`00Oomo
o`0<Ool001Uoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03
001oogoo00]oo`03001oogoo00Moo`<000moo`006Goo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol01goo10003Woo000IOol00`00
Oomoo`3oOol_Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00
Oomoo`3oOol_Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol2003o
Ool`Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3o
Ool_Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3o
Ool_Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol2003oOol`Ool0
01Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3oOol_Ool0
01Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3oOol_Ool0
01Uoo`03001oogoo0?moobmoo`006Goo0P00ogoo<7oo000IOol00`00Oomoo`3oOol_Ool001Uoo`03
001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3oOol_Ool001Uoo`03
001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000AOol40004Ool00`00Oomoo`3oOol_Ool0
015oo`03001oogoo00Eoo`03001oogoo0?moobmoo`004Woo00<007ooOol017oo0`00ogoo;goo000C
Ool00`00Oomoo`03Ool00`00Oomoo`3oOol_Ool0015oo`04001oogoo0004Ool00`00Oomoo`3oOol_
Ool0019oo`8000Eoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomo
o`3oOol_Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol2003oOol`
Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3oOol_
Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3oOol_
Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol2000HOolP003gOol0
01Uoo`03001oogoo01Moob000?Moo`006Goo00<007ooOol05goo0P0077oo0P00mgoo000IOol00`00
Oomoo`0GOol2000LOol2003gOol001Uoo`03001oogoo01Moo`8001aoo`800?Moo`006Goo00<007oo
Ool05goo0P0077oo0P00mgoo000IOol00`00Oomoo`0GOol2000LOol2003gOol001Uoo`03001oogoo
01Moo`8001aoo`800?Moo`006Goo0P0067oo0P0077oo0P00mgoo000IOol00`00Oomoo`0GOol2000L
Ool2003gOol001Uoo`03001oogoo01Moo`8001aoo`800?Moo`006Goo00<007ooOol05goo0P0077oo
0P00mgoo000IOol00`00Oomoo`0GOol2000LOol2003gOol001Uoo`03001oogoo01Moo`8001aoo`80
0?Moo`006Goo00<007ooOol05goo0P0077oo0P00mgoo000COol30003Ool00`00Oomoo`0GOol2000L
Ool2003gOol001Aoo`03001oogoo009oo`03001oogoo01Moo`8001aoo`800?Moo`004Goo1@000goo
0`004Woo1`0077oo6`00gWoo000AOol01000Oomoo`0017oo00<007ooOol04Woo1`0077oo7000gGoo
000BOol00`00Ool00004Ool00`00Oomoo`0BOol2000kOol2003MOol001=oo`8000Aoo`03001oogoo
019oo`8003]oo`800=eoo`006Goo00<007ooOol04Woo0P00>goo0P00gGoo000IOol00`00Oomoo`0B
Ool2000kOol2003MOol001Uoo`03001oogoo019oo`8003]oo`800=eoo`006Goo00<007ooOol04Woo
0P00>goo0P00gGoo000IOol00`00Oomoo`0BOol2000kOol2003MOol001Uoo`8001=oo`8003]oo`80
0=eoo`006Goo00<007ooOol04Woo0P00>goo0P00gGoo000IOol00`00Oomoo`0BOol2000kOol2003M
Ool001Uoo`03001oogoo019oo`8003]oo`800=eoo`006Goo00<007ooOol04Woo0P00>goo0P00gGoo
000IOol00`00Oomoo`0BOol2000kOol2003MOol001Uoo`03001oogoo019oo`8003]oo`800=eoo`00
6Goo00<007ooOol04Woo0P00>goo0P00gGoo000IOol2000@Ool4000lOolO0030Ool001Uoo`03001o
ogoo00moo`@003eooah00<1oo`006Goo00<007ooOol03goo0P00Fgoo0P00`7oo000IOol00`00Oomo
o`0?Ool2001KOol20030Ool001Uoo`03001oogoo00moo`8005]oo`800<1oo`006Goo00<007ooOol0
3goo0P00Fgoo0P00`7oo000IOol00`00Oomoo`0?Ool2001KOol20030Ool001Uoo`03001oogoo00mo
o`8005]oo`800<1oo`006Goo00<007ooOol03goo0P00Fgoo0P00`7oo000IOol2000@Ool2001KOol2
0030Ool001Uoo`03001oogoo00moo`8005]oo`800<1oo`006Goo00<007ooOol03goo0P00Fgoo0P00
`7oo000IOol00`00Oomoo`0?Ool2001KOol20030Ool001Uoo`03001oogoo00moo`8005]oo`800<1o
o`006Goo00<007ooOol03goo0P00Fgoo0P00`7oo000AOol30005Ool00`00Oomoo`0?Ool2001KOol2
0030Ool0015oo`04001oogoo0004Ool00`00Oomoo`0?Ool2001KOol20030Ool0015oo`04001oogoo
0004Ool3000=Ool4001KOol]002EOol0015oo`<000Eoo`03001oogoo00eoo`@005]oobd009Eoo`00
4Woo00<007ooOol017oo00<007ooOol03Goo0P00R7oo0P00UGoo000BOol30004Ool00`00Oomoo`0=
Ool20028Ool2002EOol001Uoo`03001oogoo00eoo`8008Qoo`8009Eoo`006Goo00<007ooOol03Goo
0P00R7oo0P00UGoo000IOol00`00Oomoo`0=Ool20028Ool2002EOol001Uoo`03001oogoo00eoo`80
08Qoo`8009Eoo`006Goo00<007ooOol03Goo0P00R7oo0P00UGoo000IOol2000>Ool20028Ool2002E
Ool001Uoo`03001oogoo00eoo`8008Qoo`8009Eoo`006Goo00<007ooOol03Goo0P00R7oo0P00UGoo
000IOol00`00Oomoo`0=Ool20028Ool2002EOol001Uoo`03001oogoo00eoo`8008Qoo`8009Eoo`00
6Goo00<007ooOol03Goo0P00R7oo0P00UGoo000IOol00`00Oomoo`0=Ool20028Ool2002EOol001Uo
o`03001oogoo00eoo`8008Qoo`8009Eoo`006Goo0P0037oo0`00RGoo=`00H7oo000IOol00`00Oomo
o`0;Ool30029Oolg001POol001Uoo`03001oogoo00]oo`800;moo`80061oo`006Goo00<007ooOol0
2goo0P00_goo0P00H7oo000IOol00`00Oomoo`0;Ool2002oOol2001POol001Uoo`03001oogoo00]o
o`800;moo`80061oo`006Goo00<007ooOol02goo0P00_goo0P00H7oo000IOol00`00Oomoo`0;Ool2
002oOol2001POol001Uoo`03001oogoo00]oo`800;moo`80061oo`006Goo0P0037oo0P00_goo0P00
H7oo000IOol00`00Oomoo`0;Ool2002oOol2001POol001Uoo`03001oogoo00]oo`800;moo`80061o
o`006Goo00<007ooOol02goo0P00_goo0P00H7oo000IOol00`00Oomoo`0;Ool2002oOol2001POol0
01Uoo`03001oogoo00]oo`800;moo`80061oo`006Goo00<007ooOol02goo0P00_goo0P00H7oo000B
Ool20005Ool00`00Oomoo`0;Ool2002oOol2001POol0015oo`04001oogoo0004Ool00`00Oomoo`0;
Ool2002oOol2001POol0015oo`04001oogoo0004Ool3000:Ool3002oOom2000POol0019oo`8000Eo
o`03001oogoo00Yoo`<00;mood80021oo`004Goo00@007ooOol000Aoo`03001oogoo00Yoo`800?mo
o`5oo`80021oo`004Woo0P001Goo00<007ooOol02Woo0P00ogoo0Goo0P0087oo000IOol00`00Oomo
o`0:Ool2003oOol1Ool2000POol001Uoo`03001oogoo00Yoo`800?moo`5oo`80021oo`006Goo00<0
07ooOol02Woo0P00ogoo0Goo0P0087oo000IOol00`00Oomoo`0:Ool2003oOol1Ool2000POol001Uo
o`8000]oo`800?moo`5oo`80021oo`006Goo00<007ooOol02Woo0P00ogoo0Goo0P0087oo000IOol0
0`00Oomoo`0:Ool2003oOol1Ool2000POol001Uoo`03001oogoo00Yoo`800?moo`5oo`80021oo`00
6Goo00<007ooOol02Woo0P00ogoo0Goo0P0087oo000IOol00`00Oomoo`0:Ool2003oOol1Ool2000P
Ool001Uoo`03001oogoo00Yoo`800?moo`5oo`80021oo`006Goo00<007ooOol02Woo0P00ogoo0Goo
0P0087oo000IOol00`00Oomoo`0:Ool2003oOol1Ool2000POol001Uoo`8000Yoo`<00?moo`5oo`D0
01eoo`006Goo00<007ooOol02Goo0`00ogoo0Goo1@007Goo000IOol00`00Oomoo`09Ool2003oOolT
Ool001Uoo`03001oogoo00Uoo`800?moobAoo`006Goo00<007ooOol02Goo0P00ogoo97oo000IOol0
0`00Oomoo`09Ool2003oOolTOol001Uoo`03001oogoo00Uoo`800?moobAoo`006Goo00<007ooOol0
2Goo0P00ogoo97oo000IOol2000:Ool2003oOolTOol001Uoo`03001oogoo00Uoo`800?moobAoo`00
6Goo00<007ooOol02Goo0P00ogoo97oo000IOol00`00Oomoo`09Ool2003oOolTOol001Uoo`03001o
ogoo00Uoo`800?moobAoo`006Goo00<007ooOol02Goo0P00ogoo97oo000IOol00`00Oomoo`09Ool2
003oOolTOol000]oo`D0009oo`8000Eoo`03001oogoo00Uoo`800?moobAoo`003Goo00D007ooOomo
o`00009oo`03001oogoo009oo`03001oogoo00Uoo`800?moobAoo`003Goo00D007ooOomoo`00009o
o`03001oogoo009oo`<000Qoo`<00?moobAoo`003Goo00D007ooOomoo`00009oo`03001oogoo00eo
o`<00?moobAoo`003Goo00D007ooOomoo`00009oo`03001oogoo0?moocAoo`0037oo0P0017oo0P00
ogoo=goo003oOom;Ool00?mood]oo`00ogooBgoo003oOom;Ool00?mood]oo`005goo0`00ogoo<Goo
000JOol00`00Oomoo`3oOol^Ool0015oo`800003Ool00000009oo`<000=oo`<00?moobYoo`004Goo
00L007ooOomoo`00Ool00002Ool01000Oomoo`00ogoo;Goo000BOol30002Ool01000Oomoo`000Woo
1000ogoo:Woo000BOol00`00Ool00003Ool40002Ool2003oOol[Ool001=oo`03001oogoo0?moocEo
o`004Woo0P00ogoo=goo003oOom;Ool00?mood]oo`00ogooBgoo0000\
\>"],
  ImageRangeCache->{{{0, 329.875}, {203.5, 0}} -> {-0.092254, -0.727541, \
0.0036068, 0.0583593}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(SetDirectory["\<c:/temp\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<seqplot1.eps\>", 
        seqplot1, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<seqplot2.eps\>", seqplot2, "\<EPS\>"];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(computemax[ .4,  .95];\)\), "\[IndentingNewLine]", 
    \(TFRNFRAge[ .8,  .95]\), "\[IndentingNewLine]", 
    \(Table[
      Birth[t, n, c], {t, 0, K}, {n, 0, nmax - 1}, {c, 0, 1}]\)}], "Input"],

Cell[BoxData[
    \({3.4704`, 2.637504`, 4}\)], "Output"],

Cell[BoxData[
    \({{{0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{0, 
          0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{0, 
          0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{0, 
          0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 
          0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 
          0}, {1, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 
          1}, {1, 0}, {1, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 
          1}, {1, 0}, {1, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 
          1}, {1, 1}, {1, 1}, {1, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 
          0}}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{858, 679},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 52, 0, 115, "Title"],
Cell[1782, 54, 93, 2, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1900, 60, 24, 0, 59, "Section"],
Cell[1927, 62, 231, 4, 52, "Text"],
Cell[2161, 68, 91, 2, 50, "Input"],
Cell[2255, 72, 37, 0, 33, "Text"],
Cell[2295, 74, 84, 1, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2416, 80, 40, 0, 59, "Section"],
Cell[2459, 82, 65, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[2549, 86, 4894, 78, 1310, "Input"],
Cell[7446, 166, 181, 3, 24, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7676, 175, 61, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[7762, 179, 4557, 80, 1385, "Input"],
Cell[12322, 261, 221, 5, 24, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12592, 272, 40, 0, 59, "Section"],
Cell[12635, 274, 298, 5, 140, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12970, 284, 41, 0, 59, "Section"],
Cell[13014, 286, 69, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[13108, 290, 888, 17, 290, "Input"],
Cell[13999, 309, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14088, 315, 600, 9, 90, "Input"],
Cell[14691, 326, 65, 1, 29, "Output"],
Cell[14759, 329, 62, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14858, 335, 885, 17, 290, "Input"],
Cell[15746, 354, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15835, 360, 516, 8, 70, "Input"],
Cell[16354, 370, 67, 1, 29, "Output"],
Cell[16424, 373, 56, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16517, 379, 558, 9, 70, "Input"],
Cell[17078, 390, 42, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17157, 396, 461, 8, 70, "Input"],
Cell[17621, 406, 14647, 498, 213, 5919, 386, "GraphicsData", "PostScript", \
"Graphics"],
Cell[32271, 906, 130, 3, 29, "Output"]
}, Open  ]],
Cell[32416, 912, 248, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[32689, 920, 217, 4, 70, "Input"],
Cell[32909, 926, 57, 1, 29, "Output"],
Cell[32969, 929, 727, 10, 181, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

