(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     56261,       1726]*)
(*NotebookOutlinePosition[     56905,       1748]*)
(*  CellTagsIndexPosition[     56861,       1744]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mortality in the Barro-Becker Model", "Title"],

Cell["\<\
This is the sequential choice model that is used in the paper.\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Setup", "Section"],

Cell["\<\
Setting up some fixed parameters. Notice that T-K has to be at least equal to \
two; otherwise people have births until the last period and their are \
children left who did not have a chance to die yet.prob\
\>", "Text"],

Cell[BoxData[{
    \(\(T = 14;\)\), "\[IndentingNewLine]", 
    \(\(K = 12;\)\)}], "Input"],

Cell["The utility function:", "Text"],

Cell[BoxData[
    \(\(u[c_] := c\^\(1 - \[Sigma]\)\/\(1 - \[Sigma]\);\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the Optimum", "Section"],

Cell["The prodedure for computing the optimal solution:", "Text"],

Cell[BoxData[
    \(computemax[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]par = 
          Join[prepar, {si \[Rule] sin, 
              sc \[Rule] scin}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Here\ nmax\ is\ K\ because\ old\ children\ cause\ no\ cost\ \
*) \[IndentingNewLine]\[IndentingNewLine]nmax = 
          K; \[IndentingNewLine]\[IndentingNewLine]For[n = 0, 
          n \[LessEqual] nmax, \(n++\), 
          Util[T, n, 0] = \[Beta]\ n\^\[Epsilon]\ V /. 
              par]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          The\ following\ loop\ performs\ the\ backward\ induction\ \
*) \[IndentingNewLine] (*\ First\ the\ non - fecund, \ 
          than\ the\ fecund\ period\ *) \[IndentingNewLine] (*\ 
          Order\ of\ \(indeces : \ Period\), \ old\ children, \ 
          young\ children\ *) \[IndentingNewLine]\[IndentingNewLine]For[
          j = 1, j < T - K, \(j++\), \[IndentingNewLine]For[n = 0, 
            n < nmax, \(n++\), \[IndentingNewLine]Util[T - j, n, 0] = 
              u[w] + \[Gamma]\ \ Util[T - j + 1, n, 0] /. 
                par; \[IndentingNewLine]Util[T - j, n, 1] = 
              u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) Util[T - j + 1, n, 0])\) /. 
                par;\[IndentingNewLine]]; \[IndentingNewLine]Util[T - j, 
              nmax, 0] = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax, 0] /. 
              par;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine] (*\ In\ the\ fecund\ period, \ 
          fertility\ choice\ only\ if\ n\ is\ less\ than\ max\ \
*) \[IndentingNewLine]\[IndentingNewLine]For[j = T - K, 
          j \[LessEqual] T, \(j++\), \[IndentingNewLine]For[n = 0, 
            n < nmax - 
                1, \(n++\), \[IndentingNewLine]\[IndentingNewLine]Ubirthchild \
= u[w - q - p] + \[Gamma]\ \((sc\ si\ Util[T - j + 1, n + 1, 
                            1] + \((1 - sc)\) si\ Util[T - j + 1, n, 1] + 
                        sc \((1 - si)\)\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) \((1 - si)\) 
                          Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Unobirthchild = 
              u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Ubirthnochild = 
              u[w - q] + \[Gamma]\ \((si\ Util[T - j + 1, n, 
                            1] + \((1 - si)\) Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Unobirthnochild = 
              u[w] + \[Gamma]\ \ Util[T - j + 1, n, 0] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]If[
              Ubirthchild > Unobirthchild, Birth[T - j, n, 1] = 1, 
              Birth[T - j, n, 1] = 0]; \[IndentingNewLine]If[
              Ubirthnochild > Unobirthnochild, Birth[T - j, n, 0] = 1, 
              Birth[T - j, n, 0] = 
                0]; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, n, 0] = 
              Max[Ubirthnochild, Unobirthnochild]; \[IndentingNewLine]Util[
                T - j, n, 1] = 
              Max[Ubirthchild, 
                Unobirthchild];\[IndentingNewLine]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine] (*\ 
            nmax - 1\ and\ nmax\ are\ done\ separately, \ 
            because\ a\ birth\ may\ not\ be\ possible\ *) \[IndentingNewLine]\
\[IndentingNewLine]Unobirthchild = 
            u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, nmax, 
                          0] + \((1 - sc)\) Util[T - j + 1, nmax - 1, 0])\) /. 
              par; \[IndentingNewLine]\[IndentingNewLine]Ubirthnochild = 
            u[w - q] + \[Gamma]\ \((si\ Util[T - j + 1, nmax - 1, 
                          1] + \((1 - si)\) Util[T - j + 1, nmax - 1, 0])\) /. 
              par; \[IndentingNewLine]\[IndentingNewLine]Unobirthnochild = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax - 1, 0] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]If[
            Ubirthnochild > Unobirthnochild, Birth[T - j, nmax - 1, 0] = 1, 
            Birth[T - j, nmax - 1, 0] = 
              0]; \[IndentingNewLine]\[IndentingNewLine]Birth[T - j, 
              nmax - 1, 1] = 
            0; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, nmax - 1, 
              0] = Max[Ubirthnochild, 
              Unobirthnochild]; \[IndentingNewLine]Util[T - j, nmax - 1, 1] = 
            Unobirthchild; \[IndentingNewLine]\[IndentingNewLine]Birth[T - j, 
              nmax, 0] = 0; \[IndentingNewLine]Birth[T - j, nmax, 1] = 
            0; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, nmax, 0] = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax, 0] /. 
              par;\[IndentingNewLine]];\[IndentingNewLine]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing Fertility and Reproduction Rates", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComputeFertility[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]par = 
          Join[prepar, {si \[Rule] sin, 
              sc \[Rule] scin}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          In\ the\ initial\ period, \ 
          zero\ children\ for\ sure\ \
*) \[IndentingNewLine]\[IndentingNewLine]ageatfirstchild = 
          0; \[IndentingNewLine]\[IndentingNewLine]prob[0, 0, 0] = 
          1; \[IndentingNewLine]For[n = 1, n \[LessEqual] nmax, \(n++\), 
          prob[0, n, 0] = 0]; \[IndentingNewLine]For[n = 0, 
          n \[LessEqual] nmax, \(n++\), 
          prob[0, n, 1] = 0]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          The\ following\ loops\ moves\ forward\ in\ time\ \
*) \[IndentingNewLine] (*\ First\ the\ fecund, \ 
          than\ the\ non - fecund\ period\ *) \[IndentingNewLine] (*\ 
          Order\ of\ \(indeces : \ Period\), \ old\ children, \ 
          young\ children\ *) \[IndentingNewLine] (*\ 
          n = 0\ \((at\ least)\)\ will\ have\ to\ be\ done\ separately\ \
*) \[IndentingNewLine]\[IndentingNewLine]For[j = 0, 
          j \[LessEqual] 
            K, \(j++\), \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Age\ at\ first\ birth\ \
*) \[IndentingNewLine]If[\((ageatfirstchild \[Equal] 
                    0)\) && \((Birth[j, 0, 0] == 1)\), 
              ageatfirstchild = j]\[IndentingNewLine]\[IndentingNewLine] (*\ 
              Expected\ number\ of\ children\ \((born\ previously)\)\ and\ \
expected\ number\ of\ births\ *) \[IndentingNewLine]\[IndentingNewLine]\(FR[
                j] = \[Sum]\+\(n = 0\)\%nmax\((prob[j, n, 0] Birth[j, n, 0] + 
                    prob[j, n, 1] 
                      Birth[j, n, 1])\)\); \[IndentingNewLine]Eofn[
              j] = \[Sum]\+\(n = 0\)\%nmax\((n\ prob[j, n, 0] + \((n + 1)\) 
                    prob[j, n, 1])\); \[IndentingNewLine] (*\ 
            First\ the\ n = 0\ case, \ 
            the\ loop\ below\ does\ the\ rest\ *) \[IndentingNewLine]\
\[IndentingNewLine]prob[j + 1, 0, 
              0] = \((1 - si\ Birth[j, 0, 0])\) 
                  prob[j, 0, 0] + \((1 - si\ Birth[j, 0, 1])\) \((1 - sc)\) 
                  prob[j, 0, 1] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, 0, 1] = 
            si\ Birth[j, 0, 0] prob[j, 0, 0] + 
                si\ Birth[j, 0, 1] \((1 - sc)\) prob[j, 0, 1] /. 
              
              par; \[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]\
For[n = 1, 
            n \[LessEqual] 
              nmax, \(n++\), \[IndentingNewLine]\[IndentingNewLine]prob[
                j + 1, n, 
                0] = \((1 - si\ Birth[j, n, 0])\) 
                    prob[j, n, 0] + \((1 - si\ Birth[j, n, 1])\) \((1 - sc)\) 
                    prob[j, n, 1] + \((1 - si\ Birth[j, n - 1, 1])\) 
                    sc\ prob[j, n - 1, 1] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, n, 
                1] = si\ Birth[j, n, 0] prob[j, n, 0] + 
                  si\ Birth[j, n, 1] \((1 - sc)\) prob[j, n, 1] + 
                  si\ Birth[j, n - 1, 1] sc\ prob[j, n - 1, 1] /. 
                par;\[IndentingNewLine]];\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]For[j = K + 1, 
          j \[LessEqual] 
            T, \(j++\), \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Fertility\ Rates\ and\ Expected\ number\ of\ children\ \((born\ \
previously)\)\ *) \[IndentingNewLine]\[IndentingNewLine]FR[j] = 
            0; \[IndentingNewLine]Eofn[
              j] = \[Sum]\+\(n = 0\)\%nmax\((n\ prob[j, n, 0] + \((n + 1)\) 
                    prob[j, n, 
                      1])\); \[IndentingNewLine]\[IndentingNewLine] (*\ 
            First\ the\ n = 0\ case, \ 
            the\ loop\ below\ does\ the\ rest\ *) \[IndentingNewLine]\
\[IndentingNewLine]prob[j + 1, 0, 0] = 
            prob[j, 0, 0] + \((1 - sc)\) prob[j, 0, 1] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, 0, 1] = 
            0 /. par; \[IndentingNewLine]\[IndentingNewLine]For[n = 1, 
            n \[LessEqual] 
              nmax, \(n++\), \[IndentingNewLine]\[IndentingNewLine]prob[
                j + 1, n, 0] = 
              prob[j, n, 0] + \((1 - sc)\) prob[j, n, 1] + 
                  sc\ prob[j, n - 1, 1] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, n, 
                1] = 0 /. 
                par;\[IndentingNewLine]];\[IndentingNewLine]\
\[IndentingNewLine]];\[IndentingNewLine]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"prob\" is similar to \
existing symbol \"prob\"."\)], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing TFR and NFR", "Section"],

Cell[BoxData[
    \(TFRNFRAge[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]computemax[sin, 
          scin]; \[IndentingNewLine]ComputeFertility[sin, 
          scin]; \[IndentingNewLine]{\[Sum]\+\(j = 0\)\%T FR[j], Eofn[T], 
          ageatfirstchild}\[IndentingNewLine]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Actual Computation", "Section"],

Cell["15 is the lowest V (up to 0.1) that gives five births", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Vset = 8;\)\), "\[IndentingNewLine]", 
    \(\(Vlo = 1;\)\), "\[IndentingNewLine]", 
    \(\(Vhi = 8000;\)\), "\[IndentingNewLine]", 
    \(\(NTarget = 5;\)\), "\[IndentingNewLine]", 
    \(\(it = 1;\)\), "\[IndentingNewLine]", 
    \(While[
      it < 30, \[IndentingNewLine]Clear[Util, Birth, prob, 
        FR]; \[IndentingNewLine]prepar = {\[Sigma] \[Rule]  .05, \[Epsilon] \
\[Rule]  .05, \[Beta] \[Rule] 0.2, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, 
          q \[Rule] 1/12, V \[Rule] Vset, 
          w \[Rule] 
            1}; \[IndentingNewLine]\[IndentingNewLine]If[\(TFRNFRAge[ .84, 
              0.87]\)[\([1]\)] > NTarget, Vhi = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vlo, Vlo = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vhi]; \[IndentingNewLine]\
\[IndentingNewLine]it = it + 1\[IndentingNewLine]]\), "\[IndentingNewLine]", 
    \(Vset\)}], "Input"],

Cell[BoxData[
    \(257.2634723633528`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TFRNFRAge[ .84, 0.87]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(5.386128`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[Util, Birth, prob, FR];\)\), "\[IndentingNewLine]", 
    \(\(prepar = {\[Sigma] \[Rule]  .05, \[Epsilon] \[Rule]  .05, \[Beta] \
\[Rule] 0.2, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, q \[Rule] 1/12, 
          V \[Rule] Vset, w \[Rule] 1};\)\), "\[IndentingNewLine]", 
    \({\(TFRNFRAge[ .84, 0.87]\)[\([1]\)], \(TFRNFRAge[ .84, 
          0.87]\)[\([2]\)], \(TFRNFRAge[ .84, 
          0.87]\)[\([3]\)]}\), "\[IndentingNewLine]", 
    \({\(TFRNFRAge[ .97, 0.995]\)[\([1]\)], \(TFRNFRAge[ .97, 
          0.995]\)[\([2]\)], \(TFRNFRAge[ .97, 0.995]\)[\([3]\)]}\)}], "Input"],

Cell[BoxData[
    \({5.16`, 3.7709279999999996`, 7}\)], "Output"],

Cell[BoxData[
    \({5.`, 4.825749999999999`, 8}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Vset = 8;\)\), "\[IndentingNewLine]", 
    \(\(Vlo = 1;\)\), "\[IndentingNewLine]", 
    \(\(Vhi = 1000;\)\), "\[IndentingNewLine]", 
    \(\(NTarget = 5;\)\), "\[IndentingNewLine]", 
    \(\(it = 1;\)\), "\[IndentingNewLine]", 
    \(While[
      it < 30, \[IndentingNewLine]Clear[Util, Birth, prob, 
        FR]; \[IndentingNewLine]prepar = {\[Sigma] \[Rule]  .01, \[Epsilon] \
\[Rule]  .01, \[Beta] \[Rule] 1, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, 
          q \[Rule] 1/12, V \[Rule] Vset, 
          w \[Rule] 
            1}; \[IndentingNewLine]\[IndentingNewLine]If[\(TFRNFRAge[ .73, 
              1]\)[\([1]\)] > NTarget, Vhi = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vlo, Vlo = Vset; 
        Vset =  .5\ Vset\  + \  .5\ Vhi]; \[IndentingNewLine]\
\[IndentingNewLine]it = it + 1\[IndentingNewLine]]\), "\[IndentingNewLine]", 
    \(Vset\)}], "Input"],

Cell[BoxData[
    \(250.2930412888527`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[""], "Input"],

Cell[BoxData[
    \(260\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Vset = 240\), "\[IndentingNewLine]", 
    \(\(prepar = {\[Sigma] \[Rule]  .01, \[Epsilon] \[Rule]  .01, \[Beta] \
\[Rule] 1, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, q \[Rule] 1/12, 
          V \[Rule] Vset, w \[Rule] 1};\)\), "\[IndentingNewLine]", 
    \({\(TFRNFRAge[ .73, 1]\)[\([1]\)], \(TFRNFRAge[ .73, 
          1]\)[\([2]\)], \(TFRNFRAge[ .73, 
          1]\)[\([3]\)]}\), "\[IndentingNewLine]", 
    \({\(TFRNFRAge[ .8, 1]\)[\([1]\)], \(TFRNFRAge[ .8, 
          1]\)[\([2]\)], \(TFRNFRAge[ .8, 
          1]\)[\([3]\)]}\), "\[IndentingNewLine]", 
    \({\(TFRNFRAge[ .965, 1]\)[\([1]\)], \(TFRNFRAge[ .965, 
          1]\)[\([2]\)], \(TFRNFRAge[ .965, 1]\)[\([3]\)]}\)}], "Input"],

Cell[BoxData[
    \(240\)], "Output"],

Cell[BoxData[
    \({4.961540021611`, 3.6219242157760303`, 6}\)], "Output"],

Cell[BoxData[
    \({4.5856`, 3.66848`, 7}\)], "Output"],

Cell[BoxData[
    \({4.`, 3.86`, 9}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prepar = {\[Sigma] \[Rule]  .01, \[Epsilon] \[Rule]  .01, \[Beta] \
\[Rule] 1, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, q \[Rule] 1/12, 
          V \[Rule] Vset, w \[Rule] 1};\)\), "\[IndentingNewLine]", 
    \(seqplot1 = 
      Plot[{\(TFRNFRAge[s, 1]\)[\([1]\)], \(TFRNFRAge[s, 1]\)[\([2]\)]}, {s, 
          0.06,  .99}, PlotRange \[Rule] {{0, 1}, {0, 11}}, 
        AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
        PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
              Thickness[ .008]}}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .5175 m
.06454 .50486 L
.06877 .49345 L
.07115 .48716 L
.0734 .48132 L
.07465 .47813 L
.07535 .50879 L
.076 .50912 L
.07715 .50656 L
.07837 .50387 L
.07954 .50128 L
.08066 .49885 L
.08194 .5275 L
.08312 .52521 L
.08528 .52107 L
.08646 .51881 L
.08758 .5167 L
.08821 .5155 L
.0889 .54068 L
.0901 .5404 L
.09131 .53831 L
.09243 .53639 L
.09499 .53206 L
.09639 .52969 L
.09709 .52853 L
.09773 .52746 L
.09896 .55042 L
.09962 .54939 L
.10031 .5483 L
.10266 .54461 L
.10727 .53747 L
.1085 .53558 L
.10915 .53459 L
.10983 .53354 L
.11109 .55133 L
.11224 .55132 L
.1129 .55034 L
.1136 .5493 L
.11487 .54743 L
.11773 .5432 L
.12343 .53489 L
.12623 .53085 L
.12881 .52715 L
.13002 .52542 L
.13115 .5238 L
.13234 .53797 L
.13296 .53707 L
.13364 .53766 L
.13431 .5367 L
.13504 .53566 L
Mistroke
.13637 .53376 L
.13887 .53021 L
.15812 .50349 L
.16366 .49602 L
.16638 .49239 L
.16757 .49081 L
.16888 .48908 L
.17005 .48752 L
.17115 .50985 L
.17231 .51286 L
.17356 .51146 L
.17861 .50577 L
.18345 .50041 L
.18857 .49479 L
.18986 .49339 L
.19054 .49266 L
.19125 .49189 L
.19204 .50865 L
.19277 .50793 L
.19345 .51157 L
.1942 .51085 L
.19487 .51019 L
.1955 .50958 L
.19623 .52385 L
.19689 .52319 L
.19939 .52068 L
.20895 .51257 L
.21417 .50742 L
.21905 .50265 L
.22356 .49829 L
.22485 .49704 L
.22608 .49586 L
.22718 .4948 L
.22838 .50886 L
.22961 .50773 L
.23031 .51052 L
.23096 .50991 L
.23371 .5074 L
.23864 .50292 L
.25667 .48681 L
.26538 .4792 L
.27469 .47022 L
.27744 .46791 L
.28004 .46573 L
.28117 .46478 L
.28237 .46378 L
.283 .46326 L
.28369 .44921 L
.2849 .44827 L
.29441 .44098 L
Mistroke
.31396 .42646 L
.33456 .41181 L
.34428 .40513 L
.34907 .40188 L
.35352 .3989 L
.35479 .39806 L
.35599 .39726 L
.35665 .41112 L
.35737 .4107 L
.35862 .42118 L
.35929 .42081 L
.36002 .4204 L
.36151 .41958 L
.36417 .41811 L
.37392 .41281 L
.41341 .39259 L
.45142 .37484 L
.49183 .35675 L
.53076 .34389 L
.56821 .33225 L
.58715 .32692 L
.60805 .32044 L
.61758 .31792 L
.62784 .31522 L
.63256 .31398 L
.63753 .31268 L
.63959 .31214 L
.64071 .31185 L
.64178 .31157 L
.64304 .31081 L
.64418 .30858 L
.64525 .30832 L
.64641 .29536 L
.64762 .29513 L
.64872 .29492 L
.6512 .29446 L
.65567 .29361 L
.66584 .29169 L
.68639 .28781 L
.72524 .27962 L
.73535 .2778 L
.74485 .27609 L
.75339 .27453 L
.75572 .27411 L
.75819 .27365 L
.7603 .27327 L
.76149 .27305 L
.7626 .27075 L
.7638 .27056 L
.76511 .27035 L
Mistroke
.76747 .26996 L
.77191 .26924 L
.78187 .2676 L
.78454 .26716 L
.78704 .26674 L
.78829 .26653 L
.789 .26641 L
.78965 .25926 L
.79035 .25915 L
.79112 .25903 L
.79252 .25881 L
.80236 .25727 L
.80755 .25645 L
.81243 .25568 L
.81457 .25535 L
.81573 .25516 L
.81682 .25499 L
.818 .24671 L
.81862 .24663 L
.81929 .24655 L
.82157 .24626 L
.8242 .24593 L
.82706 .24556 L
.82838 .2454 L
.82909 .2453 L
.82977 .24522 L
.83096 .24213 L
.83159 .24207 L
.83227 .24201 L
.83346 .2419 L
.83413 .23406 L
.83476 .23402 L
.83737 .23388 L
.84204 .23361 L
.88016 .23147 L
.89015 .23091 L
.89542 .23062 L
.90099 .2303 L
.90334 .23017 L
.90464 .2301 L
.90587 .23003 L
.90656 .22999 L
.90731 .22474 L
.908 .22474 L
.90864 .22474 L
.91123 .22474 L
.92067 .22474 L
.95892 .22474 L
.99 .22474 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .03105 m
.09773 .05155 L
.13887 .07363 L
.17751 .09 L
.21468 .10882 L
.21978 .11032 L
.22247 .11109 L
.22394 .1115 L
.22532 .11189 L
.22652 .11223 L
.22781 .11604 L
.22855 .11626 L
.22925 .11647 L
.22987 .11666 L
.23056 .11765 L
.23177 .11801 L
.23306 .11839 L
.23539 .11908 L
.25423 .12431 L
.26452 .12695 L
.2742 .12905 L
.27843 .13005 L
.28074 .13058 L
.28187 .13084 L
.2829 .13108 L
.28403 .12751 L
.28524 .12779 L
.2878 .12837 L
.29231 .12937 L
.31252 .13361 L
.33122 .13717 L
.34058 .13884 L
.34937 .14034 L
.35152 .14069 L
.35378 .14106 L
.35496 .14126 L
.35563 .14136 L
.35626 .14655 L
.35736 .14677 L
.35853 .15102 L
.35921 .15118 L
.35984 .15131 L
.36126 .15163 L
.36383 .15219 L
.36865 .15323 L
.40712 .16109 L
.44412 .16794 L
.48351 .17383 L
.52142 .18081 L
.56173 .18767 L
Mistroke
.60056 .19364 L
.62016 .19674 L
.62869 .19803 L
.63317 .1987 L
.6379 .1994 L
.64037 .19975 L
.64105 .19985 L
.64177 .19996 L
.64245 .20005 L
.64307 .19987 L
.64424 .19879 L
.64551 .19899 L
.64671 .19098 L
.64782 .19117 L
.65715 .19276 L
.67765 .19615 L
.71604 .20139 L
.73531 .20428 L
.75295 .20677 L
.75774 .20742 L
.76007 .20773 L
.76108 .20787 L
.76218 .20802 L
.76334 .20658 L
.76443 .20674 L
.76682 .20709 L
.77188 .20783 L
.77704 .20856 L
.78249 .20932 L
.78474 .20962 L
.78715 .20995 L
.78786 .21005 L
.78853 .21014 L
.78979 .20474 L
.79098 .2049 L
.79226 .20508 L
.80221 .2064 L
.81155 .20761 L
.81383 .2079 L
.81508 .20806 L
.81624 .20821 L
.8175 .20174 L
.81816 .20183 L
.81887 .20194 L
.82129 .20228 L
.82419 .20269 L
.82693 .20308 L
.82812 .20324 L
.82939 .20342 L
.83005 .20105 L
Mistroke
.83078 .20117 L
.83206 .20138 L
.83332 .20159 L
.83449 .1953 L
.83577 .19554 L
.83714 .1958 L
.84196 .1967 L
.85102 .19838 L
.87142 .20214 L
.88147 .20397 L
.89234 .20594 L
.89733 .20684 L
.90006 .20733 L
.9026 .20779 L
.90478 .20818 L
.90599 .2084 L
.9071 .20386 L
.90832 .20414 L
.90964 .20443 L
.91204 .20497 L
.95188 .21393 L
.99 .22249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00AP3oool2000000@0oooo0P0000030?ooo`@00000803oool2000000@0oooo0P0000050?oo
o`<00000803oool2000000@0oooo0P0000030?ooo`<000008@3oool2000000@0oooo0P0000040?oo
o`8000009`3oool500000180oooo00150?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool0803oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01h0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000O0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`0B0?ooo`00A@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool00000203oool5
000001l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000O0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000:03oool00`000000oooo0?ooo`0B0?oo
o`00A@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01h0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000P0?ooo`040000003oool0oooo000000P0oooo
0`00000P0?ooo`040000003oool0oooo000000T0oooo0P00000Y0?ooo`030000003oool0oooo0180
oooo00150?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000007`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool000000200oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000:03oool00`000000oooo0?ooo`0B0?ooo`00AP3oool2000000X0oooo0P00000Q0?ooo`800000
2`3oool200000240oooo0P00000:0?ooo`<00000803oool2000000X0oooo0P00000X0?ooo`800000
503oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo503oool3000000X0
oooo003o0?oooaL0oooo00<000000?ooo`3oool01`3oool001h0ooookP0000070?ooo`<000002P3o
ool001h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00D0oooo100000090?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?oo
o`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0>d0oooo000N0?ooo`030000003oool0oooo0100oooo0P00003]0?ooo`007P3oool0
0`000000oooo0?ooo`0B0?ooo`800000j`3oool001h0oooo00<000000?ooo`3oool0o`3oool001h0
oooo00<000000?ooo`3oool0o`3oool001h0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`3U0?ooo`007P3oool00`000000oooo0?ooo`0H0?ooo`800000i@3oool001h0oooo00<00000
0?ooo`3oool06P3oool200000><0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`03
0000003oool0oooo01l0oooo0P00003N0?ooo`007P3oool00`000000oooo0?ooo`0Q0?ooo`800000
g03oool001h0oooo00<000000?ooo`3oool08`3oool200000=X0oooo000N0?ooo`030000003oool0
oooo0?l0oooo000N0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0e03oool001h0
oooo00<000000?ooo`3oool0:@3oool200000=@0oooo000F0?ooo`@00000103oool00`000000oooo
0?ooo`0[0?ooo`800000dP3oool001H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3o0?ooo`005`3oool00`000000oooo0?ooo`040?ooo`800000<P3oool200000<`0oooo000H0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`390?oo
o`005P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0b03oool001L0oooo0P0000050?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0``3oool001h0oooo00<000000?ooo`3oool0>P3oool5000000<0oooo0P00002k0?ooo`007P3o
ool00`000000oooo0?ooo`140?ooo`<00000^03oool001h0oooo00<000000?ooo`3oool0B`3oool3
00000;40oooo000N0?ooo`030000003oool0oooo04h0oooo0P00002_0?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooo`007P3oool00`000000oooo0?oo
o`1B0?ooo`H00000Y`3oool001h0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`2P
0?ooo`007P3oool00`000000oooo0?ooo`1M0?ooo`@00000WP3oool001h0oooo00<000000?ooo`3o
ool0I@3oool3000009L0oooo000N0?ooo`030000003oool0oooo06P0oooo0`00002D0?ooo`007P3o
ool00`000000oooo0?ooo`1^0?ooo`H00000R`3oool001h0oooo00<000000?ooo`3oool0N03oool2
000008D0oooo000N0?ooo`030000003oool0oooo07X0oooo0`0000220?ooo`007P3oool00`000000
oooo0?ooo`210?ooo`D00000N@3oool001h0oooo00<000000?ooo`3oool0QP3oool3000000d0oooo
1000001U0?ooo`007P3oool00`000000oooo0?ooo`2=0?ooo`D00000103oool00`000000oooo0?oo
o`050?ooo`8000008P3oool3000003X0oooo000N0?ooo`030000003oool0oooo0:00oooo0`000004
0?ooo`800000603oool010000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool0<@3o
ool001h0oooo00<000000?ooo`3oool0Z@3oool4000000@0oooo00<000000?ooo`3oool01@3oool3
000000D0oooo00<000000?ooo`3oool0203oool5000000<0oooo0`00000X0?ooo`007P3oool00`00
0000oooo0?ooo`2`0?ooo`H000001P3oool2000001T0oooo0P00000V0?ooo`007P3oool00`000000
oooo0?ooo`3M0?ooo`<000007`3oool001P0oooo0`0000030?ooo`030000003oool0oooo0>00oooo
0`00000L0?ooo`006@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0>H0oooo0P00
000G0?ooo`005P3oool5000000<0oooo0P00003E0?oooa@000005`3oool001H0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`390?ooo`/00000:`3oool001L0oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`320?ooo`L00000=P3oool001P0oooo0P0000040?ooo`03
0000003oool0oooo0<80oooo00<000000?ooo`3oool0>P3oool001h0oooo00<000000?ooo`3oool0
`@3oool2000003`0oooo000N0?ooo`030000003oool0oooo0;h0oooo1000000m0?ooo`007P3oool0
0`000000oooo0?ooo`2n0?ooo`030000003oool0oooo03h0oooo000N0?ooo`030000003oool0oooo
0;`0oooo0`0000100?ooo`007P3oool00`000000oooo0?ooo`2h0?ooo`@00000@`3oool001h0oooo
00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`140?ooo`007P3oool00`000000oooo0?oo
o`2c0?ooo`H00000AP3oool001h0oooo00<000000?ooo`3oool0/03oool3000004`0oooo000N0?oo
o`030000003oool0oooo0:X0oooo1P00001?0?ooo`007P3oool00`000000oooo0?ooo`2V0?ooo`@0
0000E@3oool001h0oooo00<000000?ooo`3oool0XP3oool4000005T0oooo000N0?ooo`030000003o
ool0oooo09d0oooo1@00001M0?ooo`007P3oool00`000000oooo0?ooo`2F0?ooo`L00000HP3oool0
01h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`1V0?ooo`007P3oool00`000000
oooo0?ooo`2F0?ooo`030000003oool0oooo06H0oooo000N0?ooo`030000003oool0oooo09D0oooo
00<000000?ooo`3oool0I`3oool001h0oooo00<000000?ooo`3oool0U03oool2000006T0oooo000N
0?ooo`030000003oool0oooo0940oooo1000001Z0?ooo`007P3oool00`000000oooo0?ooo`2<0?oo
o`D00000KP3oool001h0oooo00<000000?ooo`3oool0RP3oool2000007<0oooo000F0?ooo`<00000
1@3oool00`000000oooo0?ooo`260?ooo`@00000M@3oool001H0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`220?ooo`@00000N@3oool001H0oooo00@000000?ooo`3oool00000
103oool200000800oooo0`00001m0?ooo`005P3oool3000000D0oooo00<000000?ooo`3oool0O03o
ool300000800oooo000G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0N@3oool3
000008<0oooo000G0?ooo`<00000103oool00`000000oooo0?ooo`1f0?ooo`<00000QP3oool001h0
oooo00<000000?ooo`3oool0L`3oool3000008T0oooo000N0?ooo`030000003oool0oooo0700oooo
0`00002<0?ooo`007P3oool00`000000oooo0?ooo`1^0?ooo`800000S`3oool001h0oooo00<00000
0?ooo`3oool0K03oool200000940oooo000N0?ooo`030000003oool0oooo06X0oooo0P00002C0?oo
o`007P3oool00`000000oooo0?ooo`1X0?ooo`800000U@3oool001h0oooo00<000000?ooo`3oool0
IP3oool2000009L0oooo000N0?ooo`030000003oool0oooo06@0oooo0P00002I0?ooo`007P3oool0
0`000000oooo0?ooo`1R0?ooo`800000V`3oool001h0oooo00<000000?ooo`3oool0H03oool20000
09d0oooo000N0?ooo`030000003oool0oooo05h0oooo0P00002O0?ooo`007P3oool00`000000oooo
0?ooo`1@0?ooo`8000002P3oool200000:40oooo000N0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`0000001`3oool300000:<0oooo000N0?ooo`030000003oool0oooo04h0oooo00@00000
0?ooo`3oool000001@3oool200000:H0oooo000N0?ooo`030000003oool0oooo04`0oooo0P000003
0?ooo`040000003oool0oooo0?ooo`800000Z03oool001h0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool000000:X0oooo000N0?ooo`030000003oool0oooo
04T0oooo0P0000070?ooo`800000Z`3oool001h0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`2d0?ooo`007P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0;D0oooo
000N0?ooo`030000003oool0oooo04D0oooo0P00002h0?ooo`007P3oool00`000000oooo0?ooo`13
0?ooo`800000^P3oool001L0oooo0P0000050?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool0^P3oool001H0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0;/0oooo000F0?ooo`040000003oool0oooo000000@0oooo0P0000110?oo
o`030000003oool0oooo0;`0oooo000G0?ooo`8000001@3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo0;`0oooo000F0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`2l0?ooo`005`3oool2000000D0oooo00<000000?ooo`3oool0
?`3oool200000;h0oooo000N0?ooo`030000003oool0oooo03h0oooo0P00002o0?ooo`007P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0;h0oooo000N0?ooo`030000003oool0oooo
03`0oooo0P0000310?ooo`007P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0`@3oool001h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo0<80oooo000N0?ooo`030000003oool0oooo00d0oooo0P00
000F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0``3oool001h0oooo00<00000
0?ooo`3oool03@3oool2000001D0oooo0P0000040?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0a03oool001h0oooo00<000000?ooo`3oool03@3oool2000001@0oooo00<000000?oo
o`0000000`3oool2000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`350?oo
o`007P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool00000008000004@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0000000L0oooo00D000000?ooo`3oool0oooo00000038
0?ooo`007P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool00000008000004@3oool01P00
0000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00`3oool2000000040?ooo`00
0000oooo00000<T0oooo000N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000P00
000@0?ooo`040000003oool0oooo0?ooo`8000000`3oool2000000<0oooo00@000000?ooo`3oool0
oooo0P00003:0?ooo`007P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`8000000`3oool200000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`390?ooo`007P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0080oooo0P00000=0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`000000d@3oool001h0oooo00<000000?ooo`3oool0403oool2000000d0oooo00<00000
0?ooo`3oool02@3oool200000=80oooo000N0?ooo`030000003oool0oooo0100oooo0P0000090?oo
o`80000000<0oooo0000003oool02`3oool00`000000oooo0?ooo`3A0?ooo`007P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool00000008000001@3oool010000000oooo00000000003Q0?oo
o`007P3oool00`000000oooo0?ooo`0B0?ooo`<0000000<0oooo0000000000000P3oool010000000
oooo00000000003Q0?ooo`007P3oool00`000000oooo0?ooo`0B0?ooo`040000003oool000000?oo
o`80000000D0oooo0000003oool0oooo0000003R0?ooo`007P3oool00`000000oooo0?ooo`0B0?oo
o`050000003oool000000000003oool00P00003V0?ooo`007P3oool00`000000oooo0?ooo`0D0?oo
o`80000000<0oooo000000000000iP3oool001h0oooo00<000000?ooo`3oool0503oool010000000
oooo0?ooo`00003W0?ooo`00403oool500000080oooo0P0000050?ooo`030000003oool0oooo0?l0
oooo000B0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0?l0oooo000B0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`800000o`3oool10?ooo`004P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`004P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`00
4@3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003o
ool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo
0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo
000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?oo
o`030000003oool0oooo0?l0oooo000N0?ooo`030000003oool0oooo0?l0oooo000N0?ooo`030000
003oool0oooo0?l0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo00080?ooo`<0000000D0oooo00000000000000000?ooo`0200000080oooo
0`0000020?ooo`<00000103oool4000000030?ooo`0000000000008000000`3oool3000000030?oo
o`00000000000080oooo0P00003Z0?ooo`001`3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo00000>/0oooo00070?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`020?ooo`@000000P3oool010000000oooo0?ooo`00
003[0?ooo`001`3oool00`000000oooo0?ooo`030?ooo`<00000103oool2000000@0oooo00<00000
0?ooo`3oool00`3oool300000080oooo100000030?ooo`8000000P3oool400000>`0oooo00070?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0?/0oooo00080?ooo`<0000000<0oooo0000000000001`3oool01000
0000oooo0?ooo`3oool2000000H0oooo0P00003m0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(SetDirectory["\<c:/temp\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<seqplot3new.eps\>", seqplot1, "\<EPS\>"];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prepar = {\[Sigma] \[Rule]  .5, \[Epsilon] \[Rule]  .5, \[Beta] \
\[Rule] 0.2, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, q \[Rule] 1/12, 
          V \[Rule] 15.05, w \[Rule] 1};\)\), "\[IndentingNewLine]", 
    \(seqplot2 = 
      Plot[\(TFRNFRAge[s, 1]\)[\([3]\)], {s, 0.04,  .99}, 
        PlotRange \[Rule] {{0, 1}, {0, 10}}, 
        AxesLabel \[Rule] {"\<s\>", "\<Age\>"}, 
        PlotStyle \[Rule] {{Thickness[ .008]}}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.0618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.375 ]
[1.025 0 10 6.375 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -11 0 ]
[0 .64303 11 12.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Age) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.04464 .61803 m
.04464 .61803 L
.0458 .61803 L
.0469 .55623 L
.04788 .55623 L
.04895 .55623 L
.05013 .49443 L
.05143 .49443 L
.05269 .49443 L
.05339 .49443 L
.05405 .49443 L
.05532 .43262 L
.05648 .43262 L
.05766 .43262 L
.05876 .43262 L
.06001 .37082 L
.06113 .37082 L
.06366 .37082 L
.06585 .37082 L
.06708 .37082 L
.06822 .30902 L
.06945 .30902 L
.07061 .30902 L
.07324 .30902 L
.0758 .30902 L
.07653 .30902 L
.07723 .30902 L
.07854 .24721 L
.07978 .24721 L
.08095 .24721 L
.08361 .24721 L
.089 .24721 L
.09365 .24721 L
.09493 .24721 L
.09562 .24721 L
.09627 .24721 L
.09742 .18541 L
.09867 .18541 L
.12057 .18541 L
.15952 .18541 L
.17938 .18541 L
.18984 .18541 L
.19556 .18541 L
.20091 .18541 L
.20335 .18541 L
.20456 .18541 L
.20567 .18541 L
.20695 .24721 L
.20763 .24721 L
.20835 .24721 L
Mistroke
.21079 .24721 L
.22166 .24721 L
.24079 .24721 L
.26076 .24721 L
.27125 .24721 L
.28232 .24721 L
.28713 .24721 L
.29227 .24721 L
.29379 .24721 L
.29523 .24721 L
.29651 .24721 L
.29724 .24721 L
.29792 .30902 L
.29913 .30902 L
.30047 .30902 L
.30318 .30902 L
.32234 .30902 L
.3625 .30902 L
.38096 .30902 L
.39142 .30902 L
.39652 .30902 L
.40114 .30902 L
.4023 .30902 L
.40353 .30902 L
.40418 .30902 L
.40488 .37082 L
.40613 .37082 L
.41083 .37082 L
.42117 .37082 L
.44223 .37082 L
.48252 .37082 L
.5213 .37082 L
.53143 .37082 L
.54246 .37082 L
.54751 .37082 L
.55288 .37082 L
.55508 .37082 L
.55746 .37082 L
.55812 .37082 L
.55882 .37082 L
.56007 .43262 L
.56124 .43262 L
.56252 .43262 L
.60295 .43262 L
.64187 .43262 L
.68323 .43262 L
.70395 .43262 L
.72308 .43262 L
.74169 .43262 L
.74622 .43262 L
Mistroke
.74871 .43262 L
.74994 .43262 L
.75108 .43262 L
.75173 .49443 L
.75241 .49443 L
.75387 .49443 L
.75642 .49443 L
.76142 .49443 L
.80291 .49443 L
.8429 .49443 L
.88137 .49443 L
.92229 .49443 L
.94268 .49443 L
.9617 .49443 L
.96872 .49443 L
.97536 .49443 L
.97714 .49443 L
.97812 .49443 L
.97903 .49443 L
.98002 .55623 L
.9811 .55623 L
.98302 .55623 L
.99 .55623 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{330.875, 204.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005:0000c1000`40O003h00OogooBgoo001:Ool2
0004Ool20003Ool4000XOol20004Ool20005Ool3000WOol20004Ool20003Ool3000ZOol20004Ool2
0004Ool2000^Ool5000IOol004Uoo`04001oogoo0008Ool00`00Oomoo`0XOol01000Oomoo`002goo
00<007ooOol09Goo00@007ooOol000Qoo`04001oogoo000XOol01000Oomoo`0027oo00@007ooOol0
02moo`03001oogoo01Uoo`00BGoo00@007ooOol000Uoo`03001oogoo02Moo`04001oogoo0008Ool5
000VOol01000Oomoo`0027oo00@007ooOol002Qoo`04001oogoo0008Ool01000Oomoo`00;goo00<0
07ooOol06Goo0019Ool01000Oomoo`002Woo00<007ooOol09Woo00@007ooOol000Qoo`04001oogoo
000WOol01000Oomoo`0027oo0`00:Goo00@007ooOol000Uoo`80031oo`03001oogoo01Uoo`00BGoo
00@007ooOol000Qoo`04001oogoo000WOol01000Oomoo`002Goo00<007oo00009goo00@007ooOol0
00Uoo`03001oogoo02Qoo`04001oogoo0008Ool01000Oomoo`00;goo00<007ooOol06Goo001:Ool2
000:Ool2000YOol2000;Ool2000XOol2000:Ool3000YOol2000:Ool2000_Ool2000KOol00?mood]o
o`00ogooBgoo003oOom;Ool00?mood]oo`00ogoo>Goo0`003goo000IOooo000G000<Ool00`00Oomo
o`0<Ool001Uoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03
001oogoo00]oo`03001oogoo00Moo`<000moo`006Goo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol01goo10003Woo000IOol00`00
Oomoo`3oOol_Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00
Oomoo`3oOol_Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol2003o
Ool`Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3o
Ool_Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3o
Ool_Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol2003oOol`Ool0
01Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3oOol_Ool0
01Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3oOol_Ool0
01Uoo`03001oogoo0?moobmoo`006Goo0P00ogoo<7oo000IOol00`00Oomoo`3oOol_Ool001Uoo`03
001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3oOol_Ool001Uoo`03
001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000AOol40004Ool00`00Oomoo`3oOol_Ool0
015oo`03001oogoo00Eoo`03001oogoo0?moobmoo`004Woo00<007ooOol017oo0`00ogoo;goo000C
Ool00`00Oomoo`03Ool00`00Oomoo`3oOol_Ool0015oo`04001oogoo0004Ool00`00Oomoo`3oOol_
Ool0019oo`8000Eoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomo
o`3oOol_Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol2003oOol`
Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3oOol_
Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol00`00Oomoo`3oOol_
Ool001Uoo`03001oogoo0?moobmoo`006Goo00<007ooOol0ogoo;goo000IOol2000HOolP003gOol0
01Uoo`03001oogoo01Moob000?Moo`006Goo00<007ooOol05goo0P0077oo0P00mgoo000IOol00`00
Oomoo`0GOol2000LOol2003gOol001Uoo`03001oogoo01Moo`8001aoo`800?Moo`006Goo00<007oo
Ool05goo0P0077oo0P00mgoo000IOol00`00Oomoo`0GOol2000LOol2003gOol001Uoo`03001oogoo
01Moo`8001aoo`800?Moo`006Goo0P0067oo0P0077oo0P00mgoo000IOol00`00Oomoo`0GOol2000L
Ool2003gOol001Uoo`03001oogoo01Moo`8001aoo`800?Moo`006Goo00<007ooOol05goo0P0077oo
0P00mgoo000IOol00`00Oomoo`0GOol2000LOol2003gOol001Uoo`03001oogoo01Moo`8001aoo`80
0?Moo`006Goo00<007ooOol05goo0P0077oo0P00mgoo000COol30003Ool00`00Oomoo`0GOol2000L
Ool2003gOol001Aoo`03001oogoo009oo`03001oogoo01Moo`8001aoo`800?Moo`004Goo1@000goo
0`004Woo1`0077oo6`00gWoo000AOol01000Oomoo`0017oo00<007ooOol04Woo1`0077oo7000gGoo
000BOol00`00Ool00004Ool00`00Oomoo`0BOol2000kOol2003MOol001=oo`8000Aoo`03001oogoo
019oo`8003]oo`800=eoo`006Goo00<007ooOol04Woo0P00>goo0P00gGoo000IOol00`00Oomoo`0B
Ool2000kOol2003MOol001Uoo`03001oogoo019oo`8003]oo`800=eoo`006Goo00<007ooOol04Woo
0P00>goo0P00gGoo000IOol00`00Oomoo`0BOol2000kOol2003MOol001Uoo`8001=oo`8003]oo`80
0=eoo`006Goo00<007ooOol04Woo0P00>goo0P00gGoo000IOol00`00Oomoo`0BOol2000kOol2003M
Ool001Uoo`03001oogoo019oo`8003]oo`800=eoo`006Goo00<007ooOol04Woo0P00>goo0P00gGoo
000IOol00`00Oomoo`0BOol2000kOol2003MOol001Uoo`03001oogoo019oo`8003]oo`800=eoo`00
6Goo00<007ooOol04Woo0P00>goo0P00gGoo000IOol2000@Ool4000lOolO0030Ool001Uoo`03001o
ogoo00moo`@003eooah00<1oo`006Goo00<007ooOol03goo0P00Fgoo0P00`7oo000IOol00`00Oomo
o`0?Ool2001KOol20030Ool001Uoo`03001oogoo00moo`8005]oo`800<1oo`006Goo00<007ooOol0
3goo0P00Fgoo0P00`7oo000IOol00`00Oomoo`0?Ool2001KOol20030Ool001Uoo`03001oogoo00mo
o`8005]oo`800<1oo`006Goo00<007ooOol03goo0P00Fgoo0P00`7oo000IOol2000@Ool2001KOol2
0030Ool001Uoo`03001oogoo00moo`8005]oo`800<1oo`006Goo00<007ooOol03goo0P00Fgoo0P00
`7oo000IOol00`00Oomoo`0?Ool2001KOol20030Ool001Uoo`03001oogoo00moo`8005]oo`800<1o
o`006Goo00<007ooOol03goo0P00Fgoo0P00`7oo000AOol30005Ool00`00Oomoo`0?Ool2001KOol2
0030Ool0015oo`04001oogoo0004Ool00`00Oomoo`0?Ool2001KOol20030Ool0015oo`04001oogoo
0004Ool3000=Ool4001KOol]002EOol0015oo`<000Eoo`03001oogoo00eoo`@005]oobd009Eoo`00
4Woo00<007ooOol017oo00<007ooOol03Goo0P00R7oo0P00UGoo000BOol30004Ool00`00Oomoo`0=
Ool20028Ool2002EOol001Uoo`03001oogoo00eoo`8008Qoo`8009Eoo`006Goo00<007ooOol03Goo
0P00R7oo0P00UGoo000IOol00`00Oomoo`0=Ool20028Ool2002EOol001Uoo`03001oogoo00eoo`80
08Qoo`8009Eoo`006Goo00<007ooOol03Goo0P00R7oo0P00UGoo000IOol2000>Ool20028Ool2002E
Ool001Uoo`03001oogoo00eoo`8008Qoo`8009Eoo`006Goo00<007ooOol03Goo0P00R7oo0P00UGoo
000IOol00`00Oomoo`0=Ool20028Ool2002EOol001Uoo`03001oogoo00eoo`8008Qoo`8009Eoo`00
6Goo00<007ooOol03Goo0P00R7oo0P00UGoo000IOol00`00Oomoo`0=Ool20028Ool2002EOol001Uo
o`03001oogoo00eoo`8008Qoo`8009Eoo`006Goo0P0037oo0`00RGoo=`00H7oo000IOol00`00Oomo
o`0;Ool30029Oolg001POol001Uoo`03001oogoo00]oo`800;moo`80061oo`006Goo00<007ooOol0
2goo0P00_goo0P00H7oo000IOol00`00Oomoo`0;Ool2002oOol2001POol001Uoo`03001oogoo00]o
o`800;moo`80061oo`006Goo00<007ooOol02goo0P00_goo0P00H7oo000IOol00`00Oomoo`0;Ool2
002oOol2001POol001Uoo`03001oogoo00]oo`800;moo`80061oo`006Goo0P0037oo0P00_goo0P00
H7oo000IOol00`00Oomoo`0;Ool2002oOol2001POol001Uoo`03001oogoo00]oo`800;moo`80061o
o`006Goo00<007ooOol02goo0P00_goo0P00H7oo000IOol00`00Oomoo`0;Ool2002oOol2001POol0
01Uoo`03001oogoo00]oo`800;moo`80061oo`006Goo00<007ooOol02goo0P00_goo0P00H7oo000B
Ool20005Ool00`00Oomoo`0;Ool2002oOol2001POol0015oo`04001oogoo0004Ool00`00Oomoo`0;
Ool2002oOol2001POol0015oo`04001oogoo0004Ool3000:Ool3002oOom2000POol0019oo`8000Eo
o`03001oogoo00Yoo`<00;mood80021oo`004Goo00@007ooOol000Aoo`03001oogoo00Yoo`800?mo
o`5oo`80021oo`004Woo0P001Goo00<007ooOol02Woo0P00ogoo0Goo0P0087oo000IOol00`00Oomo
o`0:Ool2003oOol1Ool2000POol001Uoo`03001oogoo00Yoo`800?moo`5oo`80021oo`006Goo00<0
07ooOol02Woo0P00ogoo0Goo0P0087oo000IOol00`00Oomoo`0:Ool2003oOol1Ool2000POol001Uo
o`8000]oo`800?moo`5oo`80021oo`006Goo00<007ooOol02Woo0P00ogoo0Goo0P0087oo000IOol0
0`00Oomoo`0:Ool2003oOol1Ool2000POol001Uoo`03001oogoo00Yoo`800?moo`5oo`80021oo`00
6Goo00<007ooOol02Woo0P00ogoo0Goo0P0087oo000IOol00`00Oomoo`0:Ool2003oOol1Ool2000P
Ool001Uoo`03001oogoo00Yoo`800?moo`5oo`80021oo`006Goo00<007ooOol02Woo0P00ogoo0Goo
0P0087oo000IOol00`00Oomoo`0:Ool2003oOol1Ool2000POol001Uoo`8000Yoo`<00?moo`5oo`D0
01eoo`006Goo00<007ooOol02Goo0`00ogoo0Goo1@007Goo000IOol00`00Oomoo`09Ool2003oOolT
Ool001Uoo`03001oogoo00Uoo`800?moobAoo`006Goo00<007ooOol02Goo0P00ogoo97oo000IOol0
0`00Oomoo`09Ool2003oOolTOol001Uoo`03001oogoo00Uoo`800?moobAoo`006Goo00<007ooOol0
2Goo0P00ogoo97oo000IOol2000:Ool2003oOolTOol001Uoo`03001oogoo00Uoo`800?moobAoo`00
6Goo00<007ooOol02Goo0P00ogoo97oo000IOol00`00Oomoo`09Ool2003oOolTOol001Uoo`03001o
ogoo00Uoo`800?moobAoo`006Goo00<007ooOol02Goo0P00ogoo97oo000IOol00`00Oomoo`09Ool2
003oOolTOol000]oo`D0009oo`8000Eoo`03001oogoo00Uoo`800?moobAoo`003Goo00D007ooOomo
o`00009oo`03001oogoo009oo`03001oogoo00Uoo`800?moobAoo`003Goo00D007ooOomoo`00009o
o`03001oogoo009oo`<000Qoo`<00?moobAoo`003Goo00D007ooOomoo`00009oo`03001oogoo00eo
o`<00?moobAoo`003Goo00D007ooOomoo`00009oo`03001oogoo0?moocAoo`0037oo0P0017oo0P00
ogoo=goo003oOom;Ool00?mood]oo`00ogooBgoo003oOom;Ool00?mood]oo`005goo0`00ogoo<Goo
000JOol00`00Oomoo`3oOol^Ool0015oo`800003Ool00000009oo`<000=oo`<00?moobYoo`004Goo
00L007ooOomoo`00Ool00002Ool01000Oomoo`00ogoo;Goo000BOol30002Ool01000Oomoo`000Woo
1000ogoo:Woo000BOol00`00Ool00003Ool40002Ool2003oOol[Ool001=oo`03001oogoo0?moocEo
o`004Woo0P00ogoo=goo003oOom;Ool00?mood]oo`00ogooBgoo0000\
\>"],
  ImageRangeCache->{{{0, 329.875}, {203.5, 0}} -> {-0.092254, -0.727541, \
0.0036068, 0.0583593}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(SetDirectory["\<c:/temp\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<seqplot1.eps\>", 
        seqplot1, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<seqplot2.eps\>", seqplot2, "\<EPS\>"];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(computemax[ .4,  .95];\)\), "\[IndentingNewLine]", 
    \(TFRNFRAge[ .8,  .95]\), "\[IndentingNewLine]", 
    \(Table[
      Birth[t, n, c], {t, 0, K}, {n, 0, nmax - 1}, {c, 0, 1}]\)}], "Input"],

Cell[BoxData[
    \({3.4704`, 2.637504`, 4}\)], "Output"],

Cell[BoxData[
    \({{{0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{0, 
          0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{0, 
          0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{0, 
          0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 
          0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 
          0}, {1, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 
          1}, {1, 0}, {1, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 
          1}, {1, 0}, {1, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 
          1}, {1, 1}, {1, 1}, {1, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 
          0}}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 52, 0, 115, "Title"],
Cell[1782, 54, 93, 2, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1900, 60, 24, 0, 59, "Section"],
Cell[1927, 62, 231, 4, 52, "Text"],
Cell[2161, 68, 91, 2, 50, "Input"],
Cell[2255, 72, 37, 0, 33, "Text"],
Cell[2295, 74, 84, 1, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2416, 80, 40, 0, 59, "Section"],
Cell[2459, 82, 65, 0, 33, "Text"],
Cell[2527, 84, 4894, 78, 1310, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7458, 167, 61, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[7544, 171, 4557, 80, 1385, "Input"],
Cell[12104, 253, 221, 5, 24, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12374, 264, 40, 0, 59, "Section"],
Cell[12417, 266, 298, 5, 140, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12752, 276, 41, 0, 59, "Section"],
Cell[12796, 278, 69, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[12890, 282, 892, 17, 290, "Input"],
Cell[13785, 301, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13874, 307, 67, 1, 30, "Input"],
Cell[13944, 310, 43, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14024, 316, 602, 9, 90, "Input"],
Cell[14629, 327, 65, 1, 29, "Output"],
Cell[14697, 330, 62, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14796, 336, 887, 17, 290, "Input"],
Cell[15686, 355, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15775, 361, 26, 0, 30, "Input"],
Cell[15804, 363, 37, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15878, 369, 711, 12, 110, "Input"],
Cell[16592, 383, 37, 1, 29, "Output"],
Cell[16632, 386, 75, 1, 29, "Output"],
Cell[16710, 389, 56, 1, 29, "Output"],
Cell[16769, 392, 49, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16855, 398, 557, 9, 70, "Input"],
Cell[17415, 409, 21938, 755, 186, 9139, 592, "GraphicsData", "PostScript", \
"Graphics"],
Cell[39356, 1166, 130, 3, 29, "Output"]
}, Open  ]],
Cell[39501, 1172, 156, 2, 50, "Input"],

Cell[CellGroupData[{
Cell[39682, 1178, 461, 8, 70, "Input"],
Cell[40146, 1188, 14647, 498, 213, 5919, 386, "GraphicsData", "PostScript", \
"Graphics"],
Cell[54796, 1688, 130, 3, 29, "Output"]
}, Open  ]],
Cell[54941, 1694, 248, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[55214, 1702, 217, 4, 70, "Input"],
Cell[55434, 1708, 57, 1, 29, "Output"],
Cell[55494, 1711, 727, 10, 105, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

