(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    303648,      12243]*)
(*NotebookOutlinePosition[    304292,      12265]*)
(*  CellTagsIndexPosition[    304248,      12261]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mortality in the Barro-Becker Model", "Title"],

Cell["\<\
This is the sequential choice model that is used in the paper.\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Setup", "Section"],

Cell["\<\
Setting up some fixed parameters. Notice that T-K has to be at least equal to \
two; otherwise people have births until the last period and their are \
children left who did not have a chance to die yet.prob\
\>", "Text"],

Cell[BoxData[{
    \(\(T = 14;\)\), "\[IndentingNewLine]", 
    \(\(K = 12;\)\)}], "Input"],

Cell["The utility function:", "Text"],

Cell[BoxData[
    \(\(u[c_] := c\^\(1 - \[Sigma]\)\/\(1 - \[Sigma]\);\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the Optimum", "Section"],

Cell["The prodedure for computing the optimal solution:", "Text"],

Cell[BoxData[
    \(computemax[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]par = 
          Join[prepar, {si \[Rule] sin, 
              sc \[Rule] scin}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          Here\ nmax\ is\ K\ because\ old\ children\ cause\ no\ cost\ \
*) \[IndentingNewLine]\[IndentingNewLine]nmax = 
          K; \[IndentingNewLine]\[IndentingNewLine]For[n = 0, 
          n \[LessEqual] nmax, \(n++\), 
          Util[T, n, 0] = \[Beta]\ n\^\[Epsilon]\ V /. 
              par]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          The\ following\ loop\ performs\ the\ backward\ induction\ \
*) \[IndentingNewLine] (*\ First\ the\ non - fecund, \ 
          than\ the\ fecund\ period\ *) \[IndentingNewLine] (*\ 
          Order\ of\ \(indeces : \ Period\), \ old\ children, \ 
          young\ children\ *) \[IndentingNewLine]\[IndentingNewLine]For[
          j = 1, j < T - K, \(j++\), \[IndentingNewLine]For[n = 0, 
            n < nmax, \(n++\), \[IndentingNewLine]Util[T - j, n, 0] = 
              u[w] + \[Gamma]\ \ Util[T - j + 1, n, 0] /. 
                par; \[IndentingNewLine]Util[T - j, n, 1] = 
              u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) Util[T - j + 1, n, 0])\) /. 
                par;\[IndentingNewLine]]; \[IndentingNewLine]Util[T - j, 
              nmax, 0] = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax, 0] /. 
              par;\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine] (*\ In\ the\ fecund\ period, \ 
          fertility\ choice\ only\ if\ n\ is\ less\ than\ max\ \
*) \[IndentingNewLine]\[IndentingNewLine]For[j = T - K, 
          j \[LessEqual] T, \(j++\), \[IndentingNewLine]For[n = 0, 
            n < nmax - 
                1, \(n++\), \[IndentingNewLine]\[IndentingNewLine]Ubirthchild \
= u[w - q - p] + \[Gamma]\ \((sc\ si\ Util[T - j + 1, n + 1, 
                            1] + \((1 - sc)\) si\ Util[T - j + 1, n, 1] + 
                        sc \((1 - si)\)\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) \((1 - si)\) 
                          Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Unobirthchild = 
              u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, n + 1, 
                            0] + \((1 - sc)\) Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Ubirthnochild = 
              u[w - q] + \[Gamma]\ \((si\ Util[T - j + 1, n, 
                            1] + \((1 - si)\) Util[T - j + 1, n, 0])\) /. 
                par; \[IndentingNewLine]\[IndentingNewLine]Unobirthnochild = 
              u[w] + \[Gamma]\ \ Util[T - j + 1, n, 0] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]If[
              Ubirthchild > Unobirthchild, Birth[T - j, n, 1] = 1, 
              Birth[T - j, n, 1] = 0]; \[IndentingNewLine]If[
              Ubirthnochild > Unobirthnochild, Birth[T - j, n, 0] = 1, 
              Birth[T - j, n, 0] = 
                0]; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, n, 0] = 
              Max[Ubirthnochild, Unobirthnochild]; \[IndentingNewLine]Util[
                T - j, n, 1] = 
              Max[Ubirthchild, 
                Unobirthchild];\[IndentingNewLine]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine] (*\ 
            nmax - 1\ and\ nmax\ are\ done\ separately, \ 
            because\ a\ birth\ may\ not\ be\ possible\ *) \[IndentingNewLine]\
\[IndentingNewLine]Unobirthchild = 
            u[w - p\ ] + \[Gamma]\ \((sc\ Util[T - j + 1, nmax, 
                          0] + \((1 - sc)\) Util[T - j + 1, nmax - 1, 0])\) /. 
              par; \[IndentingNewLine]\[IndentingNewLine]Ubirthnochild = 
            u[w - q] + \[Gamma]\ \((si\ Util[T - j + 1, nmax - 1, 
                          1] + \((1 - si)\) Util[T - j + 1, nmax - 1, 0])\) /. 
              par; \[IndentingNewLine]\[IndentingNewLine]Unobirthnochild = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax - 1, 0] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]If[
            Ubirthnochild > Unobirthnochild, Birth[T - j, nmax - 1, 0] = 1, 
            Birth[T - j, nmax - 1, 0] = 
              0]; \[IndentingNewLine]\[IndentingNewLine]Birth[T - j, 
              nmax - 1, 1] = 
            0; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, nmax - 1, 
              0] = Max[Ubirthnochild, 
              Unobirthnochild]; \[IndentingNewLine]Util[T - j, nmax - 1, 1] = 
            Unobirthchild; \[IndentingNewLine]\[IndentingNewLine]Birth[T - j, 
              nmax, 0] = 0; \[IndentingNewLine]Birth[T - j, nmax, 1] = 
            0; \[IndentingNewLine]\[IndentingNewLine]Util[T - j, nmax, 0] = 
            u[w] + \[Gamma]\ \ Util[T - j + 1, nmax, 0] /. 
              par;\[IndentingNewLine]];\[IndentingNewLine]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing Fertility and Reproduction Rates", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComputeFertility[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]par = 
          Join[prepar, {si \[Rule] sin, 
              sc \[Rule] scin}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          In\ the\ initial\ period, \ 
          zero\ children\ for\ sure\ \
*) \[IndentingNewLine]\[IndentingNewLine]ageatfirstchild = 
          0; \[IndentingNewLine]\[IndentingNewLine]prob[0, 0, 0] = 
          1; \[IndentingNewLine]For[n = 1, n \[LessEqual] nmax, \(n++\), 
          prob[0, n, 0] = 0]; \[IndentingNewLine]For[n = 0, 
          n \[LessEqual] nmax, \(n++\), 
          prob[0, n, 1] = 0]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
          The\ following\ loops\ moves\ forward\ in\ time\ \
*) \[IndentingNewLine] (*\ First\ the\ fecund, \ 
          than\ the\ non - fecund\ period\ *) \[IndentingNewLine] (*\ 
          Order\ of\ \(indeces : \ Period\), \ old\ children, \ 
          young\ children\ *) \[IndentingNewLine] (*\ 
          n = 0\ \((at\ least)\)\ will\ have\ to\ be\ done\ separately\ \
*) \[IndentingNewLine]\[IndentingNewLine]For[j = 0, 
          j \[LessEqual] 
            K, \(j++\), \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Age\ at\ first\ birth\ \
*) \[IndentingNewLine]If[\((ageatfirstchild \[Equal] 
                    0)\) && \((Birth[j, 0, 0] == 1)\), 
              ageatfirstchild = j]\[IndentingNewLine]\[IndentingNewLine] (*\ 
              Expected\ number\ of\ children\ \((born\ previously)\)\ and\ \
expected\ number\ of\ births\ *) \[IndentingNewLine]\[IndentingNewLine]\(FR[
                j] = \[Sum]\+\(n = 0\)\%nmax\((prob[j, n, 0] Birth[j, n, 0] + 
                    prob[j, n, 1] 
                      Birth[j, n, 1])\)\); \[IndentingNewLine]Eofn[
              j] = \[Sum]\+\(n = 0\)\%nmax\((n\ prob[j, n, 0] + \((n + 1)\) 
                    prob[j, n, 1])\); \[IndentingNewLine] (*\ 
            First\ the\ n = 0\ case, \ 
            the\ loop\ below\ does\ the\ rest\ *) \[IndentingNewLine]\
\[IndentingNewLine]prob[j + 1, 0, 
              0] = \((1 - si\ Birth[j, 0, 0])\) 
                  prob[j, 0, 0] + \((1 - si\ Birth[j, 0, 1])\) \((1 - sc)\) 
                  prob[j, 0, 1] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, 0, 1] = 
            si\ Birth[j, 0, 0] prob[j, 0, 0] + 
                si\ Birth[j, 0, 1] \((1 - sc)\) prob[j, 0, 1] /. 
              
              par; \[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]\
For[n = 1, 
            n \[LessEqual] 
              nmax, \(n++\), \[IndentingNewLine]\[IndentingNewLine]prob[
                j + 1, n, 
                0] = \((1 - si\ Birth[j, n, 0])\) 
                    prob[j, n, 0] + \((1 - si\ Birth[j, n, 1])\) \((1 - sc)\) 
                    prob[j, n, 1] + \((1 - si\ Birth[j, n - 1, 1])\) 
                    sc\ prob[j, n - 1, 1] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, n, 
                1] = si\ Birth[j, n, 0] prob[j, n, 0] + 
                  si\ Birth[j, n, 1] \((1 - sc)\) prob[j, n, 1] + 
                  si\ Birth[j, n - 1, 1] sc\ prob[j, n - 1, 1] /. 
                par;\[IndentingNewLine]];\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]For[j = K + 1, 
          j \[LessEqual] 
            T, \(j++\), \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Fertility\ Rates\ and\ Expected\ number\ of\ children\ \((born\ \
previously)\)\ *) \[IndentingNewLine]\[IndentingNewLine]FR[j] = 
            0; \[IndentingNewLine]Eofn[
              j] = \[Sum]\+\(n = 0\)\%nmax\((n\ prob[j, n, 0] + \((n + 1)\) 
                    prob[j, n, 
                      1])\); \[IndentingNewLine]\[IndentingNewLine] (*\ 
            First\ the\ n = 0\ case, \ 
            the\ loop\ below\ does\ the\ rest\ *) \[IndentingNewLine]\
\[IndentingNewLine]prob[j + 1, 0, 0] = 
            prob[j, 0, 0] + \((1 - sc)\) prob[j, 0, 1] /. 
              par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, 0, 1] = 
            0 /. par; \[IndentingNewLine]\[IndentingNewLine]For[n = 1, 
            n \[LessEqual] 
              nmax, \(n++\), \[IndentingNewLine]\[IndentingNewLine]prob[
                j + 1, n, 0] = 
              prob[j, n, 0] + \((1 - sc)\) prob[j, n, 1] + 
                  sc\ prob[j, n - 1, 1] /. 
                par; \[IndentingNewLine]\[IndentingNewLine]prob[j + 1, n, 
                1] = 0 /. 
                par;\[IndentingNewLine]];\[IndentingNewLine]\
\[IndentingNewLine]];\[IndentingNewLine]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"prob\" is similar to \
existing symbol \"prob\"."\)], "Message",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing TFR and NFR", "Section"],

Cell[BoxData[
    \(TFRNFRAge[sin_, scin_] := 
      Module[{local}, \[IndentingNewLine]computemax[sin, 
          scin]; \[IndentingNewLine]ComputeFertility[sin, 
          scin]; \[IndentingNewLine]{\[Sum]\+\(j = 0\)\%T FR[j], Eofn[T], 
          ageatfirstchild}\[IndentingNewLine]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Actual Computation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(NTarget = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(iind = 1;\)\), "\[IndentingNewLine]", 
    \(\(jind = 1;\)\), "\[IndentingNewLine]", 
    \(\(While[
        iind < 5, \[IndentingNewLine]While[
          jind < 5, \[IndentingNewLine]\[IndentingNewLine]sigmaset =  .01 + \
\((iind - 1)\)\  .98/
                  4; \[IndentingNewLine]epsset =  .01 + \((jind - 1)\)\  .98/
                  4; \[IndentingNewLine]\[IndentingNewLine]Vlo = 
            0; \[IndentingNewLine]Vset = 0.5; \[IndentingNewLine]Vhi = 
            1000; \[IndentingNewLine]\[IndentingNewLine]it = 
            1; \[IndentingNewLine]While[
              it < 30, \[IndentingNewLine]Clear[Util, Birth, prob, 
                FR]; \[IndentingNewLine]prepar = {\[Sigma] \[Rule] 
                    sigmaset, \[Epsilon] \[Rule] epsset, \[Beta] \[Rule] 
                    1, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, q \[Rule] 1/12, 
                  V \[Rule] Vset, 
                  w \[Rule] 
                    1}; \[IndentingNewLine]\[IndentingNewLine]If[\(TFRNFRAge[ \
.73, 1]\)[\([1]\)] > NTarget, Vhi = Vset; Vset =  .5\ Vset\  + \  .5\ Vlo, 
                Vlo = Vset; 
                Vset =  .5\ Vset\  + \  .5\ Vhi]; \[IndentingNewLine]\
\[IndentingNewLine]it = 
                it + 1;\[IndentingNewLine]]\[IndentingNewLine]\
\[IndentingNewLine]Print[
              Vset]; \[IndentingNewLine]\[IndentingNewLine]prepar = {\[Sigma] \
\[Rule] sigmaset, \[Epsilon] \[Rule] epsset, \[Beta] \[Rule] 
                1, \[Gamma] \[Rule]  .95, p \[Rule] 5/12, q \[Rule] 1/12, 
              V \[Rule] Vset, 
              w \[Rule] 
                1}; \[IndentingNewLine]Print[{\(TFRNFRAge[ .73, 
                  1]\)[\([1]\)], \(TFRNFRAge[ .73, 
                  1]\)[\([2]\)], \(TFRNFRAge[ .73, 
                  1]\)[\([3]\)]}]; \[IndentingNewLine]Print[{\(TFRNFRAge[ \
.965, 1]\)[\([1]\)], \(TFRNFRAge[ .965, 1]\)[\([2]\)], \(TFRNFRAge[ .965, 
                  1]\)[\([3]\)]}]; \
\[IndentingNewLine]\[IndentingNewLine]Plot[{\(TFRNFRAge[s, 
                  1]\)[\([1]\)], \(TFRNFRAge[s, 1]\)[\([2]\)]}, {s, 
              0.06,  .99}, PlotRange \[Rule] {{0, 1}, {0, 11}}, 
            AxesLabel \[Rule] {"\<s\>", "\<Children\>"}, 
            PlotStyle \[Rule] {{Thickness[ .008]}, {Dashing[{ .02,  .02}], 
                  Thickness[ .008]}}]; \
\[IndentingNewLine]\[IndentingNewLine]jind = 
            jind + 1;\[IndentingNewLine]]; \[IndentingNewLine]jind = 
          1; \[IndentingNewLine]iind = 
          iind + 1;\[IndentingNewLine]];\)\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(jind\)\" is similar to \
existing symbol \"\!\(iind\)\"."\)], "Message"],

Cell[BoxData[
    \(250.2930417722091`\)], "Print"],

Cell[BoxData[
    \({4.961540021611`, 3.6219242157760303`, 6}\)], "Print"],

Cell[BoxData[
    \({4.`, 3.86`, 9}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .5175 m
.07837 .53455 L
.08772 .54452 L
.09019 .54024 L
.09086 .53908 L
.09158 .53785 L
.09286 .56015 L
.09406 .55823 L
.09518 .55643 L
.09773 .55237 L
.10029 .54832 L
.10171 .5461 L
.1024 .54501 L
.10305 .544 L
.10426 .5633 L
.1049 .56233 L
.10558 .5613 L
.10789 .55782 L
.11244 .55102 L
.11736 .54374 L
.11883 .54158 L
.11964 .54041 L
.12039 .53931 L
.12103 .55426 L
.12172 .55326 L
.12248 .55379 L
.12317 .55278 L
.12864 .54484 L
.13887 .53021 L
.14791 .51753 L
.15286 .51068 L
.15529 .50736 L
.15635 .50591 L
.15751 .50432 L
.15868 .52443 L
.15992 .5408 L
.16057 .54003 L
.16126 .5392 L
.16251 .53772 L
.16804 .5327 L
.17066 .52961 L
.17314 .5267 L
.17537 .5241 L
.17662 .52264 L
.17778 .54074 L
.179 .54306 L
.18017 .54185 L
.18234 .53958 L
.18725 .53452 L
.1961 .52546 L
Mistroke
.20077 .52074 L
.20334 .51817 L
.20459 .51691 L
.20575 .51576 L
.20642 .51509 L
.20712 .52868 L
.20783 .528 L
.20861 .53072 L
.20926 .53011 L
.20995 .52946 L
.2112 .52828 L
.21626 .52353 L
.23564 .50564 L
.2567 .48678 L
.26652 .4782 L
.27695 .46926 L
.28123 .46564 L
.28348 .46374 L
.28471 .46272 L
.28585 .46176 L
.28711 .46963 L
.28778 .46907 L
.28849 .46848 L
.29091 .46646 L
.29219 .4654 L
.2934 .4644 L
.29448 .46351 L
.29566 .46536 L
.29687 .46436 L
.29797 .46344 L
.30045 .46139 L
.30492 .45771 L
.31021 .45339 L
.3151 .44943 L
.31755 .44746 L
.31879 .44647 L
.3195 .46712 L
.32016 .46666 L
.32083 .4662 L
.32154 .47368 L
.3228 .47283 L
.32351 .47236 L
.32417 .47103 L
.32489 .47056 L
.32566 .47005 L
.32695 .46919 L
.32835 .46827 L
.329 .46785 L
.32968 .4674 L
.3309 .45039 L
Mistroke
.33207 .4497 L
.33317 .44904 L
.33567 .44756 L
.37355 .42602 L
.38342 .42067 L
.38864 .41788 L
.3942 .41495 L
.39695 .41351 L
.3983 .4128 L
.39954 .41216 L
.40067 .41157 L
.40186 .41945 L
.40306 .41886 L
.40374 .41853 L
.40438 .41821 L
.40561 .42467 L
.40674 .42413 L
.40926 .42292 L
.41382 .42074 L
.45127 .40342 L
.47021 .39503 L
.48027 .39002 L
.48556 .3878 L
.49111 .38548 L
.4935 .38419 L
.49481 .38365 L
.49605 .38314 L
.49675 .36562 L
.49751 .36536 L
.49884 .36491 L
.50144 .36403 L
.5109 .36025 L
.52948 .35425 L
.53873 .35129 L
.54126 .35048 L
.54266 .35004 L
.54335 .34982 L
.54398 .34962 L
.54521 .33953 L
.54586 .33933 L
.54655 .33913 L
.5489 .33843 L
.56945 .3319 L
.61013 .31989 L
.63056 .3145 L
.64932 .3085 L
.65883 .30616 L
.66346 .30502 L
.66768 .30398 L
.66878 .3037 L
Mistroke
.66997 .30341 L
.6711 .30313 L
.67214 .30195 L
.67325 .30169 L
.67446 .3014 L
.67573 .28982 L
.67692 .2896 L
.68704 .28769 L
.70513 .28318 L
.71469 .28149 L
.71994 .28056 L
.72489 .27968 L
.72758 .2792 L
.72832 .27906 L
.7291 .27893 L
.72977 .27881 L
.7305 .30015 L
.73177 .30004 L
.73313 .29992 L
.73558 .29971 L
.74552 .29886 L
.75078 .29842 L
.75577 .298 L
.76026 .29762 L
.76148 .29752 L
.76279 .29741 L
.7639 .29732 L
.76513 .29412 L
.76632 .29405 L
.76742 .29399 L
.76993 .29385 L
.77498 .29357 L
.78401 .29306 L
.80438 .29192 L
.81465 .29134 L
.82434 .29079 L
.82857 .29056 L
.83089 .29043 L
.83305 .2903 L
.83418 .29024 L
.83539 .28092 L
.83608 .28092 L
.83673 .28092 L
.83796 .28092 L
.84249 .28092 L
.85187 .28092 L
.85702 .28092 L
.86186 .28092 L
.86639 .28092 L
.86763 .28092 L
Mistroke
.86831 .28092 L
.86894 .28092 L
.87006 .23204 L
.87129 .23197 L
.87983 .23149 L
.89005 .23092 L
.89973 .23037 L
.90395 .23014 L
.90625 .23001 L
.90842 .22989 L
.90954 .22982 L
.91075 .22474 L
.91141 .22474 L
.9121 .22474 L
.91333 .22474 L
.91786 .22474 L
.95511 .22474 L
.99 .22474 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .03105 m
.09773 .05398 L
.13887 .07363 L
.17751 .09604 L
.19697 .10333 L
.20109 .10465 L
.20335 .10537 L
.20445 .10571 L
.20546 .10603 L
.20656 .10931 L
.20774 .10971 L
.20903 .11085 L
.21025 .11126 L
.21468 .11271 L
.2245 .11581 L
.23379 .11861 L
.25423 .12431 L
.29153 .13584 L
.33122 .14912 L
.36943 .15822 L
.37947 .16044 L
.39034 .16276 L
.39533 .1638 L
.39805 .16437 L
.39938 .16464 L
.4006 .16489 L
.40171 .16853 L
.40277 .16876 L
.4039 .16901 L
.40509 .16927 L
.40632 .17242 L
.40746 .17267 L
.41003 .17326 L
.4469 .18117 L
.46738 .18521 L
.47635 .18657 L
.48616 .18841 L
.49076 .18925 L
.49198 .18947 L
.49267 .18945 L
.4933 .18956 L
.49444 .18977 L
.49569 .18999 L
.49686 .18164 L
.49795 .18186 L
.50034 .18232 L
.50456 .18314 L
.52393 .18654 L
.5341 .18841 L
.5391 .18932 L
Mistroke
.54154 .18975 L
.5426 .18994 L
.54374 .19015 L
.54487 .18505 L
.54591 .18524 L
.54794 .18559 L
.54898 .18578 L
.55011 .18562 L
.5513 .18584 L
.5524 .18603 L
.56185 .18769 L
.59989 .19353 L
.61927 .1966 L
.64033 .19975 L
.64277 .2001 L
.64405 .20028 L
.64475 .20038 L
.6454 .20048 L
.64659 .19991 L
.64721 .2 L
.64788 .2001 L
.65016 .20044 L
.65511 .20117 L
.66058 .20196 L
.66563 .20267 L
.66811 .20302 L
.66919 .20317 L
.67039 .20333 L
.67146 .20348 L
.67247 .203 L
.67353 .20315 L
.67466 .20331 L
.67591 .19587 L
.67708 .19606 L
.67929 .19642 L
.69706 .19922 L
.69943 .19958 L
.70072 .19978 L
.70193 .19996 L
.70256 .19927 L
.70323 .19938 L
.70467 .19961 L
.70718 .20001 L
.71669 .20149 L
.72188 .20228 L
.72443 .20267 L
.72679 .20302 L
.72789 .20319 L
.72893 .20334 L
.73001 .21914 L
Mistroke
.73119 .21942 L
.73597 .22055 L
.75648 .22538 L
.79436 .23233 L
.80424 .23478 L
.81501 .23743 L
.81994 .23864 L
.82519 .23992 L
.82774 .24054 L
.83015 .24113 L
.8323 .24166 L
.83352 .24195 L
.83464 .23447 L
.83587 .23482 L
.83704 .23514 L
.83923 .23576 L
.84415 .23714 L
.85303 .23964 L
.8627 .24235 L
.86535 .2431 L
.8668 .24351 L
.86751 .24371 L
.86816 .24389 L
.86932 .20175 L
.87056 .20198 L
.87321 .20247 L
.89171 .20583 L
.89677 .20674 L
.90218 .20771 L
.90481 .20819 L
.90729 .20863 L
.90837 .20882 L
.90952 .20903 L
.91077 .20469 L
.91193 .20495 L
.94894 .21327 L
.98835 .22212 L
.99 .22249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo00]oo`03001oogoo0?5oo`007Woo00<007ooOol037oo0P00lGoo000NOol00`00Oomo
o`0>Ool00`00Oomoo`3^Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`0BOol3003ZOol001ioo`03001oogoo01Eoo`800>Qoo`007Woo00<007ooOol05goo00<007oo
Ool0iGoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo01]oo`03001oogoo0>5oo`007Woo00<0
07ooOol077oo0P00hGoo000NOol00`00Oomoo`0NOol2003OOol001ioo`03001oogoo0?moo`007Woo
00<007ooOol08goo00<007ooOol0fGoo000NOol00`00Oomoo`0TOol2003IOol001ioo`03001oogoo
02Ioo`800=Moo`007Woo00<007ooOol09goo00<007ooOol0eGoo000FOol40004Ool00`00Oomoo`0/
Ool2003AOol001Ioo`03001oogoo00Eoo`03001oogoo02eoo`03001oogoo0<moo`005goo00<007oo
Ool017oo0P00;goo0`00cWoo000HOol00`00Oomoo`03Ool00`00Oomoo`3oOol001Ioo`04001oogoo
0004Ool00`00Oomoo`0dOol30038Ool001Moo`8000Eoo`03001oogoo03Moo`<00<Eoo`007Woo00<0
07ooOol0?Goo0P00`7oo000NOol00`00Oomoo`0oOol2002nOol001ioo`03001oogoo045oo`800;ao
o`007Woo00<007ooOol0AWoo0P00]goo000NOol00`00Oomoo`18Ool2002eOol001ioo`03001oogoo
04Yoo`800;=oo`007Woo00<007ooOol0Cgoo0`00[Goo000NOol00`00Oomoo`1BOol3002ZOol001io
o`03001oogoo05Uoo`<00:=oo`007Woo00<007ooOol0Fgoo0P00XWoo000NOol00`00Oomoo`1LOol2
002QOol001ioo`03001oogoo065oo`8009aoo`007Woo00<007ooOol0Hgoo0`00VGoo000NOol00`00
Oomoo`1ZOol20006Ool50028Ool001ioo`03001oogoo06aoo`@000]oo`8000=oo`D007Yoo`007Woo
00<007ooOol0RGoo1000LWoo000NOol00`00Oomoo`2=Ool2000>Ool3001OOol001ioo`03001oogoo
099oo`H000Aoo`03001oogoo00Eoo`D0029oo`03001oogoo035oo`007Woo00<007ooOol0W7oo00<0
07ooOol02Goo00<007ooOol087oo0P001goo0P00:Goo000NOol00`00Oomoo`3:Ool00`00Oomoo`04
Ool40005Ool2000SOol001ioo`03001oogoo0<Yoo`03001oogoo00moo`<0021oo`0067oo0`000goo
00<007ooOol0ZGoo0P00>7oo0P006Woo000IOol00`00Oomoo`02Ool00`00Oomoo`3UOol3000GOol0
01Ioo`D000=oo`800:moo`D0025ooa@001Moo`005Woo00@007ooOol000Aoo`03001oogoo0;Moo`03
001oogoo01=oo`P002Yoo`005goo00<007oo000017oo00<007ooOol0^7oo1@001Goo0P001Woo0`00
<Woo000HOol20004Ool00`00Oomoo`30Ool00`00Ool00007Ool2000cOol001ioo`03001oogoo0<5o
o`8000Eoo`@003=oo`007Woo00<007ooOol0bgoo00<007ooOol0<Goo000NOol00`00Oomoo`3;Ool0
0`00Oomoo`0aOol001ioo`03001oogoo0<]oo`03001oogoo035oo`007Woo00<007ooOol0bWoo00<0
07ooOol0<Woo000NOol00`00Oomoo`3:Ool00`00Oomoo`0bOol001ioo`03001oogoo0<Yoo`03001o
ogoo039oo`007Woo00<007ooOol0bWoo00<007ooOol0<Woo000NOol00`00Oomoo`3:Ool00`00Oomo
o`0bOol001ioo`03001oogoo0:Ioo`@001Uoo`P003Aoo`007Woo00<007ooOol0XWoo10000goo00<0
07ooOol05Woo00<007ooOol0>Woo000NOol00`00Oomoo`2MOol50007Ool00`00Oomoo`0DOol3000l
Ool001ioo`03001oogoo09eoo`03001oogoo00Yoo`03001oogoo00Eoo`h003moo`007Woo00<007oo
Ool0W7oo00<007ooOol02goo00<007ooOol01P00C7oo000NOol00`00Oomoo`2KOol2000=Ool3001B
Ool001ioo`03001oogoo09Qoo`@006=oo`007Woo00<007ooOol0UGoo0`00Igoo000NOol00`00Oomo
o`2@Ool5001ZOol001ioo`03001oogoo08aoo`@006moo`007Woo00<007ooOol0RGoo0`00Lgoo000F
Ool30005Ool00`00Oomoo`26Ool3001fOol001Ioo`04001oogoo0004Ool00`00Oomoo`23Ool3001i
Ool001Ioo`04001oogoo0004Ool20022Ool2001lOol001Ioo`<000Eoo`03001oogoo07ioo`<007io
o`005goo00<007ooOol017oo00<007ooOol0OGoo00<007ooOol0Ogoo000GOol30004Ool00`00Oomo
o`1mOol00`00Oomoo`1oOol001ioo`03001oogoo07Yoo`@0085oo`007Woo00<007ooOol0N7oo0P00
QGoo000NOol00`00Oomoo`1eOol30027Ool001ioo`03001oogoo079oo`<008Yoo`007Woo00<007oo
Ool0LWoo00<007ooOol0RWoo000NOol00`00Oomoo`1bOol00`00Oomoo`2:Ool001ioo`03001oogoo
079oo`03001oogoo08Yoo`007Woo00<007ooOol0LWoo00<007ooOol0RWoo000NOol00`00Oomoo`1`
Ool2002=Ool001ioo`03001oogoo06ioo`8008moo`007Woo00<007ooOol0Jgoo0`00TGoo000NOol0
0`00Oomoo`1YOol2002DOol001ioo`03001oogoo06Moo`8009Ioo`007Woo00<007ooOol0IGoo0P00
V7oo000NOol00`00Oomoo`1KOol00`00Oomoo`05Ool2002JOol001ioo`03001oogoo05Yoo`8000Eo
o`8009aoo`007Woo00<007ooOol0Egoo0`000Woo00<007ooOol00P00WWoo000NOol00`00Oomoo`1E
Ool20006Ool2002POol001ioo`03001oogoo05=oo`800:Yoo`007Woo00<007ooOol0DWoo00<007oo
Ool0ZWoo000NOol00`00Oomoo`1@Ool2002]Ool001Moo`8000Eoo`03001oogoo04moo`03001oogoo
0:eoo`005Woo00@007ooOol000Aoo`03001oogoo04Qoo`03001oogoo009oo`800;1oo`005Woo00@0
07ooOol000Aoo`8004Qoo`80009oo`800;9oo`005goo0P001Goo00<007ooOol0AWoo00<007oo0000
0Woo00<007ooOol0/Goo000FOol01000Oomoo`0017oo00<007ooOol0AGoo00@007ooOol0009oo`03
001oogoo0;5oo`005goo0P001Goo00<007ooOol0@7oo00<007oo00000P000goo00@007ooOol00;=o
o`007Woo00<007ooOol0?goo1@0017oo0P0000=oo`00Ool0/Woo000NOol00`00Oomoo`0nOol01000
Oomoo`001goo0P00]7oo000NOol00`00Oomoo`0mOol00`00Oomoo`09Ool00`00Oomoo`2cOol001io
o`03001oogoo03aoo`03001oogoo0<1oo`007Woo00<007ooOol0>Woo0P00`goo000NOol00`00Oomo
o`0iOol00`00Oomoo`33Ool001ioo`03001oogoo03Qoo`03001oogoo0<Aoo`007Woo00<007ooOol0
=Woo0P00agoo000NOol00`00Oomoo`0eOol00`00Oomoo`37Ool001ioo`03001oogoo029oo`03001o
ogoo00moo`03001oogoo0<Qoo`007Woo00<007ooOol08Goo0P0047oo00<007ooOol0bGoo000NOol0
0`00Oomoo`0QOol2000?Ool00`00Oomoo`3:Ool001ioo`03001oogoo00]oo`03001oogoo019oo`03
001oo`0000Yoo`03001oogoo009oo`03001oogoo0<Yoo`007Woo00<007ooOol037oo00<007ooOol0
47oo00@007ooOol000=oo`03001oogoo00=oo`8000=oo`03001oogoo0<]oo`007Woo00<007ooOol0
3Goo00<007ooOol03Woo00D007ooOomoo`0000=oo`03001oogoo009oo`06001oogoo001oo`00cWoo
000NOol00`00Oomoo`0>Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`020003Ool01000
Oomoogoo0P00cgoo000NOol00`00Oomoo`0?Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Ool0
0002Ool00`00Ool0003EOol001ioo`03001oogoo011oo`03001oo`0000Ioo`04001oogoo0005Ool2
0003Ool2003FOol001ioo`03001oogoo011oo`03001oo`00009oo`03001oogoo00800003Ool007oo
00Eoo`8000=oo`03001oogoo0=Eoo`007Woo00<007ooOol04Goo0P0000Uoo`00001oo`00Ool007oo
0000hgoo000NOol00`00Oomoo`0COol300000goo001oo`02003TOol0011oo`D0009oo`8000Eoo`03
001oogoo01=oo`04001oo`000002Ool2003TOol0019oo`05001oogooOol00002Ool00`00Oomoo`02
Ool00`00Oomoo`0COol01000Ool00000j7oo000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo
0P005Woo0P00j7oo000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0ogoo000B
Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0ogoo000AOol20004Ool20005Ool0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo0008Ool300001Goo00000000Ool00P000Woo0`000Woo0`0017oo
100000=oo`0000000P000goo0`0000=oo`0000000Woo0P00jWoo0007Ool00`00Oomoo`03Ool01000
Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`03
001oogoo00=oo`04001oogoo003[Ool000Moo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo10000Woo00@007ooOol00>]o
o`001goo00<007ooOol00goo0`0017oo0P0017oo00<007ooOol00goo0`000Woo10000goo0P000Woo
1000k7oo0007Ool01000Oomoo`000Woo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0ngoo
0008Ool300000goo00000007Ool01000Oomoogoo0P001Woo0P00oGoo003oOolQOol00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(7.354374189861119`\)], "Print"],

Cell[BoxData[
    \({5.27`, 3.8470999999999997`, 7}\)], "Print"],

Cell[BoxData[
    \({4.`, 3.86`, 9}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .5175 m
.06877 .49345 L
.07837 .46878 L
.08321 .45697 L
.08839 .44478 L
.0909 .43903 L
.09214 .43623 L
.09328 .43368 L
.09431 .46867 L
.09541 .46827 L
.09651 .46611 L
.09773 .46374 L
.09904 .4612 L
.10047 .45846 L
.10112 .45721 L
.10182 .45589 L
.10307 .48869 L
.10371 .48759 L
.10439 .48641 L
.10564 .48428 L
.10796 .48034 L
.11075 .47568 L
.11143 .47456 L
.11215 .47336 L
.11295 .50123 L
.1137 .50177 L
.11437 .50072 L
.11511 .49958 L
.11645 .49752 L
.11897 .49369 L
.12398 .48618 L
.1252 .48438 L
.12651 .48245 L
.12727 .48135 L
.12796 .50515 L
.12861 .5058 L
.12931 .50481 L
.13887 .49139 L
.14367 .48484 L
.14819 .47875 L
.14941 .47714 L
.1507 .47543 L
.15137 .49445 L
.15211 .49346 L
.15278 .49256 L
.15341 .49311 L
.1546 .49152 L
.15569 .49006 L
.15815 .48682 L
.16684 .47551 L
Mistroke
.1716 .46943 L
.17609 .46379 L
.17727 .46232 L
.17852 .46077 L
.17917 .48088 L
.17989 .4801 L
.18114 .48393 L
.18229 .48271 L
.18351 .48141 L
.18572 .47907 L
.19466 .46978 L
.19727 .46712 L
.19865 .46572 L
.20011 .46425 L
.20138 .46297 L
.20211 .47616 L
.20279 .47553 L
.20398 .47975 L
.20526 .47858 L
.20653 .47743 L
.20772 .47636 L
.20895 .49533 L
.2096 .49472 L
.2103 .49407 L
.21154 .49291 L
.21272 .49182 L
.21377 .49216 L
.21491 .4911 L
.25492 .46487 L
.26453 .45774 L
.26982 .45386 L
.27243 .45196 L
.27484 .4502 L
.2771 .44856 L
.27824 .44774 L
.2795 .439 L
.28075 .43818 L
.28211 .43731 L
.28457 .43572 L
.29345 .43003 L
.29832 .42693 L
.30286 .42405 L
.30514 .42261 L
.30642 .4218 L
.30759 .43139 L
.30886 .43974 L
.30959 .43936 L
.31025 .43902 L
.31277 .43771 L
.31721 .43541 L
Mistroke
.31939 .43429 L
.32138 .43327 L
.32245 .43272 L
.32347 .42388 L
.32454 .4234 L
.32572 .42288 L
.3305 .42077 L
.35133 .41166 L
.37021 .40353 L
.37135 .40304 L
.37259 .40252 L
.37375 .40202 L
.37481 .39303 L
.376 .3926 L
.37712 .39219 L
.37967 .39128 L
.38222 .39035 L
.38292 .3901 L
.38366 .38983 L
.3843 .39844 L
.385 .39821 L
.3899 .3966 L
.3945 .39508 L
.39692 .39429 L
.39823 .39385 L
.39946 .39345 L
.40054 .39309 L
.4017 .39001 L
.40298 .3896 L
.40414 .39653 L
.4052 .39621 L
.40635 .39586 L
.40843 .39523 L
.40962 .39487 L
.41074 .39452 L
.41136 .37511 L
.41203 .37492 L
.41322 .37457 L
.41769 .37327 L
.42024 .37253 L
.42098 .37232 L
.42167 .37212 L
.42229 .37194 L
.42297 .38175 L
.42421 .3814 L
.42552 .38103 L
.42786 .38036 L
.43031 .37966 L
.43166 .37928 L
.43293 .37891 L
Mistroke
.43412 .37857 L
.43541 .36954 L
.43658 .36928 L
.43767 .36903 L
.44841 .36655 L
.46824 .36189 L
.47795 .35957 L
.48683 .35744 L
.48894 .35692 L
.49009 .35664 L
.49118 .35638 L
.49181 .34698 L
.49248 .34682 L
.49365 .34654 L
.49594 .34599 L
.50462 .3439 L
.50712 .3433 L
.50946 .34273 L
.51064 .34245 L
.5119 .33316 L
.51262 .33303 L
.51331 .3329 L
.51458 .33266 L
.52376 .33094 L
.52862 .33002 L
.531 .32957 L
.53318 .32915 L
.5343 .32894 L
.53547 .33962 L
.53665 .33946 L
.53794 .3393 L
.54319 .33862 L
.56118 .33631 L
.58192 .33362 L
.59173 .33234 L
.59603 .33178 L
.59848 .33146 L
.60077 .33117 L
.60297 .33088 L
.60421 .33072 L
.60534 .31652 L
.60653 .31644 L
.60782 .31635 L
.61018 .31619 L
.62038 .31549 L
.63889 .31418 L
.64409 .3138 L
.64898 .31345 L
.65338 .31312 L
.65458 .31304 L
Mistroke
.65585 .31294 L
.65694 .3002 L
.65813 .30013 L
.67862 .29898 L
.6993 .29782 L
.71813 .29676 L
.72267 .29651 L
.72516 .29637 L
.72749 .29624 L
.72871 .29617 L
.72939 .29613 L
.73001 .28092 L
.73066 .28092 L
.73136 .28092 L
.73278 .28092 L
.73767 .28092 L
.75616 .28092 L
.79581 .28092 L
.83398 .28092 L
.85345 .28092 L
.87454 .28092 L
.88442 .28092 L
.89488 .28092 L
.89919 .28092 L
.90381 .28092 L
.90517 .28092 L
.90646 .28092 L
.90762 .28092 L
.90888 .22474 L
.91007 .22474 L
.91134 .22474 L
.91362 .22474 L
.95044 .22474 L
.98965 .22474 L
.99 .22474 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .03105 m
.06877 .03393 L
.07837 .03674 L
.08321 .03802 L
.08839 .03931 L
.0909 .03991 L
.09214 .04019 L
.09328 .04045 L
.09431 .0442 L
.09541 .04468 L
.09651 .04499 L
.09773 .04532 L
.09904 .04568 L
.10047 .04606 L
.10112 .04623 L
.10182 .04642 L
.10307 .05037 L
.10371 .05057 L
.10439 .05078 L
.10564 .05116 L
.10796 .05186 L
.11075 .05268 L
.11143 .05288 L
.11215 .05309 L
.11295 .05661 L
.1137 .05705 L
.11437 .05727 L
.11511 .05751 L
.11645 .05794 L
.11897 .05873 L
.12398 .06028 L
.1252 .06064 L
.12651 .06104 L
.12727 .06126 L
.12796 .06464 L
.12861 .06505 L
.12931 .06528 L
.13887 .06824 L
.14368 .06966 L
.14622 .07039 L
.1476 .07078 L
.1489 .07115 L
.15003 .07146 L
.15125 .07481 L
.15194 .07501 L
.1526 .0752 L
.15383 .07577 L
.15495 .07609 L
.156 .07639 L
.15837 .07705 L
Mistroke
.16767 .07955 L
.17171 .08058 L
.17609 .08167 L
.1773 .08196 L
.17858 .08227 L
.17967 .0863 L
.18086 .08758 L
.18199 .08791 L
.18319 .08825 L
.18536 .08887 L
.19523 .0916 L
.19787 .09231 L
.19926 .09268 L
.20074 .09306 L
.20202 .0934 L
.20276 .09642 L
.20344 .09662 L
.20465 .09805 L
.20532 .09825 L
.20594 .09843 L
.20704 .09875 L
.20821 .09909 L
.2095 .10366 L
.2107 .10402 L
.21569 .10577 L
.23517 .11116 L
.25627 .11887 L
.26616 .12151 L
.27157 .12291 L
.27421 .12357 L
.27662 .12418 L
.27768 .12444 L
.27883 .12472 L
.27992 .12281 L
.28093 .12307 L
.28555 .12424 L
.29536 .12665 L
.33367 .13993 L
.3705 .14946 L
.39096 .15492 L
.39529 .15607 L
.39767 .1567 L
.39992 .15729 L
.4012 .15762 L
.40192 .15672 L
.40258 .1569 L
.40376 .16015 L
.405 .16049 L
.40728 .16111 L
.40854 .16145 L
Mistroke
.40973 .16177 L
.41086 .16208 L
.41209 .15449 L
.41321 .15478 L
.41425 .15504 L
.41848 .15611 L
.41974 .15643 L
.42093 .15672 L
.42199 .15699 L
.42314 .16151 L
.4244 .16184 L
.42573 .16219 L
.42811 .16281 L
.43042 .1634 L
.43169 .16372 L
.43289 .16403 L
.43401 .16432 L
.43522 .16085 L
.43632 .16115 L
.43735 .16142 L
.44748 .16412 L
.46727 .16921 L
.47696 .17161 L
.4812 .17265 L
.48584 .17377 L
.48801 .17429 L
.4892 .17458 L
.49032 .17484 L
.49137 .17509 L
.49251 .17081 L
.49354 .17104 L
.49449 .17126 L
.50359 .17331 L
.50802 .17429 L
.50923 .17456 L
.5099 .17471 L
.51054 .17484 L
.51177 .17051 L
.51289 .17078 L
.52272 .17309 L
.52757 .17421 L
.53212 .17526 L
.53335 .17553 L
.53464 .17583 L
.53532 .17598 L
.53606 .18201 L
.53674 .1822 L
.53737 .18237 L
.54212 .18365 L
.56009 .18844 L
Mistroke
.57834 .19321 L
.58796 .19569 L
.59815 .19829 L
.60063 .19892 L
.6033 .19959 L
.60408 .19979 L
.60483 .19998 L
.60549 .19165 L
.60622 .19185 L
.60897 .1926 L
.61895 .19533 L
.62926 .19813 L
.63861 .20065 L
.64336 .20192 L
.6485 .20329 L
.65086 .20392 L
.65335 .20458 L
.65438 .20485 L
.65548 .20514 L
.65669 .19715 L
.65782 .19744 L
.67829 .20281 L
.69763 .20783 L
.70783 .21047 L
.71867 .21325 L
.72329 .21443 L
.72571 .21505 L
.72827 .21571 L
.72893 .21588 L
.72963 .21605 L
.7304 .20519 L
.73112 .20539 L
.73374 .20612 L
.73887 .20757 L
.75757 .21282 L
.79808 .2242 L
.83711 .23516 L
.87466 .24571 L
.89406 .25116 L
.89877 .25249 L
.90384 .25391 L
.90533 .25433 L
.90674 .25473 L
.90801 .25508 L
.90873 .20423 L
.9094 .20438 L
.9146 .20555 L
.95285 .21414 L
.99 .22249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo00]oo`03001oogoo0?5oo`007Woo00<007ooOol037oo1@00kWoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo01Aoo`03001oogoo0>Qoo`007Woo00<007ooOol05Goo00<007ooOol0
igoo000NOol00`00Oomoo`0EOol3003WOol001ioo`03001oogoo01Moo`03001oogoo0>Eoo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`0KOol00`00Oomoo`3QOol001ioo`03001oogoo01aoo`D0
0=ioo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`0TOol00`00Oomoo`3HOol001ioo`03001o
ogoo02Eoo`<00=Moo`007Woo00<007ooOol09goo0P00eWoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo02aoo`800=5oo`007Woo00<007ooOol0;Goo0P00d7oo000FOol40004Ool00`00Oomoo`0^
Ool00`00Oomoo`3>Ool001Ioo`03001oogoo00Eoo`03001oogoo02moo`03001oogoo0<eoo`005goo
00<007ooOol017oo0P00=Goo0P00bGoo000HOol00`00Oomoo`03Ool00`00Oomoo`0fOol30036Ool0
01Ioo`04001oogoo0004Ool00`00Oomoo`3oOol001Moo`8000Eoo`03001oogoo03eoo`D00;eoo`00
7Woo00<007ooOol0ogoo000NOol00`00Oomoo`16Ool2002gOol001ioo`03001oogoo04Qoo`<00;Ao
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`1?Ool3002]Ool001ioo`03001oogoo059oo`<0
0:Yoo`007Woo00<007ooOol0F7oo0P00YGoo000NOol00`00Oomoo`1JOol300000goo001oo`2OOol0
01ioo`03001oogoo05eoo`8000=oo`D009Qoo`007Woo00<007ooOol0JWoo00<007ooOol0TWoo000N
Ool00`00Oomoo`1[Ool50003Ool00`00Oomoo`020027Ool001ioo`03001oogoo06moo`03001oogoo
009oo`<000Aoo`03001oogoo085oo`007Woo00<007ooOol0Ngoo00<007ooOol0PGoo000NOol00`00
Oomoo`1lOol20021Ool001ioo`03001oogoo07ioo`800003Ool007oo07aoo`007Woo00<007ooOol0
PWoo0P00Ngoo000NOol00`00Oomoo`28Ool01@00Oomoogoo00000Woo10001Goo0P00IGoo000NOol0
0`00Oomoo`29Ool40006Ool20003Ool01000Ool00000Hgoo000NOol00`00Oomoo`2HOol00`00Oomo
o`05Ool00`00Oomoo`07Ool00`00Oomoo`0WOol2000YOol001ioo`03001oogoo0:5oo`@000Eoo`80
02Qoo`04001oo`00000WOol001ioo`03001oogoo0:Eoo`05001oogooOol00006Ool3000QOol00`00
Oomoo`04Ool4000POol001Qoo`<000=oo`03001oogoo0:Uoo`03001oogoo00Moo`<002Uoo`8001io
o`006Goo00<007ooOol00Woo00<007ooOol0iGoo0`005goo000FOol50003Ool2002jOol3000HOolD
000GOol001Ioo`04001oogoo0004Ool00`00Oomoo`2lOol3000EOol00`00Oomoo`0XOol001Moo`03
001oo`0000Aoo`03001oogoo0<9oo`<000moo`03001oogoo02Qoo`0067oo0P0017oo00<007ooOol0
aGoo0`0037oo00<007ooOol0:7oo000NOol00`00Oomoo`3DOol00`00Oomoo`0XOol001ioo`03001o
ogoo0<]oo`<000Ioo`03001oogoo02Qoo`007Woo00<007ooOol0cWoo0`000goo00<007ooOol0:7oo
000NOol00`00Oomoo`3DOol00`00Oomoo`0XOol001ioo`03001oogoo0=Aoo`03001oogoo02Qoo`00
7Woo00<007ooOol0e7oo00<007ooOol0:7oo000NOol00`00Oomoo`3DOol00`00Oomoo`0XOol001io
o`03001oogoo0=Aoo`03001oogoo02Qoo`007Woo00<007ooOol0e7oo00<007ooOol0:7oo000NOol0
0`00Oomoo`2ZOol[000ZOol001ioo`03001oogoo0:Yoo`03001oogoo059oo`007Woo00<007ooOol0
ZGoo00<007ooOol0Dgoo000NOol00`00Oomoo`2YOol00`00Oomoo`1COol001ioo`03001oogoo09ao
o`h005Eoo`007Woo00<007ooOol0V7oo1000Hgoo000NOol00`00Oomoo`2HOol00`00Oomoo`1TOol0
01ioo`03001oogoo09Qoo`03001oogoo06Aoo`007Woo00<007ooOol0SGoo3000IWoo000NOol00`00
Oomoo`2<Ool2001aOol001ioo`03001oogoo08aoo`03001oogoo071oo`005Woo0`001Goo00<007oo
Ool0Ngoo00<007ooOol03Woo00<007ooOol0L7oo000FOol01000Oomoo`0017oo00<007ooOol0MWoo
1P0037oo1@00LWoo000FOol01000Oomoo`0017oo0P00Mgoo00<007ooOol00Woo00<007ooOol00Woo
2000Mgoo000FOol30005Ool00`00Oomoo`1fOol00`00Oomoo`02Ool5001oOol001Moo`03001oogoo
00Aoo`03001oogoo07Aoo`<008Qoo`005goo0`0017oo00<007ooOol0LGoo0`00Rgoo000NOol00`00
Oomoo`1aOol00`00Oomoo`2;Ool001ioo`03001oogoo071oo`8008eoo`007Woo00<007ooOol0JWoo
1P00Sgoo000NOol00`00Oomoo`1VOol4002EOol001ioo`03001oogoo06Aoo`8009Uoo`007Woo00<0
07ooOol0GWoo100000=oo`00Ool0VWoo000NOol00`00Oomoo`1NOol01P00Oomoo`00Ool009]oo`00
7Woo00<007ooOol0GWoo00<007ooOol00`00Vgoo000NOol00`00Oomoo`1NOol00`00Oomoo`2NOol0
01ioo`03001oogoo05Ioo`8000Aoo`03001oo`000:1oo`007Woo00<007ooOol0EGoo0`000Woo1@00
X7oo000NOol00`00Oomoo`1EOol00`00Oomoo`020002Ool00`00Oomoo`2POol001ioo`03001oogoo
05Aoo`800:Uoo`007Woo00<007ooOol0DWoo0P00Zgoo000NOol00`00Oomoo`1?Ool3002]Ool001io
o`03001oogoo04eoo`800;1oo`007Woo00<007ooOol0AGoo00<007ooOol00goo0P00/Woo000NOol0
0`00Oomoo`14Ool20003Ool2002dOol001ioo`03001oogoo049oo`800003Ool007oo009oo`03001o
ogoo0;=oo`007Woo00<007ooOol04goo00<007ooOol0:goo00D007ooOomoo`00009oo`800;Eoo`00
7Woo00<007ooOol04Woo0P00:goo0P0017oo00@007oo00000;Ioo`005goo0P001Goo00<007ooOol0
4Woo0P00:goo00<007ooOol017oo00<007ooOol0]Woo000FOol01000Oomoo`0017oo00<007ooOol0
4Goo00<007oo0000:Woo00<007ooOol0_Woo000FOol01000Oomoo`0017oo0P004Woo00<007oo0000
:Woo00<007ooOol0_Woo000GOol20005Ool00`00Oomoo`0@Ool01000Oomoo`00:7oo0P00`Goo000F
Ool01000Oomoo`0017oo00<007ooOol047oo00<007ooOol00`009Goo00<007ooOol0`Goo000GOol2
0005Ool00`00Oomoo`0@Ool00`00Oomoo`03000@Ool20004Ool00`00Oomoo`0;Ool00`00Oomoo`32
Ool001ioo`03001oogoo00moo`07001oogooOol007oo00003goo00<007oo00000goo0P0037oo00<0
07ooOol0`goo000NOol00`00Oomoo`0?Ool01`00Oomoogoo001oo`0000moo`03001oo`0000=oo`80
00Yoo`800<Ioo`007Woo00<007ooOol03goo00<007ooOol00goo00<007oo000027oo00D007ooOomo
o`00009oo`05001oogoo001oo`030006Ool20038Ool001ioo`03001oogoo00ioo`03001oogoo00Ao
o`<000Qoo`04001oogoo0003Ool00`00Ool00003Ool20005Ool00`00Oomoo`38Ool001ioo`03001o
ogoo00ioo`03001oogoo00Aoo`<0009oo`8000=oo`80009oo`04001oogooOol20005Ool01000Oomo
ogoo0P00bgoo000NOol00`00Oomoo`0=Ool00`00Oomoo`05Ool00`00Ool00002Ool20002Ool01@00
Ool007oo00002goo00@007oo00000<eoo`007Woo00<007ooOol03Goo00<007ooOol01goo00L007oo
001oo`00Ool00002Ool2000<Ool2003?Ool001ioo`03001oogoo00eoo`03001oogoo00Moo`<00003
Ool0000000=oo`03001oogoo00]oo`03001oogoo0<ioo`007Woo00<007ooOol037oo00<007ooOol0
27oo0P000Woo0P00hWoo000NOol00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`3QOol001io
o`03001oogoo00aoo`03001oogoo0?1oo`007Woo00<007ooOol02goo00<007ooOol0lGoo000NOol0
0`00Oomoo`0;Ool00`00Oomoo`3aOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000@Ool50002Ool20005Ool00`00
Oomoo`3oOol0019oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`3oOol0019oo`05
001oogooOol00002Ool00`00Oomoo`02Ool2003oOol1Ool0019oo`05001oogooOol00002Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol0019oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomo
o`3oOol0015oo`8000Aoo`8000Eoo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001o
ogoo0?moo`007Woo00<007ooOol0ogoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000Qoo`<00005Ool00000
001oo`020002Ool30002Ool30004Ool400000goo000000020003Ool300000goo00000002Ool2003Z
Ool000Moo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000
Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo00@007ooOol00>]oo`001goo00<007ooOol0
0goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomo
o`02Ool40002Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool30004Ool20004Ool00`00Oomo
o`03Ool30002Ool40003Ool20002Ool4003/Ool000Moo`04001oogoo0002Ool00`00Oomoo`0:Ool0
0`00Oomoo`05Ool00`00Oomoo`3kOol000Qoo`<00003Ool0000000Moo`04001oogooOol20006Ool2
003mOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(2.8886700635775924`\)], "Print"],

Cell[BoxData[
    \({5.`, 3.6499999999999995`, 8}\)], "Print"],

Cell[BoxData[
    \({5.`, 4.825`, 8}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .32917 m
.06219 .32706 L
.0634 .32591 L
.06454 .32483 L
.0656 .32382 L
.06675 .35738 L
.0678 .35612 L
.06877 .35497 L
.07343 .34946 L
.07456 .34814 L
.07578 .34672 L
.07647 .34592 L
.07711 .37475 L
.07837 .37299 L
.08311 .36641 L
.08829 .3594 L
.09066 .35626 L
.09196 .35454 L
.09318 .35294 L
.09433 .37448 L
.09557 .3726 L
.09773 .36933 L
.10815 .35412 L
.11384 .34616 L
.11662 .34236 L
.11916 .33894 L
.12027 .33745 L
.12149 .33584 L
.12263 .37078 L
.12369 .372 L
.12481 .37073 L
.12605 .36935 L
.12856 .36656 L
.13112 .36374 L
.13246 .36228 L
.13319 .36148 L
.13388 .36075 L
.13512 .39279 L
.13578 .39215 L
.13648 .39147 L
.13887 .38917 L
.14373 .38456 L
.14639 .38208 L
.14887 .37978 L
.15017 .37858 L
.1509 .37792 L
.15156 .40267 L
.15229 .40204 L
.15308 .40363 L
.15382 .40299 L
Mistroke
.15452 .40239 L
.15972 .39791 L
.16925 .38986 L
.17199 .38758 L
.17457 .38545 L
.17689 .38355 L
.17753 .38303 L
.1782 .38248 L
.17939 .401 L
.18059 .40003 L
.18127 .40154 L
.18189 .40103 L
.18425 .3991 L
.18867 .39551 L
.19097 .39366 L
.1916 .39316 L
.19227 .39261 L
.1935 .40645 L
.19412 .40602 L
.1948 .41164 L
.19551 .41117 L
.19617 .41074 L
.19861 .40913 L
.21653 .39757 L
.21777 .39678 L
.21893 .39605 L
.22014 .40276 L
.22078 .38765 L
.22147 .39331 L
.22222 .39297 L
.22293 .39265 L
.22426 .39205 L
.22683 .39089 L
.22908 .38987 L
.23032 .38931 L
.23148 .38879 L
.23273 .40538 L
.23339 .40508 L
.23411 .40476 L
.23538 .4042 L
.23654 .40693 L
.2376 .40645 L
.23873 .40593 L
.24076 .405 L
.24538 .4029 L
.2547 .39865 L
.26469 .39411 L
.26743 .39287 L
.26892 .39219 L
.26965 .39185 L
Mistroke
.27032 .39155 L
.27152 .39682 L
.2728 .39627 L
.27347 .39597 L
.2742 .39566 L
.27488 .40024 L
.27552 .39996 L
.27676 .40514 L
.27741 .40489 L
.2781 .41093 L
.27936 .4105 L
.28052 .41011 L
.28505 .40858 L
.29519 .40515 L
.29995 .40355 L
.30446 .40204 L
.30695 .4012 L
.30763 .40097 L
.30835 .40073 L
.30897 .38451 L
.30965 .38434 L
.31439 .38316 L
.32311 .38099 L
.32787 .37979 L
.33229 .37868 L
.33347 .37839 L
.33457 .37811 L
.33585 .38315 L
.33701 .38289 L
.34216 .38174 L
.3512 .37972 L
.3611 .37749 L
.37157 .37512 L
.37606 .37409 L
.37854 .37353 L
.38089 .37299 L
.38221 .37269 L
.38296 .37252 L
.38365 .37657 L
.38488 .37634 L
.38618 .37609 L
.39113 .37513 L
.39347 .37468 L
.39471 .37444 L
.39601 .37419 L
.39715 .37398 L
.3984 .38427 L
.39953 .38408 L
.40059 .3839 L
.40504 .38315 L
Mistroke
.407 .38282 L
.40804 .38264 L
.40915 .38245 L
.41038 .36406 L
.41154 .36395 L
.41406 .3637 L
.4194 .36318 L
.42908 .36221 L
.44722 .36036 L
.46646 .35834 L
.47662 .35725 L
.48746 .35606 L
.49289 .35546 L
.49555 .35517 L
.498 .35489 L
.50023 .35464 L
.50136 .35451 L
.50259 .35969 L
.50383 .35957 L
.50516 .35944 L
.50756 .35921 L
.51725 .35827 L
.52622 .35738 L
.52871 .35713 L
.52992 .35701 L
.53104 .35689 L
.53221 .36339 L
.53347 .36332 L
.53615 .36317 L
.54141 .36288 L
.54406 .36273 L
.54479 .36269 L
.54556 .36264 L
.54629 .3626 L
.54696 .33711 L
.54818 .33711 L
.54948 .33711 L
.5518 .33711 L
.55706 .33711 L
.5666 .33711 L
.60359 .33711 L
.64297 .33711 L
.68087 .33711 L
.70014 .33711 L
.71032 .33711 L
.71591 .33711 L
.72116 .33711 L
.72624 .33711 L
.72763 .33711 L
.72839 .33711 L
Mistroke
.7291 .33711 L
.73035 .28092 L
.73102 .28092 L
.73173 .28092 L
.7413 .28092 L
.75998 .28092 L
.8004 .28092 L
.83935 .28092 L
.87682 .28092 L
.91668 .28092 L
.95506 .28092 L
.99 .28092 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .01975 m
.09773 .03609 L
.13887 .05405 L
.17751 .068 L
.21468 .0856 L
.25423 .1014 L
.2631 .10388 L
.26757 .1051 L
.26879 .10543 L
.26947 .10561 L
.27011 .10579 L
.27135 .1077 L
.27249 .10802 L
.27373 .10836 L
.27442 .10855 L
.27505 .11006 L
.27627 .11041 L
.27742 .11232 L
.27807 .11427 L
.27876 .11449 L
.28 .11488 L
.2828 .11576 L
.29231 .11871 L
.30223 .12173 L
.30494 .12255 L
.30644 .123 L
.30718 .12322 L
.30786 .12342 L
.3085 .12361 L
.30917 .11886 L
.30986 .11907 L
.31061 .11931 L
.31311 .12007 L
.33278 .12598 L
.37204 .13952 L
.39008 .14641 L
.39502 .14789 L
.39645 .14832 L
.39715 .14852 L
.39779 .14871 L
.399 .15328 L
.39963 .15348 L
.40031 .1537 L
.40522 .15525 L
.40762 .156 L
.40876 .15636 L
.40982 .15669 L
.41092 .14958 L
.41212 .14997 L
.41431 .15068 L
Mistroke
.41914 .15223 L
.42939 .15552 L
.44999 .16203 L
.48825 .17381 L
.49317 .17529 L
.49776 .17666 L
.50007 .17736 L
.50074 .17755 L
.50137 .17774 L
.50255 .18076 L
.50318 .18096 L
.50386 .18117 L
.50506 .18155 L
.5078 .18239 L
.5188 .18579 L
.52367 .18728 L
.52622 .18806 L
.52891 .18888 L
.53007 .18923 L
.53131 .18961 L
.53202 .18982 L
.53267 .19355 L
.53393 .19397 L
.53853 .1955 L
.54075 .19625 L
.54317 .19705 L
.54427 .19742 L
.54544 .1978 L
.54644 .19814 L
.54754 .18458 L
.5482 .1848 L
.54892 .18505 L
.55022 .18548 L
.55267 .18631 L
.55816 .18816 L
.56808 .19151 L
.60788 .20492 L
.64619 .21784 L
.68302 .23025 L
.70348 .23715 L
.71244 .24017 L
.71718 .24177 L
.72225 .24348 L
.72481 .24434 L
.72723 .24516 L
.72829 .24551 L
.72941 .24589 L
.73063 .20525 L
.73176 .20557 L
.74063 .20806 L
Mistroke
.75999 .2135 L
.79696 .22389 L
.83632 .23494 L
.8742 .24558 L
.91447 .2569 L
.95327 .2678 L
.99 .27812 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol02goo0`00lGoo000NOol00`00Oomoo`0>
Ool3003^Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol057oo00<007ooOol0j7oo000NOol0
0`00Oomoo`0EOol2003XOol001ioo`03001oogoo01Moo`800>Ioo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`0MOol00`00Oomoo`3OOol001ioo`03001oogoo01ioo`800=moo`007Woo00<007oo
Ool087oo0P00gGoo000NOol00`00Oomoo`0VOol00`00Oomoo`3FOol001ioo`03001oogoo02Moo`80
0=Ioo`007Woo00<007ooOol0:Goo0P00e7oo000NOol00`00Oomoo`3oOol001ioo`03001oogoo02io
o`03001oogoo0<ioo`007Woo00<007ooOol0;goo0P00cWoo000NOol00`00Oomoo`0aOol3003;Ool0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0=goo00<007ooOol0aGoo000FOol40004Ool00`00
Oomoo`0hOol50032Ool001Ioo`03001oogoo00Eoo`03001oogoo0?moo`005goo00<007ooOol017oo
0P00ogoo0Goo000HOol00`00Oomoo`03Ool00`00Oomoo`0oOol2002nOol001Ioo`04001oogoo0004
Ool00`00Oomoo`11Ool40002Ool2002fOol001Moo`8000Eoo`03001oogoo04Uoo`<00;=oo`007Woo
00<007ooOol0C7oo00<007ooOol0/7oo000NOol00`00Oomoo`1@Ool2002]Ool001ioo`03001oogoo
059oo`800:]oo`007Woo00<007ooOol0E7oo0P00ZGoo000NOol00`00Oomoo`1IOol00`00Oomoo`2S
Ool001ioo`03001oogoo05Yoo`8000=oo`03001oogoo09eoo`007Woo00<007ooOol0Fgoo0`000Woo
0`00W7oo000NOol00`00Oomoo`1SOol2002JOol001ioo`03001oogoo06Qoo`8009Eoo`007Woo00<0
07ooOol0JWoo0P00Tgoo000NOol00`00Oomoo`1/Ool2002AOol001ioo`03001oogoo075oo`<008]o
o`007Woo00<007ooOol0Lgoo0P00RWoo000NOol00`00Oomoo`1dOol30028Ool001ioo`03001oogoo
07Yoo`03001oogoo00=oo`8007eoo`007Woo00<007ooOol0Ngoo00<007ooOol017oo0`00NWoo000N
Ool00`00Oomoo`1lOol30020Ool001ioo`03001oogoo08Uoo`8007Aoo`007Woo00<007ooOol0Rgoo
0`00LGoo000NOol00`00Oomoo`2]Ool2001@Ool001ioo`03001oogoo099oo`8001Ioo`03001oogoo
009oo`<004eoo`0067oo0`000goo00<007ooOol0U7oo0`004goo00<007ooOol0DWoo000IOol00`00
Oomoo`02Ool00`00Oomoo`2ZOol00`00Oomoo`09Ool20017Ool001Ioo`D000=oo`8009aoo`8000ao
o`03001oogoo00aoo`<004Aoo`005Woo00@007ooOol000Aoo`03001oogoo09eoo`<000Uoo`03001o
ogoo01=oo`8003ioo`005goo00<007oo000017oo00<007ooOol0ZGoo00<007ooOol05Goo1000>Woo
000HOol20004Ool00`00Oomoo`2TOol2001IOol001ioo`03001oogoo0:Ioo`<001moo`8003Eoo`00
7Woo00<007ooOol0bWoo1000<Goo000NOol00`00Oomoo`3AOol2000/Ool001ioo`03001oogoo0==o
o`<002Uoo`007Woo00<007ooOol0eWoo00<007ooOol09Woo000NOol00`00Oomoo`3JOol2000SOol0
01ioo`03001oogoo0=aoo`@001moo`007Woo00<007ooOol0hgoo0P006Woo000NOol00`00Oomoo`3U
Ool3000GOol001ioo`03001oogoo0:Yooch001Moo`007Woo00<007ooOol0ZWoo00<007ooOol0DWoo
000NOol00`00Oomoo`2ZOol00`00Oomoo`1BOol001ioo`03001oogoo0:Yoo`03001oogoo059oo`00
7Woo00<007ooOol0ZWoo00<007ooOol0DWoo000NOol00`00Oomoo`2ZOol00`00Oomoo`1BOol001io
o`03001oogoo0:Yoo`03001oogoo059oo`007Woo00<007ooOol0ZGoo00<007ooOol0Dgoo000NOol0
0`00Oomoo`2YOol00`00Oomoo`1COol001ioo`03001oogoo0:Uoo`03001oogoo05=oo`007Woo00<0
07ooOol037oo00<007ooOol0VWoo00<007ooOol0Dgoo000FOol30005Ool00`00Oomoo`0;Ool2002L
Ool00`00Oomoo`1COol001Ioo`04001oogoo0004Ool00`00Oomoo`0;Ool2002LOol00`00Oomoo`1C
Ool001Ioo`04001oogoo0004Ool2000=Ool00`00Oomoo`0:Ool00`00Oomoo`1ROol/001EOol001Io
o`<000Eoo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo069oo`03001oogoo07ioo`005goo
00<007ooOol017oo00<007ooOol037oo00<007ooOol02Goo0P00I7oo00<007ooOol0OWoo000GOol3
0004Ool00`00Oomoo`0<Ool01000Ool0000027oo0P00I7oo00<007ooOol0OWoo000NOol00`00Oomo
o`0<Ool200000goo001oo`02Ool00`00Oomoo`0200000goo001oo`1SOol00`00Oomoo`1nOol001io
o`03001oogoo00aoo`800004Ool007ooOol200000goo001oo`03Ool00`00Oomoo`1=Ool:0003Ool4
0003Ool00`00Oomoo`1nOol001ioo`03001oogoo00moo`07001oo`00Ool007oo000017oo00<007oo
0000AGoo20002Woo0`000goo00<007ooOol00P00P7oo000NOol00`00Oomoo`0?Ool20002Ool20005
Ool30011Ool4000IOol30021Ool001ioo`03001oogoo00moo`04001oogooOol20005Ool00`00Ool0
0011Ool00`00Oomoo`2NOol001ioo`03001oogoo00moo`05001oogooOol00006Ool00`00Ool0000g
Ool4000017oo000000000Woo00<007ooOol0WWoo000NOol00`00Oomoo`0LOol01@00Oomoogoo0000
:Woo0P001Goo0P000goo0P000Woo00@007ooOol00:1oo`007Woo00<007ooOol07Goo00@007oo0000
00Eoo`8001moo`@00003Ool0000000@000Uoo`04001oo`00002POol001ioo`03001oogoo01eoo`04
001oo`000004Ool30009Ool00`00Oomoo`0BOol00`00Oomoo`0BOol2002ROol001ioo`03001oogoo
01eoo`800003Ool007oo00=oo`03001oo`0000Uoo`<000Qoo`8000Qoo`03001oogoo0;Ioo`007Woo
00<007ooOol07Goo00@007ooOol0009oo`80009oo`04001oo`000005Ool200000goo001oo`06Ool4
0007Ool00`00Oomoo`2fOol001ioo`03001oogoo021oo`03001oo`0000Aoo`800003Ool007oo00Ao
o`800003Ool007oo00Aoo`80009oo`8000Moo`03001oogoo0;Ioo`007Woo00<007ooOol087oo0P00
1Goo0P0000=oo`00Ool00Woo0P0000Eoo`00Oomoo`00009oo`8000Eoo`03001oogoo00=oo`<00;Qo
o`007Woo00<007ooOol0:Woo10001Woo0`001goo00<007oo00000`00^goo000NOol00`00Oomoo`0[
Ool00`00Oomoo`0@Ool2002oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001Moo`8000Eoo`03001oogoo0?moo`005Woo00@007ooOol000Aoo`03001oogoo0?moo`005Woo
00@007ooOol000Aoo`800?moo`5oo`005goo0P001Goo00<007ooOol0ogoo000FOol01000Oomoo`00
17oo00<007ooOol0ogoo000GOol20005Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0011oo`D0009oo`8000Eoo`03001oogoo
0?moo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo0?moo`004Woo00D007oo
Oomoo`00009oo`03001oogoo009oo`800?moo`5oo`004Woo00D007ooOomoo`00009oo`03001oogoo
009oo`03001oogoo0?moo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo0?mo
o`004Goo0P0017oo0P001Goo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo
0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`0027oo0`0000Eoo`00000007oo
0080009oo`<0009oo`<000Aoo`@00003Ool00000008000=oo`<00003Ool00000009oo`800>Yoo`00
1goo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool0
1000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009o
o`@0009oo`04001oogoo003[Ool000Moo`03001oogoo00=oo`<000Aoo`8000Aoo`03001oogoo00=o
o`<0009oo`@000=oo`80009oo`@00>aoo`001goo00@007ooOol0009oo`03001oogoo00Yoo`03001o
ogoo00Eoo`03001oogoo0?]oo`0027oo0`0000=oo`0000001goo00@007ooOomoo`8000Ioo`800?eo
o`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(1.3950207838788629`\)], "Print"],

Cell[BoxData[
    \({5.`, 3.6499999999999995`, 8}\)], "Print"],

Cell[BoxData[
    \({5.`, 4.825`, 8}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 0 m
.06877 0 L
.07837 0 L
.08321 0 L
.08839 0 L
.0909 0 L
.09328 0 L
.09541 0 L
.09662 0 L
.09773 .05618 L
.09896 .05618 L
.10009 .05618 L
.10263 .05618 L
.10376 .05618 L
.10499 .05618 L
.10615 .10641 L
.10723 .10635 L
.1123 .10606 L
.11376 .10598 L
.11447 .10594 L
.11513 .1059 L
.11636 .1497 L
.11701 .1496 L
.1177 .14949 L
.12257 .14874 L
.12779 .14793 L
.12933 .14769 L
.13009 .14758 L
.13079 .14747 L
.13142 .14737 L
.1321 .184 L
.13278 .18381 L
.13352 .1836 L
.13887 .18211 L
.14367 .18078 L
.14873 .17939 L
.15304 .17821 L
.15423 .17789 L
.15549 .17755 L
.15668 .17722 L
.15776 .2052 L
.15903 .20469 L
.16038 .20415 L
.16279 .20318 L
.16824 .20101 L
.17341 .19898 L
.17813 .19714 L
.18039 .19627 L
.18159 .19581 L
.18286 .19532 L
Mistroke
.18408 .22052 L
.18519 .22585 L
.1863 .22556 L
.18735 .22529 L
.19724 .22274 L
.20143 .22168 L
.20371 .2211 L
.20584 .22057 L
.20696 .22029 L
.20815 .23658 L
.20883 .23644 L
.20947 .24213 L
.21068 .24189 L
.21513 .24102 L
.22001 .24007 L
.22239 .2396 L
.22458 .23917 L
.2257 .23895 L
.22688 .26335 L
.22806 .26299 L
.22935 .2626 L
.23461 .26101 L
.23693 .26031 L
.23912 .25965 L
.24033 .25929 L
.24102 .25908 L
.24165 .26798 L
.24276 .26771 L
.24394 .26743 L
.24593 .26696 L
.24703 .2667 L
.24807 .26646 L
.2493 .28457 L
.25042 .28435 L
.25146 .29007 L
.25261 .28985 L
.27189 .28605 L
.27658 .28513 L
.27904 .28465 L
.28164 .28414 L
.2823 .28401 L
.28302 .28387 L
.2838 .29094 L
.28453 .29082 L
.28719 .29038 L
.28972 .28997 L
.2911 .28974 L
.2924 .28953 L
.29359 .28933 L
.29487 .29229 L
Mistroke
.2956 .29219 L
.29629 .2921 L
.29759 .29192 L
.30239 .29128 L
.308 .29052 L
.31074 .29016 L
.31322 .28983 L
.31435 .28968 L
.31557 .28951 L
.31672 .30152 L
.31777 .3014 L
.3189 .30127 L
.32013 .30945 L
.32142 .30931 L
.32263 .30917 L
.33289 .30803 L
.34311 .30687 L
.34813 .3063 L
.35034 .30605 L
.35151 .30592 L
.35278 .30577 L
.35391 .31313 L
.35495 .31717 L
.35595 .31711 L
.35699 .31705 L
.36146 .3168 L
.3709 .31627 L
.40814 .31418 L
.44776 .31195 L
.46607 .31092 L
.48591 .30981 L
.49119 .30951 L
.49677 .3092 L
.49906 .30907 L
.50153 .30893 L
.50226 .30889 L
.50295 .30885 L
.50356 .30882 L
.50424 .33711 L
.50488 .33711 L
.50555 .33711 L
.50677 .33711 L
.52645 .33711 L
.56713 .33711 L
.60632 .33711 L
.64404 .33711 L
.68415 .33711 L
.70415 .33711 L
.7139 .33711 L
.72278 .33711 L
Mistroke
.7272 .33711 L
.72841 .33711 L
.7297 .33711 L
.73079 .28092 L
.732 .28092 L
.74073 .28092 L
.75993 .28092 L
.79926 .28092 L
.83711 .28092 L
.87735 .28092 L
.91611 .28092 L
.9534 .28092 L
.99 .28092 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 0 m
.06877 0 L
.07837 0 L
.08321 0 L
.08839 0 L
.0909 0 L
.09328 0 L
.09541 0 L
.09662 0 L
.09773 .00549 L
.09896 .00556 L
.10009 .00562 L
.10263 .00577 L
.10376 .00583 L
.10499 .0059 L
.10615 .0113 L
.10723 .0114 L
.1123 .01191 L
.11376 .01206 L
.11447 .01213 L
.11513 .01219 L
.11636 .01742 L
.11701 .01751 L
.1177 .0176 L
.12257 .01823 L
.12779 .0189 L
.12933 .0191 L
.13009 .0192 L
.13079 .01929 L
.13142 .01937 L
.1321 .02431 L
.13278 .02441 L
.13352 .02451 L
.13887 .02529 L
.14367 .02597 L
.14873 .02668 L
.15304 .02727 L
.15423 .02743 L
.15549 .02761 L
.15668 .02777 L
.15776 .03237 L
.15903 .03255 L
.16038 .03274 L
.16279 .03308 L
.16824 .03382 L
.17341 .0345 L
.17813 .03512 L
.18039 .0354 L
.18159 .03556 L
.18286 .03572 L
Mistroke
.18408 .04059 L
.18519 .04182 L
.1863 .04202 L
.18735 .04221 L
.19724 .04394 L
.20143 .04465 L
.20371 .04504 L
.20584 .0454 L
.20696 .04559 L
.20815 .04924 L
.20883 .04938 L
.20947 .05072 L
.21068 .05096 L
.21513 .05185 L
.22001 .05282 L
.22239 .05328 L
.22458 .05371 L
.2257 .05393 L
.22688 .05975 L
.22806 .05998 L
.22935 .06023 L
.23461 .06123 L
.23693 .06168 L
.23912 .06209 L
.24033 .06232 L
.24102 .06244 L
.24165 .06476 L
.24276 .06499 L
.24394 .06524 L
.24593 .06565 L
.24703 .06588 L
.24807 .0661 L
.2493 .07094 L
.25042 .07121 L
.25146 .07294 L
.25261 .07322 L
.27151 .07769 L
.2924 .08466 L
.33071 .10195 L
.36994 .11702 L
.40769 .1281 L
.44783 .1397 L
.46785 .14542 L
.47761 .14819 L
.48649 .1507 L
.49092 .15195 L
.49573 .15331 L
.49793 .15393 L
.50027 .15458 L
.50226 .15514 L
Mistroke
.5034 .15546 L
.50446 .17006 L
.50564 .17046 L
.50694 .17089 L
.50929 .17169 L
.51372 .17318 L
.52367 .17653 L
.56338 .18992 L
.60161 .20281 L
.64223 .2165 L
.68138 .2297 L
.69934 .23575 L
.70953 .23919 L
.71904 .2424 L
.72387 .24402 L
.72625 .24483 L
.72845 .24557 L
.72967 .24598 L
.73029 .20516 L
.73097 .20535 L
.73372 .20612 L
.73853 .20747 L
.7591 .21325 L
.79838 .22428 L
.83618 .2349 L
.87637 .24619 L
.91508 .25707 L
.95231 .26753 L
.99 .27812 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00=7oo00<007ooOol0ggoo00<007ooOol01goo
000NOoo^0007Ool3000:Ool001ioo`03001oogoo01=oo`03001oogoo01Ioo`03001oogoo02aoo`03
001oogoo02eoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<0
07ooOol04goo00<007ooOol00`00iWoo000NOol00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomo
o`3TOol001ioo`03001oogoo01=oo`03001oogoo009oo`800>Eoo`007Woo00<007ooOol04goo00<0
07ooOol0jGoo000NOol00`00Oomoo`0COol00`00Oomoo`07Ool6003LOol001ioo`03001oogoo01Ao
o`03001oogoo0>Qoo`007Woo00<007ooOol057oo00<007ooOol03goo0`00eWoo000NOol00`00Oomo
o`0DOol00`00Oomoo`3XOol001ioo`03001oogoo01Aoo`03001oogoo01Eoo`<00=1oo`007Woo00<0
07ooOol057oo00<007ooOol05goo00<007ooOol0cWoo000NOol00`00Oomoo`0DOol00`00Oomoo`0G
Ool3003>Ool001ioo`03001oogoo01Aoo`800>Uoo`007Woo00<007ooOol05Goo00<007ooOol06goo
1000b7oo000NOol00`00Oomoo`0EOol00`00Oomoo`0NOol20037Ool001ioo`03001oogoo01Eoo`03
001oogoo0>Moo`007Woo00<007ooOol05Goo00<007ooOol0igoo000NOol00`00Oomoo`0EOol00`00
Oomoo`0SOol40030Ool001ioo`03001oogoo01Eoo`03001oogoo02Moo`800;ioo`007Woo00<007oo
Ool05Woo00<007ooOol0iWoo000NOol00`00Oomoo`0FOol00`00Oomoo`0[Ool00`00Oomoo`2hOol0
01ioo`03001oogoo01Ioo`03001oogoo02aoo`800;Qoo`007Woo00<007ooOol05Woo00<007ooOol0
;Woo0P00]Woo000FOol40004Ool00`00Oomoo`0FOol00`00Oomoo`0dOol00`00Oomoo`2_Ool001Io
o`03001oogoo00Eoo`03001oogoo01Ioo`<003Eoo`800:moo`005goo00<007ooOol017oo0P006Goo
00<007ooOol0=Goo0P00[Goo000HOol00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`3TOol0
01Ioo`04001oogoo0004Ool00`00Oomoo`0HOol00`00Oomoo`0kOol2002WOol001Moo`8000Eoo`03
001oogoo01Qoo`03001oogoo03eoo`<00:Aoo`007Woo00<007ooOol067oo00<007ooOol0A7oo00<0
07ooOol0WGoo000NOol00`00Oomoo`0HOol00`00Oomoo`15Ool2002MOol001ioo`03001oogoo01Qo
o`03001oogoo04Moo`8009]oo`007Woo00<007ooOol067oo00<007ooOol0CGoo0P00UGoo000NOol0
0`00Oomoo`0HOol01@00Oomoogoo0000CGoo0`00TWoo000NOol00`00Oomoo`0HOol5003ROol001io
o`03001oogoo01aoo`03001oogoo059oo`@008Yoo`007Woo00<007ooOol077oo00<007ooOol0EGoo
00<007ooOol0R7oo000NOol00`00Oomoo`0LOol00`00Oomoo`3POol001ioo`03001oogoo01aoo`03
001oogoo0>1oo`007Woo00<007ooOol077oo00<007ooOol0EWoo00<007ooOol0Qgoo000NOol00`00
Oomoo`0LOol00`00Oomoo`1GOol40025Ool001ioo`03001oogoo01aoo`03001oogoo00@005Moo`03
001oogoo089oo`007Woo00<007ooOol077oo0`000goo00<007ooOol0FGoo00<007ooOol0OWoo000N
Ool00`00Oomoo`0ROol00`00Oomoo`1JOol2001nOol001ioo`03001oogoo029oo`03001oogoo05ao
o`<007]oo`007Woo00<007ooOol08Woo00<007ooOol00Woo0P00GWoo00<007ooOol0MGoo000NOol0
0`00Oomoo`0ROol00`00Ool0000200000goo001oo`1NOol2001eOol001ioo`03001oogoo029oo`80
00Aoo`03001oogoo05moo`<0079oo`007Woo00<007ooOol0:7oo00<007ooOol0IGoo0P006Goo0`00
DGoo000NOol00`00Oomoo`0XOol00`00Oomoo`1WOol2000JOol3001>Ool001Qoo`<000=oo`03001o
ogoo02Qoo`03001oogoo06Uoo`8001Aoo`03001oogoo00Moo`<004Qoo`006Goo00<007ooOol00Woo
00<007ooOol0:7oo00<007ooOol01000JWoo0P003goo00<007ooOol02Woo0`00AGoo000FOol50003
Ool2000YOol30003Ool00`00Oomoo`1ZOol2000=Ool00`00Oomoo`1BOol001Ioo`04001oogoo0004
Ool00`00Oomoo`0^Ool00`00Oomoo`1/Ool2000:Ool00`00Oomoo`0BOol2000oOol001Moo`03001o
o`0000Aoo`03001oogoo02ioo`03001oogoo075oo`8000Eoo`03001oogoo01Aoo`<003aoo`0067oo
0P0017oo00<007ooOol0;Woo00<007ooOol00P00LGoo0P000goo00<007ooOol06goo00<007ooOol0
=Goo000NOol00`00Oomoo`0^Ool300000goo001oo`1bOol2000POol2000eOol001ioo`03001oogoo
039oo`03001oogoo09Eoo`8003=oo`007Woo00<007ooOol0<Woo00<007ooOol0Vgoo0P00;Goo000N
Ool00`00Oomoo`0bOol00`00Oomoo`2MOol3000ZOol001ioo`03001oogoo039oo`03001oo`000080
0:9oo`03001oogoo02=oo`007Woo00<007ooOol0<Woo0P000Woo00<007ooOol0XGoo0P008goo000N
Ool00`00Oomoo`0fOol2002TOol2000QOol001ioo`03001oogoo03Moo`03001oogoo0:Qoo`<001Yo
o`007Woo00<007ooOol0=goo00<007ooOol0Zgoo0`005goo000NOol00`00Oomoo`0hOol00`00Oomo
o`1_Ooln000GOol001ioo`03001oogoo03Qoo`03001oogoo00H006Uoo`03001oogoo059oo`007Woo
00<007ooOol0>7oo0`001Goo0`000goo0P00HWoo00<007ooOol0DWoo000NOol00`00Oomoo`12Ool4
00000goo001oo`1QOol00`00Oomoo`1BOol001ioo`03001oogoo04Qoo`03001oogoo05moo`03001o
ogoo059oo`007Woo00<007ooOol0B7oo00<007ooOol0Ggoo00<007ooOol0DWoo000NOol00`00Oomo
o`18Ool00`00Oomoo`02Ool4001IOol00`00Oomoo`1BOol001ioo`03001oogoo04Qoo`D000=oo`03
001oogoo011ooa8003Aoo`03001oogoo05=oo`007Woo00<007ooOol0D7oo00@007ooOomoo`l0015o
o`03001oogoo039oo`03001oogoo05=oo`007Woo00<007ooOol0DGoo0`0087oo00<007ooOol0<Woo
00<007ooOol0Dgoo000NOol00`00Oomoo`1dOol00`00Oomoo`0bOol00`00Oomoo`1COol001Ioo`<0
00Eoo`03001oogoo07Aoo`03001oogoo039oo`03001oogoo05=oo`005Woo00@007ooOol000Aoo`03
001oogoo07Aoo`03001oogoo039oo`03001oogoo05=oo`005Woo00@007ooOol000Aoo`8007EoocH0
05Eoo`005Woo0`001Goo00<007ooOol0ogoo000GOol00`00Oomoo`04Ool00`00Oomoo`3oOol001Mo
o`<000Aoo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`005goo0P001Goo00<007ooOol0ogoo000FOol01000Oomoo`0017oo00<0
07ooOol0ogoo000FOol01000Oomoo`0017oo0P00ogoo0Goo000GOol20005Ool00`00Oomoo`3oOol0
01Ioo`04001oogoo0004Ool00`00Oomoo`3oOol001Moo`8000Eoo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001o
ogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`00
7Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`0047oo1@000Woo
0P001Goo00<007ooOol0ogoo000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0
ogoo000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo0P00ogoo0Goo000BOol01@00Oomoogoo
00000Woo00<007ooOol00Woo00<007ooOol0ogoo000BOol01@00Oomoogoo00000Woo00<007ooOol0
0Woo00<007ooOol0ogoo000AOol20004Ool20005Ool00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0008Ool3
00001Goo00000000Ool00P000Woo0`000Woo0`0017oo100000=oo`0000000P000goo0`0000=oo`00
00000Woo0P00jWoo0007Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol00Woo00<007oo
Ool00Woo00@007ooOol000=oo`03001oogoo009oo`03001oogoo00=oo`04001oogoo003[Ool000Mo
o`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`00
0goo00<007ooOol00Woo10000Woo00@007ooOol00>]oo`001goo00<007ooOol00goo0`0017oo0P00
17oo00<007ooOol00goo0`000Woo10000goo0P000Woo1000k7oo0007Ool01000Oomoo`000Woo00<0
07ooOol02Woo00<007ooOol01Goo00<007ooOol0ngoo0008Ool300000goo00000007Ool01000Oomo
ogoo0P001Woo0P00oGoo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(271.0056469300762`\)], "Print"],

Cell[BoxData[
    \({5.081964770910999`, 3.7098342827650295`, 6}\)], "Print"],

Cell[BoxData[
    \({4.`, 3.86`, 9}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .5175 m
.06219 .51134 L
.0634 .50799 L
.06454 .50486 L
.0656 .50196 L
.06675 .52874 L
.0678 .52625 L
.06877 .52397 L
.06991 .52128 L
.07098 .54599 L
.07216 .54355 L
.07343 .54094 L
.07475 .53824 L
.07601 .53569 L
.07713 .55983 L
.07837 .55758 L
.07957 .5554 L
.08087 .55305 L
.0821 .55085 L
.08323 .55064 L
.08386 .54952 L
.08455 .54829 L
.08527 .56894 L
.08594 .56783 L
.08841 .5638 L
.08951 .562 L
.09072 .56004 L
.09185 .55999 L
.0929 .5583 L
.09413 .55634 L
.09475 .57428 L
.09543 .57323 L
.09773 .56971 L
.1027 .56216 L
.10338 .56114 L
.10401 .56192 L
.10475 .56082 L
.10542 .55981 L
.10673 .55784 L
.10794 .55602 L
.10858 .55507 L
.10926 .56982 L
.10994 .56882 L
.11068 .56772 L
.11368 .56332 L
.11895 .55563 L
.12391 .55008 L
.12924 .54239 L
.13182 .5387 L
.1331 .53689 L
Mistroke
.13427 .53521 L
.13534 .5337 L
.13647 .5442 L
.13773 .5424 L
.13887 .54076 L
.14134 .53724 L
.14365 .53397 L
.14481 .53232 L
.14605 .55219 L
.14676 .55133 L
.14743 .55051 L
.14869 .54898 L
.15306 .54367 L
.15413 .54238 L
.15527 .541 L
.15653 .54114 L
.1577 .53972 L
.15899 .53817 L
.16035 .53654 L
.16151 .53515 L
.16277 .55107 L
.16395 .54981 L
.1652 .54846 L
.16637 .5472 L
.16745 .54605 L
.16812 .54533 L
.16883 .54842 L
.16954 .54767 L
.17031 .54685 L
.17301 .54401 L
.17805 .53874 L
.18049 .5362 L
.18316 .53345 L
.18437 .53219 L
.18567 .53086 L
.18678 .52972 L
.188 .54143 L
.18917 .5403 L
.19025 .53926 L
.19141 .53815 L
.19268 .53693 L
.19379 .53587 L
.19482 .53862 L
.19591 .53758 L
.19708 .53647 L
.21749 .51736 L
.22748 .50822 L
.23274 .50346 L
.23562 .50087 L
.23831 .49846 L
Mistroke
.24066 .49637 L
.24133 .49577 L
.24198 .4952 L
.24318 .50258 L
.24382 .50545 L
.24451 .50485 L
.24574 .50377 L
.24854 .50132 L
.25798 .49314 L
.26804 .48453 L
.27891 .47537 L
.2839 .47121 L
.28662 .46895 L
.28796 .46785 L
.28917 .46685 L
.29028 .48216 L
.29134 .4814 L
.29367 .47973 L
.29861 .47621 L
.30804 .46958 L
.31806 .46268 L
.32662 .4569 L
.32896 .45534 L
.33149 .45366 L
.33265 .45289 L
.33387 .45208 L
.33491 .45139 L
.33605 .45948 L
.33735 .45866 L
.33853 .4579 L
.34122 .45619 L
.3461 .45312 L
.35081 .45018 L
.35311 .44875 L
.35412 .44812 L
.35522 .44745 L
.35639 .45374 L
.3575 .45309 L
.35995 .45165 L
.36516 .44864 L
.37568 .44263 L
.38089 .43971 L
.38345 .43828 L
.38457 .43766 L
.38579 .43698 L
.3869 .41884 L
.38794 .41833 L
.39019 .41719 L
.39494 .41483 L
.41544 .40493 L
Mistroke
.45351 .38764 L
.46348 .38303 L
.46873 .38081 L
.4743 .37849 L
.4755 .37709 L
.47665 .37663 L
.47796 .3761 L
.47917 .37562 L
.48049 .37509 L
.48193 .37451 L
.48258 .37425 L
.48328 .37397 L
.48453 .38228 L
.48575 .38179 L
.48707 .38126 L
.48948 .38031 L
.49397 .37854 L
.51305 .36999 L
.53399 .36229 L
.54361 .3588 L
.54615 .35788 L
.54891 .35689 L
.55017 .35644 L
.55086 .35619 L
.55152 .35595 L
.55266 .35399 L
.55393 .35356 L
.55621 .35278 L
.55861 .35196 L
.55987 .35153 L
.56058 .33442 L
.56125 .33423 L
.56366 .33354 L
.57254 .33102 L
.61066 .31975 L
.65117 .30805 L
.6902 .29765 L
.69882 .2956 L
.7013 .29501 L
.70365 .29444 L
.70468 .2942 L
.70577 .29394 L
.70697 .29039 L
.70808 .29015 L
.71824 .28802 L
.72281 .28706 L
.72521 .28655 L
.72775 .28601 L
.72905 .28573 L
.72979 .28557 L
Mistroke
.73048 .27591 L
.73169 .27567 L
.73299 .27541 L
.73553 .2749 L
.73678 .27465 L
.73793 .27441 L
.73905 .27419 L
.74024 .26906 L
.74144 .26886 L
.74275 .26863 L
.74715 .26787 L
.75225 .26698 L
.75775 .26603 L
.76028 .26559 L
.76294 .26513 L
.76404 .26494 L
.76521 .26474 L
.7665 .29711 L
.76769 .29701 L
.7689 .29691 L
.76959 .29685 L
.77023 .29383 L
.77091 .2938 L
.77152 .29376 L
.77291 .29368 L
.77772 .29341 L
.78857 .2928 L
.80826 .2917 L
.81727 .29119 L
.82221 .29091 L
.82686 .29065 L
.82926 .29052 L
.82992 .29048 L
.83062 .29044 L
.83186 .24496 L
.83252 .24487 L
.83322 .24478 L
.83449 .24462 L
.83738 .24426 L
.84 .24393 L
.84129 .24376 L
.84248 .24361 L
.84356 .24232 L
.84471 .24219 L
.84712 .24192 L
.8483 .24179 L
.84958 .24164 L
.8508 .24151 L
.85192 .23306 L
.85304 .233 L
Mistroke
.85405 .23294 L
.85631 .23281 L
.8662 .23226 L
.88407 .23125 L
.90446 .23011 L
.9134 .22961 L
.91813 .22934 L
.92321 .22905 L
.92575 .22891 L
.92816 .22878 L
.92921 .22872 L
.93032 .22865 L
.93155 .22474 L
.93268 .22474 L
.94152 .22474 L
.96086 .22474 L
.99 .22474 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .03105 m
.09773 .05568 L
.13887 .0751 L
.17751 .09573 L
.21468 .11162 L
.25423 .12619 L
.27249 .131 L
.27749 .13224 L
.2828 .13351 L
.28498 .13403 L
.28732 .13457 L
.28801 .13473 L
.28867 .13488 L
.2899 .13986 L
.29105 .14017 L
.29231 .14051 L
.31311 .14593 L
.32343 .14847 L
.3283 .14963 L
.33278 .15068 L
.33398 .15096 L
.33509 .15122 L
.33626 .15446 L
.33753 .15477 L
.34267 .15601 L
.34746 .15714 L
.35199 .1582 L
.35319 .15848 L
.35447 .15877 L
.35513 .15892 L
.35587 .16158 L
.35654 .16174 L
.35716 .1619 L
.36188 .16304 L
.37247 .16555 L
.37744 .16669 L
.38207 .16775 L
.38441 .16827 L
.38508 .16842 L
.38571 .16856 L
.3869 .16205 L
.38754 .16219 L
.38822 .16235 L
.38943 .16262 L
.39218 .16323 L
.41025 .16713 L
.44725 .1746 L
.45781 .17661 L
.46783 .17833 L
.47683 .17955 L
Mistroke
.47929 .18001 L
.48065 .18025 L
.48192 .18049 L
.48311 .1807 L
.4844 .1852 L
.48556 .18542 L
.48664 .18562 L
.52455 .19185 L
.53345 .19337 L
.54297 .19494 L
.54578 .1954 L
.54844 .19583 L
.5496 .19601 L
.55083 .19621 L
.55147 .19631 L
.55217 .19556 L
.55342 .19576 L
.55584 .19616 L
.55711 .19637 L
.55845 .19658 L
.55962 .19677 L
.56091 .18753 L
.56208 .18773 L
.56316 .18792 L
.60134 .19377 L
.64191 .19998 L
.64438 .20033 L
.64574 .20052 L
.64703 .20071 L
.64822 .20088 L
.6489 .20097 L
.64953 .20035 L
.65063 .20051 L
.65181 .19996 L
.65303 .20014 L
.65417 .20032 L
.65679 .20071 L
.66227 .20152 L
.68101 .20419 L
.68982 .20539 L
.6991 .20661 L
.70145 .20691 L
.70396 .20723 L
.7047 .20732 L
.7054 .20741 L
.70603 .20749 L
.70671 .20526 L
.70736 .20535 L
.70805 .20545 L
.70928 .20562 L
Mistroke
.71862 .20692 L
.72334 .20756 L
.72566 .20787 L
.72782 .20815 L
.72902 .20831 L
.73029 .20153 L
.73102 .20162 L
.7317 .20171 L
.73299 .20187 L
.73528 .20216 L
.73654 .20232 L
.73771 .20247 L
.73874 .2026 L
.73984 .19912 L
.74107 .19929 L
.74218 .19944 L
.7463 .20002 L
.75558 .20129 L
.76028 .20193 L
.76286 .20227 L
.76412 .20244 L
.76527 .20259 L
.76627 .22768 L
.76733 .22793 L
.76839 .22818 L
.76954 .22844 L
.7707 .22644 L
.77178 .22671 L
.77424 .22732 L
.79451 .23237 L
.80452 .23485 L
.81537 .23752 L
.82035 .23874 L
.82562 .24002 L
.82778 .24055 L
.83011 .24112 L
.8308 .24129 L
.83145 .24145 L
.83267 .20388 L
.83381 .20404 L
.83506 .20421 L
.83756 .20456 L
.83888 .20474 L
.84027 .20494 L
.84149 .2051 L
.84218 .2052 L
.84282 .2043 L
.84395 .20447 L
.84517 .20465 L
.84763 .20501 L
Mistroke
.84884 .20519 L
.84996 .20535 L
.85097 .2055 L
.85205 .19857 L
.85313 .19877 L
.85432 .19899 L
.87482 .20276 L
.89535 .20649 L
.91414 .20985 L
.92342 .2115 L
.92596 .21195 L
.92867 .21243 L
.92999 .21266 L
.93123 .21288 L
.93234 .20953 L
.93355 .2098 L
.95199 .21395 L
.99 .22249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo00]oo`03001oogoo0?5oo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo00moo`03001oogoo0>eoo`007Woo00<007ooOol047oo0P00kGoo000NOol00`00
Oomoo`0BOol2003[Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol05goo00<007ooOol0iGoo
000NOol00`00Oomoo`0HOol2003UOol001ioo`03001oogoo01Yoo`800>=oo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo021oo`03001oogoo0=aoo`007Woo00<007oo
Ool08Goo0P00g7oo000NOol00`00Oomoo`0SOol2003JOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0:7oo00<007ooOol0e7oo000FOol40004Ool00`00Oomoo`0YOol2003DOol001Ioo`03001o
ogoo00Eoo`03001oogoo02]oo`800=9oo`005goo00<007ooOol017oo0P00ogoo0Goo000HOol00`00
Oomoo`03Ool00`00Oomoo`0aOol2003<Ool001Ioo`04001oogoo0004Ool00`00Oomoo`0cOol30039
Ool001Moo`8000Eoo`03001oogoo0?moo`007Woo00<007ooOol0>Woo0P00`goo000NOol00`00Oomo
o`0lOol30030Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0@Woo0`00^Woo000NOol00`00
Oomoo`15Ool3002gOol001ioo`03001oogoo04]oo`800;9oo`007Woo00<007ooOol0C7oo0P00/Goo
000NOol00`00Oomoo`1>Ool2002_Ool001ioo`03001oogoo05=oo`03001oogoo0:Uoo`007Woo00<0
07ooOol0E7oo1@000Woo1000X7oo000NOol00`00Oomoo`1OOol2002NOol001ioo`03001oogoo06Eo
o`D009Eoo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`1_Ool2002>Ool001ioo`03001oogoo
071oo`D000aoo`<007]oo`007Woo00<007ooOol0NGoo0`001Goo00<007ooOol00P0017oo0`00LWoo
000NOol00`00Oomoo`1lOol3000>Ool2001`Ool001ioo`03001oogoo09=oo`H001=oo`H001Aoo`@0
03Eoo`007Woo00<007ooOol0W7oo1P000goo00<007ooOol06goo10001goo1000;Goo000NOol00`00
Oomoo`2VOol4000XOol00`00Oomoo`05Ool00`00Oomoo`0ROol001ioo`03001oogoo0=Moo`<00003
Ool007oo029oo`0067oo0`000goo00<007ooOol0/Woo00<007ooOol03Goo00<007ooOol06goo0P00
7Goo000IOol00`00Oomoo`02Ool00`00Oomoo`2bOol00`00Oomoo`0=Ool00`00Oomoo`0MOol3000J
Ool001Ioo`D000=oo`800;=oo`<000eoo`03001oogoo01Aoo`l001Moo`005Woo00@007ooOol000Ao
o`03001oogoo0;9oo`<000eoo`03001oogoo00Qoo`d002Eoo`005goo00<007oo000017oo00<007oo
Ool0^Goo10001Goo00@007ooOomoo`L0039oo`0067oo0P0017oo00<007ooOol0_Goo0P000goo00D0
07ooOomoo`0003Qoo`007Woo00<007ooOol0`goo1000>7oo000NOol00`00Oomoo`32Ool00`00Oomo
o`0jOol001ioo`03001oogoo0<9oo`03001oogoo03Yoo`007Woo00<007ooOol0`Woo00<007ooOol0
>Woo000NOol00`00Oomoo`32Ool00`00Oomoo`0jOol001ioo`03001oogoo0;5oo`8000moo`03001o
ogoo03Yoo`007Woo00<007ooOol0[7oo1@0000=oo`00Ool03Goo00<007ooOol0>goo000NOol00`00
Oomoo`2/Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`0kOol001ioo`03001oogoo0:Yo
o`<000Eoo`03001oogoo00aoo`03001oogoo03]oo`007Woo00<007ooOol0ZWoo00<007ooOol01Goo
00<007ooOol037oo00<007ooOol0>goo000NOol00`00Oomoo`2XOol30007Ool00`00Oomoo`0<Ool0
0`00Oomoo`0kOol001ioo`03001oogoo0:Aoo`D000Uoo`03001oogoo00Yoo`<003eoo`007Woo00<0
07ooOol0Xgoo0P003Goo3@00@7oo000NOol00`00Oomoo`2OOol4000?Ool2001;Ool001ioo`03001o
ogoo09aoo`<0061oo`007Woo00<007ooOol0VGoo0`00Hgoo000NOol00`00Oomoo`2EOol4001VOol0
01ioo`03001oogoo091oo`D006Yoo`007Woo00<007ooOol0S7oo1000Kgoo000NOol00`00Oomoo`29
Ool3001cOol001Ioo`<000Eoo`03001oogoo08Ioo`<007Ioo`005Woo00@007ooOol000Aoo`03001o
ogoo08Aoo`8007Uoo`005Woo00@007ooOol000Aoo`80089oo`<007]oo`005Woo0`001Goo00<007oo
Ool0PGoo00<007ooOol0Ngoo000GOol00`00Oomoo`04Ool00`00Oomoo`21Ool00`00Oomoo`1kOol0
01Moo`<000Aoo`03001oogoo085oo`03001oogoo07]oo`007Woo00<007ooOol0P7oo0P00OGoo000N
Ool00`00Oomoo`1nOol2001oOol001ioo`03001oogoo07Yoo`@0085oo`007Woo00<007ooOol0N7oo
0P00QGoo000NOol00`00Oomoo`1fOol20027Ool001ioo`03001oogoo06ioo`8000Aoo`8008Uoo`00
7Woo00<007ooOol0KGoo0`000Woo0P00Rgoo000NOol00`00Oomoo`1ZOol30002Ool3002=Ool001io
o`03001oogoo06Qoo`8009Eoo`007Woo00<007ooOol0IWoo0P00Ugoo000NOol00`00Oomoo`1TOol2
002IOol001ioo`03001oogoo069oo`8009]oo`007Woo00<007ooOol0H7oo0P00WGoo000NOol00`00
Oomoo`1NOol2002OOol001ioo`03001oogoo05aoo`800:5oo`007Woo00<007ooOol0FGoo0`00Xgoo
000NOol00`00Oomoo`1HOol00`00Oomoo`2TOol001ioo`03001oogoo05Qoo`03001oogoo0:Aoo`00
7Woo00<007ooOol0F7oo00<007ooOol0Y7oo000NOol00`00Oomoo`1HOol00`00Oomoo`2TOol001io
o`03001oogoo05Moo`800:Ioo`005goo0P001Goo00<007ooOol0EWoo0P00Ygoo000FOol01000Oomo
o`0017oo00<007ooOol0E7oo0P00ZGoo000FOol01000Oomoo`0017oo0P00DGoo0P0000=oo`00Ool0
ZWoo000GOol20005Ool00`00Oomoo`1:Ool30002Ool01000Ool00000[7oo000FOol01000Oomoo`00
17oo00<007ooOol0BWoo00<007oo00000P00/7oo000GOol20005Ool00`00Oomoo`18Ool2002eOol0
01ioo`03001oogoo045oo`03001oogoo00=oo`03001oogoo0;Eoo`007Woo00<007ooOol0@7oo0P00
0goo0P00^7oo000NOol00`00Oomoo`0oOol01000Ool007oo0P00^Woo000NOol00`00Oomoo`0mOol2
0002Ool2002lOol001ioo`03001oogoo03aoo`03001oogoo009oo`800;aoo`007Woo00<007ooOol0
>goo00<007ooOol0`Goo000NOol00`00Oomoo`0jOol00`00Oomoo`32Ool001ioo`03001oogoo03Io
o`04001oo`000035Ool001ioo`03001oogoo00aoo`03001oogoo02Eoo`@00<Moo`007Woo00<007oo
Ool037oo00<007ooOol09Goo00@007oo00000<Moo`007Woo00<007ooOol037oo00<007ooOol08goo
0P00bgoo000NOol00`00Oomoo`0;Ool2000TOol00`00Oomoo`3;Ool001ioo`03001oogoo00]oo`80
02=oo`03001oogoo0<aoo`007Woo00<007ooOol037oo0P008Goo00<007ooOol0cGoo000NOol00`00
Oomoo`0<Ool2000POol00`00Oomoo`3>Ool001ioo`03001oogoo00aoo`8001]oo`05001oogooOol0
003AOol001ioo`03001oogoo00eoo`03001oo`0000aoo`800003Ool007oo009oo`03001oogoo009o
o`80009oo`03001oogoo0=1oo`007Woo00<007ooOol03Goo0`0037oo10000Woo0P000goo00<007oo
00000P00dgoo000NOol00`00Oomoo`0=Ool3000;Ool01P00Ool007oo001oo`<0009oo`04001oogoo
003EOol001ioo`03001oogoo00eoo`05001oo`00Ool00008Ool01@00Oomoo`00Ool00P000Woo0`00
fGoo000NOol00`00Oomoo`0?Ool30008Ool00`00Oomoo`02Ool20002Ool3003IOol0011oo`D0009o
o`8000Eoo`03001oogoo00moo`<00005Ool007ooOol00002Ool00`00Oomoo`3SOol0019oo`05001o
ogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Ool0000200001Goo000007oo0000
iWoo000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo0P004Woo0`0000Aoo`0000000>Moo`00
4Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo015oo`05001oo`00001oo`02003W
Ool0019oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`0COol200000goo001oo`3W
Ool0015oo`8000Aoo`8000Eoo`03001oogoo01=oo`03001oogoo0>Uoo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000Qoo`<0
0005Ool00000001oo`020002Ool30002Ool30004Ool400000goo000000020003Ool300000goo0000
0002Ool2003ZOol000Moo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo00@007ooOol00>]oo`001goo
00<007ooOol00goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003
Ool00`00Oomoo`02Ool40002Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool30004Ool20004
Ool00`00Oomoo`03Ool30002Ool40003Ool20002Ool4003/Ool000Moo`04001oogoo0002Ool00`00
Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`3kOol000Qoo`<00003Ool0000000Moo`04001oogoo
Ool20006Ool2003mOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(7.520048103295267`\)], "Print"],

Cell[BoxData[
    \({5.27`, 3.8470999999999997`, 7}\)], "Print"],

Cell[BoxData[
    \({4.`, 3.86`, 9}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .5175 m
.06877 .49345 L
.07837 .46878 L
.08321 .45697 L
.08839 .44478 L
.0909 .43903 L
.09214 .43623 L
.09328 .43368 L
.09431 .43138 L
.09541 .4665 L
.09651 .46433 L
.09773 .46197 L
.09904 .45943 L
.10047 .4567 L
.10112 .45545 L
.10182 .45413 L
.10307 .48519 L
.10371 .4841 L
.10439 .48292 L
.10564 .48081 L
.10796 .47689 L
.10866 .47573 L
.1094 .47449 L
.11011 .47503 L
.11075 .47397 L
.11215 .47166 L
.11295 .47035 L
.1137 .46915 L
.11432 .49742 L
.11499 .4964 L
.1164 .49424 L
.11897 .49037 L
.12352 .48523 L
.12591 .48172 L
.12722 .47982 L
.12843 .47807 L
.12908 .47713 L
.12977 .50099 L
.13054 .4999 L
.13124 .49892 L
.13382 .49533 L
.13887 .48989 L
.14874 .4766 L
.15114 .47345 L
.15246 .47172 L
.15371 .47009 L
.15442 .48902 L
.15519 .48801 L
.15654 .48624 L
.15919 .4828 L
Mistroke
.16901 .47148 L
.17791 .46036 L
.18025 .45749 L
.18148 .45599 L
.18215 .45517 L
.18278 .45441 L
.18392 .47431 L
.18516 .47298 L
.18735 .47066 L
.19741 .46022 L
.20189 .45567 L
.2041 .45346 L
.20613 .45144 L
.20727 .45031 L
.20848 .46317 L
.20969 .46207 L
.21039 .46143 L
.21102 .46085 L
.21213 .46558 L
.21332 .46452 L
.21548 .46261 L
.21673 .4615 L
.21791 .46047 L
.21897 .48023 L
.22012 .47919 L
.22508 .47474 L
.23399 .46808 L
.23664 .46575 L
.23793 .46463 L
.23911 .4636 L
.24036 .45429 L
.24104 .45375 L
.24169 .45325 L
.24452 .45104 L
.24917 .44745 L
.25044 .44648 L
.25114 .44594 L
.25179 .44544 L
.25295 .44908 L
.25422 .45959 L
.25537 .45875 L
.25659 .45785 L
.2588 .45624 L
.26381 .45259 L
.269 .44884 L
.27155 .44701 L
.2739 .44533 L
.27611 .44376 L
.27722 .44297 L
.27844 .43371 L
Mistroke
.27967 .43294 L
.28098 .43211 L
.28336 .43061 L
.29197 .42522 L
.31123 .41334 L
.31375 .41181 L
.31647 .41015 L
.31772 .4094 L
.31904 .4086 L
.32017 .40792 L
.3214 .3989 L
.32215 .40622 L
.32282 .4059 L
.32434 .40517 L
.32709 .40386 L
.33224 .40142 L
.33719 .39909 L
.34258 .39657 L
.34504 .39542 L
.34766 .39421 L
.3499 .39317 L
.35117 .39258 L
.35237 .39887 L
.35346 .39837 L
.35465 .39782 L
.35706 .39672 L
.36135 .39476 L
.37104 .39038 L
.41066 .36723 L
.41956 .36441 L
.42897 .36145 L
.43135 .3607 L
.43265 .36029 L
.43389 .35991 L
.43459 .35969 L
.43535 .35219 L
.43604 .35201 L
.43669 .35185 L
.4393 .35117 L
.44881 .34869 L
.46967 .34325 L
.48935 .33812 L
.49971 .33543 L
.50479 .33411 L
.50945 .3329 L
.51165 .33233 L
.5137 .3318 L
.51474 .33153 L
.51585 .32333 L
.51707 .32307 L
Mistroke
.51819 .32284 L
.52763 .32089 L
.5367 .31899 L
.54167 .31795 L
.5441 .31744 L
.54516 .31722 L
.54632 .31698 L
.54756 .31231 L
.54874 .31208 L
.55134 .31158 L
.55687 .31051 L
.56661 .30862 L
.58742 .30456 L
.59725 .30263 L
.60629 .30084 L
.61088 .29993 L
.6132 .29948 L
.61383 .29935 L
.61451 .29921 L
.61574 .28436 L
.61642 .28427 L
.61705 .28419 L
.61848 .284 L
.62108 .28365 L
.62596 .28301 L
.64449 .28051 L
.68282 .27518 L
.70204 .27243 L
.71967 .26986 L
.72444 .26916 L
.72676 .26882 L
.72777 .26867 L
.72887 .2685 L
.73002 .29609 L
.73111 .29603 L
.7335 .2959 L
.73856 .29561 L
.74121 .29546 L
.7437 .29532 L
.74495 .29525 L
.74565 .28092 L
.7463 .28092 L
.74915 .28092 L
.75892 .28092 L
.77749 .28092 L
.78257 .28092 L
.78799 .28092 L
.79063 .28092 L
.7931 .28092 L
.79419 .28092 L
Mistroke
.79533 .28092 L
.79658 .23617 L
.79773 .2361 L
.83485 .23402 L
.85553 .23286 L
.87437 .2318 L
.87891 .23154 L
.8814 .2314 L
.88373 .23127 L
.88494 .2312 L
.88562 .23117 L
.88625 .22474 L
.88689 .22474 L
.8876 .22474 L
.88902 .22474 L
.89391 .22474 L
.9124 .22474 L
.95205 .22474 L
.99 .22474 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .03105 m
.07837 .03674 L
.09773 .04515 L
.11903 .05836 L
.13887 .06803 L
.17603 .08145 L
.21411 .09931 L
.21645 .09995 L
.21713 .10013 L
.21777 .1003 L
.21897 .10516 L
.2201 .10548 L
.22115 .10577 L
.22353 .10643 L
.22828 .10801 L
.23352 .1094 L
.23625 .11011 L
.23759 .11046 L
.23882 .11078 L
.23951 .10897 L
.24024 .10916 L
.24178 .10957 L
.24447 .11028 L
.24929 .11152 L
.25061 .11186 L
.25134 .11204 L
.25203 .11222 L
.25267 .11352 L
.25336 .1137 L
.25458 .11694 L
.25574 .11725 L
.25699 .11759 L
.25925 .11819 L
.2644 .11955 L
.26948 .12086 L
.27226 .12156 L
.27484 .12221 L
.276 .1225 L
.27709 .12277 L
.27836 .12074 L
.2795 .12104 L
.28461 .12233 L
.29357 .12454 L
.33114 .1331 L
.34031 .13532 L
.34536 .13651 L
.34785 .1371 L
.35016 .13763 L
.35084 .13779 L
.35147 .13793 L
Mistroke
.3522 .14051 L
.35287 .14067 L
.35581 .14136 L
.36098 .14256 L
.37109 .14486 L
.38959 .15004 L
.39466 .1513 L
.4 .1526 L
.40457 .15371 L
.40582 .15401 L
.40651 .15417 L
.40716 .15433 L
.40842 .15028 L
.40957 .15055 L
.41902 .15277 L
.4242 .15396 L
.42905 .15507 L
.43106 .15552 L
.43317 .156 L
.43428 .15625 L
.43549 .15336 L
.43659 .15362 L
.43761 .15387 L
.44705 .15609 L
.48523 .16459 L
.49526 .1667 L
.50053 .16779 L
.50611 .16892 L
.511 .16991 L
.51234 .17017 L
.51307 .17032 L
.51377 .17046 L
.51442 .17059 L
.51513 .16663 L
.51636 .1669 L
.5258 .16892 L
.53575 .17101 L
.54062 .17201 L
.54275 .17245 L
.54396 .17269 L
.54509 .17292 L
.54619 .17314 L
.54737 .17097 L
.54863 .17123 L
.54978 .17146 L
.55483 .1725 L
.56559 .17467 L
.58588 .17861 L
.59479 .18029 L
.60461 .18209 L
Mistroke
.60914 .18291 L
.61164 .18336 L
.61287 .18358 L
.61402 .18378 L
.61508 .18397 L
.61622 .17519 L
.61748 .17544 L
.61862 .17567 L
.62283 .17652 L
.64214 .18033 L
.68128 .18763 L
.69924 .19078 L
.70943 .19251 L
.71894 .19409 L
.72378 .19488 L
.72615 .19527 L
.72835 .19562 L
.72958 .19582 L
.73019 .2162 L
.73088 .21637 L
.73362 .21707 L
.73843 .2183 L
.74092 .21893 L
.74354 .21959 L
.7442 .21976 L
.74491 .21994 L
.74569 .20948 L
.74641 .20969 L
.74904 .21042 L
.759 .21322 L
.76902 .21604 L
.77986 .21908 L
.78484 .22048 L
.79011 .22196 L
.79227 .22257 L
.79347 .2229 L
.7946 .22322 L
.79524 .2234 L
.79594 .188 L
.79716 .18824 L
.79955 .18869 L
.83931 .1962 L
.85771 .19962 L
.86739 .2014 L
.87759 .20326 L
.8828 .20421 L
.88423 .20447 L
.88502 .20462 L
.88576 .20475 L
.88645 .19922 L
Mistroke
.8872 .19939 L
.88851 .19968 L
.89855 .20194 L
.91826 .20637 L
.95816 .21534 L
.99 .22249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo00]oo`800?9oo`007Woo00<007ooOol03Goo0`00kgoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo01Aoo`03001oogoo0>Qoo`007Woo00<007ooOol05Goo00<007ooOol0igoo000N
Ool00`00Oomoo`0FOol2003WOol001ioo`03001oogoo01Qoo`03001oogoo0>Aoo`007Woo00<007oo
Ool0ogoo000NOol00`00Oomoo`0LOol00`00Oomoo`3POol001ioo`03001oogoo01eoo`800>1oo`00
7Woo00<007ooOol07goo0P00gWoo000NOol00`00Oomoo`0UOol00`00Oomoo`3GOol001ioo`03001o
ogoo02Ioo`800=Moo`007Woo00<007ooOol0:7oo0P00eGoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo02eoo`03001oogoo0<moo`007Woo00<007ooOol0;Woo0`00cWoo000FOol40004Ool00`00
Oomoo`0`Ool00`00Oomoo`3<Ool001Ioo`03001oogoo00Eoo`03001oogoo035oo`04001oogooOol2
0038Ool001Moo`03001oogoo00Aoo`8003Ioo`D00<Eoo`0067oo00<007ooOol00goo00<007ooOol0
>Goo00<007ooOol0`goo000FOol01000Oomoo`0017oo00<007ooOol0?Woo0P00_goo000GOol20005
Ool00`00Oomoo`0nOol00`00Ool00002002lOol001ioo`03001oogoo04Moo`800;Ioo`007Woo00<0
07ooOol0BGoo0`00/goo000NOol00`00Oomoo`1@Ool00`00Oomoo`2/Ool001ioo`03001oogoo059o
o`03001oogoo0:Yoo`007Woo00<007ooOol0Dgoo1000Z7oo000NOol00`00Oomoo`1MOol2002POol0
01ioo`03001oogoo05]oo`<00003Ool007oo00=oo`03001oogoo09Qoo`007Woo00<007ooOol0Hgoo
00<007oo00000P00Ugoo000NOol00`00Oomoo`1/Ool2002AOol001ioo`03001oogoo06ioo`@000Eo
o`03001oogoo08Eoo`007Woo00<007ooOol0MGoo0P0000=oo`00000017oo0`00OWoo000NOol00`00
Oomoo`1nOol00`00Oomoo`02000<Ool2001^Ool001ioo`03001oogoo08Moo`@000=oo`03001oogoo
00=oo`<006Qoo`007Woo00<007ooOol0Rgoo100027oo0`00IGoo000NOol00`00Oomoo`2NOol2001O
Ool001ioo`03001oogoo0:1oo`<001Ioo`04001oogooOol20010Ool001ioo`03001oogoo0:Moo`<0
00moo`03001oogoo00=oo`<003eoo`007Woo00<007ooOol0ZGoo00<007ooOol03Goo00<007ooOol0
2Woo1P000goo1000;7oo000NOol00`00Oomoo`2YOol00`00Oomoo`0=Ool00`00Oomoo`0GOol2000Z
Ool001ioo`03001oogoo0:eoo`8000Yoo`03001oogoo01eoo`8002Aoo`007Woo00<007ooOol0[Goo
00<007ooOol02Goo00<007ooOol07goo0`008Goo000HOol30003Ool00`00Oomoo`2[Ool30004Ool4
000/Ool3000JOol001Uoo`03001oogoo009oo`03001oogoo0:eoo`03001oogoo00Ioo`8002eoo`<0
01Moo`005Woo1@000goo0P00d7oo6@005goo000FOol01000Oomoo`0017oo00<007ooOol0bWoo1@00
<7oo000GOol00`00Ool00004Ool00`00Oomoo`2jOol@000eOol001Qoo`8000Aoo`03001oogoo0;Uo
o`03001oogoo04=oo`007Woo00<007ooOol0^Goo00<007ooOol0@goo000NOol00`00Oomoo`2iOol0
0`00Oomoo`13Ool001ioo`03001oogoo0;Uoo`03001oogoo04=oo`007Woo00<007ooOol0^Goo00<0
07ooOol0@goo000NOol00`00Oomoo`2iOol00`00Oomoo`13Ool001ioo`03001oogoo0;Uoo`03001o
ogoo04=oo`007Woo00<007ooOol0YWoo10003goo00<007ooOol0@goo000NOol00`00Oomoo`2QOol5
0003Ool00`00Oomoo`0=Ool00`00Oomoo`13Ool001ioo`03001oogoo09Yoo`L000Qoo`03001oogoo
00eoo`03001oogoo04=oo`007Woo00<007ooOol0U7oo1P003goo00@007ooOomoo`d004Eoo`007Woo
00<007ooOol0SWoo1P005Woo00@007ooOol0055oo`007Woo00<007ooOol0SWoo00<007ooOol06Goo
00@007ooOol0055oo`007Woo00<007ooOol0SWoo00<007ooOol06Goo00@007ooOol0055oo`007Woo
00<007ooOol0SWoo00<007ooOol06Goo1000DGoo000NOol00`00Oomoo`2:Ool5001`Ool001ioo`03
001oogoo08Ioo`@007Eoo`007Woo00<007ooOol0Ogoo1`00NGoo000NOol00`00Oomoo`1nOol00`00
Oomoo`1nOol001ioo`03001oogoo07aoo`<0081oo`007Woo00<007ooOol0Mgoo1@00Pgoo000FOol3
0005Ool00`00Oomoo`1gOol00`00Oomoo`25Ool001Ioo`04001oogoo0004Ool00`00Oomoo`1eOol3
0027Ool001Ioo`04001oogoo0004Ool2001dOol2002:Ool001Ioo`<000Eoo`03001oogoo06moo`@0
08aoo`005goo00<007ooOol017oo00<007ooOol0JWoo1@00T7oo000GOol30004Ool00`00Oomoo`1W
Ool3002EOol001ioo`03001oogoo06Aoo`<009Qoo`007Woo00<007ooOol0I7oo00<007ooOol0V7oo
000NOol00`00Oomoo`1ROol3002JOol001ioo`03001oogoo061oo`8009eoo`007Woo00<007ooOol0
GWoo0P00Wgoo000NOol00`00Oomoo`1LOol2002QOol001ioo`03001oogoo05Yoo`800:=oo`007Woo
00<007ooOol0F7oo0P00YGoo000NOol00`00Oomoo`1FOol2002WOol001ioo`03001oogoo05Aoo`80
0:Uoo`007Woo00<007ooOol0CWoo0`0000=oo`000000Zgoo000NOol00`00Oomoo`19Ool00`00Oomo
o`0300000goo0000002]Ool001ioo`03001oogoo04Qoo`@00;=oo`007Woo00<007ooOol0B7oo0P00
]Goo000NOol00`00Oomoo`16Ool3002fOol001ioo`03001oogoo04Eoo`03001oogoo0;Moo`007Woo
00<007ooOol0@goo0P00^Woo000NOol00`00Oomoo`12Ool00`00Oomoo`2jOol001ioo`03001oogoo
045oo`03001oogoo0;]oo`007Woo00<007ooOol04goo00<007ooOol0:Goo0P00_Woo000NOol00`00
Oomoo`0BOol2000[Ool00`00Oomoo`2mOol001Moo`8000Eoo`03001oogoo019oo`8002Yoo`03001o
ogoo0;ioo`005Woo00@007ooOol000Aoo`03001oogoo015oo`03001oo`0002Aoo`03001oogoo009o
o`800<1oo`005Woo00@007ooOol000Aoo`80019oo`03001oo`0001Yoo`03001oogoo00Eoo`<000=o
o`03001oogoo0<1oo`005goo0P001Goo00<007ooOol047oo00<007ooOol00`004Woo00<007ooOol0
0Woo0P001Woo0P0000Eoo`00Oomoo`000<=oo`005Woo00@007ooOol000Aoo`03001oogoo011oo`03
001oogoo00<0015oo`8000=oo`03001oo`0000Ioo`04001oogooOol20034Ool001Moo`8000Eoo`03
001oogoo011oo`03001oogoo00<0015oo`80009oo`03001oogoo00<000Aoo`03001oogoo0<Moo`00
7Woo00<007ooOol03goo00L007ooOomoo`00Ool0000@Ool01@00Ool007oo000017oo0P000goo0P00
bGoo000NOol00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Ool00009Ool01@00Oomoogoo00000Woo
0P001Woo00@007ooOol00<]oo`007Woo00<007ooOol03goo00<007ooOol00goo0`0027oo0P000Woo
00D007ooOomoo`0000Moo`03001oo`000<aoo`007Woo00<007ooOol03Woo00<007ooOol017oo0`00
0goo00T007ooOomoo`00Ool007oo000037oo0P00cGoo000NOol00`00Oomoo`0>Ool00`00Oomoo`04
Ool00`00Ool00002Ool20002Ool00`00Oomoo`02003LOol001ioo`03001oogoo00eoo`03001oogoo
00Eoo`05001oogoo001oo`020002Ool00`00Oomoo`02003LOol001ioo`03001oogoo00eoo`03001o
ogoo00Qoo`800004Ool007oo003QOol001ioo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo
00800>9oo`007Woo00<007ooOol037oo00<007ooOol037oo0P00hWoo000NOol00`00Oomoo`0<Ool0
0`00Oomoo`3`Ool001ioo`03001oogoo00aoo`03001oogoo0?1oo`007Woo00<007ooOol02goo00<0
07ooOol0lGoo000NOol00`00Oomoo`0;Ool00`00Oomoo`3aOol001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000@Ool5
0002Ool20005Ool00`00Oomoo`3oOol0019oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol0019oo`05001oogooOol00002Ool00`00Oomoo`02Ool2003oOol1Ool0019oo`05001o
ogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`3oOol0019oo`05001oogooOol00002Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol0015oo`8000Aoo`8000Eoo`03001oogoo0?moo`007Woo00<007oo
Ool0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
00Qoo`<00005Ool00000001oo`020002Ool30002Ool30004Ool400000goo000000020003Ool30000
0goo00000002Ool2003ZOol000Moo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo00@007ooOol00>]o
o`001goo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0003Ool00`00Oomoo`02Ool40002Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool30004
Ool20004Ool00`00Oomoo`03Ool30002Ool40003Ool20002Ool4003/Ool000Moo`04001oogoo0002
Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`3kOol000Qoo`<00003Ool0000000Moo`04
001oogooOol20006Ool2003mOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(2.923997945152223`\)], "Print"],

Cell[BoxData[
    \({5.`, 3.6499999999999995`, 8}\)], "Print"],

Cell[BoxData[
    \({4.`, 3.86`, 9}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .29041 m
.06454 .32483 L
.06558 .32384 L
.06671 .32277 L
.06778 .32177 L
.06877 .35497 L
.06994 .35356 L
.07119 .35208 L
.0734 .34949 L
.07577 .34674 L
.07641 .34599 L
.07711 .34519 L
.07837 .37299 L
.07965 .37119 L
.08084 .36954 L
.08355 .36581 L
.08848 .35916 L
.09295 .35324 L
.09424 .35156 L
.09546 .34999 L
.09655 .34858 L
.09773 .36933 L
.09897 .36748 L
.1003 .36551 L
.10269 .36198 L
.10815 .35412 L
.1138 .34621 L
.11916 .33894 L
.12155 .33575 L
.1241 .33241 L
.12473 .33158 L
.12542 .33068 L
.12618 .36679 L
.12689 .366 L
.12947 .36315 L
.13186 .36054 L
.13437 .35783 L
.13652 .35554 L
.13774 .35425 L
.13887 .38445 L
.14012 .38328 L
.14144 .38204 L
.1438 .37983 L
.14444 .37924 L
.14512 .37861 L
.14635 .3798 L
.1471 .3791 L
.14781 .37845 L
.14915 .37722 L
.15379 .37301 L
Mistroke
.15506 .37187 L
.15576 .37125 L
.15641 .37066 L
.15769 .39515 L
.15885 .39418 L
.177 .38137 L
.18195 .37739 L
.18436 .37547 L
.18656 .37374 L
.18775 .3728 L
.18888 .39137 L
.19008 .39043 L
.19137 .38941 L
.19664 .38528 L
.2147 .37451 L
.2239 .36954 L
.22642 .36819 L
.22913 .36674 L
.23038 .36608 L
.23106 .36572 L
.2317 .36539 L
.23282 .37135 L
.23404 .37787 L
.23533 .37727 L
.23672 .37663 L
.23925 .37546 L
.24397 .37329 L
.24666 .37207 L
.24812 .37141 L
.24884 .37108 L
.24949 .37079 L
.25066 .37358 L
.25191 .39129 L
.25256 .39099 L
.25328 .39066 L
.25457 .39007 L
.27386 .38135 L
.27854 .37925 L
.28101 .37815 L
.28235 .37755 L
.2836 .37699 L
.28427 .3767 L
.28498 .38217 L
.28577 .38182 L
.28649 .3815 L
.28915 .38033 L
.29436 .37804 L
.29562 .38605 L
.29681 .38558 L
.29747 .38532 L
Mistroke
.29819 .38504 L
.29945 .36709 L
.30065 .36672 L
.30192 .36633 L
.30421 .36562 L
.30918 .36409 L
.31465 .3624 L
.32365 .35962 L
.33337 .35662 L
.33594 .35583 L
.33866 .35499 L
.33977 .35465 L
.34097 .35428 L
.34166 .36366 L
.34229 .3635 L
.34351 .36319 L
.35306 .36077 L
.36172 .35859 L
.3709 .35628 L
.37551 .35512 L
.37677 .3548 L
.37813 .35446 L
.37942 .35414 L
.38059 .36204 L
.38167 .36177 L
.38268 .36153 L
.38496 .36097 L
.38955 .35985 L
.3946 .35862 L
.39936 .35745 L
.402 .35681 L
.40272 .35663 L
.40348 .35644 L
.40413 .35629 L
.40485 .33832 L
.40609 .3381 L
.40742 .33787 L
.40983 .33746 L
.45016 .3304 L
.47032 .32677 L
.48013 .32498 L
.48476 .32413 L
.489 .32335 L
.49013 .32314 L
.49119 .32294 L
.49229 .33798 L
.49349 .33784 L
.49833 .3373 L
.50711 .33631 L
.52637 .33415 L
Mistroke
.53128 .33359 L
.53661 .333 L
.53906 .33272 L
.54165 .33243 L
.54386 .33218 L
.54512 .33204 L
.5463 .30642 L
.54742 .30635 L
.54864 .30628 L
.55086 .30616 L
.55503 .30592 L
.56444 .3054 L
.60411 .30317 L
.64231 .30102 L
.6829 .29874 L
.70327 .2976 L
.71221 .29709 L
.71694 .29683 L
.72202 .29654 L
.72456 .2964 L
.72697 .29626 L
.72801 .29621 L
.72913 .29614 L
.73035 .28092 L
.73148 .28092 L
.74031 .28092 L
.75965 .28092 L
.7965 .28092 L
.83575 .28092 L
.87351 .28092 L
.89269 .28092 L
.91368 .28092 L
.92336 .28092 L
.93371 .28092 L
.93873 .28092 L
.9412 .28092 L
.94229 .28092 L
.94348 .28092 L
.94455 .22474 L
.94555 .22474 L
.94774 .22474 L
.95236 .22474 L
.99 .22474 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .01742 m
.09773 .03609 L
.13887 .05339 L
.17751 .06762 L
.21468 .0804 L
.23539 .0888 L
.24014 .09007 L
.24519 .09139 L
.24726 .09193 L
.2484 .09223 L
.24949 .09251 L
.25077 .09825 L
.25194 .09858 L
.25423 .09921 L
.26362 .10175 L
.27381 .10442 L
.2788 .1057 L
.28126 .10633 L
.28233 .1066 L
.28351 .10689 L
.28457 .10716 L
.28557 .10906 L
.28661 .10933 L
.28774 .10961 L
.29231 .11077 L
.29351 .11107 L
.29415 .11123 L
.29482 .1114 L
.29606 .11424 L
.29721 .11455 L
.29823 .11482 L
.29933 .11512 L
.30054 .11022 L
.30167 .11053 L
.31165 .11323 L
.3296 .11793 L
.33438 .11914 L
.33888 .12028 L
.34009 .12058 L
.34137 .1209 L
.34204 .12435 L
.34278 .12456 L
.34407 .12492 L
.34879 .12621 L
.35966 .12916 L
.36978 .13185 L
.37472 .13315 L
.37716 .13378 L
.37834 .13409 L
.37942 .13437 L
Mistroke
.38067 .13781 L
.38136 .13799 L
.382 .13817 L
.38483 .13892 L
.38977 .14024 L
.39876 .1426 L
.40122 .14324 L
.40257 .14358 L
.40382 .14391 L
.40489 .13698 L
.40604 .13729 L
.40847 .13794 L
.44891 .14842 L
.46916 .15341 L
.47806 .15554 L
.48278 .15666 L
.48526 .15724 L
.48787 .15785 L
.49021 .1584 L
.49085 .15855 L
.49154 .15871 L
.49277 .16652 L
.49398 .16686 L
.49512 .16718 L
.49726 .16778 L
.50606 .17025 L
.52535 .1756 L
.53487 .17821 L
.54007 .17963 L
.54261 .18032 L
.54372 .18062 L
.54493 .18095 L
.54604 .16732 L
.54706 .1676 L
.54908 .16816 L
.55353 .16938 L
.56296 .17197 L
.60128 .18238 L
.63811 .19223 L
.67734 .20256 L
.69535 .20724 L
.70557 .20988 L
.71508 .21233 L
.72453 .21475 L
.72725 .21545 L
.72858 .21579 L
.72982 .2161 L
.73094 .20534 L
.73212 .20567 L
.73463 .20638 L
Mistroke
.75522 .21216 L
.79219 .22255 L
.83155 .2336 L
.86943 .24424 L
.88869 .24965 L
.9097 .25556 L
.91945 .2583 L
.92983 .26121 L
.93487 .26263 L
.93962 .26396 L
.9417 .26455 L
.94283 .26486 L
.94389 .26516 L
.94503 .21239 L
.94629 .21267 L
.9485 .21317 L
.98651 .22171 L
.99 .22249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol037oo0P00lGoo000NOol00`00Oomoo`0>
Ool2003_Ool001ioo`03001oogoo011oo`800>eoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`0EOol2003XOol001ioo`03001oogoo01Moo`<00>Eoo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`0NOol00`00Oomoo`3NOol001ioo`03001oogoo01moo`800=ioo`007Woo00<007ooOol08Goo
0P00g7oo000NOol00`00Oomoo`3oOol001ioo`03001oogoo02Moo`800=Ioo`007Woo00<007ooOol0
:Goo0`00dgoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo031oo`800<eoo`007Woo00<007oo
Ool0<Woo0`00bWoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo03Qoo`03001oogoo0<Aoo`00
7Woo00<007ooOol0>7oo0P00aGoo000FOol40004Ool00`00Oomoo`0jOol30032Ool001Ioo`03001o
ogoo00Eoo`03001oogoo041oo`04001oogoo002kOol001Moo`03001oogoo00Aoo`80049oo`800003
Ool007oo0;Uoo`0067oo00<007ooOol00goo00<007ooOol0@goo00<007ooOol00Woo1000/goo000F
Ool01000Oomoo`0017oo00<007ooOol0C7oo0P00/Goo000GOol20005Ool00`00Oomoo`3oOol001io
o`03001oogoo055oo`800:aoo`007Woo00<007ooOol0Dgoo0`00ZGoo000NOol00`00Oomoo`1GOol2
002VOol001ioo`03001oogoo05Uoo`<0009oo`<009ioo`007Woo00<007ooOol0HGoo0`00Vgoo000N
Ool00`00Oomoo`1WOol3002EOol001ioo`03001oogoo06Yoo`<0099oo`007Woo00<007ooOol0LGoo
00<007ooOol0Rgoo000NOol00`00Oomoo`1aOol00`00Oomoo`2;Ool001ioo`03001oogoo075oo`80
00aoo`03001oogoo07eoo`007Woo00<007ooOol0Lgoo0P002goo0`00O7oo000NOol00`00Oomoo`1h
Ool20009Ool00`00Oomoo`1iOol001ioo`03001oogoo07Yoo`@000Yoo`8007Eoo`007Woo00<007oo
Ool0RWoo0`00LWoo000NOol00`00Oomoo`2AOol2001/Ool001ioo`03001oogoo09=oo`8006Yoo`00
7Woo00<007ooOol0UGoo00<007ooOol0Igoo000NOol00`00Oomoo`2JOol2001SOol001ioo`03001o
ogoo09aoo`@000Yoo`8005=oo`007Woo00<007ooOol0Xgoo0P001Woo0`00DGoo000NOol00`00Oomo
o`2UOol40005Ool3001>Ool001Qoo`<000=oo`03001oogoo0;Aoo`8002Yoo`8001eoo`006Goo00<0
07ooOol00Woo00<007ooOol0]Woo0`008goo00<007ooOol00goo0`006Woo000FOol50003Ool2002j
Ool00`00Oomoo`0POol<000GOol001Ioo`04001oogoo0004Ool00`00Oomoo`2nOol2000LOol00`00
Oomoo`0POol001Moo`03001oo`0000Aoo`03001oogoo0<1oo`<001Uoo`03001oogoo021oo`0067oo
0P0017oo00<007ooOol0agoo0P004goo00<007ooOol087oo000NOol00`00Oomoo`39Ool3000@Ool0
0`00Oomoo`0POol001ioo`03001oogoo0<]oo`03001oogoo00ioo`03001oogoo021oo`007Woo00<0
07ooOol0d7oo0P002Woo00<007ooOol087oo000NOol00`00Oomoo`3BOol30007Ool00`00Oomoo`0P
Ool001ioo`03001oogoo0=Uoo`04001oogoo000ROol001ioo`03001oogoo0=Yoo`<0029oo`007Woo
00<007ooOol0g7oo00<007ooOol087oo000NOol00`00Oomoo`3LOol00`00Oomoo`0POol001ioo`03
001oogoo0=aoo`03001oogoo021oo`007Woo00<007ooOol0ZWoo<`008Woo000NOol00`00Oomoo`2Z
Ool00`00Oomoo`1BOol001ioo`03001oogoo00]oo`03001oogoo09]oo`03001oogoo05=oo`007Woo
00<007ooOol02goo00<007ooOol0Vgoo00<007ooOol0Dgoo000NOol00`00Oomoo`0;Ool00`00Oomo
o`2<Ool@001EOol001ioo`03001oogoo00]oo`03001oogoo07Yooa8006Eoo`007Woo00<007ooOol0
2goo00<007ooOol0L7oo2P00Mgoo000NOol00`00Oomoo`0<Ool00`00Oomoo`1_Ool00`00Oomoo`1n
Ool001ioo`03001oogoo00aoo`03001oogoo06moo`03001oogoo07ioo`007Woo00<007ooOol037oo
00<007ooOol0Kgoo00<007ooOol0OWoo000NOol00`00Oomoo`0<Ool2001QOol3000<Ool00`00Oomo
o`1nOol001Ioo`<000Eoo`03001oogoo00aoo`8005aoo`D0009oo`03001oogoo00Yoo`03001oogoo
07ioo`005Woo00@007ooOol000Aoo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo04Qoo`D0
00Moo`03001oogoo00Qoo`<0081oo`005Woo00@007ooOol000Aoo`8000ioo`03001oogoo00Uoo`80
04Ioo`@000aoo`03001oo`0000P008=oo`005Woo0`001Goo00<007ooOol03Goo00<007ooOol02Goo
0P00@Goo1@0047oo0P00S7oo000GOol00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Ool00008Ool0
0`00Ool00011Ool00`00Oomoo`2POol001Moo`<000Aoo`03001oogoo00eoo`<000=oo`03001oogoo
009oo`03001oo`00045oo`03001oogoo0:1oo`007Woo00<007ooOol03Goo00<007oo00000goo00<0
07ooOol00P000Woo00@007ooOol002moo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo0:1o
o`007Woo00<007ooOol03Goo00<007oo00000Woo0P0000=oo`00Ool00goo00@007oo000002eoo`<0
00Ioo`<000Aoo`800:9oo`007Woo00<007ooOol03goo00D007ooOol007oo008000Aoo`04001oo`00
000YOol40003Ool00`00Ool000030003Ool4002TOol001ioo`03001oogoo00moo`<0009oo`03001o
ogoo00=oo`800003Ool007oo01Aoo`03001oogoo00ioo`<000Moo`800:moo`007Woo00<007ooOol0
3goo0P000goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol037oo0`0017oo00<007ooOol0
2Goo00<007ooOol0^7oo000NOol00`00Oomoo`0?Ool00`00Oomoo`0;Ool01000Oomoogoo0P001Woo
00<007ooOol00goo0P000goo00<007oo00000P002goo00<007ooOol0^7oo000NOol00`00Oomoo`0M
Ool01P00Ool00000Ool000Eoo`8000Aoo`03001oogoo00=oo`80009oo`03001oogoo00Aoo`800003
Ool000000;]oo`007Woo00<007ooOol07Goo0`000Woo00@007ooOomoo`800004Ool007ooOol2000:
Ool00`00Oomoo`02Ool200000goo00000002002kOol001ioo`03001oogoo01eoo`03001oogoo009o
o`04001oogoo0003Ool00`00Ool0000<Ool00`00Oomoo`020006Ool00`00Oomoo`2iOol001ioo`03
001oogoo029oo`<000Aoo`8000eoo`<00<Aoo`007Woo00<007ooOol08Woo00<007ooOol0fWoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001Moo`8000Eoo`03
001oogoo0?moo`005Woo00@007ooOol000Aoo`03001oogoo0?moo`005Woo00@007ooOol000Aoo`80
0?moo`5oo`005goo0P001Goo00<007ooOol0ogoo000FOol01000Oomoo`0017oo00<007ooOol0ogoo
000GOol20005Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo
0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol0011oo`D0009oo`8000Eoo`03001oogoo0?moo`004Woo00D007oo
Oomoo`00009oo`03001oogoo009oo`03001oogoo0?moo`004Woo00D007ooOomoo`00009oo`03001o
ogoo009oo`800?moo`5oo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo0?mo
o`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo0?moo`004Goo0P0017oo0P00
1Goo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007oo
Ool0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`0027oo0`0000Eoo`00000007oo0080009oo`<0009oo`<0
00Aoo`@00003Ool00000008000=oo`<00003Ool00000009oo`800>Yoo`001goo00<007ooOol00goo
00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`@0009oo`04001oogoo
003[Ool000Moo`03001oogoo00=oo`<000Aoo`8000Aoo`03001oogoo00=oo`<0009oo`@000=oo`80
009oo`@00>aoo`001goo00@007ooOol0009oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo
0?]oo`0027oo0`0000=oo`0000001goo00@007ooOomoo`8000Ioo`800?eoo`00ogoo8Goo003oOolQ
Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(1.4930995916947722`\)], "Print"],

Cell[BoxData[
    \({5.`, 3.6499999999999995`, 8}\)], "Print"],

Cell[BoxData[
    \({5.`, 4.825`, 8}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 0 m
.06877 0 L
.07837 0 L
.08321 0 L
.08587 0 L
.08839 0 L
.08953 0 L
.09073 0 L
.09136 .05618 L
.09206 .05618 L
.09328 .05618 L
.09541 .05618 L
.09653 .05618 L
.09773 .05618 L
.09847 .05618 L
.09915 .1068 L
.09983 .10676 L
.10047 .10673 L
.10307 .10658 L
.10545 .10645 L
.10675 .10637 L
.10796 .1063 L
.1086 .10627 L
.10927 .15081 L
.11003 .15069 L
.11072 .15058 L
.11325 .15019 L
.11622 .14972 L
.11897 .1493 L
.12134 .14893 L
.12254 .14874 L
.12323 .18651 L
.12387 .18632 L
.12919 .18482 L
.13381 .18352 L
.13887 .18211 L
.14128 .18144 L
.1426 .18108 L
.14385 .18073 L
.14501 .18041 L
.14627 .20991 L
.14742 .20944 L
.14847 .209 L
.15858 .20487 L
.16736 .20136 L
.16949 .20052 L
.17067 .20005 L
.17178 .19961 L
.17241 .2237 L
.1731 .22352 L
Mistroke
.1743 .22318 L
.17665 .22254 L
.18186 .22112 L
.18675 .2198 L
.19115 .21862 L
.19235 .2183 L
.19362 .21797 L
.19471 .23358 L
.1959 .26366 L
.19656 .26346 L
.19728 .26323 L
.19791 .26304 L
.19858 .26283 L
.19985 .26704 L
.20102 .26667 L
.2065 .26498 L
.21639 .26196 L
.22086 .2606 L
.22557 .25919 L
.22803 .25845 L
.22871 .25824 L
.22943 .25803 L
.23011 .25783 L
.23072 .27651 L
.23189 .27623 L
.23315 .27592 L
.23435 .27564 L
.23544 .2799 L
.23648 .27965 L
.23758 .27938 L
.23958 .27889 L
.24413 .27779 L
.25331 .27557 L
.2558 .27497 L
.25717 .27464 L
.25846 .27434 L
.25955 .27407 L
.26072 .28233 L
.26136 .28221 L
.26203 .28208 L
.26322 .28185 L
.27402 .27974 L
.27855 .27887 L
.28105 .27839 L
.28227 .27815 L
.2834 .27793 L
.28405 .28923 L
.28473 .29497 L
.28542 .29485 L
.28618 .29472 L
Mistroke
.28871 .29428 L
.29366 .29343 L
.30339 .29173 L
.30818 .2909 L
.31263 .29012 L
.3139 .2899 L
.3151 .28969 L
.31576 .28957 L
.31648 .29123 L
.31773 .29103 L
.31913 .2908 L
.32062 .29057 L
.32189 .29037 L
.32261 .29025 L
.32328 .30078 L
.32455 .30064 L
.32574 .30051 L
.32799 .30025 L
.33302 .29969 L
.35083 .29769 L
.36096 .29655 L
.36593 .29599 L
.37047 .29548 L
.375 .29497 L
.37728 .29471 L
.37857 .29457 L
.37977 .30264 L
.3804 .30257 L
.38108 .30249 L
.38231 .30234 L
.38462 .30207 L
.3898 .30146 L
.39498 .30085 L
.40047 .3002 L
.40516 .29964 L
.40645 .29948 L
.40715 .2994 L
.40783 .29932 L
.40845 .31416 L
.40913 .31412 L
.41032 .31406 L
.45008 .31182 L
.48836 .30967 L
.52903 .30739 L
.56823 .30518 L
.60594 .30306 L
.64605 .30081 L
.68468 .29864 L
.70413 .29755 L
.71262 .29707 L
Mistroke
.72183 .29655 L
.72431 .29641 L
.72694 .29627 L
.72802 .29621 L
.72918 .29614 L
.73046 .28092 L
.73165 .28092 L
.74094 .28092 L
.76138 .28092 L
.80162 .28092 L
.84038 .28092 L
.87767 .28092 L
.91735 .28092 L
.95554 .28092 L
.99 .28092 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 0 m
.06877 0 L
.07837 0 L
.08321 0 L
.08587 0 L
.08839 0 L
.08953 0 L
.09073 0 L
.09136 .00513 L
.09206 .00517 L
.09328 .00524 L
.09541 .00536 L
.09653 .00542 L
.09773 .00549 L
.09847 .00553 L
.09915 .01059 L
.09983 .01066 L
.10047 .01072 L
.10307 .01099 L
.10545 .01122 L
.10675 .01136 L
.10796 .01148 L
.1086 .01154 L
.10927 .01648 L
.11003 .01658 L
.11072 .01667 L
.11325 .01701 L
.11622 .0174 L
.11897 .01776 L
.12134 .01807 L
.12254 .01823 L
.12323 .02298 L
.12387 .02308 L
.12919 .02388 L
.13381 .02456 L
.13887 .02529 L
.14128 .02563 L
.1426 .02582 L
.14385 .026 L
.14501 .02616 L
.14627 .0307 L
.14742 .03087 L
.14847 .03103 L
.15858 .03249 L
.16736 .0337 L
.16949 .03399 L
.17067 .03414 L
.17178 .03429 L
.17241 .03857 L
.1731 .03869 L
Mistroke
.1743 .0389 L
.17665 .03931 L
.18186 .04021 L
.18675 .04105 L
.19115 .04179 L
.19235 .04199 L
.19362 .0422 L
.19471 .04548 L
.1959 .05165 L
.19656 .05179 L
.19728 .05193 L
.19791 .05206 L
.19858 .05219 L
.19985 .05337 L
.20102 .05361 L
.2065 .05472 L
.21639 .05669 L
.22086 .05756 L
.22557 .05846 L
.22803 .05893 L
.22871 .05906 L
.22943 .0592 L
.23011 .05933 L
.23072 .0638 L
.23189 .06405 L
.23315 .06433 L
.23435 .06459 L
.23544 .0659 L
.23648 .06613 L
.23758 .06637 L
.23958 .06682 L
.24413 .06782 L
.25331 .0698 L
.2558 .07034 L
.25717 .07063 L
.25846 .0709 L
.25955 .07113 L
.26072 .07361 L
.26136 .07376 L
.26203 .07391 L
.26322 .07419 L
.27402 .07666 L
.27855 .07768 L
.28105 .07824 L
.28227 .07851 L
.2834 .07877 L
.28405 .08216 L
.28473 .08399 L
.28542 .08416 L
.28618 .08434 L
Mistroke
.28871 .08496 L
.29366 .08617 L
.33302 .0998 L
.35114 .10452 L
.36071 .10698 L
.3709 .10958 L
.3738 .11031 L
.37652 .111 L
.37771 .1113 L
.37897 .11162 L
.37963 .1149 L
.38035 .11508 L
.38162 .11541 L
.39156 .11796 L
.39646 .1192 L
.40171 .12053 L
.40425 .12117 L
.40551 .12149 L
.40666 .12178 L
.40771 .12204 L
.40883 .12843 L
.40995 .12875 L
.41118 .12911 L
.45046 .14045 L
.48825 .1512 L
.52845 .16245 L
.56716 .17312 L
.60439 .18322 L
.64402 .1938 L
.68217 .20382 L
.70163 .20887 L
.71187 .21151 L
.71747 .21294 L
.72271 .21429 L
.72738 .21548 L
.72872 .21582 L
.73 .21615 L
.73114 .2054 L
.73239 .20575 L
.74304 .20874 L
.76177 .214 L
.80153 .22517 L
.83981 .23592 L
.88049 .24735 L
.91968 .25836 L
.9574 .26896 L
.99 .27812 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo019oo`<001Moo`03001oogoo02aoo`03001oogoo02eoo`03001o
ogoo02aoo`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol04Woo00<007oo
Ool0jWoo000NOol00`00Oomoo`0BOol01000Oomoogoo0P00igoo000NOol00`00Oomoo`0BOol00`00
Oomoo`02Ool4003TOol001ioo`03001oogoo019oo`03001oogoo00Eoo`03001oogoo0>9oo`007Woo
00<007ooOol04Woo00<007ooOol02Woo00<007ooOol0gGoo000NOol00`00Oomoo`0BOol00`00Oomo
o`0:Ool5003KOol001ioo`03001oogoo019oo`03001oogoo0>Yoo`007Woo00<007ooOol04Woo00<0
07ooOol04goo0`00e7oo000NOol00`00Oomoo`0BOol00`00Oomoo`0EOol2003COol001ioo`03001o
ogoo019oo`03001oogoo01Ioo`03001oogoo0=5oo`007Woo00<007ooOol04Woo00<007ooOol0jWoo
000NOol00`00Oomoo`0BOol3000JOol5003;Ool001ioo`03001oogoo01Aoo`03001oogoo01aoo`03
001oogoo0<Uoo`007Woo00<007ooOol057oo00<007ooOol0j7oo000NOol00`00Oomoo`0DOol00`00
Oomoo`0POol40034Ool001ioo`03001oogoo01Aoo`03001oogoo02=oo`<00<9oo`007Woo00<007oo
Ool057oo00<007ooOol0j7oo000NOol00`00Oomoo`0DOol00`00Oomoo`0YOol00`00Oomoo`2lOol0
01ioo`03001oogoo01Aoo`03001oogoo02Uoo`04001oo`00002kOol001ioo`03001oogoo01Aoo`03
001oogoo02eoo`800;Uoo`007Woo00<007ooOol057oo00<007ooOol0;goo0P00]goo000NOol00`00
Oomoo`0DOol00`00Oomoo`0dOol3002aOol001Ioo`@000Aoo`03001oogoo01Aoo`03001oogoo03Mo
o`<00:ioo`005Woo00<007ooOol01Goo00<007ooOol057oo0`00j7oo000GOol00`00Oomoo`04Ool2
000GOol00`00Oomoo`0kOol3002XOol001Qoo`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo
03ioo`800:Ioo`005Woo00@007ooOol000Aoo`03001oogoo01Ioo`03001oogoo04Aoo`03001oogoo
09moo`005goo0P001Goo00<007ooOol05Woo00<007ooOol0A7oo00<007ooOol0Wgoo000NOol00`00
Oomoo`0FOol00`00Oomoo`14Ool2002POol001ioo`03001oogoo01Ioo`03001oogoo04Ioo`8009io
o`007Woo00<007ooOol05Woo00<007ooOol0C7oo00<007ooOol0Ugoo000NOol00`00Oomoo`0FOol0
0`00Oomoo`1=Ool4002EOol001ioo`03001oogoo01Ioo`03001oogoo0>Ioo`007Woo00<007ooOol0
5Woo1@00Dgoo1000SGoo000NOol00`00Oomoo`0JOol00`00Oomoo`1EOol2002;Ool001ioo`03001o
ogoo01Yoo`03001oogoo05Yoo`8008Ioo`007Woo00<007ooOol06Woo00<007ooOol0G7oo0P00Q7oo
000NOol00`00Oomoo`0JOol00`00Oomoo`1NOol20022Ool001ioo`03001oogoo01Yoo`03001oogoo
06=oo`8007eoo`007Woo00<007ooOol06Woo00<007ooOol0IGoo1000NGoo000NOol00`00Oomoo`0J
Ool01000Oomoogoo0P00JGoo0P00M7oo000NOol00`00Oomoo`0JOol6001[Ool2001bOol001ioo`03
001oogoo01Yoo`03001oogoo009oo`03001oogoo06]oo`80071oo`007Woo00<007ooOol07goo00<0
07ooOol0LGoo0`00JGoo000NOol00`00Oomoo`0OOol00`00Oomoo`1dOol2001WOol001ioo`03001o
ogoo01moo`03001oogoo009oo`8007Ioo`03001oogoo061oo`007Woo00<007ooOol07goo00<007oo
Ool00P0000=oo`00Ool0MWoo1000GWoo000NOol00`00Oomoo`0OOol30003Ool00`00Oomoo`24Ool3
001@Ool001ioo`03001oogoo02Eoo`03001oogoo07eoo`D000Eoo`8004ioo`0067oo0`000goo00<0
07ooOol09Goo00<007ooOol00Woo00<007ooOol0O7oo0P002Woo0P00B7oo000IOol00`00Oomoo`02
Ool00`00Oomoo`0UOol6002<Ool20016Ool001Ioo`D000=oo`8002Ioo`8000=oo`03001oogoo08ao
o`8004Aoo`005Woo00@007ooOol000Aoo`03001oogoo02]oo`03001oogoo091oo`<003ioo`005goo
00<007oo000017oo00<007ooOol0:goo00<007ooOol0Tgoo0`00>goo000HOol20004Ool00`00Oomo
o`0[Ool00`00Oomoo`3AOol001ioo`03001oogoo02]oo`03001oogoo09Uoo`<003Eoo`007Woo00<0
07ooOol0:goo00<007ooOol0W7oo0`00<Woo000NOol00`00Oomoo`0[Ool00`00Oomoo`2ROol3000/
Ool001ioo`03001oogoo02]oo`03001oogoo0:Eoo`<002Uoo`007Woo00<007ooOol0:goo00<007oo
Ool00goo0`00bgoo000NOol00`00Oomoo`0[Ool60002Ool00`00Oomoo`2TOol2000SOol001ioo`03
001oogoo02aoo`03001oogoo00Aoo`03001oogoo0:Ioo`<0021oo`007Woo00<007ooOol0<goo00<0
07ooOol017oo00<007ooOol0YWoo0P006Woo000NOol00`00Oomoo`0cOol200000goo000000030004
Ool2002TOol3000GOol001ioo`03001oogoo03Aoo`8000Aoo`L006Uooch001Moo`007Woo00<007oo
Ool0@7oo00<007ooOol0Igoo00<007ooOol0DWoo000NOol00`00Oomoo`10Ool00`00Oomoo`03Ool4
001OOol00`00Oomoo`1COol001ioo`03001oogoo041oo`H0009oo`8000]oo`80059oo`03001oogoo
05=oo`007Woo00<007ooOol0BGoo00<007ooOol00Woo1`0000=oo`00Ool01Goo00<007ooOol0>goo
3`00EGoo000NOol00`00Oomoo`19Ool50009Ool7000ZOolC001TOol001ioo`03001oogoo05eoo`03
001oogoo01Iooa8007Moo`007Woo00<007ooOol0GGoo00<007ooOol00goo4`00RGoo000NOol00`00
Oomoo`1MOol6002LOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000FOol30005Ool0
0`00Oomoo`3oOol001Ioo`04001oogoo0004Ool00`00Oomoo`3oOol001Ioo`04001oogoo0004Ool2
003oOol1Ool001Ioo`<000Eoo`03001oogoo0?moo`005goo00<007ooOol017oo00<007ooOol0ogoo
000GOol30004Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo
0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001Moo`8000Eoo`03001oogoo0?moo`005Woo00@007ooOol000Ao
o`03001oogoo0?moo`005Woo00@007ooOol000Aoo`800?moo`5oo`005goo0P001Goo00<007ooOol0
ogoo000FOol01000Oomoo`0017oo00<007ooOol0ogoo000GOol20005Ool00`00Oomoo`3oOol001io
o`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo
0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo
00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0011oo`D0
009oo`8000Eoo`03001oogoo0?moo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001o
ogoo0?moo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`800?moo`5oo`004Woo00D007oo
Oomoo`00009oo`03001oogoo009oo`03001oogoo0?moo`004Woo00D007ooOomoo`00009oo`03001o
ogoo009oo`03001oogoo0?moo`004Goo0P0017oo0P001Goo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo
0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
27oo0`0000Eoo`00000007oo0080009oo`<0009oo`<000Aoo`@00003Ool00000008000=oo`<00003
Ool00000009oo`800>Yoo`001goo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo009oo`03
001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01000Oomoo`00jgoo
0007Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Ool000=oo`03001oogoo009oo`@0009oo`04001oogoo003[Ool000Moo`03001oogoo00=oo`<000Ao
o`8000Aoo`03001oogoo00=oo`<0009oo`@000=oo`80009oo`@00>aoo`001goo00@007ooOol0009o
o`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo0?]oo`0027oo0`0000=oo`0000001goo00@0
07ooOomoo`8000Ioo`800?eoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(301.54670480731875`\)], "Print"],

Cell[BoxData[
    \({5.539999999999999`, 4.0442`, 6}\)], "Print"],

Cell[BoxData[
    \({4.035`, 3.893775`, 8}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .54523 m
.06454 .55966 L
.06558 .55741 L
.06671 .55499 L
.06778 .55272 L
.06877 .57369 L
.06994 .57145 L
.07119 .56908 L
.0734 .56494 L
.07462 .56267 L
.07577 .58129 L
.07702 .57916 L
.07767 .57805 L
.07837 .57687 L
.07965 .5765 L
.08084 .5745 L
.08157 .57328 L
.08226 .57213 L
.08355 .5881 L
.08478 .58617 L
.08592 .58439 L
.08716 .58424 L
.08779 .58326 L
.08848 .58219 L
.09079 .5786 L
.09206 .57664 L
.09326 .57478 L
.09438 .57306 L
.0956 .58659 L
.0967 .58671 L
.09773 .58518 L
.10229 .57839 L
.10721 .57112 L
.10858 .5691 L
.10933 .568 L
.11003 .56697 L
.11126 .56687 L
.11191 .56591 L
.11261 .57723 L
.11326 .57627 L
.11398 .57523 L
.11526 .57334 L
.11768 .56982 L
.12303 .56202 L
.12573 .5581 L
.12647 .55703 L
.12727 .55589 L
.12802 .5548 L
.1287 .57186 L
.12933 .57108 L
Mistroke
.13 .57024 L
.1312 .56875 L
.1326 .567 L
.13329 .56615 L
.13392 .56536 L
.13517 .56563 L
.13583 .56481 L
.13652 .56395 L
.13887 .56103 L
.14007 .55955 L
.1407 .55877 L
.14137 .55795 L
.1426 .57112 L
.14373 .56987 L
.14815 .56501 L
.15043 .56252 L
.15162 .56121 L
.15288 .55985 L
.15355 .57128 L
.15428 .57048 L
.15557 .56907 L
.15809 .56633 L
.1593 .56501 L
.16044 .56377 L
.16147 .56265 L
.16258 .57437 L
.16379 .57316 L
.16508 .57187 L
.16737 .56958 L
.1684 .56855 L
.1695 .56746 L
.17054 .56999 L
.17149 .56905 L
.176 .56459 L
.18502 .55768 L
.18997 .55281 L
.19462 .54825 L
.19579 .54711 L
.19702 .5459 L
.19767 .55502 L
.19837 .55435 L
.19962 .55318 L
.20033 .55251 L
.201 .55188 L
.20177 .55445 L
.20247 .55379 L
.20514 .55128 L
.21488 .54214 L
.22436 .5333 L
.2344 .52401 L
Mistroke
.23853 .52021 L
.24297 .51615 L
.24428 .51496 L
.24552 .51383 L
.24663 .51281 L
.24785 .52425 L
.24899 .52333 L
.25021 .52234 L
.25241 .52058 L
.29304 .49289 L
.29431 .47927 L
.29551 .48358 L
.29618 .48313 L
.2969 .48264 L
.29817 .48178 L
.30295 .47854 L
.30795 .4752 L
.31343 .47158 L
.31815 .46849 L
.32317 .46524 L
.32523 .46391 L
.32745 .46249 L
.32873 .46168 L
.32989 .46967 L
.33101 .46898 L
.33218 .46826 L
.3345 .46684 L
.33564 .46615 L
.33669 .46551 L
.3379 .47203 L
.33854 .47165 L
.33921 .47125 L
.3415 .46988 L
.35017 .46475 L
.36984 .45338 L
.37977 .44779 L
.38919 .44257 L
.39329 .44032 L
.39553 .4391 L
.39664 .4385 L
.39765 .43795 L
.39885 .42983 L
.39949 .42949 L
.40016 .42913 L
.40243 .42791 L
.40686 .42554 L
.42587 .41561 L
.43572 .4106 L
.44114 .40789 L
.44627 .40535 L
Mistroke
.4511 .40298 L
.45178 .40231 L
.45242 .402 L
.45309 .40168 L
.45382 .40132 L
.45503 .38665 L
.45572 .38635 L
.45634 .38609 L
.4655 .38218 L
.48342 .37391 L
.52218 .35791 L
.54174 .35092 L
.55025 .34793 L
.55259 .34711 L
.55386 .34667 L
.55505 .34626 L
.55607 .3459 L
.55716 .34397 L
.55837 .34357 L
.55947 .34321 L
.5619 .34241 L
.56318 .34199 L
.56388 .34175 L
.56454 .34154 L
.56573 .34954 L
.56636 .34933 L
.56704 .34909 L
.56935 .34831 L
.57867 .34517 L
.58845 .34188 L
.59362 .34015 L
.59646 .3392 L
.59915 .33831 L
.60038 .3379 L
.60169 .33746 L
.60238 .33723 L
.60313 .33478 L
.60381 .33456 L
.60445 .33436 L
.60697 .33358 L
.60928 .33287 L
.61039 .33252 L
.61161 .33214 L
.61276 .33179 L
.61382 .3235 L
.61506 .32313 L
.61619 .3228 L
.61871 .32206 L
.62944 .31893 L
.63415 .31757 L
Mistroke
.63664 .31684 L
.63931 .31607 L
.64058 .31571 L
.64179 .31536 L
.64287 .31505 L
.64405 .29982 L
.64516 .29954 L
.64634 .29923 L
.64847 .29869 L
.64954 .29809 L
.65068 .29781 L
.65192 .2975 L
.65306 .29721 L
.65431 .29545 L
.65502 .29529 L
.65568 .29513 L
.65813 .29456 L
.67847 .28982 L
.69679 .2856 L
.70181 .28445 L
.70712 .28324 L
.71166 .28222 L
.7129 .28193 L
.71358 .28178 L
.71423 .28163 L
.71549 .27894 L
.71664 .27871 L
.72148 .27773 L
.72663 .27669 L
.72792 .27643 L
.7286 .27629 L
.72931 .27615 L
.73011 .31125 L
.73084 .31117 L
.73228 .31101 L
.73751 .31042 L
.7572 .30821 L
.7665 .30716 L
.77644 .30605 L
.78127 .3055 L
.78364 .30524 L
.78468 .30512 L
.78583 .30499 L
.78686 .30488 L
.78782 .29285 L
.78883 .29279 L
.78993 .29273 L
.79437 .29248 L
.81362 .2914 L
.82379 .29082 L
Mistroke
.82937 .29051 L
.83463 .29022 L
.8371 .29008 L
.83844 .29 L
.8397 .28993 L
.84036 .28989 L
.84106 .24379 L
.84184 .24369 L
.84256 .24361 L
.8432 .24352 L
.8439 .24344 L
.84518 .24214 L
.84633 .24201 L
.84759 .24187 L
.85015 .24158 L
.85475 .24106 L
.86384 .24004 L
.8688 .23948 L
.87341 .23896 L
.87569 .23871 L
.87697 .23856 L
.87812 .23159 L
.8794 .23152 L
.88077 .23144 L
.88327 .2313 L
.89231 .23079 L
.91268 .22965 L
.95265 .2274 L
.99 .22474 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .03271 m
.09773 .05719 L
.13887 .07791 L
.17751 .09996 L
.21468 .11643 L
.25423 .13198 L
.29231 .14424 L
.33278 .15571 L
.33523 .15635 L
.33593 .15653 L
.3366 .15671 L
.33786 .15949 L
.33904 .15981 L
.34014 .1601 L
.34262 .16076 L
.34759 .16207 L
.35306 .16349 L
.37177 .16815 L
.38112 .17037 L
.38993 .17241 L
.39481 .17351 L
.39614 .17381 L
.39687 .17398 L
.39755 .17413 L
.39876 .17142 L
.3994 .17156 L
.40008 .1717 L
.40928 .17364 L
.42863 .17754 L
.43883 .1795 L
.44442 .18055 L
.44716 .18106 L
.44836 .18128 L
.44967 .18152 L
.45084 .18174 L
.45192 .18178 L
.45307 .18199 L
.4543 .1758 L
.45494 .17592 L
.45564 .17605 L
.45691 .17629 L
.45928 .17674 L
.46988 .17871 L
.48858 .18169 L
.50761 .18501 L
.52854 .18796 L
.53812 .18953 L
.5434 .19037 L
.54842 .19116 L
.55307 .19188 L
Mistroke
.55434 .19208 L
.55504 .19219 L
.5557 .19229 L
.55698 .19162 L
.55814 .1918 L
.5624 .19248 L
.56357 .19266 L
.56481 .19285 L
.56586 .19777 L
.56702 .19795 L
.57765 .19958 L
.5877 .20107 L
.59673 .20236 L
.59921 .2027 L
.60056 .20289 L
.60183 .20307 L
.60291 .20188 L
.60407 .20205 L
.60654 .20241 L
.60878 .20274 L
.61117 .20308 L
.61188 .20318 L
.61254 .20327 L
.61379 .19856 L
.61496 .19873 L
.61622 .19891 L
.6264 .20033 L
.631 .20096 L
.63587 .20161 L
.64002 .20216 L
.64116 .20231 L
.64238 .20247 L
.64353 .19303 L
.64459 .19317 L
.68346 .19729 L
.70123 .19956 L
.7061 .20016 L
.70866 .20048 L
.71135 .2008 L
.7125 .20094 L
.71372 .20109 L
.71442 .20117 L
.71506 .19952 L
.71631 .19969 L
.72086 .2003 L
.72562 .20092 L
.72692 .20109 L
.7283 .20127 L
.72948 .20142 L
.73015 .22726 L
Mistroke
.73078 .2274 L
.74015 .22954 L
.76065 .23414 L
.7708 .23639 L
.7758 .23749 L
.78044 .2385 L
.78463 .23941 L
.78584 .23967 L
.78697 .23992 L
.78799 .23075 L
.78909 .23103 L
.79853 .23337 L
.81764 .23807 L
.82775 .24055 L
.83332 .2419 L
.83606 .24257 L
.83726 .24286 L
.83859 .24319 L
.83984 .24349 L
.84102 .20504 L
.84226 .20521 L
.84295 .20531 L
.8436 .20539 L
.84426 .20451 L
.84498 .20462 L
.84643 .20483 L
.84903 .20521 L
.85855 .2066 L
.86749 .20788 L
.87219 .20854 L
.87477 .2089 L
.87602 .20908 L
.87717 .20924 L
.8784 .20341 L
.87908 .20354 L
.87972 .20365 L
.88252 .20416 L
.88746 .20506 L
.89716 .20681 L
.91532 .21006 L
.95268 .21664 L
.99 .22249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo00]oo`03001oogoo0?5oo`007Woo00<007ooOol037oo00<007ooOol0l7oo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol047oo00<007ooOol0k7oo000N
Ool00`00Oomoo`0AOol2003/Ool001ioo`03001oogoo01=oo`800>Yoo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`0HOol00`00Oomoo`3TOol001ioo`03001oogoo01Uoo`800>Aoo`007Woo00<0
07ooOol06goo0P00hWoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007oo
Ool08Goo00<007ooOol0fgoo000NOol00`00Oomoo`0ROol2003KOol001ioo`03001oogoo02Aoo`80
0=Uoo`007Woo00<007ooOol0ogoo000FOol40004Ool00`00Oomoo`0YOol00`00Oomoo`3COol001Io
o`03001oogoo00Eoo`03001oogoo02Yoo`800==oo`005goo00<007ooOol017oo0P00;Goo0P00dGoo
000HOol00`00Oomoo`03Ool00`00Oomoo`3oOol001Ioo`04001oogoo0004Ool00`00Oomoo`0bOol0
0`00Oomoo`3:Ool001Moo`8000Eoo`03001oogoo03=oo`800<Yoo`007Woo00<007ooOol0=Goo0P00
b7oo000NOol00`00Oomoo`0jOol20033Ool001ioo`03001oogoo03aoo`800<5oo`007Woo00<007oo
Ool0?Woo0P00_goo000NOol00`00Oomoo`14Ool00`00Oomoo`2hOol001ioo`03001oogoo04Eoo`80
0;Qoo`007Woo00<007ooOol0Agoo0P00]Woo000NOol00`00Oomoo`1<Ool2002aOol001ioo`03001o
ogoo04ioo`@00:eoo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`1EOol5002UOol001ioo`03
001oogoo05Yoo`04001oogooOol20008Ool2002EOol001ioo`03001oogoo061oo`@000Aoo`04001o
o`00002COol001ioo`03001oogoo06Qoo`03001oogoo00Eoo`D008Yoo`007Woo00<007ooOol0NGoo
1000PWoo000NOol00`00Oomoo`1mOol20002Ool2001lOol001ioo`03001oogoo08=oo`03001oogoo
00moo`04001oogooOol5001QOol001ioo`03001oogoo08Aoo`03001oogoo009oo`@000Aoo`D000ao
o`H005Moo`007Woo00<007ooOol0Rgoo00@007oo000000Ioo`03001oogoo02eoo`@000Aoo`<002mo
o`007Woo00<007ooOol0ZGoo00<007ooOol07Goo0P001Goo0`000goo0`009Woo000NOol00`00Oomo
o`2YOol00`00Oomoo`0]Ool3000SOol001Qoo`<000=oo`03001oogoo0:Uoo`03001oogoo03Aoo`80
01eoo`006Goo00<007ooOol00Woo00<007ooOol0ZWoo00<007ooOol05goo00<007ooOol06goo0`00
6Woo000FOol50003Ool2002[Ool00`00Oomoo`0GOol00`00Oomoo`0COol>000GOol001Ioo`04001o
ogoo0004Ool00`00Oomoo`2[Ool3000FOol00`00Oomoo`06Ool=000UOol001Moo`03001oo`0000Ao
o`03001oogoo0:ioo`8000Moo`04001oogooOol20007Ool00`00Oomoo`05Ool00`00Oomoo`0`Ool0
01Qoo`8000Aoo`03001oogoo0;Aoo`@000Eoo`@000=oo`03001oogoo009oo`@0039oo`007Woo00<0
07ooOol0a7oo1@00=Woo000NOol00`00Oomoo`34Ool00`00Oomoo`0hOol001ioo`03001oogoo0<Ao
o`03001oogoo03Qoo`007Woo00<007ooOol0a7oo00<007ooOol0>7oo000NOol00`00Oomoo`34Ool0
0`00Oomoo`0hOol001ioo`03001oogoo0<Aoo`03001oogoo03Qoo`007Woo00<007ooOol0a7oo00<0
07ooOol0>7oo000NOol00`00Oomoo`34Ool00`00Oomoo`0hOol001ioo`03001oogoo0:Qoo`8001Yo
o`03001oogoo03Qoo`007Woo00<007ooOol0YGoo0`0000=oo`00Ool06Goo00<007ooOol0>7oo000N
Ool00`00Oomoo`2POol50004Ool00`00Oomoo`0HOol00`00Oomoo`0hOol001ioo`03001oogoo09ao
o`@000Uoo`03001oogoo01=oo`H003Yoo`007Woo00<007ooOol0V7oo10003Goo00<007ooOol02goo
2000@7oo000NOol00`00Oomoo`2FOol3000AOol00`00Oomoo`0:Ool00`00Oomoo`15Ool001ioo`03
001oogoo09Eoo`03001oogoo019oo`03001oogoo00Yoo`03001oogoo04Eoo`007Woo00<007ooOol0
UGoo00<007ooOol04Woo00<007ooOol01Goo1P00Agoo000NOol00`00Oomoo`2EOol00`00Oomoo`0B
Ool8001=Ool001ioo`03001oogoo09Aoo`8006Uoo`007Woo00<007ooOol0TGoo0`00Jgoo000NOol0
0`00Oomoo`2>Ool3001^Ool001Ioo`<000Eoo`03001oogoo08ioo`03001oogoo06ioo`005Woo00@0
07ooOol000Aoo`03001oogoo08eoo`80071oo`005Woo00@007ooOol000Aoo`8008aoo`80079oo`00
5Woo0`001Goo00<007ooOol0PWoo00<007ooOol017oo0`00Lgoo000GOol00`00Oomoo`04Ool00`00
Oomoo`21Ool20002Ool4001fOol001Moo`<000Aoo`03001oogoo07moo`80009oo`8007Yoo`007Woo
00<007ooOol0Ngoo1000P7oo000NOol00`00Oomoo`1gOol40024Ool001ioo`03001oogoo07Eoo`80
08Qoo`007Woo00<007ooOol0Lgoo0P00RWoo000NOol00`00Oomoo`1aOol2002<Ool001ioo`03001o
ogoo06moo`8008ioo`007Woo00<007ooOol0KGoo0P00T7oo000NOol00`00Oomoo`1[Ool2002BOol0
01ioo`03001oogoo06Qoo`<009Aoo`007Woo00<007ooOol0J7oo00<007ooOol0U7oo000NOol00`00
Oomoo`1XOol00`00Oomoo`2DOol001ioo`03001oogoo06Qoo`03001oogoo09Aoo`007Woo00<007oo
Ool0Igoo0P00UWoo000NOol00`00Oomoo`1UOol2002HOol001ioo`03001oogoo06=oo`8009Yoo`00
7Woo00<007ooOol0HGoo0P00W7oo000NOol00`00Oomoo`1OOol2002NOol001ioo`03001oogoo05eo
o`800:1oo`007Woo00<007ooOol0Fgoo0P00XWoo000NOol00`00Oomoo`1KOol00`00Oomoo`2QOol0
01ioo`03001oogoo05]oo`03001oogoo0:5oo`005goo0P001Goo00<007ooOol0FGoo0P00Y7oo000F
Ool01000Oomoo`0017oo00<007ooOol0F7oo00<007ooOol0Y7oo000FOol01000Oomoo`0017oo0P00
Egoo0P00Ygoo000GOol20005Ool00`00Oomoo`1DOol2002YOol001Ioo`04001oogoo0004Ool00`00
Oomoo`1COol00`00Oomoo`2YOol001Moo`8000Eoo`03001oogoo04Yoo`03001oogoo00Aoo`800:ao
o`007Woo00<007ooOol0BGoo0P0000Aoo`00Oomoo`800:ioo`007Woo00<007ooOol0Agoo0P000Woo
00@007oo00000;1oo`007Woo00<007ooOol0AWoo00<007ooOol0]Woo000NOol00`00Oomoo`12Ool0
1000Ool00000^Goo000NOol00`00Oomoo`12Ool2002kOol001ioo`03001oogoo049oo`03001oogoo
0;Yoo`007Woo00<007ooOol0@Woo00<007ooOol0^Woo000NOol00`00Oomoo`10Ool2002mOol001io
o`03001oogoo03moo`03001oogoo0;eoo`007Woo00<007ooOol0?Woo00<007ooOol0_Woo000NOol0
0`00Oomoo`0lOol20031Ool001ioo`03001oogoo03Moo`05001oogooOol00033Ool001ioo`03001o
ogoo03Ioo`800003Ool000000<Aoo`007Woo00<007ooOol0=Goo00@007oo00000<Ioo`007Woo00<0
07ooOol0=7oo00<007ooOol00P00aWoo000NOol00`00Oomoo`0cOol00`00Oomoo`39Ool001ioo`03
001oogoo039oo`03001oogoo0<Yoo`007Woo00<007ooOol0<7oo0P00cGoo000NOol00`00Oomoo`0_
Ool00`00Oomoo`3=Ool001ioo`03001oogoo00]oo`03001oogoo01eoo`04001oogoo003@Ool001io
o`03001oogoo00]oo`03001oogoo01aoo`@00=5oo`0047oo1@000Woo0P001Goo00<007ooOol037oo
0P003Goo00<007ooOol037oo1000dGoo000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<0
07ooOol037oo0P0037oo0P0000=oo`0000000Woo00<007ooOol017oo0P00eGoo000BOol01@00Oomo
ogoo00000Woo00<007ooOol00Woo0P003Woo0P002goo0P0000Aoo`00001oo`@0009oo`800=Moo`00
4Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00eoo`8000Moo`800003Ool007oo
00D00003Ool0000000<00=Uoo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo
00eoo`800005Ool007ooOol00002Ool30002Ool00`00Oomoo`0200000goo001oo`03003IOol0015o
o`8000Aoo`8000Eoo`03001oogoo00ioo`<00006Ool00000Ool007oo0P002Woo00<007ooOol0fGoo
000NOol00`00Oomoo`0>Ool300001Goo000007oo0000jGoo000NOol00`00Oomoo`0@Ool5003ZOol0
01ioo`03001oogoo011oo`04001oogoo003[Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0008Ool300001Goo
00000000Ool00P000Woo0`000Woo0`0017oo100000=oo`0000000P000goo0`0000=oo`0000000Woo
0P00jWoo0007Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo
00@007ooOol000=oo`03001oogoo009oo`03001oogoo00=oo`04001oogoo003[Ool000Moo`03001o
ogoo00=oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00<0
07ooOol00Woo10000Woo00@007ooOol00>]oo`001goo00<007ooOol00goo0`0017oo0P0017oo00<0
07ooOol00goo0`000Woo10000goo0P000Woo1000k7oo0007Ool01000Oomoo`000Woo00<007ooOol0
2Woo00<007ooOol01Goo00<007ooOol0ngoo0008Ool300000goo00000007Ool01000Oomoogoo0P00
1Woo0P00oGoo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(8.354933668859303`\)], "Print"],

Cell[BoxData[
    \({5.27`, 3.8470999999999997`, 7}\)], "Print"],

Cell[BoxData[
    \({4.035`, 3.893775`, 8}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .5175 m
.06877 .49345 L
.07837 .46878 L
.08086 .46266 L
.08208 .45969 L
.08321 .45697 L
.08384 .45546 L
.08451 .48878 L
.08518 .48736 L
.08592 .4858 L
.08839 .48066 L
.08958 .47821 L
.09071 .4759 L
.09134 .47464 L
.09202 .50485 L
.09321 .50266 L
.09773 .49453 L
.09907 .49216 L
.09977 .49092 L
.10052 .48962 L
.10117 .51649 L
.10188 .51533 L
.10314 .51329 L
.10805 .50546 L
.10947 .50325 L
.1108 .50116 L
.11154 .50001 L
.11234 .50048 L
.11307 .49935 L
.11375 .52253 L
.11497 .52071 L
.11633 .51872 L
.11906 .51471 L
.12398 .50761 L
.12463 .50668 L
.12532 .5057 L
.12656 .50553 L
.12724 .50457 L
.12786 .50369 L
.12928 .50168 L
.13052 .49994 L
.13121 .49896 L
.13185 .51812 L
.13303 .51647 L
.13428 .51474 L
.13887 .50843 L
.14809 .49742 L
.15317 .49067 L
.15567 .48738 L
.15799 .48435 L
Mistroke
.1591 .4829 L
.16015 .48154 L
.16136 .49775 L
.16246 .4965 L
.165 .49362 L
.16611 .49236 L
.16733 .49099 L
.16836 .48983 L
.16933 .50734 L
.17035 .50619 L
.17144 .50497 L
.17587 .50002 L
.17838 .49724 L
.17965 .49585 L
.18037 .51067 L
.18105 .51 L
.18225 .5088 L
.18335 .50943 L
.18456 .50822 L
.18583 .50695 L
.19665 .49634 L
.20605 .48738 L
.20862 .48497 L
.21003 .48365 L
.21137 .48241 L
.21261 .48126 L
.21331 .4854 L
.21396 .49531 L
.2151 .49431 L
.21631 .49325 L
.23568 .47671 L
.24414 .46971 L
.24646 .46781 L
.24773 .46678 L
.24893 .46581 L
.24994 .46499 L
.25103 .45742 L
.25224 .45652 L
.25336 .4557 L
.25811 .45222 L
.26071 .45034 L
.26197 .44942 L
.26312 .44859 L
.26422 .45229 L
.26526 .45154 L
.26755 .44989 L
.27239 .44641 L
.27365 .44551 L
.27485 .45091 L
.27551 .45047 L
Mistroke
.27624 .45 L
.2775 .44916 L
.2823 .44603 L
.28472 .44445 L
.2873 .44279 L
.28807 .44229 L
.28879 .44182 L
.28945 .4414 L
.29015 .43298 L
.29082 .4326 L
.29153 .43219 L
.2928 .43147 L
.29512 .43014 L
.2964 .42942 L
.29761 .42873 L
.29874 .43515 L
.29997 .43448 L
.30211 .43333 L
.31232 .42786 L
.32161 .42296 L
.32616 .42058 L
.33033 .41842 L
.33249 .41731 L
.33357 .41675 L
.33475 .41951 L
.33595 .40954 L
.33722 .40899 L
.33952 .408 L
.34965 .40368 L
.35519 .40134 L
.3579 .4002 L
.3591 .3997 L
.35973 .39943 L
.36041 .39915 L
.36158 .40551 L
.36269 .40505 L
.36394 .40452 L
.3651 .41358 L
.36634 .41309 L
.3677 .41256 L
.37017 .41159 L
.3801 .40774 L
.38497 .40586 L
.3871 .40503 L
.38944 .40413 L
.39007 .40389 L
.39074 .40363 L
.39195 .39274 L
.39267 .39251 L
.39335 .39229 L
Mistroke
.39461 .39188 L
.4002 .39008 L
.40993 .38693 L
.42778 .38118 L
.43792 .37792 L
.44743 .37487 L
.45221 .37334 L
.45676 .37189 L
.45797 .3715 L
.45864 .37129 L
.45927 .37109 L
.46001 .35813 L
.46068 .35795 L
.462 .35761 L
.4668 .35636 L
.48733 .35098 L
.52496 .34106 L
.52982 .33978 L
.53502 .3384 L
.53755 .33774 L
.53994 .3371 L
.54098 .33683 L
.54209 .33654 L
.5433 .33417 L
.54442 .33389 L
.54558 .31269 L
.54682 .31245 L
.54908 .31201 L
.55422 .31102 L
.56499 .30894 L
.60515 .30107 L
.62518 .29709 L
.64383 .29337 L
.65308 .29152 L
.66181 .28976 L
.66664 .28879 L
.66797 .28852 L
.66869 .28838 L
.66937 .28824 L
.67056 .27691 L
.6712 .27682 L
.67188 .27673 L
.68103 .27544 L
.70031 .27268 L
.71049 .27121 L
.71607 .27039 L
.72133 .26962 L
.7264 .26887 L
.7278 .26866 L
.72856 .26855 L
Mistroke
.72926 .26845 L
.73052 .29607 L
.73118 .29603 L
.73189 .29599 L
.74146 .29545 L
.76014 .2944 L
.77009 .29384 L
.78091 .29323 L
.78587 .29296 L
.79113 .29266 L
.79329 .29254 L
.79562 .29241 L
.79627 .29237 L
.79695 .29233 L
.79817 .28321 L
.79932 .28319 L
.80057 .28316 L
.80305 .2831 L
.80436 .28308 L
.80507 .28306 L
.80574 .28304 L
.80695 .24643 L
.80759 .24636 L
.80828 .24628 L
.81062 .24602 L
.81499 .24553 L
.8173 .24527 L
.81975 .24499 L
.8204 .24492 L
.8211 .24484 L
.82187 .23475 L
.8226 .23471 L
.82524 .23456 L
.83045 .23427 L
.84022 .23372 L
.88034 .23146 L
.91899 .22929 L
.95616 .2272 L
.99 .22474 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .03105 m
.09773 .04833 L
.13887 .07061 L
.17751 .08844 L
.19697 .0977 L
.20546 .10025 L
.20779 .10093 L
.21025 .10164 L
.21127 .10194 L
.21236 .10225 L
.21355 .10361 L
.21468 .1062 L
.21593 .10658 L
.21731 .107 L
.21981 .10775 L
.2245 .10914 L
.23379 .11182 L
.23892 .11325 L
.24439 .11474 L
.24705 .11545 L
.24835 .1158 L
.24955 .11612 L
.25065 .11641 L
.2518 .11503 L
.25296 .11535 L
.25423 .11569 L
.29371 .12657 L
.3317 .13856 L
.33284 .13884 L
.33403 .14025 L
.33465 .14041 L
.33534 .14058 L
.33654 .13774 L
.33768 .13804 L
.33889 .13836 L
.34108 .13893 L
.34582 .14016 L
.35105 .1415 L
.35399 .14225 L
.35677 .14295 L
.35799 .14325 L
.35927 .14357 L
.35994 .14374 L
.36068 .14639 L
.36135 .14657 L
.36198 .14672 L
.36328 .14706 L
.36453 .14737 L
.36564 .15114 L
.36685 .15147 L
Mistroke
.37209 .15287 L
.38187 .15544 L
.38468 .15617 L
.38733 .15685 L
.38849 .15714 L
.38971 .15745 L
.39035 .15762 L
.39105 .1537 L
.39228 .15402 L
.411 .15889 L
.43169 .16401 L
.44148 .16634 L
.45052 .16844 L
.45507 .16948 L
.45737 .17 L
.45799 .17014 L
.45867 .17029 L
.45989 .16472 L
.46113 .16501 L
.46249 .16533 L
.46521 .16597 L
.47007 .16711 L
.48857 .17132 L
.50936 .17582 L
.52823 .1797 L
.53282 .18062 L
.53766 .18157 L
.5402 .18207 L
.54089 .1822 L
.54164 .18235 L
.54234 .18136 L
.54298 .18149 L
.54419 .18173 L
.54487 .18186 L
.5455 .17058 L
.54665 .17082 L
.54788 .17107 L
.56641 .17483 L
.60324 .18184 L
.6237 .18548 L
.64247 .18866 L
.65198 .19021 L
.66085 .19162 L
.66531 .19231 L
.6666 .19251 L
.66782 .1927 L
.66891 .19287 L
.67009 .1856 L
.67131 .18582 L
.67265 .18607 L
Mistroke
.67536 .18656 L
.68021 .18744 L
.70077 .19104 L
.71957 .1942 L
.72407 .19493 L
.72654 .19533 L
.72775 .19552 L
.72886 .1957 L
.72951 .19581 L
.73019 .2162 L
.73087 .21637 L
.73162 .21656 L
.73412 .2172 L
.739 .21844 L
.75745 .22311 L
.77812 .22829 L
.7879 .23073 L
.7922 .2318 L
.79465 .2324 L
.79585 .2327 L
.79695 .23297 L
.79801 .23324 L
.79913 .22631 L
.80026 .22661 L
.80148 .22693 L
.80401 .2276 L
.80511 .22789 L
.8063 .22821 L
.80698 .19886 L
.80761 .19896 L
.80885 .19915 L
.81157 .19958 L
.81647 .20033 L
.81854 .20065 L
.81967 .20082 L
.82075 .20099 L
.82202 .19296 L
.82318 .19318 L
.82546 .19361 L
.83496 .19539 L
.87233 .2023 L
.91209 .20949 L
.95037 .21624 L
.99 .22249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo00]oo`03001oogoo0?5oo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`0?Ool2
003^Ool001ioo`03001oogoo015oo`800>aoo`007Woo00<007ooOol04goo0P00jWoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo01Qoo`03001oogoo0>Aoo`007Woo00<007ooOol06Goo0P00i7oo
000NOol00`00Oomoo`0KOol2003ROol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`0POol00`00Oomoo`3LOol001ioo`03001oogoo025oo`800=aoo`007Woo00<007oo
Ool08goo0P00fWoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo02Uoo`03001oogoo0==oo`00
7Woo00<007ooOol0:Woo1000dGoo000FOol40004Ool00`00Oomoo`3oOol001Ioo`03001oogoo00Eo
o`03001oogoo035oo`800<aoo`005goo00<007ooOol017oo0P00=7oo0`00bGoo000HOol00`00Oomo
o`03Ool00`00Oomoo`0fOol01000Oomoogoo0P00`goo000FOol01000Oomoo`0017oo00<007ooOol0
?7oo0P00`Goo000GOol20005Ool00`00Oomoo`0nOol2002oOol001ioo`03001oogoo04=oo`<00;Uo
o`007Woo00<007ooOol0AWoo0`00]Woo000NOol00`00Oomoo`1<Ool2002aOol001ioo`03001oogoo
04aoo`03001oo`0000800:ioo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo05Aoo`@00:Moo`007Woo00<007ooOol0F7oo0P000goo0`00Wgoo000NOol00`00Oomoo`1P
Ool2002MOol001ioo`03001oogoo06Ioo`800003Ool007oo09Aoo`007Woo00<007ooOol0J7oo0P00
17oo100037oo0`00OWoo000NOol00`00Oomoo`1bOol2000=Ool3001kOol001ioo`03001oogoo07Mo
o`D000]oo`<007Eoo`007Woo00<007ooOol0O7oo00<007ooOol02goo0`00LWoo000NOol00`00Oomo
o`2AOol50005Ool5001OOol001ioo`03001oogoo09Yoo`8000Aoo`8000Aoo`03001oogoo01Ioo`80
03ioo`007Woo00<007ooOol0Ygoo0`005Goo00@007oo000003aoo`007Woo00<007ooOol0ZGoo00<0
07ooOol04Woo0P001Woo1P00<goo000NOol00`00Oomoo`3@Ool2000]Ool001ioo`03001oogoo0;ao
o`03001oogoo01=oo`<002Yoo`007Woo00<007ooOol0_7oo00<007ooOol06Woo0`008goo000HOol3
0003Ool00`00Oomoo`2[Ool3000>Ool00`00Oomoo`0MOol3000POol001Uoo`03001oogoo009oo`03
001oogoo0:ioo`8000aoo`03001oogoo02=oo`H001Moo`005Woo1@000goo0P00]Goo00<007ooOol0
1Goo00<007ooOol077oo3@005goo000FOol01000Oomoo`0017oo00<007ooOol0]Goo100047oo4P00
97oo000GOol00`00Ool00004Ool00`00Oomoo`2iOol00`00Oomoo`03Ool:000fOol001Qoo`8000Ao
o`03001oogoo0;moo`03001oogoo03eoo`007Woo00<007ooOol0_goo00<007ooOol0?Goo000NOol0
0`00Oomoo`2lOol4000oOol001ioo`03001oogoo0;aoo`03001oogoo041oo`007Woo00<007ooOol0
_7oo00<007ooOol0@7oo000NOol00`00Oomoo`2lOol00`00Oomoo`10Ool001ioo`03001oogoo0;ao
o`03001oogoo041oo`007Woo00<007ooOol0Ygoo0`004Woo00<007ooOol0@7oo000NOol00`00Oomo
o`2QOol60002Ool00`00Oomoo`0@Ool00`00Oomoo`10Ool001ioo`03001oogoo09]oo`H000Qoo`03
001oogoo011oo`03001oogoo041oo`007Woo00<007ooOol0Vgoo00<007ooOol02goo00<007ooOol0
47oo00<007ooOol0@7oo000NOol00`00Oomoo`2KOol00`00Oomoo`0<Ool00`00Oomoo`0=Ool30012
Ool001ioo`03001oogoo09Uoo`<000ioo`03001oogoo00aoo`03001oogoo04=oo`007Woo00<007oo
Ool0U7oo1@004Goo00<007ooOol00Woo2`00AGoo000NOol00`00Oomoo`2?Ool5000FOol5001@Ool0
01ioo`03001oogoo08Yoo`D0071oo`007Woo00<007ooOol0QGoo1@00MGoo000NOol00`00Oomoo`1o
Ool6001jOol001ioo`03001oogoo07ioo`03001oogoo07ioo`007Woo00<007ooOol0OWoo00<007oo
Ool0OWoo000NOol00`00Oomoo`1nOol00`00Oomoo`1nOol001Ioo`<000Eoo`03001oogoo07ioo`03
001oogoo07ioo`005Woo00@007ooOol000Aoo`03001oogoo07ioo`03001oogoo07ioo`005Woo00@0
07ooOol000Aoo`8007ioo`80081oo`005Woo0`001Goo00<007ooOol0N7oo1@00PWoo000GOol00`00
Oomoo`04Ool00`00Oomoo`1eOol30027Ool001Moo`<000Aoo`03001oogoo079oo`<008Yoo`007Woo
00<007ooOol0KWoo1000SGoo000NOol00`00Oomoo`1ZOol4002AOol001ioo`03001oogoo06Yoo`03
001oogoo099oo`007Woo00<007ooOol0JGoo00<007ooOol0Tgoo000NOol00`00Oomoo`1YOol00`00
Oomoo`2COol001ioo`03001oogoo06Ioo`@009Eoo`007Woo00<007ooOol0I7oo0P00VGoo000NOol0
0`00Oomoo`1QOol3002KOol001ioo`03001oogoo05eoo`@009ioo`007Woo00<007ooOol0FWoo0`00
XWoo000NOol00`00Oomoo`1IOol2002TOol001ioo`03001oogoo055oo`8000Ioo`03001oogoo0:=o
o`007Woo00<007ooOol0Cgoo1@001Goo00<007ooOol0Xgoo000NOol00`00Oomoo`1<Ool30003Ool2
0002Ool3002VOol001ioo`03001oogoo04aoo`03001oogoo00Aoo`<00:Uoo`007Woo00<007ooOol0
Bgoo0P001Woo00<007ooOol0ZGoo000NOol00`00Oomoo`1:Ool3002bOol001ioo`03001oogoo04Uo
o`03001oogoo0;=oo`007Woo00<007ooOol0@Woo0P000Woo0`00]Woo000NOol00`00Oomoo`11Ool5
002iOol001ioo`03001oogoo045oo`04001oo`00002jOol001Moo`8000Eoo`03001oogoo045oo`03
001oogoo0;]oo`005Woo00@007ooOol000Aoo`03001oogoo03eoo`04001oo`00002nOol001Ioo`04
001oogoo0004Ool2000kOol300000goo001oo`2oOol001Moo`8000Eoo`03001oogoo011oo`03001o
ogoo02Moo`800<=oo`005Woo00@007ooOol000Aoo`03001oogoo011oo`03001oogoo02Eoo`800<Eo
o`005goo0P001Goo00<007ooOol047oo00<007ooOol09Goo00<007ooOol0a7oo000NOol00`00Oomo
o`0?Ool2000VOol20036Ool001ioo`03001oogoo00moo`8002Eoo`03001oogoo0<Ioo`007Woo00<0
07ooOol03goo00@007oo0000029oo`03001oogoo0<Moo`007Woo00<007ooOol03Woo00<007ooOol0
0P008Goo00<007ooOol0b7oo000NOol00`00Oomoo`0>Ool00`00Oomoo`02000?Ool00`00Oomoo`09
Ool20003Ool00`00Oomoo`39Ool001ioo`03001oogoo00eoo`04001oogooOol2000>Ool2000:Ool0
1000Ool007oo0P00c7oo000NOol00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Ool0000<Ool20000
0goo001oo`06Ool00`00Oomoo`02003>Ool001ioo`03001oogoo00eoo`03001oogoo009oo`03001o
o`0000]oo`03001oogoo0080009oo`05001oogooOol00003Ool2003>Ool001ioo`03001oogoo00ao
o`03001oogoo00=oo`<0009oo`04001oogooOol20002Ool01000Oomoogoo0P0000=oo`0000000Woo
00<007ooOol0dWoo000NOol00`00Oomoo`0<Ool00`00Oomoo`03Ool300000goo00000002Ool30000
0goo001oo`05Ool00`00Ool00002Ool00`00Oomoo`3BOol001ioo`03001oogoo00aoo`03001oogoo
00Ioo`03001oo`00009oo`04001oo`000007Ool00`00Ool00002003EOol001ioo`03001oogoo00]o
o`03001oogoo00Moo`05001oo`00Ool00002Ool00`00Oomoo`08Ool00`00Oomoo`3EOol001ioo`03
001oogoo00]oo`03001oogoo00Moo`03001oo`000080009oo`03001oogoo0>1oo`007Woo00<007oo
Ool05goo0P00iWoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol0011oo`D0009oo`8000Eoo`03001oogoo0?moo`004Woo00D007ooOomoo`00009o
o`03001oogoo009oo`03001oogoo0?moo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`80
0?moo`5oo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo0?moo`004Woo00D0
07ooOomoo`00009oo`03001oogoo009oo`03001oogoo0?moo`004Goo0P0017oo0P001Goo00<007oo
Ool0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`0027oo0`0000Eoo`00000007oo0080009oo`<0009oo`<000Aoo`@00003
Ool00000008000=oo`<00003Ool00000009oo`800>Yoo`001goo00<007ooOol00goo00@007ooOol0
00Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`@0009oo`04001oogoo003[Ool000Mo
o`03001oogoo00=oo`<000Aoo`8000Aoo`03001oogoo00=oo`<0009oo`@000=oo`80009oo`@00>ao
o`001goo00@007ooOol0009oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo0?]oo`0027oo
0`0000=oo`0000001goo00@007ooOomoo`8000Ioo`800?eoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(3.0420454954728484`\)], "Print"],

Cell[BoxData[
    \({5.0729`, 3.7032169999999995`, 7}\)], "Print"],

Cell[BoxData[
    \({4.035`, 3.893775`, 8}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .32917 m
.06219 .32706 L
.0634 .32591 L
.06454 .32483 L
.0656 .32382 L
.06675 .35738 L
.0678 .35612 L
.06877 .35497 L
.07343 .34946 L
.07456 .34814 L
.07578 .34672 L
.07647 .37565 L
.07711 .37475 L
.07837 .37299 L
.08311 .36641 L
.08829 .3594 L
.09066 .35626 L
.09196 .35454 L
.09318 .35294 L
.09433 .37448 L
.09557 .3726 L
.09773 .36933 L
.10815 .35412 L
.11384 .34616 L
.11916 .33894 L
.12149 .33584 L
.12263 .33433 L
.12369 .33294 L
.12491 .36821 L
.12555 .36749 L
.12624 .36673 L
.12856 .36416 L
.13346 .35881 L
.1348 .35737 L
.13551 .35662 L
.13625 .35583 L
.1369 .38633 L
.13762 .38565 L
.13887 .38445 L
.14403 .37962 L
.14891 .37514 L
.15103 .37321 L
.15328 .37119 L
.15445 .37015 L
.15512 .36955 L
.15575 .39454 L
.15684 .39362 L
.15802 .39263 L
.16864 .38605 L
.17848 .37809 L
Mistroke
.18327 .3743 L
.18465 .37322 L
.18533 .37269 L
.18595 .3722 L
.18711 .39076 L
.18837 .38978 L
.19916 .38334 L
.20037 .3824 L
.20105 .39632 L
.20168 .3959 L
.20406 .39432 L
.20681 .39251 L
.20932 .39087 L
.2115 .38944 L
.21274 .38864 L
.21391 .37194 L
.21514 .37128 L
.21626 .37068 L
.21879 .36932 L
.22344 .36685 L
.22777 .36458 L
.22995 .36343 L
.23117 .3628 L
.23228 .36876 L
.2335 .36817 L
.23481 .36754 L
.23597 .36698 L
.23721 .36639 L
.23846 .3686 L
.23964 .36803 L
.24232 .36674 L
.24509 .36541 L
.24645 .36476 L
.24772 .36416 L
.24889 .3636 L
.25014 .38242 L
.25139 .38184 L
.25278 .38121 L
.2574 .3791 L
.26219 .37692 L
.2648 .37574 L
.26608 .37516 L
.26724 .37464 L
.26831 .38069 L
.26932 .38024 L
.27155 .37926 L
.27627 .37719 L
.29662 .36835 L
.29765 .37656 L
.29874 .37614 L
Mistroke
.29993 .37568 L
.30104 .37526 L
.30217 .37482 L
.30324 .37441 L
.3042 .35573 L
.30523 .35542 L
.31007 .35396 L
.31449 .35262 L
.31978 .35103 L
.3221 .35033 L
.32464 .34957 L
.3258 .34922 L
.32704 .34885 L
.32821 .35226 L
.32927 .35193 L
.33415 .35042 L
.34344 .34756 L
.34834 .34606 L
.35354 .34448 L
.35479 .3441 L
.35615 .34368 L
.35692 .34345 L
.35763 .34916 L
.35831 .34895 L
.35902 .34873 L
.36409 .34718 L
.37408 .34412 L
.38341 .34128 L
.38854 .33972 L
.39105 .33896 L
.39216 .33863 L
.39337 .33826 L
.39451 .33792 L
.39557 .35011 L
.39668 .34984 L
.39789 .34954 L
.40277 .34832 L
.40691 .3473 L
.40918 .34674 L
.41029 .34646 L
.41131 .34621 L
.41194 .32857 L
.41261 .32845 L
.41401 .32819 L
.41645 .32775 L
.42122 .32689 L
.432 .32493 L
.45164 .32135 L
.48879 .31458 L
.52833 .30736 L
Mistroke
.54658 .30403 L
.5562 .30228 L
.56146 .30132 L
.5664 .30042 L
.56888 .29997 L
.56959 .29984 L
.57027 .29972 L
.57154 .27878 L
.57222 .27869 L
.57295 .2786 L
.57425 .27843 L
.57721 .27805 L
.58719 .27675 L
.60686 .27419 L
.64745 .26888 L
.66782 .26621 L
.67675 .26504 L
.68656 .26375 L
.69113 .26315 L
.69364 .26282 L
.69488 .26266 L
.69602 .26251 L
.6971 .26237 L
.69824 .25865 L
.69938 .25852 L
.70065 .25838 L
.70486 .2579 L
.71495 .25677 L
.71936 .25627 L
.7242 .25573 L
.7265 .25547 L
.72776 .25533 L
.72896 .2552 L
.73007 .28502 L
.73128 .28498 L
.73339 .28492 L
.74308 .28463 L
.74822 .28449 L
.75367 .28433 L
.75832 .28421 L
.7596 .28417 L
.76097 .28413 L
.76163 .28412 L
.76226 .2841 L
.76344 .23803 L
.76466 .23796 L
.76598 .23789 L
.76836 .23775 L
.77282 .2375 L
.78281 .23694 L
Mistroke
.80078 .23593 L
.84086 .23368 L
.87945 .23151 L
.91657 .22943 L
.95609 .22721 L
.99 .22474 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .01975 m
.09773 .03609 L
.13887 .05339 L
.17751 .06725 L
.21468 .07976 L
.21978 .08105 L
.22532 .08244 L
.22786 .08306 L
.22925 .0834 L
.22993 .08357 L
.23056 .08372 L
.23166 .0855 L
.23286 .0858 L
.23539 .08645 L
.23654 .08674 L
.23762 .08702 L
.23887 .088 L
.24001 .08829 L
.24262 .08894 L
.24505 .08955 L
.24617 .08982 L
.24735 .09012 L
.24835 .09036 L
.24946 .09548 L
.25065 .0958 L
.25193 .09614 L
.25423 .09675 L
.27247 .10323 L
.28209 .10568 L
.28736 .107 L
.29231 .10822 L
.29477 .10882 L
.29545 .10898 L
.29616 .10915 L
.29743 .11203 L
.29811 .1122 L
.29883 .11239 L
.30013 .11273 L
.30155 .1131 L
.30229 .11329 L
.30308 .1135 L
.30375 .1081 L
.30448 .10829 L
.30577 .10863 L
.30831 .10929 L
.31305 .11052 L
.3327 .11673 L
.37209 .12827 L
.38088 .13028 L
.3857 .13136 L
Mistroke
.39023 .13237 L
.39282 .13294 L
.39353 .1331 L
.39427 .13326 L
.39491 .1334 L
.39561 .1385 L
.39683 .13881 L
.39814 .13914 L
.40049 .13973 L
.40505 .14086 L
.40745 .14145 L
.41 .14208 L
.41066 .14224 L
.41138 .14242 L
.41216 .13541 L
.41289 .13559 L
.41556 .13627 L
.42082 .13759 L
.43068 .14004 L
.45031 .14482 L
.49053 .15415 L
.52928 .16259 L
.54881 .16663 L
.55733 .16835 L
.5618 .16925 L
.56654 .17019 L
.56899 .17067 L
.56966 .1708 L
.57038 .17094 L
.57106 .15924 L
.57168 .15936 L
.57642 .16033 L
.58573 .16221 L
.6062 .16626 L
.64508 .17365 L
.66285 .17689 L
.67297 .17869 L
.68247 .18037 L
.69175 .18198 L
.69429 .18242 L
.69568 .18265 L
.69697 .18288 L
.69808 .18057 L
.69926 .18078 L
.70176 .18123 L
.71243 .18313 L
.72227 .18486 L
.72711 .18571 L
.72829 .18591 L
.72956 .18613 L
Mistroke
.73029 .20814 L
.73095 .20831 L
.73225 .20866 L
.74309 .21151 L
.75329 .21419 L
.75826 .2155 L
.7606 .21612 L
.76163 .21639 L
.76276 .21669 L
.76384 .1818 L
.76498 .18202 L
.76738 .18249 L
.77174 .18334 L
.78131 .18519 L
.80155 .18908 L
.84105 .19653 L
.87906 .20353 L
.91947 .2108 L
.9584 .21763 L
.99 .22249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol037oo00<007ooOol0l7oo000NOol00`00
Oomoo`0=Ool2003`Ool001ioo`03001oogoo00moo`800>ioo`007Woo00<007ooOol057oo0P00jGoo
000NOol00`00Oomoo`0FOol2003WOol001ioo`03001oogoo01Qoo`800>Eoo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`0MOol2003POol001ioo`03001oogoo01moo`800=ioo`007Woo00<007oo
Ool08Goo0P00g7oo000NOol00`00Oomoo`0VOol2003GOol001ioo`03001oogoo02Qoo`800=Eoo`00
7Woo00<007ooOol0:Woo0P00dgoo000NOol00`00Oomoo`0_Ool00`00Oomoo`3=Ool001ioo`03001o
ogoo031oo`@00<]oo`007Woo00<007ooOol0<goo00<007ooOol0bGoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo03Qoo`<00<Aoo`007Woo00<007ooOol0>goo0P00`Woo000FOol40004Ool00`00
Oomoo`3oOol001Ioo`03001oogoo00Eoo`03001oogoo041oo`@00;]oo`005goo00<007ooOol017oo
0P00A7oo0P000goo0P00]Goo000HOol00`00Oomoo`03Ool00`00Oomoo`1:Ool2002cOol001Ioo`04
001oogoo0004Ool00`00Oomoo`1<Ool00`00Oomoo`2`Ool001Moo`8000Eoo`03001oogoo055oo`80
0:aoo`007Woo00<007ooOol0Dgoo0`00ZGoo000NOol00`00Oomoo`1HOol3002TOol001ioo`03001o
ogoo05ioo`@009eoo`007Woo00<007ooOol0GWoo00<007ooOol01Goo00<007ooOol0UWoo000NOol0
0`00Oomoo`1WOol2002FOol001ioo`03001oogoo06Uoo`8009Aoo`007Woo00<007ooOol0Kgoo0`00
SGoo000NOol00`00Oomoo`1bOol2002;Ool001ioo`03001oogoo07Qoo`@000Qoo`04001oogooOol2
001eOol001ioo`03001oogoo07aoo`8000Ioo`03001oogoo00=oo`@0075oo`007Woo00<007ooOol0
PGoo100037oo0P00K7oo000NOol00`00Oomoo`2COol4001XOol001ioo`03001oogoo09]oo`@0061o
o`007Woo00<007ooOol0Wgoo00<007ooOol00Woo1@002Goo00<007ooOol0BWoo000NOol00`00Oomo
o`2YOol00`00Oomoo`06Ool01000Oomoogoo1P00@goo000NOol00`00Oomoo`2YOol00`00Oomoo`06
Ool00`00Oomoo`0:Ool3000mOol001ioo`03001oogoo0:Uoo`03001oogoo00Eoo`03001oogoo00io
o`<003Yoo`007Woo00<007ooOol0/Goo00<007ooOol05Goo0P00=7oo000NOol00`00Oomoo`2aOol0
0`00Oomoo`0GOol3000aOol001ioo`03001oogoo0:]oo`03001oogoo02Aoo`D002Qoo`007Woo00<0
07ooOol0[7oo10009goo00@007ooOomoo`<0025oo`0067oo0`000goo00<007ooOol0/7oo00<007oo
Ool0:goo0`007Woo000IOol00`00Oomoo`02Ool00`00Oomoo`3UOol3000GOol001Ioo`D000=oo`80
0=aoo`d001Moo`005Woo00@007ooOol000Aoo`03001oogoo0<Uooa8002Aoo`005goo00<007oo0000
17oo00<007ooOol0^Goo4000=Woo000HOol20004Ool00`00Oomoo`2aOol80016Ool001ioo`03001o
ogoo0;5oo`03001oogoo04]oo`007Woo00<007ooOol0/Goo00<007ooOol0Bgoo000NOol00`00Oomo
o`2aOol00`00Oomoo`1;Ool001ioo`03001oogoo0:Ioo`@000Moo`03001oogoo04]oo`007Woo00<0
07ooOol0XWoo10000goo00<007ooOol01Goo00<007ooOol0Bgoo000NOol00`00Oomoo`2MOol60006
Ool00`00Oomoo`05Ool00`00Oomoo`1;Ool001ioo`03001oogoo09Aoo`T000aoo`03001oogoo00Eo
o`03001oogoo04]oo`007Woo00<007ooOol0Sgoo1@005Woo00<007ooOol017oo00<007ooOol0Bgoo
000NOol00`00Oomoo`25Ool:000KOol00`00Oomoo`04Ool00`00Oomoo`1;Ool001ioo`03001oogoo
08Aoo`8002Aoo`03001oogoo00Aoo`03001oogoo04]oo`007Woo00<007ooOol0Q7oo00<007ooOol0
8goo2000CGoo000NOol00`00Oomoo`24Ool00`00Oomoo`1hOol001ioo`03001oogoo08Aoo`03001o
ogoo07Qoo`007Woo00<007ooOol0Q7oo00<007ooOol0N7oo000NOol00`00Oomoo`20Ool5001jOol0
01ioo`03001oogoo07Qoo`P007moo`007Woo00<007ooOol0Lgoo1@00Qgoo000NOol00`00Oomoo`1_
Ool4002<Ool001ioo`03001oogoo06]oo`@0091oo`007Woo00<007ooOol037oo00<007ooOol0Egoo
1@00U7oo000FOol30005Ool00`00Oomoo`0;Ool2001AOol8002IOol001Ioo`04001oogoo0004Ool0
0`00Oomoo`0;Ool2000=Ool00`00Oomoo`11Ool00`00Oomoo`2NOol001Ioo`04001oogoo0004Ool2
000=Ool00`00Oomoo`0:Ool20013Ool00`00Oomoo`2NOol001Ioo`<000Eoo`03001oogoo00aoo`03
001oogoo00Yoo`8003aoo`@000=oo`03001oogoo09ioo`005goo00<007ooOol017oo00<007ooOol0
37oo00<007ooOol02Goo00<007oo0000=Goo0P000goo0P000goo00D007ooOomoo`000:1oo`005goo
0`0017oo00<007ooOol037oo00<007oo00002Goo00<007oo0000;Woo0P000goo0P0000=oo`000000
0P001Goo1@00X7oo000NOol00`00Oomoo`0<Ool30004Ool00`00Oomoo`020002Ool00`00Oomoo`0Y
Ool8000<Ool00`00Oomoo`2ROol001ioo`03001oogoo00aoo`<000=oo`800003Ool007oo00=oo`04
001oo`00000WOol00`00Oomoo`2gOol001ioo`03001oogoo00ioo`08001oogoo001oo`00Ool000Ao
o`04001oo`00000WOol00`00Oomoo`2gOol001ioo`03001oogoo00moo`80009oo`8000Eoo`800003
Ool007oo019oo`<00003Ool00000008000]oo`03001oogoo0;Qoo`007Woo00<007ooOol03goo00@0
07ooOomoo`8000Eoo`04001oogoo0003Ool00`00Oomoo`0<Ool01000Oomoogoo0P000Woo00<007oo
Ool01goo0`00^Woo000NOol00`00Oomoo`0?Ool01@00Oomoogoo00002Goo00<007ooOol00P001Woo
0P001Goo0P001goo00D007ooOomoo`0000=oo`800003Ool000000;Yoo`007Woo00<007ooOol03goo
00<007ooOol02goo00D007oo001oo`0000Eoo`03001oo`0000Eoo`03001oogoo00Ioo`03001oo`00
00D000=oo`800;Yoo`007Woo00<007ooOol07Goo00D007oo001oo`0000Aoo`04001oogoo0002Ool0
1000Oomoo`0027oo0P000Woo00<007ooOol0`7oo000NOol00`00Oomoo`0MOol20002Ool01@00Oomo
ogoo00000goo10000Woo00<007ooOol0cGoo000NOol00`00Oomoo`0QOol01000Ool0000017oo00D0
07ooOol007oo00800<moo`007Woo00<007ooOol08Goo0P002Goo0`00d7oo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001Moo`8000Eoo`03001oogoo0?moo`00
5Woo00@007ooOol000Aoo`03001oogoo0?moo`005Woo00@007ooOol000Aoo`800?moo`5oo`005goo
0P001Goo00<007ooOol0ogoo000FOol01000Oomoo`0017oo00<007ooOol0ogoo000GOol20005Ool0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol0011oo`D0009oo`8000Eoo`03001oogoo0?moo`004Woo00D007ooOomoo`00009oo`03
001oogoo009oo`03001oogoo0?moo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`800?mo
o`5oo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo0?moo`004Woo00D007oo
Oomoo`00009oo`03001oogoo009oo`03001oogoo0?moo`004Goo0P0017oo0P001Goo00<007ooOol0
ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`0027oo0`0000Eoo`00000007oo0080009oo`<0009oo`<000Aoo`@00003Ool0
0000008000=oo`<00003Ool00000009oo`800>Yoo`001goo00<007ooOol00goo00@007ooOol000Ao
o`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol00Woo00<0
07ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`@0009oo`04001oogoo003[Ool000Moo`03
001oogoo00=oo`<000Aoo`8000Aoo`03001oogoo00=oo`<0009oo`@000=oo`80009oo`@00>aoo`00
1goo00@007ooOol0009oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo0?]oo`0027oo0`00
00=oo`0000001goo00@007ooOomoo`8000Ioo`800?eoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(1.5017342204228044`\)], "Print"],

Cell[BoxData[
    \({5.0729`, 3.7032169999999995`, 7}\)], "Print"],

Cell[BoxData[
    \({5.`, 4.825`, 8}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 0 m
.06877 0 L
.07837 0 L
.08321 0 L
.08839 0 L
.0909 0 L
.09214 0 L
.09328 0 L
.09431 .05618 L
.09541 .05618 L
.09773 .05618 L
.09903 .05618 L
.10027 .05618 L
.10138 .05618 L
.1026 .10661 L
.10329 .10657 L
.10391 .10653 L
.10531 .10645 L
.10784 .10631 L
.11018 .10618 L
.11141 .10611 L
.11208 .10607 L
.11271 .10604 L
.11385 .15009 L
.11511 .1499 L
.11731 .14956 L
.12265 .14873 L
.12528 .14832 L
.12644 .14814 L
.12771 .14794 L
.12841 .14784 L
.12907 .18485 L
.12976 .18466 L
.13051 .18445 L
.13355 .18359 L
.13887 .18211 L
.14822 .17953 L
.15078 .17883 L
.15219 .17844 L
.15351 .17808 L
.15475 .17774 L
.15545 .20614 L
.1561 .20588 L
.15844 .20493 L
.16909 .20067 L
.17429 .19863 L
.17657 .19775 L
.17905 .19678 L
.18018 .19635 L
.1814 .19588 L
Mistroke
.18254 .22093 L
.18358 .22065 L
.18788 .2195 L
.19737 .21698 L
.20236 .21567 L
.20373 .21532 L
.20517 .21495 L
.2064 .21463 L
.2071 .21445 L
.20775 .23086 L
.20902 .23059 L
.21022 .23034 L
.21247 .22988 L
.21752 .22884 L
.21969 .2284 L
.22082 .22817 L
.22202 .22792 L
.22266 .25549 L
.22335 .25529 L
.22458 .25492 L
.22697 .25421 L
.23183 .25278 L
.237 .25126 L
.23952 .25053 L
.24076 .25017 L
.24189 .24984 L
.24293 .25402 L
.24403 .2537 L
.24633 .25303 L
.24833 .25244 L
.24942 .25212 L
.25046 .25182 L
.25169 .27153 L
.25281 .27127 L
.255 .27075 L
.27277 .26663 L
.28289 .26432 L
.2924 .26217 L
.30168 .26009 L
.30422 .25953 L
.3069 .25894 L
.30918 .25843 L
.30981 .25829 L
.31048 .25815 L
.31169 .26181 L
.31721 .27394 L
.31853 .27367 L
.31992 .2734 L
.32111 .27316 L
.32179 .28287 L
Mistroke
.32243 .28276 L
.32711 .28197 L
.33219 .28112 L
.37007 .27473 L
.37995 .27307 L
.38517 .27219 L
.39072 .27125 L
.39347 .27079 L
.39482 .27056 L
.39606 .27035 L
.39719 .27368 L
.39839 .27839 L
.39959 .2782 L
.4009 .278 L
.41035 .27655 L
.42014 .27506 L
.42941 .27366 L
.43453 .27289 L
.43594 .27268 L
.43743 .27246 L
.4387 .27227 L
.43942 .27216 L
.4401 .28766 L
.44129 .28752 L
.44255 .28738 L
.44479 .28713 L
.44984 .28656 L
.48707 .28238 L
.5267 .27792 L
.56485 .27364 L
.58431 .27145 L
.60539 .26908 L
.61527 .26797 L
.62572 .2668 L
.63002 .26631 L
.63239 .26605 L
.63356 .26592 L
.63464 .26579 L
.63591 .28837 L
.63658 .28835 L
.63729 .28832 L
.63971 .28822 L
.64445 .28803 L
.68513 .28649 L
.70556 .2858 L
.71451 .2855 L
.71925 .28535 L
.72432 .28519 L
.72688 .28512 L
.72814 .28508 L
Mistroke
.7293 .28504 L
.73035 .23989 L
.73147 .23983 L
.73382 .23969 L
.74268 .2392 L
.76204 .23811 L
.79897 .23603 L
.81792 .23497 L
.82337 .23466 L
.82856 .23437 L
.83081 .23425 L
.83205 .23418 L
.83322 .23411 L
.83388 .28092 L
.8346 .28092 L
.83585 .28092 L
.8383 .28092 L
.87833 .28092 L
.91688 .28092 L
.95394 .28092 L
.99 .28092 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 0 m
.06877 0 L
.07837 0 L
.08321 0 L
.08839 0 L
.0909 0 L
.09214 0 L
.09328 0 L
.09431 .0053 L
.09541 .00536 L
.09773 .00549 L
.09903 .00556 L
.10027 .00563 L
.10138 .0057 L
.1026 .01094 L
.10329 .01101 L
.10391 .01107 L
.10531 .01121 L
.10784 .01146 L
.11018 .0117 L
.11141 .01182 L
.11208 .01189 L
.11271 .01195 L
.11385 .01709 L
.11511 .01725 L
.11731 .01754 L
.12265 .01824 L
.12528 .01858 L
.12644 .01873 L
.12771 .01889 L
.12841 .01898 L
.12907 .02386 L
.12976 .02396 L
.13051 .02407 L
.13355 .02452 L
.13887 .02529 L
.14822 .02661 L
.15078 .02696 L
.15219 .02716 L
.15351 .02734 L
.15475 .02751 L
.15545 .03204 L
.1561 .03214 L
.15844 .03247 L
.16909 .03393 L
.17429 .03462 L
.17657 .03492 L
.17905 .03523 L
.18018 .03538 L
.1814 .03553 L
Mistroke
.18254 .04033 L
.18358 .04051 L
.18788 .04124 L
.19737 .04282 L
.20236 .04364 L
.20373 .04387 L
.20517 .0441 L
.2064 .0443 L
.2071 .04441 L
.20775 .04796 L
.20902 .0482 L
.21022 .04842 L
.21247 .04884 L
.21752 .04978 L
.21969 .05018 L
.22082 .05038 L
.22202 .0506 L
.22266 .05689 L
.22335 .05702 L
.22458 .05725 L
.22697 .0577 L
.23183 .0586 L
.237 .05955 L
.23952 .06001 L
.24076 .06023 L
.24189 .06043 L
.24293 .06171 L
.24403 .06191 L
.24633 .06233 L
.24833 .06269 L
.24942 .06289 L
.25046 .06307 L
.25169 .06834 L
.25281 .06858 L
.255 .06904 L
.2924 .07666 L
.29718 .07759 L
.30234 .07859 L
.30472 .07905 L
.30722 .07953 L
.30935 .07993 L
.31056 .08016 L
.31169 .0816 L
.31285 .08182 L
.31411 .08206 L
.3153 .08229 L
.31639 .08672 L
.31767 .08699 L
.31903 .08728 L
.32028 .08754 L
Mistroke
.32143 .08778 L
.3227 .09123 L
.32341 .09139 L
.32407 .09155 L
.32655 .09211 L
.33219 .09338 L
.36951 .10155 L
.40922 .11324 L
.42759 .11713 L
.43262 .11818 L
.43537 .11875 L
.43671 .11903 L
.43793 .11928 L
.43906 .11952 L
.44012 .1266 L
.44125 .12687 L
.44247 .12716 L
.44745 .12834 L
.46837 .13324 L
.48807 .13777 L
.52791 .14665 L
.56628 .15486 L
.60316 .16245 L
.62207 .16622 L
.62725 .16724 L
.63007 .16779 L
.63145 .16806 L
.6327 .16831 L
.63385 .16853 L
.63495 .18313 L
.6361 .18343 L
.63735 .18376 L
.64244 .18509 L
.68241 .19557 L
.70231 .20079 L
.71203 .20334 L
.72091 .20568 L
.72529 .20683 L
.72649 .20714 L
.72777 .20748 L
.72898 .2078 L
.73007 .17515 L
.73119 .17537 L
.73222 .17558 L
.73455 .17604 L
.73876 .17687 L
.75793 .18064 L
.77792 .18454 L
.79656 .18812 L
.8145 .19154 L
Mistroke
.81967 .19252 L
.82456 .19344 L
.82894 .19426 L
.83015 .19449 L
.83142 .19473 L
.83251 .19493 L
.83371 .23421 L
.83496 .23456 L
.83613 .23489 L
.83878 .23563 L
.8436 .23699 L
.85265 .23953 L
.87304 .24526 L
.91123 .25599 L
.95183 .26739 L
.99 .27812 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo01=oo`03001oogoo01Ioo`03001oogoo02aoo`03001oogoo02eo
o`03001oogoo02aoo`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol04goo
00<007ooOol00P00igoo000NOol00`00Oomoo`0COol01@00Oomoogoo0000igoo000NOol00`00Oomo
o`0COol00`00Oomoo`02Ool3003TOol001ioo`03001oogoo01=oo`03001oogoo0>Uoo`007Woo00<0
07ooOol04goo00<007ooOol027oo1000gGoo000NOol00`00Oomoo`0COol00`00Oomoo`0;Ool2003L
Ool001ioo`03001oogoo01=oo`03001oogoo011oo`<00=Ioo`007Woo00<007ooOol04goo00<007oo
Ool057oo00<007ooOol0dWoo000NOol00`00Oomoo`0COol00`00Oomoo`0EOol4003@Ool001ioo`03
001oogoo01=oo`03001oogoo01Qoo`03001oogoo0<ioo`007Woo00<007ooOol04goo00<007ooOol0
jGoo000NOol00`00Oomoo`0COol3000KOol3003;Ool001ioo`03001oogoo01Eoo`03001oogoo01ao
o`<00<Qoo`007Woo00<007ooOol05Goo00<007ooOol0igoo000NOol00`00Oomoo`0EOol00`00Oomo
o`0QOol30033Ool001ioo`03001oogoo01Eoo`03001oogoo02Aoo`<00<1oo`007Woo00<007ooOol0
5Goo00<007ooOol0:goo1000^7oo000NOol00`00Oomoo`0EOol00`00Oomoo`0^Ool2002gOol001io
o`03001oogoo01Eoo`03001oogoo0>Moo`007Woo00<007ooOol05Goo00<007ooOol0igoo000NOol0
0`00Oomoo`0EOol00`00Oomoo`0cOol3002aOol001ioo`03001oogoo01Eoo`03001oogoo03Ioo`<0
0:ioo`005Woo100017oo00<007ooOol05Goo00<007ooOol0?7oo0`00Z7oo000FOol00`00Oomoo`05
Ool00`00Oomoo`0EOol3000oOol3002UOol001Moo`03001oogoo00Aoo`8001Qoo`03001oogoo04=o
o`<009moo`0067oo00<007ooOol00goo00<007ooOol05goo00<007ooOol0AWoo0`00W7oo000FOol0
1000Oomoo`0017oo00<007ooOol05goo00<007ooOol0iGoo000GOol20005Ool00`00Oomoo`0GOol0
0`00Oomoo`3UOol001ioo`03001oogoo01Moo`03001oogoo04]oo`@009Ioo`007Woo00<007ooOol0
67oo00<007ooOol0CWoo0P00U7oo000NOol00`00Oomoo`0HOol00`00Oomoo`1DOol3002=Ool001io
o`03001oogoo01Qoo`03001oogoo05Moo`8008]oo`007Woo00<007ooOol067oo00<007ooOol0GGoo
0`00Q7oo000NOol00`00Oomoo`0HOol4001OOol20022Ool001ioo`03001oogoo01]oo`03001oogoo
06=oo`@007Yoo`007Woo00<007ooOol06goo00<007ooOol0Igoo0P00N7oo000NOol00`00Oomoo`0K
Ool00`00Oomoo`1/Ool3001bOol001ioo`03001oogoo01]oo`03001oogoo06moo`<006moo`007Woo
00<007ooOol06goo00<007ooOol0MGoo00<007ooOol0JGoo000NOol00`00Oomoo`0KOol00`00Oomo
o`1eOol00`00Oomoo`0DOol00`00Oomoo`1BOol001ioo`03001oogoo01]oo`04001oogooOol3001a
Ool00`00Oomoo`0DOol01000Oomoogoo1000CGoo000NOol00`00Oomoo`0KOol40002Ool00`00Oomo
o`1_Ool3000DOol00`00Oomoo`05Ool2001;Ool001ioo`03001oogoo025oo`03001oogoo075oo`03
001oogoo015oo`03001oogoo00]oo`@004Aoo`007Woo00<007ooOol08Goo00<007ooOol0MWoo0P00
0Woo00<007ooOol027oo00<007ooOol03goo0P00@Woo000NOol00`00Oomoo`0QOol00`00Oomoo`02
Ool3001cOol3000:Ool00`00Oomoo`0EOol2000lOol001ioo`03001oogoo025oo`03001oogoo00<0
0003Ool007oo07Uoo`03001oogoo01aoo`03001oogoo03Yoo`007Woo00<007ooOol08Goo0`0017oo
00<007ooOol0NGoo10006Woo00<007ooOol0>Woo000NOol00`00Oomoo`0XOol00`00Oomoo`2GOol0
0`00Oomoo`0jOol001ioo`03001oogoo02Qoo`03001oogoo009oo`800=1oo`0067oo0`000goo00<0
07ooOol0:7oo00<007ooOol01000d7oo000IOol00`00Oomoo`02Ool00`00Oomoo`0XOol30003Ool0
0`00Oomoo`3>Ool001Ioo`D000=oo`8002moo`03001oogoo0<ioo`005Woo00@007ooOol000Aoo`03
001oogoo02ioo`@0091oo`03001oogoo03Yoo`005goo00<007oo000017oo00<007ooOol0<Goo00<0
07ooOol0PWoo3P00>goo000HOol20004Ool00`00Oomoo`0aOol00`00Oomoo`1fOol<000<Ool00`00
Ool00002000hOol001ioo`03001oogoo035oo`03001oogoo07Ioo`03001oogoo01Eoo`03001oogoo
00Eoo`03001oogoo039oo`007Woo00<007ooOol0<Goo00<007ooOol0MWoo00<007ooOol05Goo00<0
07ooOol01Woo0P00<Woo000NOol00`00Oomoo`0aOol00`00Ool00005001aOol00`00Oomoo`0EOol0
0`00Oomoo`08Ool3000_Ool001ioo`03001oogoo035oo`8000=oo`03001oo`00075oo`03001oogoo
01Eoo`03001oogoo00ioo`@002Qoo`007Woo00<007ooOol0>7oo00<007ooOol02Goo0`00Hgoo00<0
07ooOol05Goo00<007ooOol04Woo0P009Woo000NOol00`00Oomoo`0hOol00`00Oomoo`04Ool50002
Ool00`00Oomoo`1POol00`00Oomoo`0FOol00`00Oomoo`0jOol001ioo`03001oogoo03Qoo`04001o
ogooOol30008Ool00`00Oomoo`10Ool:000EOol00`00Oomoo`0FOol00`00Oomoo`0HOol3000OOol0
01ioo`03001oogoo03Qoo`@000aoo`8000aoo`H000Ioo`@001Qoo``000Uoo`03001oogoo01=oo`03
001oogoo01Ioo`03001oogoo01]oo`8001eoo`007Woo00<007ooOol0BGoo00<007ooOol017oo1P00
1Goo1`000goo00<007ooOol03Goo2@005Goo00<007ooOol04goo00<007ooOol05Woo00<007ooOol0
8Goo0P005goo000NOol00`00Oomoo`19Ool7000;Ool00`00Oomoo`07Ool00`00Oomoo`04Ool9000N
Ool00`00Oomoo`0COol00`00Oomoo`0FOolV000GOol001ioo`03001oogoo04Uoo`03001oogoo01Uo
o`03001oo`0000@002Moo`03001oogoo00Eoo`l005Eoo`007Woo00<007ooOol0IGoo0P00;7oo2000
I7oo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`005Woo0`001Goo00<007ooOol0ogoo000FOol01000Oomoo`0017oo
00<007ooOol0ogoo000FOol01000Oomoo`0017oo0P00ogoo0Goo000FOol30005Ool00`00Oomoo`3o
Ool001Moo`03001oogoo00Aoo`03001oogoo0?moo`005goo0`0017oo00<007ooOol0ogoo000NOol0
0`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3o
Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000GOol20005
Ool00`00Oomoo`3oOol001Ioo`04001oogoo0004Ool00`00Oomoo`3oOol001Ioo`04001oogoo0004
Ool2003oOol1Ool001Moo`8000Eoo`03001oogoo0?moo`005Woo00@007ooOol000Aoo`03001oogoo
0?moo`005goo0P001Goo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001o
ogoo0?moo`007Woo00<007ooOol0ogoo000@Ool50002Ool20005Ool00`00Oomoo`3oOol0019oo`05
001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`3oOol0019oo`05001oogooOol00002Ool0
0`00Oomoo`02Ool2003oOol1Ool0019oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomo
o`3oOol0019oo`05001oogooOol00002Ool00`00Oomoo`02Ool00`00Oomoo`3oOol0015oo`8000Ao
o`8000Eoo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol000Qoo`<00005Ool00000001oo`020002Ool30002
Ool30004Ool400000goo000000020003Ool300000goo00000002Ool2003ZOol000Moo`03001oogoo
00=oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007oo
Ool00Woo00<007ooOol00goo00@007ooOol00>]oo`001goo00<007ooOol00goo00@007ooOol000Ao
o`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool40002Ool01000
Oomoo`00jgoo0007Ool00`00Oomoo`03Ool30004Ool20004Ool00`00Oomoo`03Ool30002Ool40003
Ool20002Ool4003/Ool000Moo`04001oogoo0002Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00
Oomoo`3kOol000Qoo`<00003Ool0000000Moo`04001oogooOol20006Ool2003mOol00?moob5oo`00
ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(335.7126237610355`\)], "Print"],

Cell[BoxData[
    \({5.539999999999999`, 4.0442`, 6}\)], "Print"],

Cell[BoxData[
    \({4.035`, 3.893775`, 8}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .5696 m
.06454 .58185 L
.06558 .57982 L
.06671 .57764 L
.06778 .59514 L
.06877 .5934 L
.07119 .58917 L
.07233 .58719 L
.0734 .58534 L
.07455 .60063 L
.07581 .5986 L
.07837 .59451 L
.07956 .59261 L
.08019 .59161 L
.08086 .59055 L
.08209 .5904 L
.08324 .60338 L
.08444 .60156 L
.08557 .59985 L
.08769 .59665 L
.09251 .5912 L
.09383 .58922 L
.09456 .58814 L
.09523 .58714 L
.09642 .59752 L
.09705 .59659 L
.09773 .5956 L
.10302 .58958 L
.10581 .58548 L
.10878 .58113 L
.11136 .57735 L
.11207 .57631 L
.11284 .5752 L
.11356 .58904 L
.11422 .58821 L
.11667 .5851 L
.1179 .58354 L
.1186 .58266 L
.11925 .59246 L
.12048 .59282 L
.12117 .59195 L
.12181 .59115 L
.12296 .5897 L
.12422 .58811 L
.12535 .60038 L
.12641 .5992 L
.12874 .59662 L
.134 .59078 L
.13636 .58816 L
.13887 .58538 L
Mistroke
.1395 .58469 L
.14019 .58393 L
.14142 .59343 L
.14263 .59221 L
.14373 .59109 L
.14496 .58984 L
.14566 .59145 L
.14631 .59079 L
.14903 .58803 L
.15408 .58292 L
.15868 .57829 L
.16084 .57613 L
.16317 .57378 L
.16425 .5727 L
.16538 .57157 L
.16635 .57884 L
.16742 .57781 L
.16975 .5756 L
.17097 .57443 L
.17226 .57321 L
.17338 .57571 L
.17462 .57455 L
.17678 .5725 L
.19597 .55447 L
.19726 .55326 L
.19791 .55479 L
.19862 .55411 L
.20012 .5527 L
.2015 .55141 L
.20401 .54905 L
.20539 .54775 L
.2067 .54652 L
.20796 .54533 L
.20868 .54467 L
.20934 .54734 L
.2105 .54624 L
.21174 .54508 L
.21289 .544 L
.21397 .55225 L
.21516 .55125 L
.21644 .55017 L
.22095 .54638 L
.22343 .54431 L
.22577 .54236 L
.2271 .54125 L
.22785 .54063 L
.22854 .54777 L
.22977 .54678 L
.23106 .54574 L
.23599 .5418 L
Mistroke
.24071 .53804 L
.24332 .53597 L
.24579 .53402 L
.24718 .53292 L
.24797 .5323 L
.2487 .53897 L
.24999 .53803 L
.25137 .53703 L
.25658 .53323 L
.29721 .50848 L
.30713 .5017 L
.31255 .49803 L
.3176 .49465 L
.32192 .49177 L
.32316 .49095 L
.32434 .49017 L
.32539 .48947 L
.32654 .49601 L
.32772 .49525 L
.32901 .4944 L
.33164 .4927 L
.33635 .48966 L
.33873 .48813 L
.33993 .48736 L
.3406 .48693 L
.34123 .49053 L
.34237 .48982 L
.3434 .48918 L
.34571 .48774 L
.35578 .48151 L
.36029 .47875 L
.36517 .47578 L
.3674 .47443 L
.36863 .47369 L
.36977 .473 L
.37075 .45563 L
.37179 .45504 L
.37402 .4538 L
.41434 .43582 L
.45319 .41713 L
.49056 .39915 L
.50048 .39519 L
.50982 .39153 L
.51499 .38952 L
.51641 .38898 L
.51718 .38868 L
.5179 .3884 L
.51918 .38515 L
.51986 .38491 L
.52058 .38465 L
Mistroke
.5232 .3837 L
.52568 .38281 L
.5279 .38201 L
.52916 .38157 L
.53032 .35498 L
.53153 .35455 L
.53269 .35413 L
.53486 .35336 L
.53975 .35162 L
.54859 .34851 L
.56873 .34016 L
.60601 .3282 L
.60721 .32782 L
.60832 .32512 L
.60948 .32477 L
.61076 .3244 L
.61344 .32361 L
.6159 .32289 L
.62522 .32016 L
.6304 .31865 L
.63189 .31822 L
.63262 .31801 L
.6333 .31781 L
.63457 .32988 L
.63524 .32973 L
.63595 .32958 L
.64569 .32746 L
.65484 .32522 L
.65734 .3247 L
.65998 .32416 L
.66107 .32394 L
.66223 .3237 L
.66351 .31487 L
.6647 .31466 L
.68254 .31145 L
.70198 .30809 L
.71221 .30638 L
.71781 .30547 L
.72055 .30502 L
.72305 .30462 L
.7242 .30444 L
.72544 .30424 L
.72662 .27669 L
.72771 .27647 L
.72899 .27622 L
.73014 .31125 L
.73078 .31118 L
.73147 .3111 L
.73272 .31096 L
.74336 .30976 L
Mistroke
.76208 .30766 L
.7812 .30551 L
.79132 .30437 L
.80216 .30316 L
.80753 .30255 L
.81261 .30198 L
.81718 .30147 L
.81843 .30133 L
.81911 .30125 L
.81975 .30118 L
.82089 .29099 L
.82213 .29092 L
.83103 .29042 L
.83608 .29013 L
.83853 .29 L
.84076 .28987 L
.84191 .28981 L
.84316 .28974 L
.84433 .28967 L
.84541 .24211 L
.84656 .24198 L
.84783 .24184 L
.85038 .24155 L
.8605 .24042 L
.87858 .23838 L
.89919 .23607 L
.90896 .23497 L
.91326 .23449 L
.91571 .23421 L
.91691 .23408 L
.91801 .23395 L
.91907 .23383 L
.92018 .22922 L
.9213 .22916 L
.92253 .22909 L
.92733 .22882 L
.93749 .22825 L
.95596 .22721 L
.99 .2253 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .03418 m
.09773 .05821 L
.13887 .08129 L
.17751 .1015 L
.21468 .11843 L
.25423 .136 L
.29231 .14962 L
.31172 .15542 L
.33278 .16372 L
.33523 .16439 L
.33786 .16511 L
.33914 .16545 L
.34035 .16578 L
.34144 .16744 L
.34262 .16777 L
.34759 .16913 L
.35306 .17059 L
.35775 .17183 L
.36276 .17313 L
.36519 .17375 L
.36749 .17433 L
.36849 .17458 L
.36955 .17484 L
.37071 .16891 L
.37177 .16918 L
.40885 .17784 L
.44833 .188 L
.48632 .19495 L
.50567 .1988 L
.51097 .19983 L
.51387 .20039 L
.5166 .20091 L
.51772 .20112 L
.51891 .20135 L
.51953 .20003 L
.52021 .20017 L
.5214 .2004 L
.52413 .20093 L
.52671 .20143 L
.5279 .20167 L
.52916 .20191 L
.52982 .20204 L
.53054 .18829 L
.53182 .1885 L
.53645 .18926 L
.54687 .19092 L
.55154 .19165 L
.55411 .19204 L
.55655 .19242 L
.55882 .19277 L
Mistroke
.5601 .19296 L
.56129 .1923 L
.56239 .19248 L
.56339 .19263 L
.56562 .19298 L
.58603 .19606 L
.59498 .19735 L
.59972 .19802 L
.60233 .19838 L
.60479 .19872 L
.60595 .19888 L
.60718 .19905 L
.60782 .19914 L
.60852 .1978 L
.60976 .19798 L
.61429 .19864 L
.62314 .19988 L
.62795 .20054 L
.63047 .20089 L
.63185 .20107 L
.63313 .20125 L
.63426 .20927 L
.63546 .2095 L
.63801 .20999 L
.64249 .21084 L
.65252 .21252 L
.65527 .21305 L
.65817 .2136 L
.66065 .21406 L
.66133 .21419 L
.66206 .21433 L
.66275 .20877 L
.66337 .2089 L
.68306 .21267 L
.70325 .21651 L
.71213 .21819 L
.71685 .21909 L
.71933 .21955 L
.72194 .22005 L
.72427 .22049 L
.7249 .22061 L
.72559 .22074 L
.72681 .20108 L
.72802 .20123 L
.72916 .20138 L
.73018 .22726 L
.73129 .22752 L
.74007 .22952 L
.75934 .23385 L
.77834 .23804 L
Mistroke
.79926 .24256 L
.80883 .2446 L
.81411 .24571 L
.81671 .24625 L
.81797 .24652 L
.81912 .24676 L
.82028 .247 L
.82137 .23899 L
.82252 .23927 L
.82376 .23957 L
.82883 .24081 L
.83771 .24297 L
.84003 .24354 L
.84252 .24414 L
.84372 .24443 L
.84486 .24471 L
.84589 .20475 L
.847 .20492 L
.85719 .2064 L
.87777 .20933 L
.89671 .21193 L
.90677 .21329 L
.91205 .21399 L
.91493 .21437 L
.91634 .21455 L
.91761 .21472 L
.91884 .21488 L
.92 .2109 L
.92122 .21111 L
.92255 .21135 L
.92794 .2123 L
.9374 .21397 L
.95598 .21721 L
.99 .22305 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo0?moo`007Woo00<007ooOol037oo00<007ooOol0l7oo000NOol00`00Oomoo`0=Ool0
0`00Oomoo`3_Ool001ioo`03001oogoo00ioo`800>moo`007Woo00<007ooOol047oo00<007ooOol0
k7oo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol057oo00<007oo
Ool0j7oo000NOol00`00Oomoo`0EOol2003XOol001ioo`03001oogoo01Moo`800>Ioo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`0LOol00`00Oomoo`3POol001ioo`03001oogoo01eoo`800>1o
o`007Woo00<007ooOol07goo0P00gWoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`00
7Woo00<007ooOol09Goo00<007ooOol0egoo000FOol40004Ool00`00Oomoo`0VOol2003GOol001Io
o`03001oogoo00Eoo`03001oogoo02Qoo`800=Eoo`005goo00<007ooOol017oo0P00ogoo0Goo000H
Ool00`00Oomoo`03Ool00`00Oomoo`0]Ool00`00Oomoo`3?Ool001Ioo`04001oogoo0004Ool00`00
Oomoo`0^Ool3003>Ool001Moo`8000Eoo`03001oogoo035oo`800<aoo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`0fOol20037Ool001ioo`03001oogoo03Qoo`<00<Aoo`007Woo00<007ooOol0
ogoo000NOol00`00Oomoo`0oOol2002nOol001ioo`03001oogoo045oo`<00;]oo`007Woo00<007oo
Ool0ogoo000NOol00`00Oomoo`18Ool2002eOol001ioo`03001oogoo04Yoo`<00;9oo`007Woo00<0
07ooOol0C7oo00<007ooOol0/7oo000NOol00`00Oomoo`1AOol01000Oomoo`00ZWoo000NOol00`00
Oomoo`1BOol30004Ool2002TOol001ioo`03001oogoo05]oo`<00:5oo`007Woo00<007ooOol0HWoo
0P00Vgoo000NOol00`00Oomoo`1TOol3000COol30022Ool001ioo`03001oogoo06]oo`<000moo`<0
009oo`<007Yoo`007Woo00<007ooOol0KWoo0`0057oo0`001Goo00<007ooOol0Kgoo000NOol00`00
Oomoo`1dOol6000BOol5001^Ool001ioo`03001oogoo0:Uoo`03001oogoo01]oo`<003Eoo`007Woo
00<007ooOol0Tgoo0`001Goo0P0037oo00<007ooOol07Woo0`00<Woo000NOol00`00Oomoo`2FOol3
0004Ool40008Ool00`00Oomoo`0IOol00`00Oomoo`09Ool60003Ool3000ROol001Qoo`<000=oo`03
001oogoo0:Eoo`80009oo`8001Yoo`03001oogoo01Eoo`80021oo`006Goo00<007ooOol00Woo00<0
07ooOol0Ygoo10006Woo00<007ooOol06goo1@005goo000FOol50003Ool20036Ool00`00Oomoo`0F
Ool:000GOol001Ioo`04001oogoo0004Ool00`00Oomoo`2]Ool2000FOol00`00Oomoo`0?Ool7000Q
Ool001Moo`03001oo`0000Aoo`03001oogoo0:moo`@0019oo`03001oogoo00Qoo`L002Qoo`0067oo
0P0017oo00<007ooOol0]Woo0P001goo0P002Woo1@00;goo000NOol00`00Oomoo`2hOol40003Ool0
0`00Ool0000200000goo00000004000dOol001ioo`03001oogoo0<Eoo`03001oogoo03Moo`007Woo
00<007ooOol0aGoo00<007ooOol0=goo000NOol00`00Oomoo`35Ool00`00Oomoo`0gOol001ioo`03
001oogoo0<Eoo`03001oogoo03Moo`007Woo00<007ooOol0aGoo00<007ooOol0=goo000NOol00`00
Oomoo`35Ool00`00Oomoo`0gOol001ioo`03001oogoo0<Eoo`03001oogoo03Moo`007Woo00<007oo
Ool0ZGoo00<007ooOol06Goo00<007ooOol0=goo000NOol00`00Oomoo`2YOol00`00Oomoo`0IOol0
0`00Oomoo`0gOol001ioo`03001oogoo0:Uoo`03001oogoo01Uoo`03001oogoo03Moo`007Woo00<0
07ooOol0ZGoo00<007ooOol04goo1`00>Goo000NOol00`00Oomoo`2XOol2000EOol00`00Oomoo`0m
Ool001ioo`03001oogoo0:Qoo`03001oo`0001Aoo`03001oogoo03eoo`007Woo00<007ooOol0Z7oo
00<007oo00003goo1P00?goo000NOol00`00Oomoo`2UOol400000goo001oo`04Ool:0015Ool001io
o`03001oogoo09eoo`P000Eoo`H004moo`007Woo00<007ooOol0VWoo0`00HWoo000NOol00`00Oomo
o`2AOol30005Ool00`00Oomoo`1SOol001ioo`03001oogoo08eoo`@0009oo`03001oogoo009oo`80
06Eoo`005Woo0`001Goo00<007ooOol0Rgoo0`001Goo00<007oo00000`00IWoo000FOol01000Oomo
o`0017oo00<007ooOol0R7oo0`0027oo0P00JWoo000FOol01000Oomoo`0017oo0P00QWoo0`00Mgoo
000FOol30005Ool00`00Oomoo`23Ool2001jOol001Moo`03001oogoo00Aoo`03001oogoo085oo`80
07aoo`005goo0`0017oo00<007ooOol0OWoo0`00OWoo000NOol00`00Oomoo`1kOol30021Ool001io
o`03001oogoo07Yoo`8008=oo`007Woo00<007ooOol0NWoo00<007ooOol0PWoo000NOol00`00Oomo
o`1jOol00`00Oomoo`22Ool001ioo`03001oogoo07Yoo`03001oogoo089oo`007Woo00<007ooOol0
NWoo00<007ooOol0PWoo000NOol00`00Oomoo`1jOol00`00Oomoo`22Ool001ioo`03001oogoo07Uo
o`8008Aoo`007Woo00<007ooOol0N7oo00<007ooOol0Q7oo000NOol00`00Oomoo`1eOol30027Ool0
01ioo`03001oogoo07=oo`8008Yoo`007Woo00<007ooOol0L7oo0`00S7oo000NOol00`00Oomoo`1^
Ool2002?Ool001ioo`03001oogoo06aoo`80095oo`007Woo00<007ooOol0JWoo0P00Tgoo000NOol0
0`00Oomoo`1XOol2002EOol001ioo`03001oogoo06Ioo`8009Moo`007Woo00<007ooOol0I7oo0P00
VGoo000NOol00`00Oomoo`1ROol2002KOol001ioo`03001oogoo061oo`8009eoo`007Woo00<007oo
Ool0GWoo0P00Wgoo000GOol20005Ool00`00Oomoo`1LOol2002QOol001Ioo`04001oogoo0004Ool0
0`00Oomoo`1IOol3002SOol001Ioo`04001oogoo0004Ool2001HOol2002VOol001Moo`8000Eoo`03
001oogoo05Eoo`800:Qoo`005Woo00@007ooOol000Aoo`03001oogoo05Aoo`03001oogoo0:Qoo`00
5goo0P001Goo00<007ooOol0E7oo00<007ooOol0Z7oo000NOol00`00Oomoo`1DOol00`00Oomoo`2X
Ool001ioo`03001oogoo05Aoo`03001oogoo0:Qoo`007Woo00<007ooOol0Dgoo0P00ZWoo000NOol0
0`00Oomoo`1BOol00`00Oomoo`2ZOol001ioo`03001oogoo051oo`800:eoo`007Woo00<007ooOol0
CGoo0`00[goo000NOol00`00Oomoo`19Ool6002`Ool001ioo`03001oogoo04Qoo`04001oo`00002c
Ool001ioo`03001oogoo04Eoo`<00;Moo`007Woo00<007ooOol0A7oo00<007ooOol0^7oo000NOol0
0`00Oomoo`13Ool00`00Oomoo`2iOol001ioo`03001oogoo045oo`800;aoo`007Woo00<007ooOol0
?goo0P00_Woo000NOol00`00Oomoo`0nOol00`00Oomoo`2nOol001ioo`03001oogoo03aoo`800<5o
o`007Woo00<007ooOol0>Woo0P00`goo000NOol00`00Oomoo`0gOol00`00Ool00035Ool001ioo`03
001oogoo03Ioo`<00<Ioo`007Woo00<007ooOol0;goo00<007ooOol01000bGoo000NOol00`00Oomo
o`0]Ool3000017oo001oo`00bgoo000NOol00`00Oomoo`0/Ool200000goo0000003>Ool0011oo`D0
009oo`8000Eoo`03001oogoo02]oo`800=9oo`004Woo00D007ooOomoo`00009oo`03001oogoo009o
o`03001oogoo02Yoo`03001oogoo0=9oo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`80
02Uoo`800=Eoo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo02Moo`03001o
ogoo0=Eoo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00]oo`03001oogoo
01Eoo`@00=Qoo`004Goo0P0017oo0P001Goo00<007ooOol02goo0P002Woo00<007ooOol02Goo1000
f7oo000NOol00`00Oomoo`0<Ool00`00Oomoo`07Ool2000:Ool00`00Ool0003JOol001ioo`03001o
ogoo00aoo`03001oo`0000Moo`@000=oo`80009oo`03001oogoo0=]oo`007Woo00<007ooOol03Goo
0P0000Qoo`00Oomoo`00Ool007oo10000Woo1000gWoo000NOol00`00Oomoo`0=Ool4000017oo0000
000017oo0P0000=oo`00Ool00P00ggoo000NOol00`00Oomoo`0=Ool2000017oo000007oo0P001Goo
0P00hgoo000NOol00`00Oomoo`0>Ool01000Ool0000027oo00<007ooOol0hWoo000NOol00`00Oomo
o`0@Ool00`00Oomoo`3/Ool001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`0027oo0`0000Eoo`00000007oo0080009oo`<0009o
o`<000Aoo`@00003Ool00000008000=oo`<00003Ool00000009oo`800>Yoo`001goo00<007ooOol0
0goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool01000Oomoo`0017oo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`@0009oo`04001o
ogoo003[Ool000Moo`03001oogoo00=oo`<000Aoo`8000Aoo`03001oogoo00=oo`<0009oo`@000=o
o`80009oo`@00>aoo`001goo00@007ooOol0009oo`03001oogoo00Yoo`03001oogoo00Eoo`03001o
ogoo0?]oo`0027oo0`0000=oo`0000001goo00@007ooOomoo`8000Ioo`800?eoo`00ogoo8Goo003o
OolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(9.301563021726906`\)], "Print"],

Cell[BoxData[
    \({4.912554480699999`, 3.586164770911`, 6}\)], "Print"],

Cell[BoxData[
    \({4.035`, 3.893775`, 8}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .5175 m
.06454 .50486 L
.06877 .49345 L
.07115 .48716 L
.0734 .48132 L
.07465 .47813 L
.07535 .50879 L
.076 .50733 L
.07837 .50207 L
.07948 .49963 L
.08067 .49701 L
.0818 .52418 L
.08284 .52217 L
.08539 .51726 L
.08776 .51276 L
.08895 .51054 L
.09021 .53484 L
.09093 .5336 L
.0916 .53244 L
.09287 .53028 L
.09538 .52605 L
.09773 .52215 L
.09888 .52024 L
.10011 .54155 L
.10082 .54046 L
.10148 .53942 L
.10273 .53749 L
.10802 .52941 L
.11022 .52609 L
.11143 .52429 L
.11256 .5226 L
.11378 .54057 L
.11442 .53964 L
.11512 .54031 L
.11636 .53852 L
.11749 .53688 L
.12791 .52206 L
.13314 .51632 L
.13458 .51433 L
.13611 .51222 L
.13686 .51119 L
.13756 .51023 L
.13819 .50936 L
.13887 .52418 L
.14008 .52252 L
.14117 .53856 L
.14244 .53703 L
.14365 .53559 L
.14811 .53026 L
.15047 .52748 L
Mistroke
.15298 .52453 L
.15372 .52366 L
.15442 .52285 L
.15505 .52378 L
.15573 .52298 L
.15638 .52222 L
.15706 .53473 L
.15828 .53343 L
.1682 .52304 L
.17366 .51744 L
.17635 .51472 L
.17883 .51222 L
.18004 .51101 L
.18117 .50988 L
.18235 .5178 L
.18298 .51721 L
.18365 .51657 L
.1862 .51418 L
.18759 .51288 L
.18827 .51224 L
.18889 .51167 L
.18999 .52996 L
.19117 .5305 L
.19246 .52929 L
.19367 .52815 L
.19804 .52405 L
.21596 .51173 L
.22548 .5032 L
.23027 .49896 L
.23159 .4978 L
.233 .49657 L
.23368 .49597 L
.23433 .4954 L
.23554 .50023 L
.23666 .51069 L
.23771 .50988 L
.23881 .50904 L
.24002 .50811 L
.24417 .50494 L
.25357 .49787 L
.29132 .47178 L
.29608 .46889 L
.30058 .46619 L
.30179 .46546 L
.30307 .4647 L
.30374 .45346 L
.30447 .45307 L
.30577 .45239 L
.31048 .44993 L
.32135 .44432 L
Mistroke
.33146 .43917 L
.37012 .41944 L
.40948 .39648 L
.41054 .38674 L
.41165 .38638 L
.41288 .38598 L
.414 .38562 L
.41825 .38425 L
.42316 .38267 L
.4276 .38124 L
.43785 .37794 L
.44736 .37489 L
.46802 .3683 L
.47749 .36529 L
.4827 .36364 L
.48527 .36282 L
.48639 .36247 L
.48764 .36207 L
.48884 .35058 L
.48997 .35028 L
.49245 .34963 L
.49768 .34826 L
.50683 .34584 L
.52474 .34112 L
.56254 .32933 L
.58212 .3244 L
.58688 .3232 L
.5895 .32254 L
.59078 .32222 L
.59196 .32192 L
.59265 .32175 L
.59337 .30339 L
.59409 .30325 L
.59489 .30309 L
.59754 .30257 L
.60273 .30155 L
.64214 .29371 L
.68007 .28609 L
.69937 .28219 L
.70956 .28014 L
.71514 .27901 L
.7204 .27795 L
.72548 .27692 L
.72688 .27664 L
.72835 .27634 L
.7296 .27609 L
.73032 .31123 L
.73098 .31115 L
.73599 .31059 L
.74056 .31008 L
Mistroke
.74278 .30983 L
.74395 .3097 L
.7452 .30956 L
.74628 .30943 L
.74748 .29511 L
.74857 .29505 L
.74958 .29499 L
.75924 .29445 L
.77734 .29343 L
.7869 .2929 L
.79214 .2926 L
.79709 .29232 L
.7984 .29225 L
.79912 .29221 L
.79978 .29217 L
.80051 .28316 L
.8013 .28314 L
.8027 .28311 L
.80779 .283 L
.81025 .28295 L
.81258 .2829 L
.81387 .28287 L
.81459 .24557 L
.81527 .2455 L
.81772 .24522 L
.83733 .24302 L
.8571 .2408 L
.87567 .23871 L
.8843 .23774 L
.88901 .23721 L
.8934 .23672 L
.89458 .23659 L
.8957 .23646 L
.89699 .23053 L
.89816 .23046 L
.90337 .23017 L
.91252 .22965 L
.95007 .22755 L
.99 .2253 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .03105 m
.09773 .05103 L
.13887 .07279 L
.17751 .09116 L
.21468 .10922 L
.23539 .11778 L
.23657 .12083 L
.23784 .12125 L
.24014 .122 L
.24254 .12277 L
.24519 .12362 L
.25423 .12645 L
.25675 .12722 L
.25913 .12795 L
.26128 .12859 L
.26249 .12896 L
.26362 .12649 L
.26426 .12669 L
.26495 .1269 L
.2662 .12729 L
.26743 .12766 L
.26855 .12847 L
.26977 .12884 L
.27111 .12924 L
.27381 .13005 L
.27601 .13169 L
.27722 .13205 L
.27836 .13355 L
.27958 .13392 L
.28093 .13433 L
.28331 .13505 L
.29231 .13773 L
.29711 .13913 L
.29962 .13985 L
.301 .14025 L
.30227 .14061 L
.30337 .14092 L
.30454 .13797 L
.30521 .13816 L
.30584 .13835 L
.30701 .13869 L
.31136 .13995 L
.33178 .14565 L
.36935 .15503 L
.4093 .16231 L
.41044 .15875 L
.41166 .15905 L
.41299 .15939 L
.41422 .1597 L
.41889 .16087 L
Mistroke
.42427 .1622 L
.42918 .1634 L
.44778 .16781 L
.46556 .17183 L
.47491 .17387 L
.48002 .17496 L
.48478 .17596 L
.48607 .17623 L
.48729 .17649 L
.48797 .17118 L
.4887 .17135 L
.48999 .17163 L
.49569 .17289 L
.50573 .17505 L
.52543 .17914 L
.5444 .18177 L
.56531 .18578 L
.57485 .18753 L
.57986 .18844 L
.58512 .18937 L
.58976 .19018 L
.59103 .1904 L
.59173 .19052 L
.59238 .19064 L
.59366 .18008 L
.59482 .18029 L
.6037 .18193 L
.64132 .18847 L
.68132 .19475 L
.70124 .19762 L
.71097 .19897 L
.71985 .20016 L
.72424 .20074 L
.72656 .20104 L
.72783 .20121 L
.72903 .20136 L
.73006 .22724 L
.73117 .22749 L
.73354 .22803 L
.73772 .22899 L
.74259 .23009 L
.74504 .23065 L
.74571 .2308 L
.74643 .23096 L
.74711 .2205 L
.74772 .22065 L
.7569 .22297 L
.77719 .22806 L
.7861 .23028 L
.79083 .23146 L
Mistroke
.79343 .2321 L
.79591 .23272 L
.79826 .2333 L
.79891 .23346 L
.79959 .23363 L
.80083 .22676 L
.80204 .22708 L
.80318 .22738 L
.80532 .22795 L
.80961 .22909 L
.81195 .22971 L
.81309 .23001 L
.81413 .23029 L
.81525 .20014 L
.81644 .20033 L
.81897 .20071 L
.82341 .20139 L
.83344 .20291 L
.85367 .20589 L
.87237 .20857 L
.88174 .20988 L
.89053 .21109 L
.89268 .21139 L
.89386 .21155 L
.89495 .21169 L
.89613 .20663 L
.89676 .20674 L
.89743 .20686 L
.8997 .20727 L
.90982 .20908 L
.95036 .21623 L
.98942 .22295 L
.99 .22305 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001io
o`03001oogoo0?moo`007Woo00<007ooOol037oo00<007ooOol0l7oo000NOol00`00Oomoo`0=Ool2
003`Ool001ioo`03001oogoo00moo`800>ioo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`0D
Ool00`00Oomoo`3XOol001ioo`03001oogoo01Eoo`800>Qoo`007Woo00<007ooOol05goo0P00iWoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo01eoo`03001oogoo0=moo`007Woo00<007ooOol0
7Goo0P00h7oo000NOol00`00Oomoo`0OOol3003MOol001ioo`03001oogoo0?moo`007Woo00<007oo
Ool0ogoo000NOol00`00Oomoo`0UOol3003GOol001ioo`03001oogoo02Qoo`03001oogoo0=Aoo`00
7Woo00<007ooOol0:Goo00<007ooOol0dgoo000FOol40004Ool00`00Oomoo`3oOol001Ioo`03001o
ogoo00Eoo`03001oogoo02ioo`800<moo`005goo00<007ooOol017oo0P00<Goo0P00cGoo000HOol0
0`00Oomoo`03Ool00`00Oomoo`0bOol00`00Oomoo`3:Ool001Ioo`04001oogoo0004Ool00`00Oomo
o`3oOol001Moo`8000Eoo`03001oogoo03Ioo`@00<Eoo`007Woo00<007ooOol0>Goo0`00`goo000N
Ool00`00Oomoo`0oOol00`00Oomoo`2mOol001ioo`03001oogoo041oo`<00;aoo`007Woo00<007oo
Ool0@goo00@007ooOomoo`800;Ioo`007Woo00<007ooOol0BGoo1000/Woo000NOol00`00Oomoo`1@
Ool2002]Ool001ioo`03001oogoo059oo`@00:Uoo`007Woo00<007ooOol0FWoo0P000Woo00<007oo
Ool0WWoo000NOol00`00Oomoo`1LOol3002POol001ioo`03001oogoo06Aoo`@009Moo`007Woo00<0
07ooOol0J7oo0P001Woo0P00SGoo000NOol00`00Oomoo`1]Ool40004Ool20028Ool001ioo`03001o
ogoo07Moo`@000ioo`<007=oo`007Woo00<007ooOol0Ogoo0P0027oo00<007ooOol00goo0`00KGoo
000NOol00`00Oomoo`21Ool30005Ool00`00Oomoo`06Ool3001ZOol001ioo`03001oogoo08Qoo`80
00moo`8006Aoo`007Woo00<007ooOol0Vgoo0`0017oo0P00Fgoo000NOol00`00Oomoo`2TOol4000F
Ool3000nOol001ioo`03001oogoo0<5oo`8000Aoo`8000Qoo`03001oogoo02]oo`007Woo00<007oo
Ool0ZGoo00<007ooOol07Goo0`001Goo1000:Woo000NOol00`00Oomoo`2YOol00`00Oomoo`0TOol2
0006Ool3000TOol001Qoo`<000=oo`03001oogoo0:Uoo`03001oogoo02moo`<000Aoo`8001]oo`00
6Goo00<007ooOol00Woo00<007ooOol0ZWoo00@007ooOomoo`<000eoo`03001oogoo02=oo`<001Qo
o`005Woo1@000goo0P00Zgoo00D007ooOomoo`00009oo`03001oogoo00Moo`03001oo`0001aoo`h0
01Moo`005Woo00@007ooOol000Aoo`03001oogoo0:Yoo`03001oogoo00Uoo`<0009oo`<001=oo`T0
02Eoo`005goo00<007oo000017oo00<007ooOol0dGoo00<007ooOol0:goo000HOol20004Ool00`00
Oomoo`3;Ool7000]Ool001ioo`03001oogoo0<5oo`X003Aoo`007Woo00<007ooOol0_Woo0`00?Woo
000NOol00`00Oomoo`2nOol00`00Oomoo`0nOol001ioo`03001oogoo0;ioo`03001oogoo03ioo`00
7Woo00<007ooOol0_Woo00<007ooOol0?Woo000NOol00`00Oomoo`2nOol00`00Oomoo`0nOol001io
o`03001oogoo0;eoo`03001oogoo03moo`007Woo00<007ooOol0_Goo00<007ooOol0?goo000NOol0
0`00Oomoo`2WOol3000COol00`00Oomoo`0oOol001ioo`03001oogoo0:5oo`H0009oo`03001oogoo
015oo`03001oogoo03moo`007Woo00<007ooOol0W7oo1@0027oo00<007ooOol03Woo1000@Goo000N
Ool00`00Oomoo`2HOol4000=Ool00`00Oomoo`0>Ool00`00Oomoo`12Ool001ioo`03001oogoo09=o
o`D0015oo`03001oogoo009oo`d004Aoo`007Woo00<007ooOol0SWoo1@005goo00D007ooOomoo`00
051oo`007Woo00<007ooOol0RGoo1@0077oo00@007ooOol0055oo`007Woo00<007ooOol0RGoo00<0
07ooOol07Woo00@007ooOol0055oo`007Woo00<007ooOol0RGoo00<007ooOol07Woo1000DGoo000N
Ool00`00Oomoo`29Ool00`00Oomoo`1cOol001ioo`03001oogoo08Uoo`03001oogoo07=oo`007Woo
00<007ooOol0QWoo1000MGoo000FOol30005Ool00`00Oomoo`24Ool2001iOol001Ioo`04001oogoo
0004Ool00`00Oomoo`20Ool4001kOol001Ioo`04001oogoo0004Ool2001mOol4001oOol001Ioo`<0
00Eoo`03001oogoo07Qoo`@008=oo`005goo00<007ooOol017oo00<007ooOol0M7oo1000Qgoo000G
Ool30004Ool00`00Oomoo`1aOol3002;Ool001ioo`03001oogoo071oo`8008eoo`007Woo00<007oo
Ool0L7oo00<007ooOol0S7oo000NOol00`00Oomoo`1`Ool00`00Oomoo`2<Ool001ioo`03001oogoo
06eoo`@008ioo`007Woo00<007ooOol0JWoo0`00TWoo000NOol00`00Oomoo`1VOol4002EOol001io
o`03001oogoo06Aoo`8009Uoo`007Woo00<007ooOol0HGoo0`00Vgoo000NOol00`00Oomoo`1NOol3
002NOol001ioo`03001oogoo05ioo`03001oogoo09ioo`007Woo00<007ooOol0GWoo00<007ooOol0
WWoo000NOol00`00Oomoo`1LOol2002QOol001ioo`03001oogoo05Yoo`800:=oo`007Woo00<007oo
Ool0FGoo00<007ooOol0Xgoo000NOol00`00Oomoo`1GOol2002VOol001ioo`03001oogoo05Eoo`80
0:Qoo`007Woo00<007ooOol0E7oo00<007ooOol0Z7oo000NOol00`00Oomoo`1BOol2002[Ool001io
o`03001oogoo051oo`800:eoo`007Woo00<007ooOol0CWoo0P00[goo000NOol00`00Oomoo`1<Ool2
002aOol001Moo`8000Eoo`03001oogoo04]oo`03001oogoo0;5oo`005Woo00@007ooOol000Aoo`03
001oogoo04Qoo`<00;Aoo`005Woo00@007ooOol000Aoo`8004Moo`800;Moo`005goo0P001Goo00<0
07ooOol0AGoo00<007ooOol0]goo000FOol01000Oomoo`0017oo00<007ooOol0AGoo00<007ooOol0
]goo000GOol20005Ool00`00Oomoo`14Ool00`00Oomoo`2hOol001ioo`03001oogoo04Aoo`03001o
ogoo0;Qoo`007Woo00<007ooOol0@Woo0P00^goo000NOol00`00Oomoo`11Ool00`00Oomoo`2kOol0
01ioo`03001oogoo00ioo`03001oogoo02ioo`800;ioo`007Woo00<007ooOol03Woo00<007ooOol0
;Goo00<007ooOol0_Woo000NOol00`00Oomoo`0=Ool2000^Ool00`00Oomoo`2oOol001ioo`03001o
ogoo00eoo`8002aoo`800<9oo`007Woo00<007ooOol03Goo0P0000=oo`00Ool08Woo00<007ooOol0
0goo00<007ooOol0`Woo000NOol00`00Oomoo`0<Ool00`00Ool00002000ROol20003Ool20035Ool0
01ioo`03001oogoo00aoo`03001oo`000080025oo`04001oo`00Ool20037Ool001ioo`03001oogoo
00aoo`03001oo`00008000aoo`03001oogoo00Moo`03001oogoo00Moo`05001oogooOol00039Ool0
01ioo`03001oogoo00]oo`03001oogoo009oo`<000Uoo`8000Uoo`03001oo`0000Ioo`03001oogoo
009oo`03001oogoo0<Moo`007Woo00<007ooOol02goo00<007ooOol00Woo0`002Goo0P0027oo00@0
07oo000000Aoo`800<moo`007Woo00<007ooOol047oo00D007oo001oo`00009oo`06001oogooOol0
07oo0P000Woo0P0000=oo`0000000goo00<007ooOol00P00dGoo000NOol00`00Oomoo`0@Ool00`00
Ool000020002Ool01000Oomoo`000Woo0P000Woo0`001Woo0P00dgoo000NOol00`00Oomoo`0BOol3
00001Goo000007oo000017oo00@007oo001oo`8000Ioo`03001oogoo0=9oo`007Woo00<007ooOol0
4Woo00P007oo000007oo001oo`0017oo0P000Woo00<007ooOol0fWoo000NOol00`00Oomoo`0DOol2
00000goo00000005Ool00`00Oomoo`3NOol001ioo`03001oogoo01Aoo`03001oogoo00800>Ioo`00
7Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0011oo`D0009oo`8000Eoo`03001oogoo0?mo
o`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo0?moo`004Woo00D007ooOomo
o`00009oo`03001oogoo009oo`800?moo`5oo`004Woo00D007ooOomoo`00009oo`03001oogoo009o
o`03001oogoo0?moo`004Woo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo0?moo`00
4Goo0P0017oo0P001Goo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`0027oo0`0000Eoo`00000007oo0080
009oo`<0009oo`<000Aoo`@00003Ool00000008000=oo`<00003Ool00000009oo`800>Yoo`001goo
00<007ooOol00goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01000Oomoo`00jgoo0007Ool00`00Oomoo`03Ool01000
Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`@0
009oo`04001oogoo003[Ool000Moo`03001oogoo00=oo`<000Aoo`8000Aoo`03001oogoo00=oo`<0
009oo`@000=oo`80009oo`@00>aoo`001goo00@007ooOol0009oo`03001oogoo00Yoo`03001oogoo
00Eoo`03001oogoo0?]oo`0027oo0`0000=oo`0000001goo00@007ooOomoo`8000Ioo`800?eoo`00
ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(3.386715746484697`\)], "Print"],

Cell[BoxData[
    \({5.0729`, 3.7032169999999995`, 7}\)], "Print"],

Cell[BoxData[
    \({4.035`, 3.893775`, 8}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 .36561 m
.06219 .36291 L
.0634 .36144 L
.06454 .36005 L
.0656 .35877 L
.06675 .38971 L
.0678 .38816 L
.06877 .38674 L
.07343 .37999 L
.07578 .37664 L
.07642 .37572 L
.07711 .37475 L
.07837 .39994 L
.07965 .39781 L
.08084 .39585 L
.08355 .39144 L
.08848 .38357 L
.09773 .36933 L
.10031 .36548 L
.10167 .36348 L
.10311 .36138 L
.10436 .35955 L
.10508 .35852 L
.10574 .37593 L
.10692 .37401 L
.10817 .37197 L
.10939 .40638 L
.11008 .40541 L
.11072 .40452 L
.11313 .40117 L
.1153 .39819 L
.11764 .39502 L
.11828 .39415 L
.11896 .39325 L
.12017 .42332 L
.1213 .42197 L
.12254 .42049 L
.12794 .41415 L
.13068 .41099 L
.13218 .40927 L
.1336 .40766 L
.13425 .40693 L
.13493 .40616 L
.13567 .43217 L
.13636 .43144 L
.13887 .4288 L
.14809 .41931 L
.15317 .41421 L
.15567 .41173 L
.15688 .41054 L
Mistroke
.15799 .40946 L
.1591 .42996 L
.16015 .42895 L
.16127 .42787 L
.16246 .42673 L
.16368 .40736 L
.1648 .40645 L
.16601 .40547 L
.16669 .40491 L
.16733 .40657 L
.16844 .40567 L
.16949 .40482 L
.17145 .40323 L
.17248 .4024 L
.17357 .40152 L
.17477 .41228 L
.17587 .41151 L
.18504 .40517 L
.18986 .4019 L
.19248 .40013 L
.19492 .3985 L
.19708 .39707 L
.19828 .39627 L
.19938 .40156 L
.20051 .42296 L
.20171 .42412 L
.20234 .42375 L
.20303 .42334 L
.20425 .42262 L
.20864 .42002 L
.21278 .4176 L
.23181 .40668 L
.23729 .40361 L
.23999 .40211 L
.24117 .40145 L
.24181 .4011 L
.24249 .40072 L
.24365 .40535 L
.24475 .40477 L
.246 .4041 L
.24715 .40556 L
.24833 .40492 L
.24962 .40423 L
.25223 .40284 L
.25351 .38762 L
.25471 .38712 L
.25596 .3866 L
.25734 .38603 L
.26022 .38484 L
.26288 .38374 L
Mistroke
.26418 .38321 L
.26542 .38271 L
.26653 .38225 L
.26774 .38829 L
.26842 .38801 L
.26905 .38776 L
.27044 .38721 L
.27295 .38621 L
.28277 .38234 L
.2918 .37882 L
.29417 .3779 L
.29639 .37704 L
.2975 .37661 L
.2987 .39073 L
.29938 .39047 L
.30002 .39023 L
.30123 .38977 L
.31142 .38592 L
.31572 .38431 L
.31807 .38343 L
.32028 .3826 L
.32142 .38217 L
.32265 .38905 L
.32332 .38883 L
.32402 .38859 L
.32528 .38817 L
.3299 .38661 L
.33923 .38349 L
.34191 .3826 L
.34323 .38216 L
.34445 .38176 L
.34556 .3814 L
.34673 .38333 L
.3479 .36002 L
.34919 .35966 L
.3584 .35711 L
.36713 .3547 L
.37188 .3534 L
.37319 .35305 L
.37457 .35267 L
.37525 .35248 L
.37588 .35231 L
.37706 .3571 L
.37817 .35679 L
.37934 .35646 L
.38143 .35587 L
.38389 .35518 L
.38497 .35488 L
.38614 .35455 L
.38739 .36548 L
Mistroke
.38857 .3652 L
.39118 .36459 L
.39587 .36347 L
.40654 .36095 L
.42552 .35645 L
.44644 .3515 L
.45599 .34924 L
.46627 .34682 L
.47124 .34564 L
.47369 .34506 L
.47597 .34453 L
.47703 .34428 L
.47802 .34404 L
.47917 .31633 L
.48022 .31614 L
.48485 .31529 L
.52248 .30842 L
.56251 .30113 L
.60106 .29413 L
.63813 .28743 L
.65876 .28373 L
.66854 .28198 L
.67284 .28121 L
.67529 .28077 L
.67759 .28036 L
.67865 .28017 L
.67977 .27997 L
.68099 .26448 L
.68212 .26433 L
.68693 .2637 L
.69178 .26307 L
.69311 .26289 L
.69453 .26271 L
.69522 .26262 L
.69587 .26253 L
.69709 .25878 L
.69816 .25866 L
.69933 .25853 L
.7017 .25826 L
.70596 .25778 L
.71557 .2567 L
.72066 .25613 L
.72549 .25559 L
.72759 .25535 L
.72874 .25522 L
.72982 .2551 L
.73111 .28499 L
.73228 .28495 L
.73455 .28488 L
.75495 .2843 L
Mistroke
.79263 .28334 L
.83271 .2825 L
.85268 .28214 L
.86243 .28199 L
.86705 .28192 L
.87131 .28186 L
.87345 .28182 L
.87453 .28181 L
.87572 .23172 L
.87692 .23166 L
.8782 .23158 L
.88052 .23145 L
.88923 .23096 L
.90843 .22988 L
.94864 .22763 L
.98737 .22545 L
.99 .2253 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 .02194 m
.06877 .02659 L
.07135 .02733 L
.07379 .028 L
.07599 .0286 L
.07722 .02893 L
.07837 .03134 L
.07948 .03164 L
.08072 .03197 L
.08321 .03262 L
.08839 .03392 L
.09773 .03609 L
.10047 .0367 L
.10307 .03725 L
.1042 .03749 L
.10541 .03774 L
.1061 .03983 L
.10673 .03995 L
.10796 .0402 L
.10865 .04033 L
.10938 .04445 L
.11 .04461 L
.11068 .04478 L
.11363 .04551 L
.11642 .04618 L
.11775 .0465 L
.11897 .04678 L
.12019 .05088 L
.12084 .05106 L
.12152 .05125 L
.12394 .05191 L
.12926 .05334 L
.13146 .05391 L
.13262 .05421 L
.13383 .05452 L
.13448 .05469 L
.13519 .05849 L
.13643 .05885 L
.13887 .05955 L
.17848 .07312 L
.18737 .07562 L
.19223 .07695 L
.1946 .07759 L
.19678 .07817 L
.19799 .0785 L
.19914 .08 L
.20036 .08476 L
.20105 .08535 L
.20169 .08554 L
.20709 .08717 L
Mistroke
.21661 .08997 L
.2267 .09285 L
.23224 .09439 L
.23745 .09582 L
.23987 .09647 L
.24119 .09682 L
.24242 .09715 L
.24306 .0986 L
.24375 .09879 L
.2445 .099 L
.24521 .09919 L
.24586 .09937 L
.24656 .10007 L
.24778 .1004 L
.25014 .10104 L
.25143 .10139 L
.25264 .10172 L
.25367 .09831 L
.25478 .09862 L
.25713 .09928 L
.29735 .11201 L
.31744 .12179 L
.31986 .12243 L
.32052 .1226 L
.32122 .12279 L
.32247 .12548 L
.32364 .12581 L
.32474 .12611 L
.32722 .1268 L
.3361 .12924 L
.34056 .13045 L
.34276 .13104 L
.34373 .1313 L
.3448 .13159 L
.34593 .1327 L
.34713 .13302 L
.34776 .12521 L
.34844 .12539 L
.34967 .12572 L
.35413 .12688 L
.36409 .12945 L
.36894 .13068 L
.37336 .1318 L
.37447 .13208 L
.37568 .13238 L
.37682 .13459 L
.37787 .13485 L
.38269 .13605 L
.38505 .13664 L
.3857 .1368 L
Mistroke
.3864 .13697 L
.38765 .14166 L
.38833 .14184 L
.38906 .14204 L
.3904 .14241 L
.39291 .14309 L
.4135 .14857 L
.43434 .15391 L
.45321 .15858 L
.46267 .16086 L
.46765 .16204 L
.4729 .16327 L
.47513 .16379 L
.47751 .16434 L
.47821 .1645 L
.47888 .16466 L
.48012 .15179 L
.48129 .15206 L
.48256 .15235 L
.49144 .15436 L
.53129 .16301 L
.56965 .1708 L
.60653 .1778 L
.62703 .18148 L
.64581 .18474 L
.66423 .18781 L
.67349 .18931 L
.67602 .18972 L
.67742 .18994 L
.67873 .19015 L
.67996 .19034 L
.68065 .18005 L
.68129 .18016 L
.68361 .18057 L
.68818 .18136 L
.69069 .1818 L
.69308 .18221 L
.6953 .18259 L
.69655 .1828 L
.69771 .1805 L
.69879 .1807 L
.69976 .18087 L
.70194 .18126 L
.71245 .18314 L
.71706 .18395 L
.7221 .18483 L
.7244 .18524 L
.72685 .18566 L
.72804 .18587 L
.72917 .18606 L
Mistroke
.73018 .20811 L
.73128 .2084 L
.74095 .21094 L
.7613 .2163 L
.80119 .22685 L
.82102 .23212 L
.83961 .23708 L
.8574 .24184 L
.86252 .24322 L
.86739 .24453 L
.87177 .24571 L
.87297 .24603 L
.87424 .24637 L
.87545 .20287 L
.87654 .20307 L
.91565 .21012 L
.95329 .21674 L
.99 .22305 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo02ao
o`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomo
o`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol02goo00<007ooOol0lGoo000NOol00`00
Oomoo`0<Ool2003aOol001ioo`03001oogoo015oo`03001oogoo0>]oo`007Woo00<007ooOol04Goo
1@00jGoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol06Goo00<0
07ooOol0hgoo000NOol00`00Oomoo`0IOol4003ROol001ioo`03001oogoo01aoo`03001oogoo0>1o
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`0QOol2003LOol001ioo`03001oogoo02=oo`<0
0=Uoo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`0ZOol3003BOol001ioo`03001oogoo02ao
o`03001oogoo0=1oo`007Woo00<007ooOol0;7oo0`00d7oo000NOol00`00Oomoo`0_Ool00`00Oomo
o`3=Ool001ioo`03001oogoo03Aoo`<00<Qoo`007Woo00<007ooOol0=Woo0`00aWoo000FOol40004
Ool00`00Oomoo`0hOol01000Oomoogoo0`00`7oo000FOol00`00Oomoo`05Ool00`00Oomoo`0oOol3
002mOol001Moo`03001oogoo00Aoo`800?moo`5oo`0067oo00<007ooOol00goo00<007ooOol0AGoo
0P00^7oo000FOol01000Oomoo`0017oo00<007ooOol0Agoo0P00]Woo000GOol20005Ool00`00Oomo
o`18Ool20005Ool00`00Oomoo`2]Ool001ioo`03001oogoo04moo`<00:eoo`007Woo00<007ooOol0
CWoo0P001Goo0P00Z7oo000NOol00`00Oomoo`1GOol2002VOol001ioo`03001oogoo05Yoo`03001o
ogoo0:9oo`007Woo00<007ooOol0Fgoo0P00XWoo000NOol00`00Oomoo`1MOol2002POol001ioo`03
001oogoo06=oo`8000Uoo`03001oogoo009oo`8008Yoo`007Woo00<007ooOol0IGoo0`001Woo00<0
07ooOol017oo0`00Qgoo000NOol00`00Oomoo`1/Ool3000=Ool30020Ool001ioo`03001oogoo06io
o`03001oogoo00ioo`<007eoo`007Woo00<007ooOol0QGoo0`00Mgoo000NOol00`00Oomoo`28Ool3
001dOol001ioo`03001oogoo08ioo`8000moo`03001oogoo008005]oo`007Woo00<007ooOol0T7oo
100037oo100017oo00<007ooOol0E7oo000NOol00`00Oomoo`2HOol5000<Ool00`00Oomoo`1COol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ZGoo00<007ooOol0Dgoo000NOol00`00Oomoo`2Y
Ool00`00Oomoo`1COol001ioo`03001oogoo0:Yoo`03001oogoo01moo`D002ioo`007Woo00<007oo
Ool0ZWoo0`007goo00<007ooOol01Goo10009goo000NOol00`00Oomoo`3HOol2000UOol001Qoo`<0
00=oo`03001oogoo0;1oo`<002]oo`8001moo`006Goo00<007ooOol00Woo00<007ooOol0/goo0`00
:Woo0`0017oo00<007ooOol05Goo000FOol50003Ool2002jOol3000@Ool00`00Oomoo`0:Ool?000G
Ool001Ioo`04001oogoo0004Ool00`00Oomoo`2lOol3000=Ool=000VOol001Moo`03001oo`0000Ao
o`03001oogoo0<9oo`03001oogoo00Moo`03001oogoo031oo`0067oo0P0017oo00<007ooOol0`goo
0`001Woo00<007ooOol0<7oo000NOol00`00Oomoo`36Ool20004Ool00`00Oomoo`0`Ool001ioo`03
001oogoo0<aoo`03001oogoo031oo`007Woo00<007ooOol0c7oo00<007ooOol0<7oo000NOol00`00
Oomoo`2VOol5000QOol00`00Oomoo`0`Ool001ioo`03001oogoo0:9oo`@000Aoo`03001oogoo01mo
o`03001oogoo031oo`007Woo00<007ooOol0WWoo100027oo00<007ooOol07goo00<007ooOol0<7oo
000NOol00`00Oomoo`2NOol00`00Oomoo`09Ool00`00Oomoo`0OOol00`00Oomoo`0`Ool001ioo`03
001oogoo09ioo`03001oogoo00Uoo`03001oogoo01moo`03001oogoo031oo`007Woo00<007ooOol0
WWoo00<007ooOol02Goo00<007ooOol07goo00<007ooOol0<7oo000NOol00`00Oomoo`2KOol4000;
Ool00`00Oomoo`0AOol?000bOol001ioo`03001oogoo09Moo`@000mooa@0045oo`007Woo00<007oo
Ool0T7oo1`00J7oo000NOol00`00Oomoo`29Ool7001_Ool001ioo`03001oogoo08Eoo`@007Ioo`00
7Woo00<007ooOol0P7oo1@00NWoo000NOol00`00Oomoo`1kOol5001oOol001ioo`03001oogoo07Ao
o`L008Aoo`007Woo00<007ooOol0KWoo1P00Rgoo000NOol00`00Oomoo`1^Ool00`00Oomoo`2>Ool0
01ioo`03001oogoo06ioo`03001oogoo08ioo`005Woo0`001Goo00<007ooOol0KWoo00<007ooOol0
SWoo000FOol01000Oomoo`0017oo00<007ooOol0KWoo00<007ooOol0SWoo000FOol01000Oomoo`00
17oo0P00Kgoo00<007ooOol0SWoo000FOol30005Ool00`00Oomoo`1^Ool00`00Oomoo`2>Ool001Mo
o`03001oogoo00Aoo`03001oogoo06aoo`<0091oo`005goo0`0017oo00<007ooOol0J7oo1000Tgoo
000NOol00`00Oomoo`1EOol2000=Ool4002GOol001ioo`03001oogoo055oo`@00004Ool000000007
Ool4002KOol001ioo`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo03Moo`8000Moo`04001o
ogooOol4002OOol001ioo`03001oogoo00]oo`8000Moo`8003Uoo`03001oogoo00Ioo`@00:=oo`00
7Woo00<007ooOol037oo00<007ooOol01Goo0P00>Goo00<007ooOol0[Goo000NOol00`00Oomoo`0<
Ool01000Oomoo`000goo00@007ooOol003Qoo`03001oogoo0:eoo`007Woo00<007ooOol037oo00@0
07oo000000=oo`04001oogoo000[Ool2000;Ool00`00Oomoo`2]Ool001ioo`03001oogoo00aoo`04
001oo`000002Ool01@00Oomoogoo000097oo0P000Woo0`0000=oo`00Ool00goo0P000goo0`00[goo
000NOol00`00Oomoo`0<Ool2000017oo001oo`0017oo00<007ooOol087oo0P0000Aoo`00000000Ao
o`03001oogoo00800003Ool007oo00800;9oo`007Woo00<007ooOol037oo0P0000=oo`0000001Goo
00<007ooOol087oo00@007ooOol000Ioo`<000=oo`800;Aoo`007Woo00<007ooOol03goo0P001Goo
00@007oo0000019oo`03001oogoo00Uoo`03001oogoo0<Aoo`007Woo00<007ooOol03goo00<007oo
Ool017oo00@007oo0000011oo`<000]oo`03001oogoo0<Aoo`007Woo00<007ooOol05Woo0P0000=o
o`00Ool02Goo0`000goo00<007oo000027oo1000aWoo000NOol00`00Oomoo`0FOol2000017oo001o
ogoo0P001Goo0P0000=oo`00Ool00P000Woo00<007ooOol017oo0P0000=oo`000000agoo000NOol0
0`00Oomoo`0IOol00`00Oomoo`020003Ool30002Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`3:
Ool001ioo`03001oogoo01Uoo`05001oo`00Ool00003Ool30008Ool01000Oomoogoo0P00cGoo000N
Ool00`00Oomoo`0IOol20002Ool01@00Oomoo`00Ool00P0027oo00@007oo00000<moo`007Woo00<0
07ooOol06Goo00@007ooOomoo`<0009oo`8000Qoo`800=5oo`007Woo00<007ooOol07Goo00<007oo
Ool00Woo0P00fgoo000NOol00`00Oomoo`0MOol00`00Oomoo`3OOol001ioo`03001oogoo0?moo`00
5goo0P001Goo00<007ooOol0ogoo000FOol01000Oomoo`0017oo00<007ooOol0ogoo000FOol01000
Oomoo`0017oo0P00ogoo0Goo000GOol20005Ool00`00Oomoo`3oOol001Ioo`04001oogoo0004Ool0
0`00Oomoo`3oOol001Moo`8000Eoo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001o
ogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`00
7Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007oo
Ool0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`0047oo1@000Woo0P001Goo00<007ooOol0ogoo
000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0ogoo000BOol01@00Oomoogoo
00000Woo00<007ooOol00Woo0P00ogoo0Goo000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo
00<007ooOol0ogoo000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0ogoo000A
Ool20004Ool20005Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0008Ool300001Goo00000000Ool00P00
0Woo0`000Woo0`0017oo100000=oo`0000000P000goo0`0000=oo`0000000Woo0P00jWoo0007Ool0
0`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo00=oo`04001oogoo003[Ool000Moo`03001oogoo00=oo`04001o
ogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo1000
0Woo00@007ooOol00>]oo`001goo00<007ooOol00goo0`0017oo0P0017oo00<007ooOol00goo0`00
0Woo10000goo0P000Woo1000k7oo0007Ool01000Oomoo`000Woo00<007ooOol02Woo00<007ooOol0
1Goo00<007ooOol0ngoo0008Ool300000goo00000007Ool01000Oomoogoo0P001Woo0P00oGoo003o
OolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}],

Cell[BoxData[
    \(1.634861652739346`\)], "Print"],

Cell[BoxData[
    \({5.0729`, 3.7032169999999995`, 7}\)], "Print"],

Cell[BoxData[
    \({5.001225`, 4.826182125`, 7}\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 1.38778e-017 0.0561849 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 10 6.28125 ]
[-0.0125 .11237 -6 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -6 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -6 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -6 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -12 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[0 .64303 -26 0 ]
[0 .64303 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(2)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(4)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(6)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(8)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(10)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Children) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.06 0 m
.09773 .10688 L
.10721 .15113 L
.10972 .15074 L
.11243 .15031 L
.11368 .15012 L
.115 .14991 L
.11612 .14974 L
.11736 .18818 L
.11812 .18796 L
.11881 .18776 L
.12037 .18732 L
.12319 .18652 L
.1285 .18501 L
.13104 .1843 L
.13382 .18352 L
.13509 .18316 L
.13644 .18279 L
.13771 .18243 L
.13887 .213 L
.14003 .21252 L
.14129 .21199 L
.14385 .21092 L
.14843 .20902 L
.15342 .20697 L
.15877 .20479 L
.16137 .20375 L
.16265 .20323 L
.16384 .20276 L
.16491 .20233 L
.16605 .22547 L
.1672 .22515 L
.16846 .2248 L
.17751 .2223 L
.18 .22162 L
.18121 .22129 L
.18232 .22099 L
.18348 .24668 L
.18473 .2462 L
.1861 .24568 L
.18737 .24519 L
.18845 .266 L
.1896 .26564 L
.19202 .26488 L
.19641 .26351 L
.20622 .26047 L
.21164 .25881 L
.21677 .25726 L
.21909 .25656 L
.22155 .25582 L
Mistroke
.22228 .25561 L
.22297 .2554 L
.22425 .2735 L
.22546 .27321 L
.22676 .2729 L
.23589 .27075 L
.24514 .2686 L
.24966 .26756 L
.25163 .26711 L
.25267 .26687 L
.25377 .26662 L
.25497 .27076 L
.25608 .2705 L
.25826 .26999 L
.26308 .26887 L
.26834 .26765 L
.27092 .26706 L
.27328 .26651 L
.27447 .26624 L
.27558 .26599 L
.27673 .27783 L
.27799 .27758 L
.28307 .27659 L
.29386 .27451 L
.31219 .27101 L
.32184 .26919 L
.32711 .26821 L
.33204 .26729 L
.33332 .26705 L
.33454 .26683 L
.33521 .27507 L
.33594 .27496 L
.33722 .27475 L
.33865 .27452 L
.34017 .27428 L
.34148 .27407 L
.34222 .27396 L
.34291 .27931 L
.34413 .2791 L
.34542 .27889 L
.34773 .2785 L
.35292 .27762 L
.37261 .2743 L
.39209 .27102 L
.40058 .26959 L
.40505 .26884 L
.4075 .26842 L
.4087 .26822 L
.40979 .26804 L
.41097 .27174 L
Mistroke
.41223 .27156 L
.41491 .27119 L
.41963 .27053 L
.42892 .26925 L
.43394 .26856 L
.43941 .26781 L
.44191 .26747 L
.44328 .26729 L
.44457 .26711 L
.44578 .26695 L
.44646 .26686 L
.44709 .27102 L
.4482 .27085 L
.44937 .27068 L
.45863 .26931 L
.46856 .26786 L
.47337 .26716 L
.47574 .26682 L
.47793 .26651 L
.47991 .26622 L
.48092 .26608 L
.48202 .28294 L
.48313 .28282 L
.48432 .28269 L
.48647 .28245 L
.52666 .27793 L
.56537 .27358 L
.60261 .26939 L
.64223 .26494 L
.68038 .26066 L
.69984 .25847 L
.71008 .25732 L
.71568 .25669 L
.72092 .2561 L
.72559 .25557 L
.72694 .25542 L
.72821 .25528 L
.72936 .25515 L
.73061 .285 L
.73133 .28498 L
.73201 .28496 L
.73328 .28492 L
.73613 .28484 L
.74125 .28469 L
.75998 .28416 L
.7977 .28322 L
.83781 .2824 L
.87644 .28178 L
.91359 .28134 L
.93269 .28118 L
Mistroke
.94249 .28111 L
.95313 .28105 L
.96299 .281 L
.97208 .28097 L
.98078 .28095 L
.98517 .28094 L
.99 .28093 L
Mfstroke
[ .02 .02 ] 0 setdash
.06 0 m
.06877 0 L
.07837 0 L
.08321 0 L
.0846 0 L
.08529 0 L
.08592 0 L
.0871 .00489 L
.08839 .00497 L
.09073 .0051 L
.09187 .00516 L
.09292 .00522 L
.09402 .01007 L
.09521 .01019 L
.09773 .01044 L
.10026 .0107 L
.10165 .01084 L
.10233 .01091 L
.10296 .01097 L
.10418 .01579 L
.10482 .01588 L
.1055 .01597 L
.10781 .01628 L
.11306 .01698 L
.1145 .01717 L
.11529 .01728 L
.11604 .01738 L
.11674 .01747 L
.11749 .02211 L
.11818 .02221 L
.11882 .02231 L
.12854 .02378 L
.13345 .0245 L
.1348 .0247 L
.13625 .02491 L
.13691 .02501 L
.13762 .02511 L
.13887 .02958 L
.14008 .02977 L
.14138 .02997 L
.14376 .03033 L
.14819 .03099 L
.15303 .0317 L
.15815 .03243 L
.16259 .03305 L
.16381 .03322 L
.16448 .03331 L
.16512 .03339 L
.16635 .03749 L
.16748 .0377 L
Mistroke
.17609 .03921 L
.17862 .03965 L
.17987 .03987 L
.18101 .04007 L
.18205 .04025 L
.18315 .0452 L
.18426 .0454 L
.18547 .04561 L
.18614 .04573 L
.18678 .04584 L
.18797 .05003 L
.18925 .05029 L
.19064 .05058 L
.19546 .05156 L
.21343 .05512 L
.21786 .05598 L
.22019 .05642 L
.22146 .05666 L
.22263 .05688 L
.22327 .057 L
.22394 .06126 L
.22469 .06143 L
.22537 .06158 L
.22787 .06213 L
.23278 .0632 L
.25331 .06756 L
.25447 .06893 L
.25558 .06916 L
.25686 .06943 L
.25802 .06968 L
.26243 .0706 L
.26703 .07155 L
.27208 .07259 L
.27335 .07285 L
.27405 .07299 L
.27471 .07312 L
.27586 .07669 L
.27714 .07698 L
.28266 .0782 L
.2924 .08035 L
.31042 .08423 L
.32063 .08638 L
.32562 .08742 L
.33015 .08836 L
.33248 .08884 L
.33311 .08897 L
.33379 .08911 L
.335 .09216 L
.33613 .09241 L
.33719 .09265 L
Mistroke
.33959 .09318 L
.3409 .09346 L
.34213 .09373 L
.34325 .09585 L
.34446 .09612 L
.34969 .09727 L
.37029 .10172 L
.39112 .10607 L
.40095 .10807 L
.40527 .10894 L
.40771 .10943 L
.40891 .10966 L
.41 .10988 L
.41114 .11171 L
.41222 .11194 L
.4146 .11245 L
.41946 .11349 L
.42969 .11565 L
.43857 .1175 L
.441 .11801 L
.44359 .11855 L
.44465 .11877 L
.44579 .119 L
.44705 .12116 L
.44823 .1214 L
.46781 .12536 L
.47257 .12631 L
.47766 .12732 L
.47916 .12761 L
.4799 .12776 L
.48058 .12789 L
.48185 .13635 L
.48252 .1365 L
.48323 .13666 L
.48842 .13784 L
.52544 .14611 L
.56485 .15456 L
.60278 .16237 L
.6431 .17032 L
.68195 .17763 L
.70156 .1812 L
.71932 .18435 L
.72409 .18518 L
.7266 .18562 L
.72797 .18586 L
.72924 .18608 L
.73037 .20816 L
.73157 .20848 L
.73411 .20915 L
.73858 .21032 L
Mistroke
.75908 .21572 L
.79954 .22641 L
.83852 .23679 L
.87602 .24685 L
.91591 .25767 L
.95432 .2682 L
.99 .27812 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool2
0004Ool20003Ool4000POol20004Ool20005Ool3000POol20004Ool20003Ool3000QOol20004Ool2
0004Ool2000WOol5000BOol004Eoo`04001oogoo0008Ool00`00Oomoo`0POol01000Oomoo`002goo
00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`0027oo00@007ooOol0
02Qoo`03001oogoo019oo`00AGoo00@007ooOol000Uoo`03001oogoo01moo`04001oogoo0008Ool5
000OOol01000Oomoo`0027oo00@007ooOol001moo`04001oogoo0008Ool01000Oomoo`00:7oo00<0
07ooOol04Woo0015Ool01000Oomoo`002Woo00<007ooOol07Woo00@007ooOol000Qoo`04001oogoo
000POol01000Oomoo`0027oo0`0087oo00@007ooOol000Uoo`8002Uoo`03001oogoo019oo`00AGoo
00@007ooOol000Qoo`04001oogoo000OOol01000Oomoo`002Goo00<007oo000087oo00@007ooOol0
00Uoo`03001oogoo01moo`04001oogoo0008Ool01000Oomoo`00:7oo00<007ooOol04Woo0016Ool2
000:Ool2000QOol2000;Ool2000QOol2000:Ool3000POol2000:Ool2000XOol2000DOol00?moob5o
o`00ogoo8Goo003oOolQOol00?mooaAoo`<000Yoo`00ogoo5goo00<007ooOol01goo000NOoo^0007
Ool3000:Ool001ioo`03001oogoo00]oo`03001oogoo00=oo`<001Qoo`03001oogoo02aoo`03001o
ogoo02eoo`03001oogoo02aoo`03001oogoo02eoo`03001oogoo00Eoo`@000Uoo`007Woo00<007oo
Ool037oo00<007ooOol017oo0`00jGoo000NOol00`00Oomoo`0<Ool00`00Oomoo`3`Ool001ioo`03
001oogoo00aoo`03001oogoo00Uoo`03001oogoo0>Aoo`007Woo00<007ooOol03Goo00<007ooOol0
27oo1@00hWoo000NOol00`00Oomoo`0=Ool00`00Oomoo`3_Ool001ioo`03001oogoo00ioo`03001o
ogoo00moo`D00=Yoo`007Woo00<007ooOol03Woo00<007ooOol04goo00<007ooOol0f7oo000NOol0
0`00Oomoo`0>Ool00`00Oomoo`0COol5003FOol001ioo`03001oogoo00moo`03001oogoo01Ioo`03
001oogoo0=Aoo`007Woo00<007ooOol03goo00<007ooOol0kGoo000NOol00`00Oomoo`0?Ool00`00
Oomoo`0JOol2003AOol001ioo`03001oogoo011oo`03001oogoo01]oo`@00<eoo`007Woo00<007oo
Ool047oo00<007ooOol0k7oo000NOol00`00Oomoo`0@Ool00`00Oomoo`0ROol20038Ool001ioo`03
001oogoo015oo`03001oogoo02=oo`<00<Eoo`007Woo00<007ooOol04Goo00<007ooOol0:Woo00<0
07ooOol0_Woo000NOol00`00Oomoo`0AOol00`00Oomoo`0ZOol3002nOol001ioo`03001oogoo019o
o`03001oogoo02aoo`800;aoo`007Woo00<007ooOol04Woo00<007ooOol0<Goo1P00/goo000NOol0
0`00Oomoo`0COol00`00Oomoo`0eOol2002bOol001ioo`03001oogoo01=oo`03001oogoo03Moo`80
0;1oo`007Woo00<007ooOol04goo00<007ooOol0>Goo0`00[Goo000FOol40004Ool00`00Oomoo`0D
Ool00`00Oomoo`0nOol2002XOol001Ioo`03001oogoo00Eoo`03001oogoo01Aoo`03001oogoo041o
o`@00:Aoo`005goo00<007ooOol017oo0P005Goo00<007ooOol0Agoo0`00WWoo000HOol00`00Oomo
o`03Ool00`00Oomoo`0DOol00`00Oomoo`1:Ool3002KOol001Ioo`04001oogoo0004Ool00`00Oomo
o`0EOol00`00Oomoo`1?Ool2002FOol001Moo`8000Eoo`03001oogoo01Eoo`03001oogoo055oo`@0
099oo`007Woo00<007ooOol05Goo00<007ooOol0igoo000NOol00`00Oomoo`0EOol00`00Oomoo`3W
Ool001ioo`03001oogoo01Eoo`03001oogoo05Moo`<008eoo`007Woo00<007ooOol05Woo00<007oo
Ool0FGoo0`00RWoo000NOol00`00Oomoo`0FOol00`00Oomoo`1OOol30024Ool001ioo`03001oogoo
01Ioo`<0069oo`<0085oo`007Woo00<007ooOol067oo00<007ooOol0Igoo0P00Ngoo000NOol00`00
Oomoo`0HOol00`00Oomoo`1YOol3001hOol001ioo`03001oogoo01Qoo`03001oogoo071oo`80079o
o`007Woo00<007ooOol067oo00<007ooOol0LWoo0`00Kgoo000NOol00`00Oomoo`0HOol00`00Oomo
o`1iOol3001XOol001ioo`03001oogoo01Qoo`03001oogoo07aoo`<006Eoo`007Woo00<007ooOol0
67oo00<007ooOol0PWoo1P00G7oo000NOol00`00Oomoo`0HOol00`00Oomoo`030029Ool2001FOol0
01ioo`03001oogoo01Qoo`<0009oo`03001oogoo08Uoo`03001oogoo05=oo`007Woo00<007ooOol0
7Goo00<007ooOol0RGoo00<007ooOol0Dgoo000NOol00`00Oomoo`0MOol00`00Oomoo`29Ool00`00
Oomoo`1COol001ioo`03001oogoo01eoo`03001oogoo00Aoo`03001oogoo0=Qoo`007Woo00<007oo
Ool07Goo00<007ooOol00Woo0`00fWoo000NOol00`00Oomoo`0MOol00`00Oomoo`020002Ool00`00
Oomoo`24Ool2001BOol001ioo`03001oogoo01eoo`<000Aoo`03001oogoo08Ioo`80051oo`0067oo
0`000goo00<007ooOol097oo00<007ooOol0R7oo0P00CWoo000IOol00`00Oomoo`02Ool00`00Oomo
o`0TOol00`00Ool00002002<Ool20018Ool001Ioo`D000=oo`8002Eoo`80009oo`03001oogoo08ao
o`<004Eoo`005Woo00@007ooOol000Aoo`03001oogoo02Qoo`03001oogoo09=oo`8003moo`005goo
00<007oo000017oo00<007ooOol0:7oo00<007ooOol0UGoo0`00?7oo000HOol20004Ool00`00Oomo
o`0XOol00`00Oomoo`3DOol001ioo`03001oogoo02Qoo`03001oogoo09aoo`<003Eoo`007Woo00<0
07ooOol0:7oo0P00X7oo0`00<Woo000NOol00`00Oomoo`0YOol00`00Oomoo`2TOol3000/Ool001io
o`03001oogoo02Uoo`03001oogoo00Aoo`8007Aoo`@002Uoo`<002Uoo`007Woo00<007ooOol0:Goo
00@007ooOomoo`<00003Ool007oo06Moo``000=oo`03001oogoo05=oo`007Woo00<007ooOol0:Goo
100017oo00<007ooOol0GGoo2@003goo00<007ooOol0;Goo0`008goo000NOol00`00Oomoo`0YOol0
0`00Oomoo`06Ool01000Oomoogoo100000=oo`0000000P002Woo10003Woo10000goo1@000Woo1`00
67oo2@0067oo00<007ooOol0<7oo0`0087oo000NOol00`00Oomoo`0bOol40003Ool20003Ool00`00
Oomoo`04Ool40003Ool30009Ool30003Ool40004Ool30006Ool00`00Oomoo`0=Ool9000ROol00`00
Oomoo`0eOol3000JOol001ioo`03001oogoo03ioo`L000Moo`<00003Ool0000000H001Moo`03001o
ogoo00=oo`X002]oo`03001oogoo03Qoo`<001Moo`007Woo00<007ooOol0CWoo0P007goo1P00=Goo
00<007ooOol04Woo:@005goo000NOol00`00Oomoo`1_Ool00`00Oomoo`0hOolE0010Ool001ioo`03
001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001Ioo`<000Eoo`03001oogoo0?moo`005Woo00@007oo
Ool000Aoo`03001oogoo0?moo`005Woo00@007ooOol000Aoo`800?moo`5oo`005Woo0`001Goo00<0
07ooOol0ogoo000GOol00`00Oomoo`04Ool00`00Oomoo`3oOol001Moo`<000Aoo`03001oogoo0?mo
o`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<0
07ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001o
ogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`00
5goo0P001Goo00<007ooOol0ogoo000FOol01000Oomoo`0017oo00<007ooOol0ogoo000FOol01000
Oomoo`0017oo0P00ogoo0Goo000GOol20005Ool00`00Oomoo`3oOol001Ioo`04001oogoo0004Ool0
0`00Oomoo`3oOol001Moo`8000Eoo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001o
ogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`00
7Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007oo
Ool0ogoo000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000N
Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`0047oo1@000Woo0P001Goo00<007ooOol0ogoo
000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0ogoo000BOol01@00Oomoogoo
00000Woo00<007ooOol00Woo0P00ogoo0Goo000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo
00<007ooOol0ogoo000BOol01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0ogoo000A
Ool20004Ool20005Ool00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo
000NOol00`00Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00
Oomoo`3oOol001ioo`03001oogoo0?moo`007Woo00<007ooOol0ogoo000NOol00`00Oomoo`3oOol0
01ioo`03001oogoo0?moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0008Ool300001Goo00000000Ool00P00
0Woo0`000Woo0`0017oo100000=oo`0000000P000goo0`0000=oo`0000000Woo0P00jWoo0007Ool0
0`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=o
o`03001oogoo009oo`03001oogoo00=oo`04001oogoo003[Ool000Moo`03001oogoo00=oo`04001o
ogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00Woo1000
0Woo00@007ooOol00>]oo`001goo00<007ooOol00goo0`0017oo0P0017oo00<007ooOol00goo0`00
0Woo10000goo0P000Woo1000k7oo0007Ool01000Oomoo`000Woo00<007ooOol02Woo00<007ooOol0
1Goo00<007ooOol0ngoo0008Ool300000goo00000007Ool01000Oomoogoo0P001Woo0P00oGoo003o
OolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.126688, -0.89837, \
0.00421906, 0.0750924}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 52, 0, 115, "Title"],
Cell[1782, 54, 93, 2, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1900, 60, 24, 0, 59, "Section"],
Cell[1927, 62, 231, 4, 52, "Text"],
Cell[2161, 68, 91, 2, 50, "Input"],
Cell[2255, 72, 37, 0, 33, "Text"],
Cell[2295, 74, 84, 1, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2416, 80, 40, 0, 59, "Section"],
Cell[2459, 82, 65, 0, 33, "Text"],
Cell[2527, 84, 4894, 78, 1310, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7458, 167, 61, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[7544, 171, 4557, 80, 1385, "Input"],
Cell[12104, 253, 221, 5, 24, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12374, 264, 40, 0, 59, "Section"],
Cell[12417, 266, 298, 5, 140, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12752, 276, 41, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[12818, 280, 2604, 47, 770, "Input"],
Cell[15425, 329, 181, 3, 24, "Message"],
Cell[15609, 334, 51, 1, 25, "Print"],
Cell[15663, 337, 74, 1, 25, "Print"],
Cell[15740, 340, 48, 1, 25, "Print"],
Cell[15791, 343, 17877, 734, 186, 9695, 628, "GraphicsData", "PostScript", \
"Graphics"],
Cell[33671, 1079, 51, 1, 25, "Print"],
Cell[33725, 1082, 64, 1, 25, "Print"],
Cell[33792, 1085, 48, 1, 25, "Print"],
Cell[33843, 1088, 19327, 815, 186, 10951, 707, "GraphicsData", "PostScript", \
"Graphics"],
Cell[53173, 1905, 52, 1, 25, "Print"],
Cell[53228, 1908, 62, 1, 25, "Print"],
Cell[53293, 1911, 49, 1, 25, "Print"],
Cell[53345, 1914, 17079, 694, 186, 9112, 591, "GraphicsData", "PostScript", \
"Graphics"],
Cell[70427, 2610, 52, 1, 25, "Print"],
Cell[70482, 2613, 62, 1, 25, "Print"],
Cell[70547, 2616, 49, 1, 25, "Print"],
Cell[70599, 2619, 16731, 668, 186, 8586, 563, "GraphicsData", "PostScript", \
"Graphics"],
Cell[87333, 3289, 51, 1, 25, "Print"],
Cell[87387, 3292, 77, 1, 25, "Print"],
Cell[87467, 3295, 48, 1, 25, "Print"],
Cell[87518, 3298, 19115, 814, 186, 10970, 709, "GraphicsData", "PostScript", \
"Graphics"],
Cell[106636, 4114, 51, 1, 25, "Print"],
Cell[106690, 4117, 64, 1, 25, "Print"],
Cell[106757, 4120, 48, 1, 25, "Print"],
Cell[106808, 4123, 18314, 755, 186, 9999, 648, "GraphicsData", "PostScript", \
"Graphics"],
Cell[125125, 4880, 51, 1, 25, "Print"],
Cell[125179, 4883, 62, 1, 25, "Print"],
Cell[125244, 4886, 48, 1, 25, "Print"],
Cell[125295, 4889, 17094, 687, 186, 8985, 582, "GraphicsData", "PostScript", \
"Graphics"],
Cell[142392, 5578, 52, 1, 25, "Print"],
Cell[142447, 5581, 62, 1, 25, "Print"],
Cell[142512, 5584, 49, 1, 25, "Print"],
Cell[142564, 5587, 16745, 684, 186, 8916, 583, "GraphicsData", "PostScript", \
"Graphics"],
Cell[159312, 6273, 52, 1, 25, "Print"],
Cell[159367, 6276, 65, 1, 25, "Print"],
Cell[159435, 6279, 55, 1, 25, "Print"],
Cell[159493, 6282, 18943, 800, 186, 10725, 694, "GraphicsData", "PostScript", \
"Graphics"],
Cell[178439, 7084, 51, 1, 25, "Print"],
Cell[178493, 7087, 64, 1, 25, "Print"],
Cell[178560, 7090, 55, 1, 25, "Print"],
Cell[178618, 7093, 18373, 761, 186, 10115, 655, "GraphicsData", "PostScript", \
"Graphics"],
Cell[196994, 7856, 52, 1, 25, "Print"],
Cell[197049, 7859, 66, 1, 25, "Print"],
Cell[197118, 7862, 55, 1, 25, "Print"],
Cell[197176, 7865, 17322, 702, 186, 9230, 598, "GraphicsData", "PostScript", \
"Graphics"],
Cell[214501, 8569, 52, 1, 25, "Print"],
Cell[214556, 8572, 66, 1, 25, "Print"],
Cell[214625, 8575, 49, 1, 25, "Print"],
Cell[214677, 8578, 17606, 716, 186, 9331, 609, "GraphicsData", "PostScript", \
"Graphics"],
Cell[232286, 9296, 51, 1, 25, "Print"],
Cell[232340, 9299, 65, 1, 25, "Print"],
Cell[232408, 9302, 55, 1, 25, "Print"],
Cell[232466, 9305, 17988, 749, 186, 9956, 645, "GraphicsData", "PostScript", \
"Graphics"],
Cell[250457, 10056, 51, 1, 25, "Print"],
Cell[250511, 10059, 73, 1, 25, "Print"],
Cell[250587, 10062, 55, 1, 25, "Print"],
Cell[250645, 10065, 17361, 699, 186, 9155, 593, "GraphicsData", "PostScript", \
"Graphics"],
Cell[268009, 10766, 51, 1, 25, "Print"],
Cell[268063, 10769, 66, 1, 25, "Print"],
Cell[268132, 10772, 55, 1, 25, "Print"],
Cell[268190, 10775, 18360, 764, 186, 10158, 658, "GraphicsData", \
"PostScript", "Graphics"],
Cell[286553, 11541, 51, 1, 25, "Print"],
Cell[286607, 11544, 66, 1, 25, "Print"],
Cell[286676, 11547, 61, 1, 25, "Print"],
Cell[286740, 11550, 16868, 688, 186, 8990, 586, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

